(****************************************************************)
(*  This file contains the EMRK expansions of the hexagon basis *)
(*  functions through weight five.                              *)
(*                                                              *)
(*  We use the follow notation for the SVHPLs,                  *)
(*                                                              *)
(*  lp[a__] = L_ {a}^+ = 1/2(L_{a}(-w) + L_{a}(-1/w))           *)
(*  lm[a__] = L_ {a}^- = 1/2(L_{a}(-w) - L_{a}(-1/w))           *)
(*                                                              *)
(*  See sec. 3 of arxiv:1207.0186 for more details about        *)
(*  these functions.                                            *)
(*                                                              *)
(*  There are 30 expansions presented here. The notation is     *)
(*                                                              *)
(*            FuvwEMRK = F(u,v,w)|_{EMRK}, etc.                 *)
(*                                                              *)
(*  The function F is one of,                                   *)
(*                                                              *)
(*    Weight 3: Phi6tilde = \tilde{\Phi}_ 6                     *)
(*    Weight 4: F1 = F_ 1, Omega2 = \Omega_2                    *)
(*    Weight 5: G, H1 = H_ 1, J1 = J_ 1, K1 = K_ 1,             *)
(*              N, O, Qep = Q_{ep}, M1 = M_ 1                   *)
(*                                                              *)
(****************************************************************)


Phi6tildeuvwEMRK = 0
 
Omega2uvwEMRK = 0
 
Omega2vwuEMRK = lm[0]^4/64 + Log[1 - u]^4/4 + Log[1 - u]^3*lp[1] - 
     (lm[0]^2*lp[1]^2)/8 + lp[1]^4/4 + (lm[0]^2*Zeta[2])/4 + 
     lp[1]^2*Zeta[2] + Log[1 - u]^2*(-lm[0]^2/8 + (3*lp[1]^2)/2 + Zeta[2]) + 
     4*lp[1]*Zeta[3] + Log[1 - u]*(-(lm[0]^2*lp[1])/4 + lp[1]^3 + 
       2*lp[1]*Zeta[2] + 4*Zeta[3]) + (5*Zeta[4])/2
 
Omega2wuvEMRK = 0
 
F1uvwEMRK = 0
 
F1vwuEMRK = 0
 
F1wuvEMRK = 0
 
QepuvwEMRK = (-3*lm[0]^5)/8192 + (3*Log[1 - u]^5)/256 + 
     Log[1 - u]^4*((-3*lm[0])/512 + (15*lp[1])/256) + 
     (3*lm[0]^4*lp[1])/4096 + (3*lm[0]^3*lp[1]^2)/1024 - 
     (3*lm[0]^2*lp[1]^3)/512 - (3*lm[0]*lp[1]^4)/512 + (3*lp[1]^5)/256 + 
     Log[1 - u]^3*((-3*lm[0]^2)/512 - (3*lm[0]*lp[1])/128 + 
       (15*lp[1]^2)/128 + Zeta[2]/64) - (5*lm[0]^3*Zeta[2])/512 + 
     (5*lm[0]^2*lp[1]*Zeta[2])/256 - (lm[0]*lp[1]^2*Zeta[2])/128 + 
     (lp[1]^3*Zeta[2])/64 + Log[1 - u]^2*((3*lm[0]^3)/1024 - 
       (9*lm[0]^2*lp[1])/512 - (9*lm[0]*lp[1]^2)/256 + (15*lp[1]^3)/128 - 
       (lm[0]*Zeta[2])/128 + (3*lp[1]*Zeta[2])/64 + (15*Zeta[3])/64) - 
     (lm[0]^2*Zeta[3])/256 - (13*lm[0]*lp[1]*Zeta[3])/64 + 
     (15*lp[1]^2*Zeta[3])/64 + (5*Zeta[2]*Zeta[3])/128 + 
     Log[1 - u]*((3*lm[0]^4)/4096 + (3*lm[0]^3*lp[1])/512 - 
       (9*lm[0]^2*lp[1]^2)/512 - (3*lm[0]*lp[1]^3)/128 + (15*lp[1]^4)/256 + 
       (5*lm[0]^2*Zeta[2])/256 - (lm[0]*lp[1]*Zeta[2])/64 + 
       (3*lp[1]^2*Zeta[2])/64 - (13*lm[0]*Zeta[3])/64 + 
       (15*lp[1]*Zeta[3])/32 - (5*Zeta[4])/128) - (35*lm[0]*Zeta[4])/256 - 
     (5*lp[1]*Zeta[4])/128 - Zeta[5]/64
 
QepuwvEMRK = (3*lm[0]^5)/8192 + (3*Log[1 - u]^5)/256 + 
     Log[1 - u]^4*((3*lm[0])/512 + (15*lp[1])/256) + (3*lm[0]^4*lp[1])/4096 - 
     (3*lm[0]^3*lp[1]^2)/1024 - (3*lm[0]^2*lp[1]^3)/512 + 
     (3*lm[0]*lp[1]^4)/512 + (3*lp[1]^5)/256 + 
     Log[1 - u]^3*((-3*lm[0]^2)/512 + (3*lm[0]*lp[1])/128 + 
       (15*lp[1]^2)/128 + Zeta[2]/64) + (5*lm[0]^3*Zeta[2])/512 + 
     (5*lm[0]^2*lp[1]*Zeta[2])/256 + (lm[0]*lp[1]^2*Zeta[2])/128 + 
     (lp[1]^3*Zeta[2])/64 + Log[1 - u]^2*((-3*lm[0]^3)/1024 - 
       (9*lm[0]^2*lp[1])/512 + (9*lm[0]*lp[1]^2)/256 + (15*lp[1]^3)/128 + 
       (lm[0]*Zeta[2])/128 + (3*lp[1]*Zeta[2])/64 + (15*Zeta[3])/64) - 
     (lm[0]^2*Zeta[3])/256 + (13*lm[0]*lp[1]*Zeta[3])/64 + 
     (15*lp[1]^2*Zeta[3])/64 + (5*Zeta[2]*Zeta[3])/128 + 
     Log[1 - u]*((3*lm[0]^4)/4096 - (3*lm[0]^3*lp[1])/512 - 
       (9*lm[0]^2*lp[1]^2)/512 + (3*lm[0]*lp[1]^3)/128 + (15*lp[1]^4)/256 + 
       (5*lm[0]^2*Zeta[2])/256 + (lm[0]*lp[1]*Zeta[2])/64 + 
       (3*lp[1]^2*Zeta[2])/64 + (13*lm[0]*Zeta[3])/64 + 
       (15*lp[1]*Zeta[3])/32 - (5*Zeta[4])/128) + (35*lm[0]*Zeta[4])/256 - 
     (5*lp[1]*Zeta[4])/128 - Zeta[5]/64
 
QepvwuEMRK = (9*Zeta[2]*Zeta[3])/128 + (21*Zeta[5])/64
 
QepvuwEMRK = (9*Zeta[5])/32
 
QepwuvEMRK = (9*Zeta[5])/32
 
QepwvuEMRK = (9*Zeta[2]*Zeta[3])/128 + (21*Zeta[5])/64
 
M1uvwEMRK = -(lm[0]^2*Zeta[3])/2 - 2*Log[1 - u]^2*Zeta[3] - 
     2*lm[0]*lp[1]*Zeta[3] - 2*lp[1]^2*Zeta[3] + 4*Zeta[2]*Zeta[3] + 
     3*lm[0]*Zeta[4] + 6*lp[1]*Zeta[4] + Log[1 - u]*(-2*lm[0]*Zeta[3] - 
       4*lp[1]*Zeta[3] + 6*Zeta[4]) - 4*Zeta[5]
 
M1uwvEMRK = -(lm[0]^2*Zeta[3])/2 - 2*Log[1 - u]^2*Zeta[3] + 
     2*lm[0]*lp[1]*Zeta[3] - 2*lp[1]^2*Zeta[3] + 4*Zeta[2]*Zeta[3] - 
     3*lm[0]*Zeta[4] + 6*lp[1]*Zeta[4] + Log[1 - u]*(2*lm[0]*Zeta[3] - 
       4*lp[1]*Zeta[3] + 6*Zeta[4]) - 4*Zeta[5]
 
M1vwuEMRK = -2*Zeta[2]*Zeta[3] + 2*Zeta[5]
 
M1vuwEMRK = -2*Zeta[2]*Zeta[3] + 2*Zeta[5]
 
M1wuvEMRK = -2*Zeta[2]*Zeta[3] + 2*Zeta[5]
 
NuvwEMRK = lm[0]^2*Zeta[3] - 4*Log[1 - u]^2*Zeta[3] - 4*lp[1]^2*Zeta[3] + 
     8*Zeta[2]*Zeta[3] + 12*lp[1]*Zeta[4] + 
     Log[1 - u]*(-8*lp[1]*Zeta[3] + 12*Zeta[4]) - 8*Zeta[5]
 
OuvwEMRK = -8*Zeta[2]*Zeta[3] + 17*Zeta[5]
 
GuvwEMRK = 0
 
H1uvwEMRK = 0
 
H1vwuEMRK = 0
 
H1wuvEMRK = 0
 
J1uvwEMRK = 0
 
J1vwuEMRK = 0
 
J1wuvEMRK = 0
 
K1uvwEMRK = 0
 
K1vwuEMRK = 0
 
K1wuvEMRK = 0
