(****************************************************************)
(*  This file contains the MRK expansions of the hexagon basis  *)
(*  functions through weight five.                              *)
(*                                                              *)
(*  We use the follow notation for the SVHPLs,                  *)
(*                                                              *)
(*  lp[a__] = L_ {a}^+ = 1/2(L_{a}(-w) + L_{a}(-1/w))           *)
(*  lm[a__] = L_ {a}^- = 1/2(L_{a}(-w) - L_{a}(-1/w))           *)
(*                                                              *)
(*  See sec. 3 of arxiv:1207.0186 for more details about        *)
(*  these functions.                                            *)
(*                                                              *)
(*  There are 30 expansions presented here. The notation is     *)
(*                                                              *)
(*            FuvwMRK = F(u,v,w)|_{MRK}, etc.                   *)
(*                                                              *)
(*  The function F is one of,                                   *)
(*                                                              *)
(*    Weight 3: Phi6tilde = \tilde{\Phi}_ 6                     *)
(*    Weight 4: F1 = F_ 1, Omega2 = \Omega_2                    *)
(*    Weight 5: G, H1 = H_ 1, J1 = J_ 1, K1 = K_ 1,             *)
(*              N, O, Qep = Q_{ep}, M1 = M_ 1                   *)
(*                                                              *)
(****************************************************************)


Phi6tildeuvwMRK = -2*(2*Pi*I)*lm[0, 1]
 
Omega2uvwMRK = (2*Pi*I)^2*(lm[0]^2/16 + Log[1 - u]*(-lm[0]/4 + lp[1]/2) - 
       (lm[0]*lp[1])/4 + lp[1]^2/4) + (2*Pi*I)*((5*lm[0]^3)/48 - 2*lm[0, 1, 1] + 
       Log[1 - u]^2*(-lm[0]/4 + lp[1]/2) + (lm[0]^2*lp[1])/8 + 
       (lm[0]*lp[1]^2)/4 + lp[1]^3/6 + Log[1 - u]*(lm[0]^2/8 - 
         (lm[0]*lp[1])/2 + lp[1]^2/2) - lp[0, 0, 1] + (lm[0]*Zeta[2])/2 - 
       lp[1]*Zeta[2] - 2*Zeta[3])
 
Omega2vwuMRK = lm[0]^4/64 + Log[1 - u]^4/4 + Log[1 - u]^3*lp[1] - 
     (lm[0]^2*lp[1]^2)/8 + lp[1]^4/4 + (lm[0]^2*Zeta[2])/4 + 
     lp[1]^2*Zeta[2] + Log[1 - u]^2*(-lm[0]^2/8 + (3*lp[1]^2)/2 + Zeta[2]) + 
     (5*Zeta[4])/2 + 4*lp[1]*Zeta[3] + 
     (2*Pi*I)*(Log[1 - u]^3/3 + (lm[0]^2*lp[1])/4 + Log[1 - u]^2*lp[1] + 
       lp[1]^3/3 - 2*lp[0, 0, 1] + 2*lp[1]*Zeta[2] + 
       Log[1 - u]*(-lm[0]^2/4 + lp[1]^2 + 2*Zeta[2]) + 2*Zeta[3]) + 
     Log[1 - u]*(-(lm[0]^2*lp[1])/4 + lp[1]^3 + 2*lp[1]*Zeta[2] + 4*Zeta[3])
 
Omega2wuvMRK = (2*Pi*I)^2*(lm[0]^2/16 + Log[1 - u]*(lm[0]/4 + lp[1]/2) + 
       (lm[0]*lp[1])/4 + lp[1]^2/4) + (2*Pi*I)*((-5*lm[0]^3)/48 + 2*lm[0, 1, 1] + 
       Log[1 - u]^2*(lm[0]/4 + lp[1]/2) + (lm[0]^2*lp[1])/8 - 
       (lm[0]*lp[1]^2)/4 + lp[1]^3/6 + Log[1 - u]*(lm[0]^2/8 + 
         (lm[0]*lp[1])/2 + lp[1]^2/2) - lp[0, 0, 1] - (lm[0]*Zeta[2])/2 - 
       lp[1]*Zeta[2] - 2*Zeta[3])
 
F1uvwMRK = -2*(2*Pi*I)*lm[0, 1]*Log[1 - u]
 
F1vwuMRK = 0
 
F1wuvMRK = 0
 
QepuvwMRK = (-3*lm[0]^5)/8192 + (3*Log[1 - u]^5)/256 + 
     Log[1 - u]^4*((-3*lm[0])/512 + (15*lp[1])/256) + 
     (3*lm[0]^4*lp[1])/4096 + (3*lm[0]^3*lp[1]^2)/1024 - 
     (3*lm[0]^2*lp[1]^3)/512 - (3*lm[0]*lp[1]^4)/512 + (3*lp[1]^5)/256 + 
     Log[1 - u]^3*((-3*lm[0]^2)/512 - (3*lm[0]*lp[1])/128 + 
       (15*lp[1]^2)/128 + Zeta[2]/64) - (5*lm[0]^3*Zeta[2])/512 + 
     (5*lm[0]^2*lp[1]*Zeta[2])/256 - (lm[0]*lp[1]^2*Zeta[2])/128 + 
     (lp[1]^3*Zeta[2])/64 - (35*lm[0]*Zeta[4])/256 - (5*lp[1]*Zeta[4])/128 + 
     (2*Pi*I)^2*(Log[1 - u]^3/96 + (lm[0]^2*lp[1])/128 + (Log[1 - u]^2*lp[1])/32 + 
       lp[1]^3/96 - lp[0, 0, 1]/16 + Log[1 - u]*(-lm[0]^2/128 + lp[1]^2/32 + 
         Zeta[2]/16) + (lp[1]*Zeta[2])/16 + Zeta[3]/16) + 
     Log[1 - u]^2*((3*lm[0]^3)/1024 - (9*lm[0]^2*lp[1])/512 - 
       (9*lm[0]*lp[1]^2)/256 + (15*lp[1]^3)/128 - (lm[0]*Zeta[2])/128 + 
       (3*lp[1]*Zeta[2])/64 + (15*Zeta[3])/64) - (lm[0]^2*Zeta[3])/256 - 
     (13*lm[0]*lp[1]*Zeta[3])/64 + (15*lp[1]^2*Zeta[3])/64 + 
     (5*Zeta[2]*Zeta[3])/128 + (2*Pi*I)*((-17*lm[0]^4)/6144 - lm[0, 1]^2/32 + 
       (lm[0]*lm[0, 1, 1])/16 + (11*Log[1 - u]^4)/384 + 
       Log[1 - u]^3*(-lm[0]/64 + (11*lp[1])/96) - (3*lm[0]^3*lp[1])/256 + 
       (lm[0]^2*lp[1]^2)/256 - (lm[0]*lp[1]^3)/64 + (11*lp[1]^4)/384 + 
       (3*lm[0]*lp[0, 0, 1])/32 - (lp[1]*lp[0, 0, 1])/8 + 
       Log[1 - u]^2*((-5*lm[0]^2)/256 - (3*lm[0]*lp[1])/64 + 
         (11*lp[1]^2)/64 + (3*Zeta[2])/32) + (3*lm[0]^2*Zeta[2])/128 - 
       (3*lm[0]*lp[1]*Zeta[2])/32 + (3*lp[1]^2*Zeta[2])/32 + Zeta[2]^2/32 - 
       Zeta[4]/4 + Log[1 - u]*((3*lm[0]^3)/256 - (lm[0]^2*lp[1])/128 - 
         (3*lm[0]*lp[1]^2)/64 + (11*lp[1]^3)/96 - lp[0, 0, 1]/8 - 
         (3*lm[0]*Zeta[2])/32 + (3*lp[1]*Zeta[2])/16 + Zeta[3]/4) - 
       (3*lm[0]*Zeta[3])/16 + (lp[1]*Zeta[3])/4) + 
     Log[1 - u]*((3*lm[0]^4)/4096 + (3*lm[0]^3*lp[1])/512 - 
       (9*lm[0]^2*lp[1]^2)/512 - (3*lm[0]*lp[1]^3)/128 + (15*lp[1]^4)/256 + 
       (5*lm[0]^2*Zeta[2])/256 - (lm[0]*lp[1]*Zeta[2])/64 + 
       (3*lp[1]^2*Zeta[2])/64 - (5*Zeta[4])/128 - (13*lm[0]*Zeta[3])/64 + 
       (15*lp[1]*Zeta[3])/32) - Zeta[5]/64
 
QepuwvMRK = (3*lm[0]^5)/8192 + (3*Log[1 - u]^5)/256 + 
     Log[1 - u]^4*((3*lm[0])/512 + (15*lp[1])/256) + (3*lm[0]^4*lp[1])/4096 - 
     (3*lm[0]^3*lp[1]^2)/1024 - (3*lm[0]^2*lp[1]^3)/512 + 
     (3*lm[0]*lp[1]^4)/512 + (3*lp[1]^5)/256 + 
     Log[1 - u]^3*((-3*lm[0]^2)/512 + (3*lm[0]*lp[1])/128 + 
       (15*lp[1]^2)/128 + Zeta[2]/64) + (5*lm[0]^3*Zeta[2])/512 + 
     (5*lm[0]^2*lp[1]*Zeta[2])/256 + (lm[0]*lp[1]^2*Zeta[2])/128 + 
     (lp[1]^3*Zeta[2])/64 + (35*lm[0]*Zeta[4])/256 - (5*lp[1]*Zeta[4])/128 + 
     (2*Pi*I)^2*(Log[1 - u]^3/96 + (lm[0]^2*lp[1])/128 + (Log[1 - u]^2*lp[1])/32 + 
       lp[1]^3/96 - lp[0, 0, 1]/16 + Log[1 - u]*(-lm[0]^2/128 + lp[1]^2/32 + 
         Zeta[2]/16) + (lp[1]*Zeta[2])/16 + Zeta[3]/16) + 
     Log[1 - u]^2*((-3*lm[0]^3)/1024 - (9*lm[0]^2*lp[1])/512 + 
       (9*lm[0]*lp[1]^2)/256 + (15*lp[1]^3)/128 + (lm[0]*Zeta[2])/128 + 
       (3*lp[1]*Zeta[2])/64 + (15*Zeta[3])/64) - (lm[0]^2*Zeta[3])/256 + 
     (13*lm[0]*lp[1]*Zeta[3])/64 + (15*lp[1]^2*Zeta[3])/64 + 
     (5*Zeta[2]*Zeta[3])/128 + (2*Pi*I)*((-17*lm[0]^4)/6144 - lm[0, 1]^2/32 + 
       (lm[0]*lm[0, 1, 1])/16 + (11*Log[1 - u]^4)/384 + 
       Log[1 - u]^3*(lm[0]/64 + (11*lp[1])/96) + (3*lm[0]^3*lp[1])/256 + 
       (lm[0]^2*lp[1]^2)/256 + (lm[0]*lp[1]^3)/64 + (11*lp[1]^4)/384 - 
       (3*lm[0]*lp[0, 0, 1])/32 - (lp[1]*lp[0, 0, 1])/8 + 
       Log[1 - u]^2*((-5*lm[0]^2)/256 + (3*lm[0]*lp[1])/64 + 
         (11*lp[1]^2)/64 + (3*Zeta[2])/32) + (3*lm[0]^2*Zeta[2])/128 + 
       (3*lm[0]*lp[1]*Zeta[2])/32 + (3*lp[1]^2*Zeta[2])/32 + Zeta[2]^2/32 - 
       Zeta[4]/4 + Log[1 - u]*((-3*lm[0]^3)/256 - (lm[0]^2*lp[1])/128 + 
         (3*lm[0]*lp[1]^2)/64 + (11*lp[1]^3)/96 - lp[0, 0, 1]/8 + 
         (3*lm[0]*Zeta[2])/32 + (3*lp[1]*Zeta[2])/16 + Zeta[3]/4) + 
       (3*lm[0]*Zeta[3])/16 + (lp[1]*Zeta[3])/4) + 
     Log[1 - u]*((3*lm[0]^4)/4096 - (3*lm[0]^3*lp[1])/512 - 
       (9*lm[0]^2*lp[1]^2)/512 + (3*lm[0]*lp[1]^3)/128 + (15*lp[1]^4)/256 + 
       (5*lm[0]^2*Zeta[2])/256 + (lm[0]*lp[1]*Zeta[2])/64 + 
       (3*lp[1]^2*Zeta[2])/64 - (5*Zeta[4])/128 + (13*lm[0]*Zeta[3])/64 + 
       (15*lp[1]*Zeta[3])/32) - Zeta[5]/64
 
QepvwuMRK = (2*Pi*I)*((-23*lm[0]^4)/6144 + lm[0, 1]^2/32 + 
       (lm[0]*lm[0, 1, 1])/16 - Log[1 - u]^4/96 + 
       Log[1 - u]^3*(-lm[0]/768 - lp[1]/384) + (lm[0]^3*lp[1])/768 + 
       (lm[0, 1, 1]*lp[1])/8 + (3*lm[0]^2*lp[1]^2)/256 - 
       (lm[0]*lp[1]^3)/192 + (5*lp[1]^4)/384 - (lm[0]*lp[0, 0, 1])/16 - 
       (lp[1]*lp[0, 0, 1])/8 + Log[1 - u]^2*((5*lm[0]^2)/512 + 
         (5*lm[0]*lp[1])/128 + (5*lp[1]^2)/128 - (3*Zeta[2])/64) - 
       (lm[0]^2*Zeta[2])/128 - (lm[0]*lp[1]*Zeta[2])/32 - 
       (lp[1]^2*Zeta[2])/32 - Zeta[2]^2/32 + Zeta[4]/4 + 
       Log[1 - u]*((-31*lm[0]^3)/3072 + lm[0, 1, 1]/4 + (17*lm[0]^2*lp[1])/
          512 + (lm[0]*lp[1]^2)/256 + (17*lp[1]^3)/384 - lp[0, 0, 1]/8 - 
         (5*lm[0]*Zeta[2])/128 - (5*lp[1]*Zeta[2])/64 - Zeta[3]/32)) + 
     (2*Pi*I)^2*((3*lm[0]^3)/2048 + (3*Log[1 - u]^3)/256 + 
       Log[1 - u]^2*((9*lm[0])/512 + (9*lp[1])/256) + 
       (9*lm[0]^2*lp[1])/1024 + (9*lm[0]*lp[1]^2)/512 + (3*lp[1]^3)/256 + 
       Log[1 - u]*((9*lm[0]^2)/1024 + (9*lm[0]*lp[1])/256 + (9*lp[1]^2)/256 + 
         (3*Zeta[2])/128) + (3*lm[0]*Zeta[2])/256 + (3*lp[1]*Zeta[2])/128 - 
       (3*Zeta[3])/64) + (9*Zeta[2]*Zeta[3])/128 + (21*Zeta[5])/64
 
QepvuwMRK = (2*Pi*I)^3*((-3*lm[0]^2)/1024 - (3*Log[1 - u]^2)/256 + 
       Log[1 - u]*((-3*lm[0])/256 - (3*lp[1])/128) - (3*lm[0]*lp[1])/256 - 
       (3*lp[1]^2)/256 - (3*Zeta[2])/128) + 
     (2*Pi*I)^2*((5*lm[0]^3)/512 - (3*lm[0, 1, 1])/16 - Log[1 - u]^3/256 + 
       Log[1 - u]^2*((-3*lm[0])/256 - (3*lp[1])/128) - 
       (3*lm[0]^2*lp[1])/256 + (3*lm[0]*lp[1]^2)/128 - lp[1]^3/64 + 
       (3*lp[0, 0, 1])/32 + Log[1 - u]*((-9*lm[0]^2)/1024 - 
         (9*lm[0]*lp[1])/256 - (9*lp[1]^2)/256 + (5*Zeta[2])/128) + 
       (lm[0]*Zeta[2])/32 + (lp[1]*Zeta[2])/16 + (7*Zeta[3])/64) + 
     (2*Pi*I)*((7*lm[0]^4)/6144 + lm[0, 1]^2/32 - (lm[0]*lm[0, 1, 1])/32 + 
       Log[1 - u]^4/768 + Log[1 - u]^3*(-lm[0]/768 - lp[1]/384) + 
       (lm[0]^3*lp[1])/192 - (lm[0, 1, 1]*lp[1])/16 + 
       (3*lm[0]^2*lp[1]^2)/256 + (lm[0]*lp[1]^3)/96 - lp[1]^4/384 - 
       (lm[0]*lp[0, 0, 1])/64 - (lp[1]*lp[0, 0, 1])/32 + 
       Log[1 - u]^2*((-3*lm[0]^2)/1024 - (3*lm[0]*lp[1])/256 - 
         (3*lp[1]^2)/256 + (23*Zeta[2])/256) + (3*lm[0]^2*Zeta[2])/512 + 
       (3*lm[0]*lp[1]*Zeta[2])/128 + (3*lp[1]^2*Zeta[2])/128 - Zeta[2]^2/32 + 
       (59*Zeta[4])/256 + Log[1 - u]*((5*lm[0]^3)/768 - lm[0, 1, 1]/8 - 
         (lm[0]^2*lp[1])/128 + (lm[0]*lp[1]^2)/64 - lp[1]^3/96 + 
         lp[0, 0, 1]/16 + (7*lm[0]*Zeta[2])/128 + (7*lp[1]*Zeta[2])/64 + 
         (21*Zeta[3])/64) + (3*lm[0]*Zeta[3])/32 + (3*lp[1]*Zeta[3])/16) + 
     (9*Zeta[5])/32
 
QepwuvMRK = (2*Pi*I)^3*((-3*lm[0]^2)/1024 - (3*Log[1 - u]^2)/256 + 
       Log[1 - u]*((3*lm[0])/256 - (3*lp[1])/128) + (3*lm[0]*lp[1])/256 - 
       (3*lp[1]^2)/256 - (3*Zeta[2])/128) + 
     (2*Pi*I)^2*((-5*lm[0]^3)/512 + (3*lm[0, 1, 1])/16 - Log[1 - u]^3/256 + 
       Log[1 - u]^2*((3*lm[0])/256 - (3*lp[1])/128) - (3*lm[0]^2*lp[1])/256 - 
       (3*lm[0]*lp[1]^2)/128 - lp[1]^3/64 + (3*lp[0, 0, 1])/32 + 
       Log[1 - u]*((-9*lm[0]^2)/1024 + (9*lm[0]*lp[1])/256 - 
         (9*lp[1]^2)/256 + (5*Zeta[2])/128) - (lm[0]*Zeta[2])/32 + 
       (lp[1]*Zeta[2])/16 + (7*Zeta[3])/64) + 
     (2*Pi*I)*((7*lm[0]^4)/6144 + lm[0, 1]^2/32 - (lm[0]*lm[0, 1, 1])/32 + 
       Log[1 - u]^4/768 + Log[1 - u]^3*(lm[0]/768 - lp[1]/384) - 
       (lm[0]^3*lp[1])/192 + (lm[0, 1, 1]*lp[1])/16 + 
       (3*lm[0]^2*lp[1]^2)/256 - (lm[0]*lp[1]^3)/96 - lp[1]^4/384 + 
       (lm[0]*lp[0, 0, 1])/64 - (lp[1]*lp[0, 0, 1])/32 + 
       Log[1 - u]^2*((-3*lm[0]^2)/1024 + (3*lm[0]*lp[1])/256 - 
         (3*lp[1]^2)/256 + (23*Zeta[2])/256) + (3*lm[0]^2*Zeta[2])/512 - 
       (3*lm[0]*lp[1]*Zeta[2])/128 + (3*lp[1]^2*Zeta[2])/128 - Zeta[2]^2/32 + 
       (59*Zeta[4])/256 + Log[1 - u]*((-5*lm[0]^3)/768 + lm[0, 1, 1]/8 - 
         (lm[0]^2*lp[1])/128 - (lm[0]*lp[1]^2)/64 - lp[1]^3/96 + 
         lp[0, 0, 1]/16 - (7*lm[0]*Zeta[2])/128 + (7*lp[1]*Zeta[2])/64 + 
         (21*Zeta[3])/64) - (3*lm[0]*Zeta[3])/32 + (3*lp[1]*Zeta[3])/16) + 
     (9*Zeta[5])/32
 
QepwvuMRK = (2*Pi*I)*((-23*lm[0]^4)/6144 + lm[0, 1]^2/32 + 
       (lm[0]*lm[0, 1, 1])/16 - Log[1 - u]^4/96 + 
       Log[1 - u]^3*(lm[0]/768 - lp[1]/384) - (lm[0]^3*lp[1])/768 - 
       (lm[0, 1, 1]*lp[1])/8 + (3*lm[0]^2*lp[1]^2)/256 + 
       (lm[0]*lp[1]^3)/192 + (5*lp[1]^4)/384 + (lm[0]*lp[0, 0, 1])/16 - 
       (lp[1]*lp[0, 0, 1])/8 + Log[1 - u]^2*((5*lm[0]^2)/512 - 
         (5*lm[0]*lp[1])/128 + (5*lp[1]^2)/128 - (3*Zeta[2])/64) - 
       (lm[0]^2*Zeta[2])/128 + (lm[0]*lp[1]*Zeta[2])/32 - 
       (lp[1]^2*Zeta[2])/32 - Zeta[2]^2/32 + Zeta[4]/4 + 
       Log[1 - u]*((31*lm[0]^3)/3072 - lm[0, 1, 1]/4 + (17*lm[0]^2*lp[1])/
          512 - (lm[0]*lp[1]^2)/256 + (17*lp[1]^3)/384 - lp[0, 0, 1]/8 + 
         (5*lm[0]*Zeta[2])/128 - (5*lp[1]*Zeta[2])/64 - Zeta[3]/32)) + 
     (2*Pi*I)^2*((-3*lm[0]^3)/2048 + (3*Log[1 - u]^3)/256 + 
       Log[1 - u]^2*((-9*lm[0])/512 + (9*lp[1])/256) + 
       (9*lm[0]^2*lp[1])/1024 - (9*lm[0]*lp[1]^2)/512 + (3*lp[1]^3)/256 + 
       Log[1 - u]*((9*lm[0]^2)/1024 - (9*lm[0]*lp[1])/256 + (9*lp[1]^2)/256 + 
         (3*Zeta[2])/128) - (3*lm[0]*Zeta[2])/256 + (3*lp[1]*Zeta[2])/128 - 
       (3*Zeta[3])/64) + (9*Zeta[2]*Zeta[3])/128 + (21*Zeta[5])/64
 
M1uvwMRK = (2*Pi*I)*(Log[1 - u]^4/3 + Log[1 - u]^3*(lm[0]/2 + lp[1]) + 
       Log[1 - u]^2*(lm[0]^2/4 + lm[0]*lp[1] + lp[1]^2) + 
       Log[1 - u]*((-5*lm[0]^3)/24 + 4*lm[0, 1, 1] + (lm[0]^2*lp[1])/4 - 
         (lm[0]*lp[1]^2)/2 + lp[1]^3/3 - 2*lp[0, 0, 1] + lm[0]*Zeta[2] + 
         2*lp[1]*Zeta[2])) + 3*lm[0]*Zeta[4] + 6*lp[1]*Zeta[4] - 
     (lm[0]^2*Zeta[3])/2 - 2*Log[1 - u]^2*Zeta[3] - 2*lm[0]*lp[1]*Zeta[3] - 
     2*lp[1]^2*Zeta[3] + 4*Zeta[2]*Zeta[3] + 
     Log[1 - u]*(6*Zeta[4] - 2*lm[0]*Zeta[3] - 4*lp[1]*Zeta[3]) - 4*Zeta[5]
 
M1uwvMRK = (2*Pi*I)*(Log[1 - u]^4/3 + Log[1 - u]^3*(-lm[0]/2 + lp[1]) + 
       Log[1 - u]^2*(lm[0]^2/4 - lm[0]*lp[1] + lp[1]^2) + 
       Log[1 - u]*((5*lm[0]^3)/24 - 4*lm[0, 1, 1] + (lm[0]^2*lp[1])/4 + 
         (lm[0]*lp[1]^2)/2 + lp[1]^3/3 - 2*lp[0, 0, 1] - lm[0]*Zeta[2] + 
         2*lp[1]*Zeta[2])) - 3*lm[0]*Zeta[4] + 6*lp[1]*Zeta[4] - 
     (lm[0]^2*Zeta[3])/2 - 2*Log[1 - u]^2*Zeta[3] + 2*lm[0]*lp[1]*Zeta[3] - 
     2*lp[1]^2*Zeta[3] + 4*Zeta[2]*Zeta[3] + 
     Log[1 - u]*(6*Zeta[4] + 2*lm[0]*Zeta[3] - 4*lp[1]*Zeta[3]) - 4*Zeta[5]
 
M1vwuMRK = -2*Zeta[2]*Zeta[3] + 2*Zeta[5]
 
M1vuwMRK = -2*Zeta[2]*Zeta[3] + 2*Zeta[5]
 
M1wuvMRK = -2*Zeta[2]*Zeta[3] + 2*Zeta[5]
 
NuvwMRK = 12*lp[1]*Zeta[4] + (2*Pi*I)*((17*lm[0]^4)/96 + 2*lm[0, 1]^2 - 
       4*lm[0]*lm[0, 1, 1] - Log[1 - u]^4/2 - (4*Log[1 - u]^3*lp[1])/3 + 
       (5*lm[0]^2*lp[1]^2)/4 + lp[1]^4/6 - 4*lp[1]*lp[0, 0, 1] + 
       Log[1 - u]^2*(lm[0]^2/4 - lp[1]^2 - 6*Zeta[2]) + (lm[0]^2*Zeta[2])/2 - 
       2*lp[1]^2*Zeta[2] - 2*Zeta[2]^2 - 22*Zeta[4] + 
       Log[1 - u]*(-8*lp[1]*Zeta[2] - 4*Zeta[3])) + lm[0]^2*Zeta[3] - 
     4*Log[1 - u]^2*Zeta[3] - 4*lp[1]^2*Zeta[3] + 8*Zeta[2]*Zeta[3] + 
     Log[1 - u]*(12*Zeta[4] - 8*lp[1]*Zeta[3]) - 8*Zeta[5]
 
OuvwMRK = (2*Pi*I)*(Log[1 - u]^4/12 - Log[1 - u]^2*Zeta[2] + (19*Zeta[4])/2) - 
     8*Zeta[2]*Zeta[3] + (2*Pi*I)^2*(Log[1 - u]^3/6 + 2*Zeta[3]) + 17*Zeta[5]
 
GuvwMRK = (2*Pi*I)*(8*lm[0, 1]*Zeta[2] - 8*Zeta[2]^2 + 20*Zeta[4])
 
H1uvwMRK = (2*Pi*I)^2*(-(lm[0]*lm[0, 1])/4 - lm[0, 1]*Log[1 - u] - 
       (lm[0, 1]*lp[1])/2) + (2*Pi*I)*(-(lm[0]^2*lm[0, 1])/2 + 4*lm[0, 0, 0, 1] - 
       2*lm[0, 1, 1, 1] - lm[0, 1]*Log[1 - u]^2 + (lm[0]*lm[0, 1]*lp[1])/2 + 
       Log[1 - u]*(-(lm[0]*lm[0, 1])/2 - lm[0, 1]*lp[1]) - 3*lp[0, 0, 1, 1] + 
       2*lm[0, 1]*Zeta[2] - 2*Zeta[2]^2 + 5*Zeta[4])
 
H1vwuMRK = (2*Pi*I)^2*((lm[0]*lm[0, 1])/4 - lm[0, 1]*Log[1 - u] - 
       (lm[0, 1]*lp[1])/2) + (2*Pi*I)*(-(lm[0]^2*lm[0, 1])/2 + 4*lm[0, 0, 0, 1] - 
       2*lm[0, 1, 1, 1] - lm[0, 1]*Log[1 - u]^2 - (lm[0]*lm[0, 1]*lp[1])/2 + 
       Log[1 - u]*((lm[0]*lm[0, 1])/2 - lm[0, 1]*lp[1]) + 3*lp[0, 0, 1, 1] + 
       2*lm[0, 1]*Zeta[2] - 2*Zeta[2]^2 + 5*Zeta[4])
 
H1wuvMRK = (2*Pi*I)*(-(lm[0]^2*lm[0, 1]) + 6*lm[0, 0, 0, 1])
 
J1uvwMRK = (-4*(2*Pi*I)^3*lm[0, 1])/3 + (2*Pi*I)^2*(-(lm[0]*lm[0, 1]) - 
       4*lm[0, 1]*Log[1 - u] - 2*lm[0, 1]*lp[1]) + 
     (2*Pi*I)*(-8*lm[0, 1, 1, 1] - 4*lm[0, 1]*Log[1 - u]^2 - 
       2*lm[0]*lm[0, 1]*lp[1] + Log[1 - u]*(-2*lm[0]*lm[0, 1] - 
         4*lm[0, 1]*lp[1]) + 4*lp[0, 0, 1, 1] + 8*lm[0, 1]*Zeta[2] - 
       8*Zeta[2]^2 + 20*Zeta[4])
 
J1vwuMRK = (-4*(2*Pi*I)^3*lm[0, 1])/3 + (2*Pi*I)^2*(lm[0]*lm[0, 1] - 
       4*lm[0, 1]*Log[1 - u] - 2*lm[0, 1]*lp[1]) + 
     (2*Pi*I)*(-8*lm[0, 1, 1, 1] - 4*lm[0, 1]*Log[1 - u]^2 + 
       2*lm[0]*lm[0, 1]*lp[1] + Log[1 - u]*(2*lm[0]*lm[0, 1] - 
         4*lm[0, 1]*lp[1]) - 4*lp[0, 0, 1, 1] + 8*lm[0, 1]*Zeta[2] - 
       8*Zeta[2]^2 + 20*Zeta[4])
 
J1wuvMRK = (2*Pi*I)*(-8*lm[0, 0, 0, 1] + 16*lm[0, 1]*Zeta[2] - 16*Zeta[2]^2 + 
      40*Zeta[4])
 
K1uvwMRK = (2*Pi*I)^2*(lm[0]*lm[0, 1] + 2*lm[0, 1]*Log[1 - u] + 
       2*lm[0, 1]*lp[1]) + (2*Pi*I)*(2*lm[0, 1]*Log[1 - u]^2 + 
       Log[1 - u]*(lm[0]*lm[0, 1] + 2*lm[0, 1]*lp[1]) + 4*lm[0, 1]*Zeta[2] - 
       4*Zeta[2]^2 + 10*Zeta[4])
 
K1vwuMRK = (2*Pi*I)^2*(-(lm[0]*lm[0, 1]) + 2*lm[0, 1]*Log[1 - u] + 
       2*lm[0, 1]*lp[1]) + (2*Pi*I)*(2*lm[0, 1]*Log[1 - u]^2 + 
       Log[1 - u]*(-(lm[0]*lm[0, 1]) + 2*lm[0, 1]*lp[1]) + 
       4*lm[0, 1]*Zeta[2] - 4*Zeta[2]^2 + 10*Zeta[4])
 
K1wuvMRK = (2*Pi*I)*((lm[0]^2*lm[0, 1])/2 - 2*lm[0, 1]*Log[1 - u]^2 - 
      4*lm[0, 1]*Log[1 - u]*lp[1] - 2*lm[0, 1]*lp[1]^2 + 4*lm[0, 1]*Zeta[2] - 
      4*Zeta[2]^2 + 10*Zeta[4])
