(****************************************************************)
(*  This file contains the near-collinear expansion of the      *)
(*  three-loop remainder function.                              *)
(*                                                              *)
(*  We use the variables S, F, and T, which are related to      *)
(*  the cross ratios u, v, and w, by,                           *)
(*                                                              *)
(*  u = (F*S^2)/((1+T^2)*(F+F*S^2+S*T+F^2*S*T+F*T^2)),          *)
(*  v = T^2/(1+T^2),                                            *)
(*  w = F/(F+F*S^2+S*T+F^2*S*T+F*T^2) .                         *)
(*                                                              *)
(*  The variables yu, yv, and yw, are related by,               *)
(*                                                              *)
(*  yu = (F*S+T)/(F*(S+F*T)),                                   *)
(*  yv = ((S+F*T)*(1+F*S*T+T^2))/((F*S+T)*(F+S*T+F*T^2)),       *)
(*  yw = (F+S*T+F*T^2)/(F*(1+F*S*T+T^2)) .                      *)
(*                                                              *)
(*  We denote by HPL[{w1,...,wn},z] the harmonic polylogarithm  *)
(*  with weight vector {w1,...,wn} and argument z.              *)
(****************************************************************)

R63T2 = (F^2*Pi^4*T*((20*S)/F^3 + (20*S)/F - (176*S^2*T)/F^2 + 
        (78 - 83*S^2)*T + ((78 - 83*S^2)*T)/F^4))/5760 + 
     (F^2*Pi^2*T*((4*S)/F^3 + (4*S)/F + (-2 + S^2)*T + ((-2 + S^2)*T)/F^4)*
       HPL[{0}, S^2]^2)/384 + (13*F^2*Pi^4*T*((-2*(S + S^3))/F^3 - 
        (2*(S + S^3))/F - (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*
       HPL[{1}, -S^2])/(960*S^2) - 
     (F^2*Pi^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]^2*HPL[{1}, -S^2])/
      (192*S^2) - (F^2*Pi^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^2)/(24*S^2) - 
     (F^2*Pi^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{1}, -S^2]^3)/(48*S^2) - 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^3)/
      (48*S^2) - (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^4)/(16*S^2) - 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{1}, -S^2]^5)/(40*S^2) - 
     (F^2*Pi^2*T*((4*S - 8*S^3)/F^3 + (4*S - 8*S^3)/F + 
        (1 + 2*S^2 - 2*S^4)*T + ((1 + 2*S^2 - 2*S^4)*T)/F^4)*HPL[{2}, -S^2])/
      (192*S^2) - (F^2*Pi^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]*
       HPL[{2}, -S^2])/(96*S^2) + 
     (F^2*T*((4*S)/F^3 + (4*S)/F + (-2 + S^2)*T + ((-2 + S^2)*T)/F^4)*
       HPL[{0}, S^2]^2*HPL[{2}, -S^2])/64 - 
     (F^2*Pi^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{1}, -S^2]*HPL[{2}, -S^2])/
      (96*S^2) - (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/(32*S^2) - 
     ((1 + F^(-2))^2*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/
      (8*S^2) - (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/(8*S^2) + 
     (F^2*T*((4*(S + S^3))/F^3 + (4*(S + S^3))/F + (1 - 4*S^2 + S^4)*T + 
        ((1 - 4*S^2 + S^4)*T)/F^4)*HPL[{2}, -S^2]^2)/(64*S^2) - 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]*HPL[{2}, -S^2]^2)/
      (32*S^2) - (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{1}, -S^2]*
       HPL[{2}, -S^2]^2)/(16*S^2) + 
     (F^2*Pi^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{3}, -S^2])/(48*S^2) + 
     ((1 + F^(-2))^2*F^2*(1 + S^2)*(3 + S^2)*T^2*HPL[{1}, -S^2]*
       HPL[{3}, -S^2])/(8*S^2) + 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{2}, -S^2]*HPL[{3}, -S^2])/
      (8*S^2) - (F^2*T*((-4*S*(3 + S^2))/F^3 - (4*S*(3 + S^2))/F + 
        (48*(-1 + S^4)*T)/F^2 + (-27 + 8*S^2 + 23*S^4)*T + 
        ((-27 + 8*S^2 + 23*S^4)*T)/F^4)*HPL[{4}, -S^2])/(32*S^2) + 
     (3*F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]*HPL[{4}, -S^2])/
      (16*S^2) - (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{1}, -S^2]*
       HPL[{4}, -S^2])/(4*S^2) - 
     (9*F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{5}, -S^2])/(8*S^2) + 
     (F^2*Pi^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{2, 1}, -S^2])/(48*S^2) + 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]^2*HPL[{2, 1}, -S^2])/
      (16*S^2) + ((1 + F^(-2))^2*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]*
       HPL[{2, 1}, -S^2])/(4*S^2) + 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2, 1}, -S^2])/(4*S^2) + 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{2}, -S^2]*HPL[{2, 1}, -S^2])/
      (4*S^2) + (F^2*T*((-4*S^3)/F^3 - (4*S^3)/F + (4*(-1 + S^4)*T)/F^2 + 
        (-2 + 2*S^2 + S^4)*T + ((-2 + 2*S^2 + S^4)*T)/F^4)*HPL[{3, 1}, -S^2])/
      (8*S^2) + (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{1}, -S^2]*
       HPL[{3, 1}, -S^2])/(4*S^2) - 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{3, 2}, -S^2])/(4*S^2) - 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{4, 1}, -S^2])/(4*S^2) - 
     (F^2*(-1 + S^2)*T*((-4*S)/F^3 - (4*S)/F + 3*(1 + S^2)*T + 
        (3*(1 + S^2)*T)/F^4 + (8*(1 + S^2)*T)/F^2)*HPL[{2, 1, 1}, -S^2])/
      (8*S^2) - (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]*
       HPL[{2, 1, 1}, -S^2])/(4*S^2) - 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{2, 2, 1}, -S^2])/(2*S^2) - 
     (3*F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{3, 1, 1}, -S^2])/(2*S^2) + 
     (F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2]*
       (-11 - 11/F^4 - 16/F^2 + 8*(1 + F^(-2))^2*Log[T]))/(32*S^2) + 
     (F^2*Pi^2*T*HPL[{0}, S^2]*((56*(1 + F^(-2))*S)/F - 
        10*(1 + F^(-4))*(1 + S^2)*T + 16*((-4*S)/F^3 - (4*S)/F + 
          (1 + S^2)*T + ((1 + S^2)*T)/F^4)*Log[T]))/192 - 
     (F^2*(-1 + S^2)*T*HPL[{2, 1}, -S^2]*((-8*S)/F^3 - (8*S)/F - 
        11*(1 + S^2)*T - (11*(1 + S^2)*T)/F^4 + 
        4*((4*S)/F^3 + (4*S)/F + (1 + S^2)*T + ((1 + S^2)*T)/F^4)*Log[T]))/
      (32*S^2) + (F^2*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2*
       ((1 + F^(-2))*S*(1 + S^2)*(2/F + S*T + (S*T)/F^2) + 
        ((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + (1 + S^4)*T + 
          ((1 + S^4)*T)/F^4)*Log[T]))/(16*S^2) + 
     (F^2*Pi^2*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       ((1 + S^2)*((4*S)/F^3 + (4*S)/F - T - T/F^4 + (2*S^2*T)/F^2) + 
        2*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
          (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]))/(24*S^2) + 
     (F^2*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2}, -S^2]*
       (-((1 + S^2)*((-4*S)/F^3 - (4*S)/F + (1 + S^2)*T + ((1 + S^2)*T)/F^4 - 
           (2*(1 + S^2)*T)/F^2)) + 2*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
          (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]))/(8*S^2) + 
     (F^2*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^3*
       ((1 + S^2)*((6*S)/F^3 + (6*S)/F + S^2*T + (S^2*T)/F^4 + 
          ((3 + 5*S^2)*T)/F^2) + 3*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
          (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]))/
      (12*S^2) + (F^2*Pi^2*T*HPL[{1}, -S^2]^2*
       (-((1 + S^2)*((-6*S)/F^3 - (6*S)/F + T + 2*S^2*T + (2*S^2*T)/F^2 + 
           (T + 2*S^2*T)/F^4)) + 3*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
          (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]))/
      (48*S^2) - (F^2*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2]*
       ((4*S*(3 + S^2))/F^3 + (4*S*(3 + S^2))/F + (8*S^2*(1 + S^2)*T)/F^2 - 
        (3 + 4*S^2 + S^4)*T - ((3 + 4*S^2 + S^4)*T)/F^4 + 
        4*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
          (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]))/(16*S^2) + 
     (F^2*T*HPL[{0}, S^2]*HPL[{3}, -S^2]*((4*(S + S^3))/F^3 + 
        (4*(S + S^3))/F + (24*S^2*(1 + S^2)*T)/F^2 + (-5 + 8*S^2 + 7*S^4)*T + 
        ((-5 + 8*S^2 + 7*S^4)*T)/F^4 + 4*((-2*(S + S^3))/F^3 - 
          (2*(S + S^3))/F - (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*
         Log[T]))/(32*S^2) + (F^2*T*HPL[{1}, -S^2]^4*
       ((1 + S^2)*((12*S)/F^3 + (12*S)/F + (1 + S^2)*T + ((1 + S^2)*T)/F^4 + 
          (8*(1 + S^2)*T)/F^2) + 6*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
          (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]))/
      (48*S^2) - (3*F^2*T^2*(3 + 3/F^4 - 64/F^2 - 6*Log[T] - (6*Log[T])/F^4 + 
        (32*Log[T])/F^2 + 4*Log[T]^2 + (4*Log[T]^2)/F^4))/64 + 
     (F^2*T*HPL[{0}, S^2]^2*((9 + 40*S^2 + (80*S^2)/F^2 + (9 + 40*S^2)/F^4)*
         T - 2*S*(8/F^3 + 8/F + 21*S*T + (21*S*T)/F^4 + (32*S*T)/F^2)*
         Log[T] + 4*((4*S)/F^3 + (4*S)/F + (-2 + S^2)*T + ((-2 + S^2)*T)/F^4)*
         Log[T]^2))/128 + 
     (F^2*Pi^2*T*(3*(1 - 8*S^2 - (16*S^2)/F^2 + (1 - 8*S^2)/F^4)*T + 
        2*((-8*S)/F^3 - (8*S)/F + (32*S^2*T)/F^2 + (8 + 11*S^2)*T + 
          ((8 + 11*S^2)*T)/F^4)*Log[T] + 4*((4*S)/F^3 + (4*S)/F + 
          (-2 + S^2)*T + ((-2 + S^2)*T)/F^4)*Log[T]^2))/384 - 
     (F^2*(1 + S^2)*T*HPL[{1}, -S^2]^2*((-72*S)/F^3 - (72*S)/F - 
        5*(1 + S^2)*T - (5*(1 + S^2)*T)/F^4 - (40*(1 + S^2)*T)/F^2 + 
        (16*(5*(1 + F^(-2))*S + (2*T)/F + (2*S^2*T)/F)*Log[T])/F + 
        8*((-4*S)/F^3 - (4*S)/F + (1 + S^2)*T + ((1 + S^2)*T)/F^4)*Log[T]^2))/
      (32*S^2) - (F^2*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       ((-72*S)/F^3 - (72*S)/F + (11 - 21*S^2)*T + ((11 - 21*S^2)*T)/F^4 - 
        (8*(T + 9*S^2*T))/F^2 + 16*((5*S)/F^3 + (5*S)/F + (4*S^2*T)/F^2 + 
          (-1 + S^2)*T + ((-1 + S^2)*T)/F^4)*Log[T] + 
        8*((-4*S)/F^3 - (4*S)/F + (1 + S^2)*T + ((1 + S^2)*T)/F^4)*Log[T]^2))/
      (32*S^2) - (F^2*T*HPL[{0}, S^2]*
       (3*((-48*S)/F^3 - (48*S)/F + 5*(1 + S^2)*T + (5*(1 + S^2)*T)/F^4 - 
          (8*(1 + S^2)*T)/F^2) - 2*((-72*S)/F^3 - (72*S)/F + 11*(1 + S^2)*T + 
          (11*(1 + S^2)*T)/F^4 - (8*(1 + S^2)*T)/F^2)*Log[T] + 
        12*((-4*S)/F^3 - (4*S)/F + (1 + S^2)*T + ((1 + S^2)*T)/F^4)*
         Log[T]^2))/32 - (F^2*(1 + S^2)*T*HPL[{1}, -S^2]*
       (3*((-48*S)/F^3 - (48*S)/F + 5*(1 + S^2)*T + (5*(1 + S^2)*T)/F^4 - 
          (8*(1 + S^2)*T)/F^2) - 2*((-72*S)/F^3 - (72*S)/F + 11*(1 + S^2)*T + 
          (11*(1 + S^2)*T)/F^4 - (8*(1 + S^2)*T)/F^2)*Log[T] + 
        12*((-4*S)/F^3 - (4*S)/F + (1 + S^2)*T + ((1 + S^2)*T)/F^4)*
         Log[T]^2))/(32*S^2) + (F^2*(-1 + S^2)*T*HPL[{2}, -S^2]*
       (-12*(1 + F^(-2))^2*(1 + S^2)*T + ((-8*S)/F^3 - (8*S)/F + 
          11*(1 + S^2)*T + (11*(1 + S^2)*T)/F^4 + (32*(1 + S^2)*T)/F^2)*
         Log[T] + 2*((4*S)/F^3 + (4*S)/F + (1 + S^2)*T + ((1 + S^2)*T)/F^4)*
         Log[T]^2))/(32*S^2) - (F^2*T*HPL[{1}, -S^2]^3*
       (-((1 + S^2)*((10*S)/F^3 + (10*S)/F + (1 + S^2)*T + 
           ((1 + S^2)*T)/F^4 + (6*(1 + S^2)*T)/F^2)) + 
        (6*(1 + S^2)*(2*(1 + F^(-2))*S + T/F + (S^2*T)/F)*Log[T])/F + 
        2*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
          (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]^2))/(12*S^2) - 
     (F^2*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (-2*(1 + S^2)*((5*S)/F^3 + (5*S)/F + S^2*T + (S^2*T)/F^4 + 
          (2*(T + 2*S^2*T))/F^2) + (1 + S^2)*((12*S)/F^3 + (12*S)/F + 
          (-1 + S^2)*T + ((-1 + S^2)*T)/F^4 + (4*(T + 2*S^2*T))/F^2)*Log[T] + 
        2*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
          (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]^2))/(8*S^2) - 
     (F^2*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*((-8*(S + 2*S^3))/F^3 - 
        (8*(S + 2*S^3))/F - (16*(1 + S^2)*T)/F^2 + 5*(1 + S^2)^2*T + 
        (5*(1 + S^2)^2*T)/F^4 - 2*((-4*(S + 3*S^3))/F^3 - (4*(S + 3*S^3))/F - 
          (8*(1 + S^2)*T)/F^2 + (1 + 4*S^2 + 3*S^4)*T + 
          ((1 + 4*S^2 + 3*S^4)*T)/F^4)*Log[T] + 
        4*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
          (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]^2))/(32*S^2) - 
     (F^2*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*
       (-((1 + S^2)*((24*S)/F^3 + (24*S)/F + (32*S^2*T)/F^2 + 
           (9 + 19*S^2)*T + ((9 + 19*S^2)*T)/F^4)) + 16*(1 + F^(-2))*S*
         (1 + S^2)*(2/F + S*T + (S*T)/F^2)*Log[T] + 
        8*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
          (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T]^2))/(128*S^2) - 
     (F^2*Pi^2*T*HPL[{1}, -S^2]*((1 + S^2)*((-72*S)/F^3 - (72*S)/F + 
          (32*S^2*T)/F^2 + (3 + 25*S^2)*T + ((3 + 25*S^2)*T)/F^4) - 
        16*(1 + S^2)*((-6*S)/F^3 - (6*S)/F + T + 2*S^2*T + (2*S^2*T)/F^2 + 
          (T + 2*S^2*T)/F^4)*Log[T] + 8*((-2*(S + S^3))/F^3 - 
          (2*(S + S^3))/F - (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*
         Log[T]^2))/(384*S^2) + (F^2*T*HPL[{3}, -S^2]*((8*S*(3 + S^2))/F^3 + 
        (8*S*(3 + S^2))/F + (15 + 8*S^2 - 7*S^4)*T + ((15 + 8*S^2 - 7*S^4)*T)/
         F^4 + 4*(-1 + S^2)*((4*S)/F^3 + (4*S)/F + (1 + S^2)*T + 
          ((1 + S^2)*T)/F^4)*Log[T] + 16*((-2*(S + S^3))/F^3 - 
          (2*(S + S^3))/F - (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*
         Log[T]^2))/(64*S^2) + (F^2*T*((4*S)/F^3 + (4*S)/F + (-2 + S^2)*T + 
        ((-2 + S^2)*T)/F^4)*HPL[{0}, S^2]*Zeta[3])/16 - 
     (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - (4*S^2*T)/F^2 + 
        (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       Zeta[3])/(8*S^2) + (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{1}, -S^2]^2*
       Zeta[3])/(8*S^2) + (F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
        (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*HPL[{2}, -S^2]*
       Zeta[3])/(8*S^2) + (F^2*T*((-8*S)/F^3 - (8*S)/F + (12 - 11*S^2)*T + 
        ((12 - 11*S^2)*T)/F^4 + 4*((4*S)/F^3 + (4*S)/F + (-2 + S^2)*T + 
          ((-2 + S^2)*T)/F^4)*Log[T])*Zeta[3])/32 - 
     (F^2*T*HPL[{1}, -S^2]*((1 + S^2)*((2*S)/F^3 + (2*S)/F - T - T/F^4 + 
          (2*S^2*T)/F^2) + ((-2*(S + S^3))/F^3 - (2*(S + S^3))/F - 
          (4*S^2*T)/F^2 + (1 + S^4)*T + ((1 + S^4)*T)/F^4)*Log[T])*Zeta[3])/
      (4*S^2)
