(****************************************************************)
(*  This file contains expressions for the basis of hexagon     *)
(*  functions in Region I, through weight five.                 *)
(*                                                              *)
(*  There are 30 functions presented here. The notation is      *)
(*                                                              *)
(*      FuvwRegI = F(u,v,w), FuwvRegI = F(u,w,v), etc.          *)
(*                                                              *)
(*  where F is one of,                                          *)
(*                                                              *) 
(*    Weight 3: Phi6tilde = \tilde{\Phi}_ 6                     *)
(*    Weight 4: F1 = F_ 1, Omega2 = \Omega_2                    *)
(*    Weight 5: G, H1 = H_ 1, J1 = J_ 1, K1 = K_ 1,             *)
(*              N, O, Qep = Q_{ep}, M1 = M_ 1 .                 *)
(*                                                              *)
(*  We denote by G[{w1,...,wn},z] the multiple polylogarithm    *)
(*  with weight vector {w1,...,wn} and argument z.              *)
(****************************************************************)



Phi6tildeuvwRegI = -(Pi^2*G[{0}, yu])/6 - (Pi^2*G[{0}, yv])/6 - 
     (Pi^2*G[{0}, yw])/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw] + 
     G[{0}, yu]*G[{0, 1}, yu] - G[{0}, yv]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{0, 1}, yu] - G[{0}, yu]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{0, 1}, yv] - G[{0}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{0, 1}, yw] - G[{0}, yv]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{0, 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yv] - G[{0}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw] + G[{0}, yu]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw] + G[{0}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0, 0, 1}, yu] - 2*G[{0, 0, 1}, yv] - 2*G[{0, 0, 1}, yw] + 
     2*G[{0, 0, yu^(-1)}, yv] + 2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1)}, yw] - 2*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1}, yu] - 2*G[{0, 1, 1}, yv] - 2*G[{0, 1, 1}, yw] + 
     2*G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv), yv^(-1)}, yw]
 
Omega2uvwRegI = (7*Pi^4)/120 + (Pi^2*G[{0}, yu]^2)/12 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv])/6 + (Pi^2*G[{0}, yv]^2)/12 + 
     (G[{0}, yu]^2*G[{0}, yv]^2)/4 + (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu])/2 - (Pi^2*G[{1}, yu]^2)/12 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2)/2 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv])/2 + (Pi^2*G[{1}, yu]*G[{1}, yv])/
      6 + G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv] - 
     (Pi^2*G[{1}, yv]^2)/12 - (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2)/2 + 
     (Pi^2*G[{0}, yu]*G[{1}, yw])/6 + (Pi^2*G[{0}, yv]*G[{1}, yw])/6 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw])/2 - (Pi^2*G[{0}, yw]*G[{1}, yw])/
      6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw] + 
     (Pi^2*G[{1}, yu]*G[{1}, yw])/6 + G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw] - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw] - G[{0}, yu]*G[{1}, yu]^2*
      G[{1}, yw] + (Pi^2*G[{1}, yv]*G[{1}, yw])/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw] + G[{0}, yv]^2*G[{1}, yv]*
      G[{1}, yw] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw] + 
     G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw] - G[{0}, yv]*G[{1}, yv]^2*
      G[{1}, yw] - G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw] + 
     (Pi^2*G[{1}, yw]^2)/6 + (G[{0}, yu]^2*G[{1}, yw]^2)/4 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2 + (G[{0}, yv]^2*G[{1}, yw]^2)/4 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2)/2 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/2 - (G[{1}, yu]^2*G[{1}, yw]^2)/4 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/2 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/2 - (G[{1}, yv]^2*G[{1}, yw]^2)/4 + 
     (G[{0}, yu]*G[{1}, yw]^3)/2 + (G[{0}, yv]*G[{1}, yw]^3)/2 - 
     (G[{0}, yw]*G[{1}, yw]^3)/3 + (G[{1}, yu]*G[{1}, yw]^3)/6 + 
     (G[{1}, yv]*G[{1}, yw]^3)/6 + G[{1}, yw]^4/4 - 
     (2*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv])/3 - G[{0}, yu]^2*G[{1}, yw]*
      G[{yu^(-1)}, yv] - G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1}, yw]*G[{yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv] + 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv] - G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yw]^2*
      G[{yu^(-1)}, yv] + G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv] - 
     G[{1}, yw]^3*G[{yu^(-1)}, yv] + G[{1}, yw]^2*G[{yu^(-1)}, yv]^2 - 
     (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw] - (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/
      6 - G[{0}, yu]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{1/(yu*yv)}, yw] - G[{0}, yv]^2*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] + G[{1}, yu]*G[{1}, yv]^2*
      G[{1/(yu*yv)}, yw] - (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     G[{1}, yw]^3*G[{1/(yu*yv)}, yw] + (2*Pi^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/3 + G[{0}, yu]^2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw] + G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]^2)/6 - (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 - (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/4 - G[{0}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^3)/6 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^3)/
      6 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/6 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/
      3 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/6 + (Pi^2*G[{0, 1}, yu])/6 + 
     (G[{0}, yu]^2*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{0}, yv]*G[{0, 1}, yu] + 
     (G[{0}, yv]^2*G[{0, 1}, yu])/2 - (G[{1}, yu]^2*G[{0, 1}, yu])/2 + 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] - (G[{1}, yv]^2*G[{0, 1}, yu])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1}, yu] + G[{0}, yv]*G[{1}, yw]*
      G[{0, 1}, yu] - G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu] + 
     G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] - G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yu] + (G[{1}, yw]^2*G[{0, 1}, yu])/2 - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/2 + (Pi^2*G[{0, 1}, yv])/6 + 
     (G[{0}, yu]^2*G[{0, 1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*G[{0, 1}, yv] + 
     (G[{0}, yv]^2*G[{0, 1}, yv])/2 - G[{0}, yu]*G[{1}, yu]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yv] + (G[{1}, yu]^2*G[{0, 1}, yv])/2 - 
     (G[{1}, yv]^2*G[{0, 1}, yv])/2 + G[{0}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yv] - G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yv] - 2*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] + 
     G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] + (G[{1}, yw]^2*G[{0, 1}, yv])/2 - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/2 + (Pi^2*G[{0, 1}, yw])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yw] + G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0, 1}, yu]*G[{0, 1}, yw] + G[{0, 1}, yv]*G[{0, 1}, yw] + 
     G[{0, 1}, yw]^2/2 - (Pi^2*G[{0, yu^(-1)}, yv])/3 - 
     (G[{0}, yu]^2*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yv]^2*G[{0, yu^(-1)}, yv])/2 + G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yv] - 
     (G[{1}, yu]^2*G[{0, yu^(-1)}, yv])/2 + 
     (G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 - G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     (G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] + G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] + (G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + G[{0, yu^(-1)}, yv]^2/2 - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - G[{1}, yu]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, 1/(yu*yv)}, yw]^2/2 + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{1, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     (Pi^2*G[{1, yu^(-1)}, yw])/6 - (G[{0}, yu]^2*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{1, yu^(-1)}, yw])/2 - G[{0}, yu]*G[{0}, yw]*
      G[{1, yu^(-1)}, yw] + G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw] + 
     (G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/2 - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw] + G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yw] - (3*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] - G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + G[{1, yu^(-1)}, yw]^2/2 - 
     (Pi^2*G[{1, yv^(-1)}, yw])/6 - (G[{0}, yu]^2*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{1, yv^(-1)}, yw])/2 + G[{0}, yu]*G[{0}, yw]*
      G[{1, yv^(-1)}, yw] - G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/2 + G[{0}, yw]*G[{1}, yv]*
      G[{1, yv^(-1)}, yw] + G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw] + 
     (G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/2 - G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1)}, yw] - G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + G[{1, yv^(-1)}, yw]^2/2 + 
     (2*Pi^2*G[{1, 1/(yu*yv)}, yw])/3 + G[{0}, yu]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]^2*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1, 1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1), 1/(yu*yv)}, yw]^2/2 - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1), 1/(yu*yv)}, yw]^2/2 - 
     2*G[{0}, yu]*G[{0, 0, 1}, yu] + 2*G[{0}, yv]*G[{0, 0, 1}, yu] + 
     G[{1}, yu]*G[{0, 0, 1}, yu] - G[{1}, yv]*G[{0, 0, 1}, yu] + 
     G[{1}, yw]*G[{0, 0, 1}, yu] - G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{0}, yu]*G[{0, 0, 1}, yv] - 2*G[{0}, yv]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yu]*G[{0, 0, 1}, yv] + G[{1}, yv]*G[{0, 0, 1}, yv] + 
     G[{1}, yw]*G[{0, 0, 1}, yv] - G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yw]*G[{0, 0, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yv]*G[{0, 0, yu^(-1)}, yv] + 2*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yv] - G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] + G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1, 1}, yu] + G[{0}, yv]*G[{0, 1, 1}, yu] + 
     G[{1}, yu]*G[{0, 1, 1}, yu] - G[{1}, yv]*G[{0, 1, 1}, yu] - 
     G[{1}, yw]*G[{0, 1, 1}, yu] + G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     G[{0}, yu]*G[{0, 1, 1}, yv] - G[{0}, yv]*G[{0, 1, 1}, yv] - 
     G[{1}, yu]*G[{0, 1, 1}, yv] + G[{1}, yv]*G[{0, 1, 1}, yv] - 
     G[{1}, yw]*G[{0, 1, 1}, yv] + G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     G[{0}, yu]*G[{0, 1, 1}, yw] + G[{0}, yv]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1}, yw] - G[{1}, yu]*G[{0, 1, 1}, yw] - 
     G[{1}, yv]*G[{0, 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + G[{0}, yu]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1, yu^(-1)}, yw] + G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1, yv^(-1)}, yw] + G[{0}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{0, yu^(-1), 1}, yv] + 
     G[{0}, yv]*G[{0, yu^(-1), 1}, yv] + G[{1}, yu]*G[{0, yu^(-1), 1}, yv] - 
     G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + G[{1}, yw]*G[{0, yu^(-1), 1}, yv] - 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
       yw] - G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, 
       yw] - G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{0}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 3*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 3*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1, 1, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1, 1, yu^(-1)}, yw] + 3*G[{0}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - G[{0}, yu]*G[{1, 1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1, 1, yv^(-1)}, yw] + 3*G[{0}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] - G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, 
       yw] + G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, 0, 0, 1}, yu] + 3*G[{0, 0, 0, 1}, yv] - 
     3*G[{0, 0, 0, yu^(-1)}, yv] + G[{0, 0, 1, 1}, yu] + 
     G[{0, 0, 1, 1}, yv] + 2*G[{0, 0, 1, 1}, yw] + 
     2*G[{0, 0, 1, yu^(-1)}, yv] - 2*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     G[{0, 0, yu^(-1), 1}, yv] - 2*G[{0, 0, yu^(-1), 1}, yw] - 
     2*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 2*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1}, yw] - 2*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 1, 0, yu^(-1)}, yv] - G[{0, 1, 0, yu^(-1)}, yw] - 
     G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 1}, yw] + G[{0, 1, 1, yu^(-1)}, yw] + 
     G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{0, 1, yu^(-1), 1}, yw] - 
     2*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 2*G[{0, 1, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0, 1, yv^(-1), 1}, yw] - 
     2*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 2*G[{0, 1, yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0, 1, 1/(yu*yv), 1}, yw] + G[{0, 1, 1/(yu*yv), yu^(-1)}, 
      yw] + G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - G[{0, yu^(-1), 0, 1/(yu*yv)}, 
      yw] - G[{0, yu^(-1), 1, yu^(-1)}, yw] - G[{0, yu^(-1), 1, yv^(-1)}, 
      yw] - 2*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - G[{0, yv^(-1), 0, 1/(yu*yv)}, 
      yw] - G[{0, yv^(-1), 1, yu^(-1)}, yw] - G[{0, yv^(-1), 1, yv^(-1)}, 
      yw] - 2*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1}, yw] + G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv), yu^(-1), 1}, 
       yw] + 2*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - G[{1, 1, 1, yu^(-1)}, 
      yw] - G[{1, 1, 1, yv^(-1)}, yw] + 6*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 2*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     3*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0}, yu]*Zeta[3] + 
     G[{0}, yv]*Zeta[3] + 2*G[{1}, yw]*Zeta[3] - 2*G[{1/(yu*yv)}, yw]*Zeta[3]
 
Omega2vwuRegI = (7*Pi^4)/120 + (Pi^2*G[{0}, yv]^2)/12 + 
     (Pi^2*G[{0}, yv]*G[{0}, yw])/6 + (Pi^2*G[{0}, yw]^2)/12 + 
     (G[{0}, yv]^2*G[{0}, yw]^2)/4 - (Pi^2*G[{0}, yu]*G[{1}, yu])/6 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu])/6 + (Pi^2*G[{0}, yw]*G[{1}, yu])/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu] + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu])/2 + (Pi^2*G[{1}, yu]^2)/6 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2)/2 + (G[{0}, yv]^2*G[{1}, yu]^2)/4 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2)/2 + G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu]^2 + (G[{0}, yw]^2*G[{1}, yu]^2)/4 - 
     (G[{0}, yu]*G[{1}, yu]^3)/3 + (G[{0}, yv]*G[{1}, yu]^3)/2 + 
     (G[{0}, yw]*G[{1}, yu]^3)/2 + G[{1}, yu]^4/4 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv])/2 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1}, yv] + (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv] - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv])/2 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv])/2 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv])/2 - (Pi^2*G[{1}, yv]^2)/12 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2)/2 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2)/2 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2)/2 - (G[{1}, yu]^2*G[{1}, yv]^2)/2 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1}, yw] - (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw])/2 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw])/2 + (Pi^2*G[{1}, yv]*G[{1}, yw])/
      6 + G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw] + G[{0}, yv]*G[{1}, yu]*
      G[{1}, yv]*G[{1}, yw] + G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw] + 
     G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw] - (Pi^2*G[{1}, yw]^2)/12 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2)/2 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2)/2 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/2 - (G[{1}, yu]^2*G[{1}, yw]^2)/2 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv])/6 - G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv] - (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2 + G[{0}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv]^2 - G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/2 - (2*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/
      3 + (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw] - (G[{0}, yv]^2*G[{0}, yw]*
       G[{1/(yu*yv)}, yw])/2 - (G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 - (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1/(yu*yv)}, yw] - (G[{0}, yv]^2*G[{1}, yu]*
       G[{1/(yu*yv)}, yw])/2 + G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw] - (G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw] - 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/2 - 
     G[{1}, yu]^3*G[{1/(yu*yv)}, yw] - (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/
      6 - G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] + G[{1}, yu]*G[{1}, yv]^2*
      G[{1/(yu*yv)}, yw] - (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + G[{1}, yu]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]^2)/6 - (G[{0}, yu]*G[{0}, yv]*
       G[{1/(yu*yv)}, yw]^2)/2 - (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 - G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 + (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 - (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 + (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^3)/6 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/
      6 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/6 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/
      6 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + (Pi^2*G[{0, 1}, yu])/6 + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yu] + G[{0}, yu]*G[{1}, yu]*
      G[{0, 1}, yu] + G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu] - (G[{1}, yv]^2*G[{0, 1}, yu])/2 - 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yu] + G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     (G[{1}, yw]^2*G[{0, 1}, yu])/2 + G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] - G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + G[{0, 1}, yu]^2/2 + 
     (Pi^2*G[{0, 1}, yv])/6 + (G[{0}, yv]^2*G[{0, 1}, yv])/2 - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yv] + (G[{0}, yw]^2*G[{0, 1}, yv])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{0, 1}, yv] - (G[{1}, yv]^2*G[{0, 1}, yv])/2 + 
     G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] - (G[{1}, yw]^2*G[{0, 1}, yv])/2 + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/2 - G[{0, 1}, yu]*G[{0, 1}, yv] + 
     (Pi^2*G[{0, 1}, yw])/6 + (G[{0}, yv]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yw] + (G[{0}, yw]^2*G[{0, 1}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{0, 1}, yw] - G[{0}, yv]*G[{1}, yv]*
      G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] + 
     (G[{1}, yv]^2*G[{0, 1}, yw])/2 - (G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 - G[{0, 1}, yu]*G[{0, 1}, yw] - 
     (Pi^2*G[{0, yu^(-1)}, yv])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1)}, yv] - (G[{0}, yv]^2*G[{0, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1)}, yv] - (G[{0}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1)}, yv] + 
     (G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 - G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + (G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     (G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - (Pi^2*G[{0, yu^(-1)}, yw])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{0, yu^(-1)}, yw])/2 - G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, yu^(-1)}, yw])/2 - G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] - G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] - (3*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + (G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - (Pi^2*G[{0, yv^(-1)}, yw])/3 - 
     (G[{0}, yv]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yw]^2*G[{0, yv^(-1)}, yw])/2 - G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu]^2*G[{0, yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     (G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + (G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0, yv^(-1)}, yw]^2/2 + 
     (Pi^2*G[{0, 1/(yu*yv)}, yw])/3 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv)}, yw] + (G[{0}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]^2/2 + 
     (Pi^2*G[{1, yu^(-1)}, yv])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{1, yu^(-1)}, yv] + (G[{0}, yv]^2*G[{1, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1)}, yv] - G[{0}, yv]*G[{0}, yw]*
      G[{1, yu^(-1)}, yv] + (G[{0}, yw]^2*G[{1, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1)}, yv] - G[{0}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yv] - (G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/2 + 
     G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv] - G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1)}, yv] - G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/2 - 
     G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yv] + G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1, yu^(-1)}, yv]^2/2 + (Pi^2*G[{1, yu^(-1)}, yw])/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1, yu^(-1)}, yw])/2 + G[{0}, yu]*G[{0}, yw]*
      G[{1, yu^(-1)}, yw] - G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/2 + G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1)}, yw] + G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, yu^(-1)}, yw] + (3*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - G[{1}, yv]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] - (G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + G[{1, yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yw] + G[{1, yu^(-1)}, yw]^2/2 - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{1, 1/(yu*yv)}, yw] + (G[{0}, yv]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{0}, yw]*
      G[{1, 1/(yu*yv)}, yw] + (G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv)}, yw] - (G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1, 1/(yu*yv)}, yw]^2/2 - (Pi^2*G[{yu^(-1), 1/(yu*yv)}, yw])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1), 1/(yu*yv)}, yw]^2/2 - 
     (2*Pi^2*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{0, 0, 1}, yu] + 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{0}, yv]*G[{0, 0, 1}, yv] + 2*G[{0}, yw]*G[{0, 0, 1}, yv] + 
     G[{1}, yv]*G[{0, 0, 1}, yv] - G[{1}, yw]*G[{0, 0, 1}, yv] - 
     G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 2*G[{0}, yv]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1}, yw] - 2*G[{1}, yv]*G[{0, 0, 1}, yw] + 
     G[{1}, yw]*G[{0, 0, 1}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 2*G[{0}, yu]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] + G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw] + 2*G[{1}, yv]*
      G[{0, 0, yv^(-1)}, yw] - G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu]*G[{0, 1, 1}, yu] + G[{0}, yv]*G[{0, 1, 1}, yu] + 
     G[{0}, yw]*G[{0, 1, 1}, yu] - G[{0}, yv]*G[{0, 1, 1}, yv] + 
     G[{0}, yw]*G[{0, 1, 1}, yv] + G[{1}, yv]*G[{0, 1, 1}, yv] - 
     G[{1}, yw]*G[{0, 1, 1}, yv] + G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     G[{0}, yv]*G[{0, 1, 1}, yw] - G[{0}, yw]*G[{0, 1, 1}, yw] - 
     G[{1}, yv]*G[{0, 1, 1}, yw] + G[{1}, yw]*G[{0, 1, 1}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - G[{0}, yu]*G[{0, 1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, 1, yu^(-1)}, yv] + G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, 1, yu^(-1)}, yw] + G[{0}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, 
       yw] + G[{0}, yu]*G[{0, yu^(-1), 1}, yv] - 
     G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + G[{1}, yw]*G[{0, yu^(-1), 1}, yv] - 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     G[{0}, yu]*G[{0, yu^(-1), 1}, yw] + G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, 
       yw] + G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yv]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + G[{1}, yv]*G[{0, yv^(-1), 1}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, 
       yw] - G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - G[{0}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1, 1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1, 1, yu^(-1)}, yv] + G[{0}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] - 3*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + G[{0}, yu]*G[{1, 1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1, 1, yu^(-1)}, yw] - G[{0}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1, 1, 1/(yu*yv)}, yw] - 3*G[{0}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, 
       yw] + G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, 
       yw] + G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, 0, 0, 1}, yv] + 3*G[{0, 0, 0, 1}, yw] - 
     3*G[{0, 0, 0, yu^(-1)}, yv] - 3*G[{0, 0, 0, yu^(-1)}, yw] - 
     3*G[{0, 0, 0, yv^(-1)}, yw] + 3*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 1, 1}, yu] + G[{0, 0, 1, 1}, yv] + G[{0, 0, 1, 1}, yw] + 
     2*G[{0, 0, 1, yu^(-1)}, yv] + 2*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0, 0, 1, yv^(-1)}, yw] - G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     G[{0, 0, yu^(-1), 1}, yv] + G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 4*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), yv^(-1)}, yw] + G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 0, yv^(-1), 1}, yw] - 2*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), yv^(-1)}, yw] - G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, 
      yw] + G[{0, 1, 0, yv^(-1)}, yw] - G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 1}, yu] + G[{0, 1, 1, yu^(-1)}, yv] + 
     G[{0, 1, 1, yu^(-1)}, yw] - G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 2*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + G[{0, 1, 1/(yu*yv), yu^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{0, yu^(-1), 0, yv^(-1)}, 
      yw] + G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{0, yu^(-1), 1, 1}, yw] - G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     G[{0, yu^(-1), 1, yu^(-1)}, yw] + G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - G[{0, yv^(-1), 1, yu^(-1)}, 
      yw] + G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1}, yw] + G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, 1, 1, yu^(-1)}, yv] - 3*G[{1, 1, 1, yu^(-1)}, yw] + 
     3*G[{1, 1, 1, 1/(yu*yv)}, yw] - G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, 
      yw] - 2*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*Zeta[3] + G[{0}, yw]*Zeta[3] + 2*G[{1}, yu]*Zeta[3] - 
     2*G[{1/(yu*yv)}, yw]*Zeta[3]
 
Omega2wuvRegI = (7*Pi^4)/120 + (Pi^2*G[{0}, yu]^2)/12 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw])/6 + (Pi^2*G[{0}, yw]^2)/12 + 
     (G[{0}, yu]^2*G[{0}, yw]^2)/4 + (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu])/2 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu])/2 - (Pi^2*G[{1}, yu]^2)/12 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2)/2 + (Pi^2*G[{0}, yu]*G[{1}, yv])/
      6 - (Pi^2*G[{0}, yv]*G[{1}, yv])/6 + (Pi^2*G[{0}, yw]*G[{1}, yv])/6 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yv] + (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yv])/2 + 
     (Pi^2*G[{1}, yu]*G[{1}, yv])/6 + G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv] - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv] - G[{0}, yu]*G[{1}, yu]^2*
      G[{1}, yv] + (Pi^2*G[{1}, yv]^2)/6 + (G[{0}, yu]^2*G[{1}, yv]^2)/4 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2)/2 + G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]^2 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2)/2 + 
     (G[{0}, yw]^2*G[{1}, yv]^2)/4 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2)/2 - 
     (G[{1}, yu]^2*G[{1}, yv]^2)/4 + (G[{0}, yu]*G[{1}, yv]^3)/2 - 
     (G[{0}, yv]*G[{1}, yv]^3)/3 + (G[{0}, yw]*G[{1}, yv]^3)/2 + 
     (G[{1}, yu]*G[{1}, yv]^3)/6 + G[{1}, yv]^4/4 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw])/2 + (Pi^2*G[{1}, yu]*G[{1}, yw])/
      6 + G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw] - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{1}, yw] - G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw])/2 + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{1}, yw] - G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw] - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/2 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw])/2 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/2 - (Pi^2*G[{1}, yw]^2)/12 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2)/2 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2)/2 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/2 - (G[{1}, yv]^2*G[{1}, yw]^2)/2 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv])/6 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2 + G[{0}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv]^2 - G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/2 - (2*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/
      3 - (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/6 - G[{0}, yu]^2*G[{1}, yu]*
      G[{1/(yu*yv)}, yw] + G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] - 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     G[{1}, yv]^3*G[{1/(yu*yv)}, yw] - (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      6 + G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] - G[{1}, yu]^2*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + G[{1}, yv]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]^2)/6 - (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 - (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 - 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 - G[{0}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^3)/6 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/
      6 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/
      6 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/6 + (Pi^2*G[{0, 1}, yu])/6 + 
     (G[{0}, yu]^2*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{0}, yw]*G[{0, 1}, yu] + 
     (G[{0}, yw]^2*G[{0, 1}, yu])/2 - (G[{1}, yu]^2*G[{0, 1}, yu])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{0, 1}, yu] - G[{0}, yv]*G[{1}, yv]*
      G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu] + 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] + (G[{1}, yv]^2*G[{0, 1}, yu])/2 + 
     G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] - G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yu] - (G[{1}, yw]^2*G[{0, 1}, yu])/2 + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/2 + (Pi^2*G[{0, 1}, yv])/6 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yv]*
      G[{0, 1}, yv] + G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1}, yv] + G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yv] + G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     (G[{1}, yw]^2*G[{0, 1}, yv])/2 + G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv] - G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0, 1}, yu]*G[{0, 1}, yv] + G[{0, 1}, yv]^2/2 + 
     (Pi^2*G[{0, 1}, yw])/6 + (G[{0}, yu]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1}, yw] + (G[{0}, yw]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yu]*
      G[{0, 1}, yw] + (G[{1}, yu]^2*G[{0, 1}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw] + G[{1}, yu]*G[{1}, yv]*
      G[{0, 1}, yw] - (G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 - G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + (G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - (Pi^2*G[{0, yu^(-1)}, yw])/3 - 
     (G[{0}, yu]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{0}, yw]^2*G[{0, yu^(-1)}, yw])/2 + G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw] - 
     (G[{1}, yu]^2*G[{0, yu^(-1)}, yw])/2 - G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + (G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/
      2 + G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0, yu^(-1)}, yw]^2/2 - (Pi^2*G[{0, yv^(-1)}, yw])/6 - 
     (G[{0}, yu]^2*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1)}, yw] + G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/2 - G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     (G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + (G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] + (Pi^2*G[{0, 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv)}, yw])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/2 + G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]^2/2 - 
     (Pi^2*G[{1, yu^(-1)}, yv])/6 - (G[{0}, yu]^2*G[{1, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1)}, yv] + G[{0}, yu]*G[{0}, yw]*
      G[{1, yu^(-1)}, yv] + G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{1, yu^(-1)}, yv])/2 + G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1)}, yv] + (G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/2 - 
     G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yv] - G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yv] - G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1)}, yv] + G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/2 + 
     G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yv] + G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + G[{1, yu^(-1)}, yv]^2/2 - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     (Pi^2*G[{1, yv^(-1)}, yw])/6 + (G[{0}, yu]^2*G[{1, yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1)}, yw] - G[{0}, yu]*G[{0}, yw]*
      G[{1, yv^(-1)}, yw] + G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/2 + G[{0}, yv]*G[{1}, yv]*
      G[{1, yv^(-1)}, yw] + G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1)}, yw] - (G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + G[{0, yu^(-1)}, yv]*
      G[{1, yv^(-1)}, yw] - G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{1, yv^(-1)}, yw]^2/2 + (Pi^2*G[{1, 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{1, 1/(yu*yv)}, yw])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - G[{0}, yv]*G[{1}, yu]*
      G[{1, 1/(yu*yv)}, yw] - (G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + G[{1}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - G[{1, 1/(yu*yv)}, yw]^2/2 - 
     (2*Pi^2*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1), 1/(yu*yv)}, yw]^2/2 - 
     2*G[{0}, yu]*G[{0, 0, 1}, yu] + 2*G[{0}, yw]*G[{0, 0, 1}, yu] + 
     G[{1}, yu]*G[{0, 0, 1}, yu] + G[{1}, yv]*G[{0, 0, 1}, yu] - 
     G[{1}, yw]*G[{0, 0, 1}, yu] - G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yv]*G[{0, 0, 1}, yv] + 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{0}, yu]*G[{0, 0, 1}, yw] - 2*G[{0}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yu]*G[{0, 0, 1}, yw] + G[{1}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, 
       yw] - G[{0}, yu]*G[{0, 1, 1}, yu] + G[{0}, yw]*G[{0, 1, 1}, yu] + 
     G[{1}, yu]*G[{0, 1, 1}, yu] - G[{1}, yv]*G[{0, 1, 1}, yu] - 
     G[{1}, yw]*G[{0, 1, 1}, yu] + G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     G[{0}, yu]*G[{0, 1, 1}, yv] - 2*G[{0}, yv]*G[{0, 1, 1}, yv] + 
     G[{0}, yw]*G[{0, 1, 1}, yv] - G[{1}, yu]*G[{0, 1, 1}, yv] + 
     G[{0}, yu]*G[{0, 1, 1}, yw] - G[{0}, yw]*G[{0, 1, 1}, yw] - 
     G[{1}, yu]*G[{0, 1, 1}, yw] + G[{1}, yw]*G[{0, 1, 1}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + G[{0}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 1, yu^(-1)}, yv] - G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1, yv^(-1)}, yw] - G[{0}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, 
       yw] + G[{0}, yv]*G[{0, yu^(-1), 1}, yv] + 
     G[{1}, yu]*G[{0, yu^(-1), 1}, yv] - G[{0}, yu]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + G[{1}, yu]*G[{0, yu^(-1), 1}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yv]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, 
       yw] - 2*G[{0}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, 
       yw] + G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - G[{0}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1, 1, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1, 1, yu^(-1)}, yv] + 2*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yv] + G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1, 1, yv^(-1)}, yw] + G[{0}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1, 1, yv^(-1)}, yw] + 2*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     3*G[{0}, yu]*G[{1, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 3*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, 0, 0, 1}, yu] + 3*G[{0, 0, 0, 1}, yw] - 
     3*G[{0, 0, 0, yu^(-1)}, yw] - 3*G[{0, 0, 0, yv^(-1)}, yw] + 
     3*G[{0, 0, 0, 1/(yu*yv)}, yw] + G[{0, 0, 1, 1}, yu] + 
     2*G[{0, 0, 1, 1}, yv] + G[{0, 0, 1, 1}, yw] - 
     2*G[{0, 0, 1, yu^(-1)}, yv] + 2*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0, 0, 1, yv^(-1)}, yw] - G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 0, yu^(-1), 1}, yv] + G[{0, 0, yu^(-1), 1}, yw] - 
     2*G[{0, 0, yu^(-1), yu^(-1)}, yw] - G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 0, yv^(-1), 1}, yw] - 4*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 3*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, 
      yw] - G[{0, 1, 0, yu^(-1)}, yv] + G[{0, 1, 0, yu^(-1)}, yw] - 
     G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{0, 1, 1, 1}, yv] + 
     G[{0, 1, 1, yu^(-1)}, yv] + G[{0, 1, 1, yv^(-1)}, yw] - 
     G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1, yu^(-1), 1}, yv] - 
     2*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 2*G[{0, 1, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + G[{0, 1, 1/(yu*yv), yv^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0, yu^(-1), 0, yv^(-1)}, 
      yw] - G[{0, yu^(-1), 1, yu^(-1)}, yv] - G[{0, yu^(-1), 1, yv^(-1)}, 
      yw] + G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1), 1, 1}, yw] - 
     G[{0, yv^(-1), 1, yv^(-1)}, yw] + G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1}, yw] + G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - G[{1, 1, 1, yu^(-1)}, 
      yv] - 3*G[{1, 1, 1, yv^(-1)}, yw] + 3*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), yu^(-1)}, yv] - G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, 
      yw] - 4*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     2*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0}, yu]*Zeta[3] + 
     G[{0}, yw]*Zeta[3] + 2*G[{1}, yv]*Zeta[3] - 2*G[{1/(yu*yv)}, yw]*Zeta[3]
 
F1uvwRegI = (17*Pi^4)/360 + (Pi^2*G[{0}, yv]*G[{0}, yw])/6 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu])/6 - (Pi^2*G[{0}, yv]*G[{1}, yu])/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu])/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu] + (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv])/6 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv])/6 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv])/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv] + (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yw] - (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw] - (Pi^2*G[{0, 1}, yu])/6 + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yu] + G[{0}, yu]*G[{1}, yu]*
      G[{0, 1}, yu] - G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu] - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] + G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] + G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - G[{0, 1}, yu]^2/2 + 
     (Pi^2*G[{0, 1}, yv])/6 + G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1}, yu]*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yu]*
      G[{0, 1}, yv] + G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv] + 
     G[{1}, yu]^2*G[{0, 1}, yv] + G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv] + G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0, 1}, yu]*G[{0, 1}, yv] - G[{0, 1}, yv]^2/2 + 
     (Pi^2*G[{0, 1}, yw])/6 + G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{0, 1}, yw] + G[{0}, yv]*G[{1}, yu]*
      G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw] + 
     G[{1}, yu]^2*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] + G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] - G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] - G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0, 1}, yu]*G[{0, 1}, yw] - G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{0, 1}, yw]^2/2 + (Pi^2*G[{0, yu^(-1)}, yv])/6 - 
     G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1)}, yv] - G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]^2*G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + G[{0, yu^(-1)}, yv]^2/2 + 
     (Pi^2*G[{0, yu^(-1)}, yw])/6 - G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] - G[{1}, yu]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yw] + G[{0, yu^(-1)}, yw]^2/2 - 
     (Pi^2*G[{0, yv^(-1)}, yw])/6 - G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] - G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]^2/2 - (Pi^2*G[{0, 1/(yu*yv)}, yw])/6 + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]^2/2 - 
     2*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yv] + 2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 0, 1}, yu] + 2*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] - 2*G[{0}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yu]*G[{0, 0, 1}, yv] + 2*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] - 2*G[{0}, yv]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yu]*G[{0, 0, 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 0, yu^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, 
       yw] + 2*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1, 1}, yu] + 2*G[{0}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yu]*G[{0, 1, 1}, yu] + 2*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{0}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yu]*G[{0, 1, 1}, yv] + 2*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] + 2*G[{0}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 1}, yw] + 2*G[{1}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yu]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
       yw] + 2*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 1, 1}, yu] - 2*G[{0, 0, 1, 1}, yv] - 2*G[{0, 0, 1, 1}, yw] + 
     2*G[{0, 0, 1, yu^(-1)}, yv] + 2*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0, 0, 1, yv^(-1)}, yw] - 2*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yu^(-1), 1}, yv] + 2*G[{0, 0, yu^(-1), 1}, yw] + 
     2*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 2*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 2*G[{0, 0, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 2*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1, 0, yu^(-1)}, yv] + 
     2*G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1, 1}, yu] - 4*G[{0, 1, 1, yu^(-1)}, yv] - 
     4*G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1, yu^(-1), 1}, yv] - 
     2*G[{0, 1, yu^(-1), 1}, yw] + 2*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 1}, yw] + 2*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 2*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     2*G[{0, yu^(-1), yu^(-1), 1}, yw] + 4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, 
       yv] + 4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 2*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 1}, yw] - 4*G[{0, yv^(-1), yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*Zeta[3] - 
     2*G[{0}, yw]*Zeta[3]
 
F1vwuRegI = (17*Pi^4)/360 + (Pi^2*G[{0}, yu]*G[{0}, yw])/6 - 
     (Pi^2*G[{0}, yu]*G[{1}, yv])/6 - (Pi^2*G[{0}, yv]*G[{1}, yv])/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv])/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv] + (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv])/6 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv])/6 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv])/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv] + (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{yv^(-1)}, yw] - (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw] + (Pi^2*G[{0, 1}, yu])/6 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1}, yu] + G[{0}, yu]*G[{1}, yv]*
      G[{0, 1}, yu] - G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu] - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] + G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - G[{0, 1}, yu]^2/2 - 
     (Pi^2*G[{0, 1}, yv])/6 + G[{0}, yu]*G[{0}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1}, yv]*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yv]*
      G[{0, 1}, yv] - G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv] + G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] + G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0, 1}, yu]*G[{0, 1}, yv] - G[{0, 1}, yv]^2/2 + 
     (Pi^2*G[{0, 1}, yw])/6 + G[{0}, yu]*G[{0}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1}, yw] + G[{0}, yu]*G[{1}, yv]*
      G[{0, 1}, yw] - G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] + G[{1}, yv]^2*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] - G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] - G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0, 1}, yu]*G[{0, 1}, yw] + G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{0, 1}, yw]^2/2 + (Pi^2*G[{0, yu^(-1)}, yv])/6 - 
     G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1)}, yv] - G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - G[{0, yu^(-1)}, yv]^2/2 - 
     (Pi^2*G[{0, yu^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yw] - G[{0, yu^(-1)}, yw]^2/2 + 
     (Pi^2*G[{0, yv^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] + G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0, yv^(-1)}, yw]^2/2 - (Pi^2*G[{0, 1/(yu*yv)}, yw])/6 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]^2/2 + 2*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 2*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yv] - 2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 0, 1}, yu] - 2*G[{1}, yv]*G[{0, 0, 1}, yu] + 
     2*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu] + 2*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yu] - 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yv]*G[{0, 0, 1}, yv] + 2*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] - 2*G[{0}, yu]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yv]*G[{0, 0, 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] - 2*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 0, yu^(-1)}, yw] + 2*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, 
       yw] + 2*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1, 1}, yu] - 2*G[{1}, yv]*G[{0, 1, 1}, yu] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yu] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yu]*G[{0, 1, 1}, yv] + 2*G[{0}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yu]*G[{0, 1, 1}, yv] - 2*G[{1}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yw]*G[{0, 1, 1}, yw] + 2*G[{1}, yu]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 2*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, 
       yv] + 2*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 0, 1, 1}, yu] + 
     2*G[{0, 0, 1, 1}, yv] - 2*G[{0, 0, 1, 1}, yw] - 
     2*G[{0, 0, 1, yu^(-1)}, yv] + 2*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0, 0, 1, yv^(-1)}, yw] - 2*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 0, yu^(-1), 1}, yv] + 2*G[{0, 0, yu^(-1), 1}, yw] + 
     2*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 2*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 2*G[{0, 0, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0, 0, yv^(-1), 1}, yw] - 
     2*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 2*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0, 1, 0, 1/(yu*yv)}, yw] + 6*G[{0, 1, 1, 1}, yv] - 
     4*G[{0, 1, 1, yu^(-1)}, yv] - 2*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yu^(-1), 1}, yv] - 2*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 2*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 1}, yw] + 2*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{0, yu^(-1), 0, 1/(yu*yv)}, 
       yw] - 2*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 2*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1}, yv] + 2*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 1}, yw] + 4*G[{0, yv^(-1), yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*Zeta[3] - 
     2*G[{0}, yw]*Zeta[3]
 
F1wuvRegI = (17*Pi^4)/360 + (Pi^2*G[{0}, yu]*G[{0}, yv])/6 - 
     (Pi^2*G[{0}, yu]*G[{1}, yw])/6 - (Pi^2*G[{0}, yv]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw])/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw] + (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yw] + (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{yv^(-1)}, yw] - (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw] + (Pi^2*G[{0, 1}, yu])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1}, yu] + G[{0}, yu]*G[{1}, yw]*
      G[{0, 1}, yu] - G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu] - G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] + G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - G[{0, 1}, yu]^2/2 + 
     (Pi^2*G[{0, 1}, yv])/6 + G[{0}, yu]*G[{0}, yv]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1}, yv] - G[{0}, yu]*G[{1}, yw]*
      G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv] + G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] - G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0, 1}, yu]*G[{0, 1}, yv] - G[{0, 1}, yv]^2/2 - 
     (Pi^2*G[{0, 1}, yw])/6 + G[{0}, yu]*G[{0}, yv]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1}, yw] - G[{0}, yv]*G[{1}, yw]*
      G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] - G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] - G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0, 1}, yu]*G[{0, 1}, yw] + G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{0, 1}, yw]^2/2 - (Pi^2*G[{0, yu^(-1)}, yv])/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] - G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - G[{0, yu^(-1)}, yv]^2/2 + 
     (Pi^2*G[{0, yu^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1)}, yw] - G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yw] - G[{0, yu^(-1)}, yw]^2/2 + 
     (Pi^2*G[{0, yv^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1)}, yw] + G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] - G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]^2/2 - (Pi^2*G[{0, 1/(yu*yv)}, yw])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]^2/2 - 2*G[{0}, yv]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yw]*G[{0, 0, 1}, yu] + 2*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] - 2*G[{0}, yu]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yw]*G[{0, 0, 1}, yv] + 2*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] - 2*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yu]*G[{0, 0, yu^(-1)}, yv] + 2*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1, 1}, yu] - 2*G[{1}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yu] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yv]*G[{0, 1, 1}, yv] + 2*G[{1}, yu]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yw]*G[{0, 1, 1}, yv] + 2*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] + 2*G[{0}, yu]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv]*G[{0, 1, 1}, yw] + 2*G[{1}, yu]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 1}, yw] - 2*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 2*G[{0}, yu]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1}, yv] - 2*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, 
       yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, 1, 1}, yu] - 2*G[{0, 0, 1, 1}, yv] + 2*G[{0, 0, 1, 1}, yw] + 
     2*G[{0, 0, 1, yu^(-1)}, yv] - 2*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yu^(-1), 1}, yv] - 2*G[{0, 0, yu^(-1), 1}, yw] - 
     2*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 2*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 2*G[{0, 0, yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 2*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0, 1, 1, 1}, yw] - 
     2*G[{0, 1, 1, yu^(-1)}, yv] - 4*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yu^(-1), 1}, yv] - 2*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 2*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 1}, yw] + 2*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1}, yw] + 2*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 2*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     2*G[{0, yu^(-1), yu^(-1), 1}, yw] - 4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, 
       yv] + 4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1}, yw] + 2*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1}, yw] + 4*G[{0, yv^(-1), yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*Zeta[3] - 
     2*G[{0}, yv]*Zeta[3]
 
QepuvwRegI = (17*Pi^4*G[{0}, yv])/11520 + (Pi^2*G[{0}, yv]^3)/256 + 
     (Pi^2*G[{0}, yv]^2*G[{0}, yw])/96 + (Pi^2*G[{0}, yv]*G[{0}, yw]^2)/256 + 
     (3*G[{0}, yv]^3*G[{0}, yw]^2)/256 + (17*Pi^4*G[{1}, yu])/11520 + 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/192 + (5*Pi^2*G[{0}, yv]^2*G[{1}, yu])/
      768 + (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu])/32 + 
     (3*G[{0}, yv]^3*G[{0}, yw]*G[{1}, yu])/128 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu])/256 + 
     (9*G[{0}, yv]^2*G[{0}, yw]^2*G[{1}, yu])/256 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/192 + (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/
      192 + (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]^2)/64 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]^2)/64 + 
     (3*G[{0}, yv]^3*G[{1}, yu]^2)/256 + (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/384 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]^2)/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2)/8 + 
     (9*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu]^2)/128 + 
     (9*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu]^2)/256 + (Pi^2*G[{1}, yu]^3)/384 + 
     (G[{0}, yu]^2*G[{1}, yu]^3)/96 - (7*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^3)/
      96 + (9*G[{0}, yv]^2*G[{1}, yu]^3)/256 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^3)/24 + 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^3)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yu]^3)/256 - (11*G[{0}, yu]*G[{1}, yu]^4)/384 + 
     (9*G[{0}, yv]*G[{1}, yu]^4)/256 + (3*G[{0}, yw]*G[{1}, yu]^4)/128 + 
     (3*G[{1}, yu]^5)/256 - (17*Pi^4*G[{1}, yv])/11520 - 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/768 - 
     (5*Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv])/384 + 
     (3*G[{0}, yv]^3*G[{0}, yw]*G[{1}, yv])/128 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yv])/256 - 
     (9*G[{0}, yv]^2*G[{0}, yw]^2*G[{1}, yv])/256 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/192 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv])/32 + 
     (3*G[{0}, yv]^3*G[{1}, yu]*G[{1}, yv])/128 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/16 - 
     (9*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv])/128 - 
     (Pi^2*G[{1}, yu]^2*G[{1}, yv])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv])/32 + 
     (9*G[{0}, yv]^2*G[{1}, yu]^2*G[{1}, yv])/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv])/8 - 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yu]^2*G[{1}, yv])/256 + 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yv])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]^3*G[{1}, yv])/64 - (3*G[{1}, yu]^4*G[{1}, yv])/
      256 - (3*Pi^2*G[{0}, yv]*G[{1}, yv]^2)/512 + 
     (3*G[{0}, yv]^3*G[{1}, yv]^2)/256 + (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/384 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]^2)/128 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]^2)/256 + 
     (Pi^2*G[{1}, yu]*G[{1}, yv]^2)/512 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]^2)/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2)/32 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]^2)/256 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2)/32 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]^2)/256 + 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]^2)/64 + (Pi^2*G[{1}, yv]^3)/768 - 
     (G[{0}, yv]^2*G[{1}, yv]^3)/256 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^3)/
      384 - (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^3)/96 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^3)/192 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^3)/384 - (G[{1}, yu]^2*G[{1}, yv]^3)/
      768 - (G[{0}, yv]*G[{1}, yv]^4)/768 - (G[{1}, yu]*G[{1}, yv]^4)/768 + 
     (17*Pi^4*G[{1}, yw])/11520 + (Pi^2*G[{0}, yv]^2*G[{1}, yw])/768 + 
     (5*Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw])/384 - 
     (3*G[{0}, yv]^3*G[{0}, yw]*G[{1}, yw])/128 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/256 + 
     (9*G[{0}, yv]^2*G[{0}, yw]^2*G[{1}, yw])/256 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/192 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw])/32 - 
     (3*G[{0}, yv]^3*G[{1}, yu]*G[{1}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/16 + 
     (9*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw])/128 + 
     (Pi^2*G[{1}, yu]^2*G[{1}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw])/32 - 
     (9*G[{0}, yv]^2*G[{1}, yu]^2*G[{1}, yw])/256 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw])/8 + 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu]^2*G[{1}, yw])/256 - 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu]^3*G[{1}, yw])/64 + (3*G[{1}, yu]^4*G[{1}, yw])/
      256 + (3*Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/256 - 
     (3*G[{0}, yv]^3*G[{1}, yv]*G[{1}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/192 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/64 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw])/128 - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/256 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/32 - 
     (Pi^2*G[{1}, yv]^2*G[{1}, yw])/256 + 
     (3*G[{0}, yv]^2*G[{1}, yv]^2*G[{1}, yw])/256 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/128 + 
     (G[{1}, yu]^2*G[{1}, yv]^2*G[{1}, yw])/256 + 
     (G[{0}, yv]*G[{1}, yv]^3*G[{1}, yw])/192 + 
     (G[{1}, yu]*G[{1}, yv]^3*G[{1}, yw])/192 - 
     (11*Pi^2*G[{0}, yv]*G[{1}, yw]^2)/768 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      384 - (5*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]^2)/256 - 
     (5*Pi^2*G[{1}, yu]*G[{1}, yw]^2)/768 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]^2)/64 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2)/32 - 
     (5*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]^2)/128 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]^2)/64 - 
     (11*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]^2)/256 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]^2)/32 - (G[{1}, yu]^3*G[{1}, yw]^2)/
      256 + (Pi^2*G[{1}, yv]*G[{1}, yw]^2)/192 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]^2)/64 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/128 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/128 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]^2)/128 - 
     (5*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]^2)/256 - 
     (5*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]^2)/256 - 
     (5*Pi^2*G[{1}, yw]^3)/768 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^3)/384 + 
     (3*G[{0}, yw]^2*G[{1}, yw]^3)/256 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^3)/96 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^3)/384 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^3)/192 + 
     (11*G[{1}, yu]^2*G[{1}, yw]^3)/768 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^3)/32 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^3)/128 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^3)/128 + 
     (3*G[{1}, yv]^2*G[{1}, yw]^3)/256 + (G[{0}, yw]*G[{1}, yw]^4)/96 + 
     (G[{1}, yu]*G[{1}, yw]^4)/96 + (G[{1}, yv]*G[{1}, yw]^4)/96 - 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/96 - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/768 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/96 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/768 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/4 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/192 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (G[{1}, yv]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (5*Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/768 + 
     (G[{0}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/8 - 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 + 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (17*G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/8 - 
     (13*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 + 
     (19*G[{1}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 - 
     (5*G[{0}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 - 
     (11*G[{0}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 - 
     (G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/32 - 
     (7*G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/128 + 
     (7*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/512 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 + 
     (9*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/4 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (9*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/8 + 
     (35*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/256 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/64 + 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/256 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/64 + 
     (31*G[{1}, yw]^3*G[{yu^(-1)}, yv]^2)/768 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/12 - 
     (25*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/192 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/12 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/64 - 
     (67*G[{1}, yw]^2*G[{yu^(-1)}, yv]^3)/768 + 
     (41*G[{1}, yw]*G[{yu^(-1)}, yv]^4)/768 - (17*Pi^4*G[{1/(yu*yv)}, yw])/
      11520 - (Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/192 - 
     (5*Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]^3*G[{0}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yv]^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]^3*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/192 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/4 - 
     (9*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/32 - 
     (27*G[{0}, yv]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/8 - 
     (27*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/256 + 
     (11*G[{0}, yu]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/96 - 
     (9*G[{0}, yv]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/32 - 
     (15*G[{1}, yu]^4*G[{1/(yu*yv)}, yw])/256 - 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yv]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (15*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/768 + 
     (9*G[{0}, yv]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yv]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (5*Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*Pi^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/768 + 
     (21*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (21*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (33*G[{1}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{1}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (3*G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      64 + (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      4 - (3*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/192 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (9*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (7*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (25*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      4 + (9*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 - (19*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      128 + (5*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 + (11*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      128 - (21*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      128 - (5*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      64 - (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      128 - (7*Pi^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/512 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 - 
     (35*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (31*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/12 + 
     (25*G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/192 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/12 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/64 + 
     (67*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/384 - 
     (41*G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (7*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (7*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (5*G[{1}, yu]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (7*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/384 - (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (17*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (19*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (15*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (3*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (19*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (15*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (11*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (11*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{1}, yw]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (5*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (5*Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (5*Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (13*G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (23*G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (13*G[{1}, yu]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (13*Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 - 
     (11*G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (17*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (23*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (5*Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (15*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (9*G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (7*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yu]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (7*Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/512 + 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (11*G[{1}, yu]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (7*G[{1}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (11*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 + 
     (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (7*Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/384 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (7*G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (7*G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (17*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (31*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (5*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (17*G[{1}, yu]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (13*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (9*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{1}, yv]^3*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (7*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (17*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (9*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (19*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (9*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (15*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (19*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (23*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (5*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (7*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/4 - 
     (13*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (15*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (41*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (13*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (21*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (11*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (11*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (15*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (19*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/8 - (5*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (5*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{0}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/8 + (17*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 + (33*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 - (15*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (15*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 - (11*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{0}, yu]*G[{0}, yv]*
       G[{1/(yu*yv)}, yw]^3)/96 - (G[{0}, yu]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]^3)/48 - (5*G[{0}, yv]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]^3)/384 - (G[{0}, yu]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw]^3)/96 - (5*G[{0}, yv]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw]^3)/384 - (5*G[{0}, yw]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw]^3)/384 - (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/
      384 - (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (13*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/24 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/192 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yu])/32 + 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/96 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yu])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yu])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu])/16 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu])/16 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yu])/32 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu])/32 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/32 + 
     (G[{1}, yv]^3*G[{0, 1}, yu])/96 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
       G[{0, 1}, yu])/16 - (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/32 - 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu])/32 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/32 - 
     (5*G[{1}, yw]^3*G[{0, 1}, yu])/96 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu])/8 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/96 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/4 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{0}, yv]*G[{0, 1}, yu]^2)/16 - (G[{0}, yw]*G[{0, 1}, yu]^2)/32 + 
     (G[{1}, yu]*G[{0, 1}, yu]^2)/32 - (3*G[{1}, yv]*G[{0, 1}, yu]^2)/32 + 
     (3*G[{1}, yw]*G[{0, 1}, yu]^2)/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2)/
      32 + (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/768 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yv])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yv])/64 + 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yv])/768 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yv])/16 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv])/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yv])/16 - 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yv])/64 - 
     (3*G[{1}, yu]^3*G[{0, 1}, yv])/64 + (11*Pi^2*G[{1}, yv]*G[{0, 1}, yv])/
      768 - (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yv])/64 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/8 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/64 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv])/128 + 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv])/128 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yv])/64 + 
     (9*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/128 + 
     (G[{1}, yv]^3*G[{0, 1}, yv])/128 - (11*Pi^2*G[{1}, yw]*G[{0, 1}, yv])/
      768 + (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yv])/64 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/8 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/64 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/128 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/32 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/64 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yv])/128 + 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/128 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv])/64 + 
     (11*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/16 - 
     (11*G[{1}, yw]^3*G[{0, 1}, yv])/384 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/32 + 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/128 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv])/16 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/256 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (9*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/
      16 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/32 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/64 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/64 - 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 - 
     (3*G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/8 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv])/8 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1}, yv]^2)/32 + (G[{0}, yw]*G[{0, 1}, yv]^2)/32 + 
     (7*G[{1}, yv]*G[{0, 1}, yv]^2)/128 - (7*G[{1}, yw]*G[{0, 1}, yv]^2)/
      128 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2)/128 + 
     (7*Pi^2*G[{0}, yv]*G[{0, 1}, yw])/384 + (3*G[{0}, yv]^3*G[{0, 1}, yw])/
      128 - (G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yw])/16 + 
     (7*Pi^2*G[{1}, yu]*G[{0, 1}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw])/16 - 
     (7*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yw])/16 - 
     (5*G[{1}, yu]^3*G[{0, 1}, yw])/128 - (Pi^2*G[{1}, yv]*G[{0, 1}, yw])/
      128 - (5*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw])/16 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw])/64 - 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yw])/128 + 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yw])/128 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (7*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (15*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw])/128 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (11*G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (15*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (5*G[{1}, yw]^3*G[{0, 1}, yw])/128 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/48 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/12 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (5*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (11*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/32 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1}, yw]^2)/32 - (G[{0}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, 1}, yw]^2)/32 + (G[{1}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/96 - 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/768 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0, yu^(-1)}, yv])/32 + 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/96 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yv])/64 - 
     (Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/768 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yv])/4 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv])/16 + 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]^3*G[{0, yu^(-1)}, yv])/64 - 
     (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/128 - 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/64 - 
     (9*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/128 - 
     (G[{1}, yv]^3*G[{0, yu^(-1)}, yv])/128 + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/16 + 
     (11*G[{1}, yw]^3*G[{0, yu^(-1)}, yv])/384 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/32 - 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/256 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      32 + (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/64 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 + (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/32 + (3*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      64 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      32 - (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (9*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      64 - (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/64 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/64 + 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]^2)/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]^2)/32 + 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]^2)/128 - 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yv]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]^2)/128 + 
     (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/48 - 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv]^3*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (7*Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/384 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yu]^3*G[{0, yu^(-1)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/384 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (17*G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/16 - 
     (19*G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/32 - 
     (15*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{1}, yv]^3*G[{0, yu^(-1)}, yw])/32 + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (15*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (11*G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (15*G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yw])/64 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (11*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (11*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (3*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/16 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/16 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (G[{0}, yv]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/8 + (G[{1}, yu]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/8 + (G[{0}, yv]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yw])/32 + (G[{0}, yw]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yw])/16 + (3*G[{1}, yu]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yw])/32 + (3*G[{1}, yv]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yw])/64 + (5*G[{1}, yw]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yw])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yw])/64 + (G[{0}, yu]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, yu^(-1)}, yw])/16 - (3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{0, yu^(-1)}, yw])/32 - (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, yu^(-1)}, yw])/64 - (5*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, yu^(-1)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, yu^(-1)}, yw])/64 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (11*Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/384 - 
     (3*G[{0}, yv]^3*G[{0, yv^(-1)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/96 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (7*Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/8 - 
     (13*G[{0}, yv]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/16 - 
     (17*G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]^3*G[{0, yv^(-1)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/384 + 
     (5*G[{0}, yv]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/8 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/16 + 
     (13*G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/384 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (7*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (11*G[{0}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (15*G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1)}, yw])/64 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (5*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (11*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (3*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/16 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 + (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (G[{0}, yv]*G[{0, 1}, yu]*
       G[{0, yv^(-1)}, yw])/8 + (G[{1}, yv]*G[{0, 1}, yu]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yv]*G[{0, 1}, yv]*
       G[{0, yv^(-1)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yv]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, 1}, yv]*
       G[{0, yv^(-1)}, yw])/32 + (7*G[{1}, yv]*G[{0, 1}, yv]*
       G[{0, yv^(-1)}, yw])/64 - (3*G[{1}, yw]*G[{0, 1}, yv]*
       G[{0, yv^(-1)}, yw])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{0, yv^(-1)}, yw])/64 - (G[{0}, yv]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/8 - (G[{0}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/32 + (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/32 - (7*G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/64 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/64 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/48 + 
     (7*Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]^3*G[{0, 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (7*Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (13*G[{0}, yv]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (17*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw])/128 - 
     (11*Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (17*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (13*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (19*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (15*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (11*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (11*G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (15*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/12 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 + (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yv])/96 + 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/768 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1, yu^(-1)}, yv])/32 - 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/96 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/768 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/4 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/16 - 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]^3*G[{1, yu^(-1)}, yv])/64 + 
     (Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/192 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yv]^3*G[{1, yu^(-1)}, yv])/32 + 
     (5*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (9*G[{0}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (7*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/4 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/32 + 
     (25*G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (19*G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yw]^3*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/4 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/4 - 
     (7*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/16 + 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/768 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (11*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (9*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (9*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/4 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/4 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      64 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/4 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      32 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 + (3*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (13*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/32 - (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 + (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 - (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 + (3*G[{0}, yu]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 + (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 - (G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/16 + (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/32 - (7*G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/64 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (3*G[{0}, yv]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (3*G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (3*G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/32 + (7*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/64 - (3*G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (G[{0}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{1, yu^(-1)}, yv]^2)/8 + 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yv]^2)/32 + 
     (3*G[{1}, yu]*G[{1, yu^(-1)}, yv]^2)/32 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]^2)/8 + 
     (5*G[{1}, yw]*G[{1, yu^(-1)}, yv]^2)/128 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]^2)/128 - 
     (Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yw])/48 + 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv]^3*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (7*Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/16 - 
     (7*G[{0}, yv]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/16 - 
     (5*G[{1}, yu]^3*G[{1, yu^(-1)}, yw])/128 - 
     (7*Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (17*G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/16 + 
     (19*G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/32 + 
     (15*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{1}, yv]^3*G[{1, yu^(-1)}, yw])/32 - 
     (3*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (19*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (11*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (11*G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (11*G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/128 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/128 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/64 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (5*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (19*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (19*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (15*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (5*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (7*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 - 
     (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yu]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/16 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/16 + 
     (13*Pi^2*G[{0}, yv]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yv]^3*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (13*Pi^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 + 
     (13*G[{0}, yv]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/64 + 
     (11*G[{0}, yv]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]^3*G[{1, yv^(-1)}, yw])/128 - 
     (Pi^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/384 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/128 + 
     (13*Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/768 + 
     (9*G[{0}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (7*G[{1}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (9*G[{1}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/128 - 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/8 + 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{yu^(-1)}, yv]^3*G[{1, yv^(-1)}, yw])/64 - 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/256 - 
     (11*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (11*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (9*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (7*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (9*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (5*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (7*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yu]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yv]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]^3*G[{1, 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/192 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]^3*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/16 - 
     (7*Pi^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (15*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/4 + 
     (25*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (27*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw])/192 - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (13*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      8 + (5*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (9*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (13*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (7*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (3*G[{0}, yu]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (5*G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/4 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 - (5*G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*Pi^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (17*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (19*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (15*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (19*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (11*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (5*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yu]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yu]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (7*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (9*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (G[{0}, yu]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (5*G[{1}, yu]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (5*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (7*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (Pi^2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (5*Pi^2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*Pi^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (13*G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (23*G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yu]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (13*Pi^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/384 + 
     (11*G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (17*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (23*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (5*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (9*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (11*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (13*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (19*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (3*G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (19*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (19*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (13*G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (3*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 + (5*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0, 0, 1}, yu])/96 + (G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yu])/
      16 + (G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu])/4 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yu])/8 - 
     (G[{1}, yu]^2*G[{0, 0, 1}, yu])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu])/8 - 
     (G[{1}, yv]^2*G[{0, 0, 1}, yu])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yu])/32 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/4 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/4 - 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yu])/16 - (G[{0, 1}, yv]*G[{0, 0, 1}, yu])/
      16 - (G[{0, 1}, yw]*G[{0, 0, 1}, yu])/16 + 
     (5*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yu])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yu])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/4 - 
     (Pi^2*G[{0, 0, 1}, yv])/64 - (3*G[{0}, yv]^2*G[{0, 0, 1}, yv])/64 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yv])/16 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1}, yv])/128 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yv])/32 + 
     (9*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yv])/64 + 
     (15*G[{1}, yu]^2*G[{0, 0, 1}, yv])/128 + 
     (9*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv])/64 - 
     (15*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yv])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv])/32 - 
     (17*G[{1}, yv]^2*G[{0, 0, 1}, yv])/128 - 
     (9*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv])/64 + 
     (15*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/32 + 
     (17*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv])/64 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yv])/8 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{0, 0, 1}, yv])/32 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yv])/16 - (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yv])/64 - (13*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yv])/64 - (G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yv])/4 + (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yv])/64 - (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yv])/32 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yv])/64 + (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yv])/64 + (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv])/64 + 
     (3*G[{0, 1}, yu]*G[{0, 0, 1}, yv])/16 + (G[{0, 1}, yv]*G[{0, 0, 1}, yv])/
      32 + (G[{0, 1}, yw]*G[{0, 0, 1}, yv])/64 + 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yv])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv])/64 - 
     (13*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv])/64 + 
     (13*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yv])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv])/64 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 + 
     (Pi^2*G[{0, 0, 1}, yw])/96 + (G[{0}, yv]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yu]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, 0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/4 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/4 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/4 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (Pi^2*G[{0, 0, yu^(-1)}, yv])/64 - (G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yv])/
      16 + (3*G[{0}, yu]*G[{0}, yv]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yv])/128 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv])/32 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (15*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/4 - 
     (9*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (15*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/32 + 
     (17*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/4 + 
     (9*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/32 - 
     (17*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (13*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/4 - 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yv])/64 - 
     (3*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv])/32 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (13*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (13*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/96 - (G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yw])/
      16 + (G[{0}, yu]*G[{0}, yv]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/96 + (G[{0}, yv]^2*G[{0, 0, yv^(-1)}, yw])/
      16 + (G[{0}, yv]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (Pi^2*G[{0, 1, 1}, yu])/96 + (G[{0}, yu]^2*G[{0, 1, 1}, yu])/16 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu])/16 + 
     (3*G[{0}, yv]^2*G[{0, 1, 1}, yu])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yu])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yu])/16 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yu])/8 - 
     (G[{1}, yv]^2*G[{0, 1, 1}, yu])/32 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yu])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (5*Pi^2*G[{0, 1, 1}, yv])/256 - (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yv])/
      16 + (3*G[{0}, yw]^2*G[{0, 1, 1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yv])/64 - 
     (5*G[{1}, yu]^2*G[{0, 1, 1}, yv])/128 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yv])/8 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yv])/64 - 
     (13*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/64 - 
     (G[{1}, yv]^2*G[{0, 1, 1}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/8 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv])/64 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/64 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yv])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 - 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/32 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 - 
     (G[{0, 1}, yu]*G[{0, 1, 1}, yv])/16 - (5*G[{0, 1}, yv]*G[{0, 1, 1}, yv])/
      64 + (3*G[{0, 1}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yv])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv])/64 - 
     (11*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yv])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 - 
     (Pi^2*G[{0, 1, 1}, yw])/96 + (G[{0}, yv]^2*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1, 1}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw])/8 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0, 1}, yu]*G[{0, 1, 1}, yw])/16 - (G[{0, 1}, yv]*G[{0, 1, 1}, yw])/
      16 - (G[{0, 1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (5*Pi^2*G[{0, 1, yu^(-1)}, yv])/768 + 
     (G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (3*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (3*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv])/64 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (5*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (13*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/64 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/64 - 
     (G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (13*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/64 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (7*G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yv])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (11*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yv])/64 + 
     (3*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (Pi^2*G[{0, 1, yu^(-1)}, yw])/96 + (G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yw])/
      32 - (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yu]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (Pi^2*G[{0, yu^(-1), 1}, yv])/768 - 
     (G[{0}, yu]^2*G[{0, yu^(-1), 1}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{0, yu^(-1), 1}, yv])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/8 + 
     (9*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/64 + 
     (9*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/64 + 
     (13*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (13*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/32 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/48 - (G[{0}, yu]^2*G[{0, yu^(-1), 1}, yw])/
      32 + (G[{0}, yv]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (7*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/256 - 
     (G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (9*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/2 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (17*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/64 + 
     (7*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (17*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (7*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (7*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/64 + 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (5*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/48 - 
     (G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (5*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/48 + 
     (G[{0}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/96 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*Pi^2*G[{1, 1, yu^(-1)}, yv])/256 - 
     (G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/4 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (17*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (13*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (19*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (7*G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (15*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (17*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (11*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (11*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv])/4 + 
     (5*G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (9*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (5*G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (5*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (11*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (Pi^2*G[{1, 1, yu^(-1)}, yw])/24 - (G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yw])/
      32 - (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (Pi^2*G[{1, 1, yv^(-1)}, yw])/192 - 
     (7*G[{0}, yv]^2*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (27*G[{1}, yu]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (9*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (7*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (29*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (15*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (15*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (23*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (7*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (7*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (9*G[{1, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (17*G[{0}, yw]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (19*G[{1}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (13*G[{0}, yv]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (25*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (41*G[{yu^(-1)}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (21*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (29*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (29*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (11*G[{0, 1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/256 + 
     (G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (9*G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/2 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (9*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/2 - 
     (17*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (9*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (7*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/4 - 
     (31*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (33*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/
      16 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yv])/32 + (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (5*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/48 + 
     (G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (5*G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      16 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/16 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (11*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/768 - 
     (5*G[{0}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      64 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (7*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (13*G[{1}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (13*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (11*Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (7*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (9*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (11*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/32 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (21*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (25*G[{1}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (25*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (41*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{0}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      4 + (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      4 - (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 - (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (3*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 - (11*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (11*G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (11*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (17*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (29*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (11*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (23*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (39*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (15*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (23*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (23*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (43*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (23*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (23*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (43*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 + (9*G[{0}, yv]*G[{0, 0, 0, 1}, yv])/64 + 
     (9*G[{1}, yu]*G[{0, 0, 0, 1}, yv])/64 - 
     (9*G[{1}, yv]*G[{0, 0, 0, 1}, yv])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, 1}, yv])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yv])/64 - 
     (9*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yv])/64 - 
     (9*G[{1}, yu]*G[{0, 0, 0, yu^(-1)}, yv])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 0, yu^(-1)}, yv])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, yu^(-1)}, yv])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0, 0, 1, 1}, yu])/8 + (5*G[{0}, yv]*G[{0, 0, 1, 1}, yu])/
      16 - (G[{0}, yw]*G[{0, 0, 1, 1}, yu])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, 1}, yu])/8 - (3*G[{1}, yv]*G[{0, 0, 1, 1}, yu])/
      8 + (3*G[{1}, yw]*G[{0, 0, 1, 1}, yu])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yu])/8 + 
     (G[{0}, yv]*G[{0, 0, 1, 1}, yv])/16 + (3*G[{0}, yw]*G[{0, 0, 1, 1}, yv])/
      16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yv])/4 + 
     (G[{1}, yv]*G[{0, 0, 1, 1}, yv])/32 - (G[{1}, yw]*G[{0, 0, 1, 1}, yv])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv])/32 + 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yw])/
      16 + (G[{1}, yv]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv])/16 + 
     (13*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/64 + 
     (11*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv])/4 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv])/4 - 
     (9*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv])/32 + 
     (9*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yv])/32 - 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/4 - 
     (25*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/4 - 
     (9*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 + 
     (19*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 - 
     (19*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw])/4 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (7*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yu])/8 + (G[{0}, yv]*G[{0, 1, 1, 1}, yu])/
      4 + (G[{0}, yw]*G[{0, 1, 1, 1}, yu])/16 + 
     (G[{1}, yu]*G[{0, 1, 1, 1}, yu])/8 - (3*G[{1}, yv]*G[{0, 1, 1, 1}, yu])/
      16 + (3*G[{1}, yw]*G[{0, 1, 1, 1}, yu])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu])/8 + 
     (9*G[{0}, yv]*G[{0, 1, 1, 1}, yv])/64 + (G[{0}, yw]*G[{0, 1, 1, 1}, yv])/
      8 + (17*G[{1}, yu]*G[{0, 1, 1, 1}, yv])/64 - 
     (G[{1}, yv]*G[{0, 1, 1, 1}, yv])/16 + (G[{1}, yw]*G[{0, 1, 1, 1}, yv])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1, 1, 1}, yw])/16 + (3*G[{0}, yw]*G[{0, 1, 1, 1}, yw])/
      16 + (G[{1}, yu]*G[{0, 1, 1, 1}, yw])/8 + 
     (3*G[{1}, yv]*G[{0, 1, 1, 1}, yw])/16 + (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/
      8 + (G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (5*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/64 + 
     (5*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/32 - 
     (5*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (17*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv])/64 + 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv])/16 - 
     (5*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv])/64 + 
     (9*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yv])/32 - 
     (9*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yv])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yv])/32 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (13*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/32 - 
     (21*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (21*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv])/64 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yv])/16 - 
     (5*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv])/64 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv])/16 - 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (13*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/64 - 
     (5*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (25*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv])/64 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/4 + 
     (9*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv])/64 - 
     (9*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv])/32 + 
     (9*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/32 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/2 - 
     (25*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/2 - 
     (9*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 + 
     (29*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (29*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw])/8 - 
     (3*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/8 + 
     (5*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/4 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (23*G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/4 - 
     (7*G[{0}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (23*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu^(-1)}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/4 + 
     (25*G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/4 + 
     (9*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (17*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 + 
     (23*G[{0}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (35*G[{1}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (23*G[{1}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (23*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (9*G[{0}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (7*G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (9*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     (5*G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/2 + 
     (25*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/2 + 
     (9*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 + 
     (61*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (7*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (7*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (7*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (9*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (15*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/2 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (7*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (9*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (7*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (7*G[{0}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (11*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (23*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (43*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (23*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (23*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (5*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 - (43*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (7*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (23*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (23*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 + (3*G[{0, 0, 0, 1, 1}, yu])/8 - 
     (9*G[{0, 0, 0, 1, 1}, yw])/16 - (3*G[{0, 0, 0, 1, yu^(-1)}, yv])/8 + 
     (3*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 + (9*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      16 - (3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1}, yv])/8 + (3*G[{0, 0, 0, yu^(-1), 1}, yw])/
      16 + (3*G[{0, 0, 0, yu^(-1), yu^(-1)}, yv])/4 + 
     (3*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (9*G[{0, 0, 0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (9*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{0, 0, 1, 0, 1}, yu]/8 - (3*G[{0, 0, 1, 0, 1}, yv])/64 - 
     (3*G[{0, 0, 1, 0, 1}, yw])/16 - (5*G[{0, 0, 1, 0, yu^(-1)}, yv])/64 + 
     G[{0, 0, 1, 0, yu^(-1)}, yw]/16 + (3*G[{0, 0, 1, 0, yv^(-1)}, yw])/16 - 
     G[{0, 0, 1, 0, 1/(yu*yv)}, yw]/16 + G[{0, 0, 1, 1, 1}, yu]/8 + 
     (3*G[{0, 0, 1, 1, 1}, yv])/8 + (3*G[{0, 0, 1, 1, 1}, yw])/8 - 
     (3*G[{0, 0, 1, 1, yu^(-1)}, yv])/32 + (3*G[{0, 0, 1, 1, yu^(-1)}, yw])/
      16 + (5*G[{0, 0, 1, 1, yv^(-1)}, yw])/16 + 
     (11*G[{0, 0, 1, yu^(-1), 1}, yv])/64 + G[{0, 0, 1, yu^(-1), 1}, yw]/8 - 
     (41*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (5*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 0, 1, yu^(-1), yv^(-1)}, yw]/16 + G[{0, 0, 1, yv^(-1), 1}, yw]/8 - 
     G[{0, 0, 1, yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (5*G[{0, 0, yu^(-1), 0, 1}, yv])/64 + G[{0, 0, yu^(-1), 0, 1}, yw]/16 + 
     (13*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv])/64 + 
     G[{0, 0, yu^(-1), 0, yu^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     (3*G[{0, 0, yu^(-1), 1, 1}, yv])/32 - 
     (5*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     G[{0, 0, yu^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (21*G[{0, 0, yu^(-1), yu^(-1), 1}, yv])/64 + 
     (3*G[{0, 0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (17*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (7*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw]/8 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, yv^(-1), 0, 1}, yw])/16 - G[{0, 0, yv^(-1), 0, yu^(-1)}, yw]/
      16 - (3*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/16 + G[{0, 0, yv^(-1), 1, 1}, yw]/
      4 + G[{0, 0, yv^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw]/16 + 
     (9*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     G[{0, 0, 1/(yu*yv), 0, 1}, yw]/16 - G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/
      16 + G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1}, yw]/8 - G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw]/
      16 + (7*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (7*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0, 1, 0, 1, 1}, yv])/64 + G[{0, 1, 0, 1, 1}, yw]/4 - 
     G[{0, 1, 0, 1, yu^(-1)}, yv]/64 + G[{0, 1, 0, 1, yu^(-1)}, yw]/8 + 
     (3*G[{0, 1, 0, 1, yv^(-1)}, yw])/16 - G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/
      16 + G[{0, 1, 0, yu^(-1), 1}, yv]/16 + G[{0, 1, 0, yu^(-1), 1}, yw]/
      16 - (3*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw]/16 + G[{0, 1, 0, yv^(-1), 1}, yw]/
      16 - G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw]/16 - G[{0, 1, 0, 1/(yu*yv), 1}, yw]/
      8 + G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     (3*G[{0, 1, 1, 0, yu^(-1)}, yv])/64 + (3*G[{0, 1, 1, 0, yu^(-1)}, yw])/
      16 + (3*G[{0, 1, 1, 0, yv^(-1)}, yw])/16 - 
     G[{0, 1, 1, 0, 1/(yu*yv)}, yw]/8 + (3*G[{0, 1, 1, 1, 1}, yu])/16 + 
     (3*G[{0, 1, 1, 1, 1}, yv])/16 - (3*G[{0, 1, 1, 1, 1}, yw])/16 - 
     (9*G[{0, 1, 1, 1, yu^(-1)}, yv])/64 - (3*G[{0, 1, 1, 1, yu^(-1)}, yw])/
      16 - G[{0, 1, 1, 1, yv^(-1)}, yw]/8 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/
      8 - (5*G[{0, 1, 1, yu^(-1), 1}, yv])/32 - G[{0, 1, 1, yu^(-1), 1}, yw]/
      16 + (9*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{0, 1, 1, yu^(-1), yv^(-1)}, yw]/16 - G[{0, 1, 1, yv^(-1), 1}, yw]/
      16 + G[{0, 1, 1, yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{0, 1, 1, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yv]/8 - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 1, yu^(-1), 1, 1}, yv])/32 + 
     (17*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv])/64 + 
     G[{0, 1, yu^(-1), 1, yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), 1, yv^(-1)}, yw]/8 + 
     (21*G[{0, 1, yu^(-1), yu^(-1), 1}, yv])/64 - 
     (25*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/16 + 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/16 - G[{0, 1, yv^(-1), 1, 1}, yw]/8 + 
     G[{0, 1, yv^(-1), 1, yu^(-1)}, yw]/16 + 
     (3*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 1, yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yv^(-1), yv^(-1), 1}, yw]/4 + 
     G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw]/8 + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 + 
     (5*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     (3*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yv]/64 + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw]/8 - 
     (3*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw]/16 + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, yu^(-1), 1, 1, 1}, yw])/16 + G[{0, yu^(-1), 1, 1, yu^(-1)}, yv]/
      64 + G[{0, yu^(-1), 1, 1, yu^(-1)}, yw]/4 - 
     G[{0, yu^(-1), 1, 1, yv^(-1)}, yw]/16 + 
     (5*G[{0, yu^(-1), 1, yu^(-1), 1}, yv])/32 + 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yw]/16 - 
     (25*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv])/64 - 
     G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), 1, yv^(-1), 1}, yw])/16 - 
     G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw]/16 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yv]/32 + 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/8 - 
     (25*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv])/64 - 
     G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (29*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv])/64 + 
     G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw]/4 + 
     (41*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (3*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw]/16 + 
     (5*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, yv^(-1), 1, 1, 1}, yw])/16 + 
     (3*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw])/16 + 
     G[{0, yv^(-1), 1, 1, yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1, yu^(-1), 1}, yw]/16 - 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw]/16 - 
     G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw]/16 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw]/8 + 
     (3*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (3*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw])/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/16 + 
     (3*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1, 1, 1}, yw])/16 - 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 - 
     G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw]/16 + 
     (3*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw]/16 - 
     (5*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw]/8 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw]/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{1, 1, 1, 1, yu^(-1)}, yv]/16 - (7*G[{1, 1, 1, 1, yu^(-1)}, yw])/16 + 
     (5*G[{1, 1, 1, 1, yv^(-1)}, yw])/16 + G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/2 - 
     (25*G[{1, 1, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (7*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (19*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     G[{1, 1, 1, yv^(-1), yv^(-1)}, yw]/8 - 
     (7*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     3*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (33*G[{1, 1, yu^(-1), 1, yu^(-1)}, yv])/64 + 
     (3*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (3*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (7*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv]/64 - 
     (13*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (5*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (3*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (5*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (5*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (9*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (19*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     (7*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (9*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (61*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/2 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 + 
     (7*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv])/16 - 
     (7*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw]/4 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (41*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv])/32 + 
     G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 - 
     G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 + 
     G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (5*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (3*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/16 + 
     G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (9*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (3*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (17*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     (7*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (15*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/2 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 - 
     (7*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/16 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     (3*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (11*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (123*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (17*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*Zeta[3])/256 + (G[{0}, yv]^2*Zeta[3])/16 + 
     (G[{0}, yv]*G[{0}, yw]*Zeta[3])/16 - (3*G[{0}, yw]^2*Zeta[3])/64 - 
     (G[{0}, yu]*G[{1}, yu]*Zeta[3])/16 + (G[{0}, yv]*G[{1}, yu]*Zeta[3])/8 + 
     (3*G[{0}, yw]*G[{1}, yu]*Zeta[3])/32 + (7*G[{1}, yu]^2*Zeta[3])/64 - 
     (G[{0}, yv]*G[{1}, yv]*Zeta[3])/16 - (5*G[{0}, yw]*G[{1}, yv]*Zeta[3])/
      32 - (G[{1}, yu]*G[{1}, yv]*Zeta[3])/32 - (G[{1}, yv]^2*Zeta[3])/8 + 
     (G[{0}, yv]*G[{1}, yw]*Zeta[3])/16 + (5*G[{0}, yw]*G[{1}, yw]*Zeta[3])/
      32 + (G[{1}, yu]*G[{1}, yw]*Zeta[3])/32 + 
     (G[{1}, yv]*G[{1}, yw]*Zeta[3])/4 + (G[{1}, yw]^2*Zeta[3])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*Zeta[3])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (3*G[{1/(yu*yv)}, yw]^2*Zeta[3])/64 + (G[{0, 1}, yu]*Zeta[3])/16 + 
     (5*G[{0, 1}, yv]*Zeta[3])/32 - (5*G[{0, 1}, yw]*Zeta[3])/32 + 
     (G[{0, yu^(-1)}, yv]*Zeta[3])/32 - (G[{0, yu^(-1)}, yw]*Zeta[3])/32 + 
     (3*G[{0, yv^(-1)}, yw]*Zeta[3])/32 + (3*G[{0, 1/(yu*yv)}, yw]*Zeta[3])/
      32 - (G[{1, yu^(-1)}, yv]*Zeta[3])/32 + (G[{1, yu^(-1)}, yw]*Zeta[3])/
      32 - (5*G[{1, yv^(-1)}, yw]*Zeta[3])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/8 - Zeta[5]/64
 
QepuwvRegI = (17*Pi^4*G[{0}, yw])/11520 + (Pi^2*G[{0}, yv]^2*G[{0}, yw])/256 + 
     (Pi^2*G[{0}, yv]*G[{0}, yw]^2)/96 + (Pi^2*G[{0}, yw]^3)/256 + 
     (3*G[{0}, yv]^2*G[{0}, yw]^3)/256 + (17*Pi^4*G[{1}, yu])/11520 + 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/192 + (Pi^2*G[{0}, yv]^2*G[{1}, yu])/
      256 + (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu])/32 + 
     (5*Pi^2*G[{0}, yw]^2*G[{1}, yu])/768 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu])/32 + 
     (9*G[{0}, yv]^2*G[{0}, yw]^2*G[{1}, yu])/256 + 
     (3*G[{0}, yv]*G[{0}, yw]^3*G[{1}, yu])/128 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/192 + (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/
      384 + (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]^2)/64 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/192 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]^2)/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2)/8 + 
     (9*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]^2)/64 + 
     (9*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu]^2)/128 + 
     (3*G[{0}, yw]^3*G[{1}, yu]^2)/256 + (Pi^2*G[{1}, yu]^3)/384 + 
     (G[{0}, yu]^2*G[{1}, yu]^3)/96 - (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^3)/
      24 + (3*G[{0}, yv]^2*G[{1}, yu]^3)/256 - 
     (7*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^3)/96 + 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^3)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu]^3)/256 - (11*G[{0}, yu]*G[{1}, yu]^4)/384 + 
     (3*G[{0}, yv]*G[{1}, yu]^4)/128 + (9*G[{0}, yw]*G[{1}, yu]^4)/256 + 
     (3*G[{1}, yu]^5)/256 + (17*Pi^4*G[{1}, yv])/11520 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/256 + 
     (5*Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv])/384 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yv])/768 + 
     (9*G[{0}, yv]^2*G[{0}, yw]^2*G[{1}, yv])/256 - 
     (3*G[{0}, yv]*G[{0}, yw]^3*G[{1}, yv])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/32 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/192 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/16 + 
     (9*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv])/32 - 
     (3*G[{0}, yw]^3*G[{1}, yu]*G[{1}, yv])/128 + 
     (Pi^2*G[{1}, yu]^2*G[{1}, yv])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv])/8 + 
     (9*G[{0}, yv]^2*G[{1}, yu]^2*G[{1}, yv])/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv])/32 + 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yu]^2*G[{1}, yv])/256 - 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yv])/32 + 
     (3*G[{0}, yv]*G[{1}, yu]^3*G[{1}, yv])/64 + (3*G[{1}, yu]^4*G[{1}, yv])/
      256 + (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/384 - 
     (11*Pi^2*G[{0}, yw]*G[{1}, yv]^2)/768 + 
     (9*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]^2)/256 - 
     (5*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]^2)/128 - 
     (5*Pi^2*G[{1}, yu]*G[{1}, yv]^2)/768 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]^2)/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2)/32 + 
     (9*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]^2)/256 + 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2)/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2)/128 - 
     (5*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]^2)/128 + 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]^2)/64 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]^2)/32 - 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]^2)/256 - 
     (G[{1}, yu]^3*G[{1}, yv]^2)/256 - (5*Pi^2*G[{1}, yv]^3)/768 + 
     (3*G[{0}, yv]^2*G[{1}, yv]^3)/256 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^3)/
      384 + (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^3)/96 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^3)/192 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^3)/384 + 
     (11*G[{1}, yu]^2*G[{1}, yv]^3)/768 + (G[{0}, yv]*G[{1}, yv]^4)/96 + 
     (G[{1}, yu]*G[{1}, yv]^4)/96 - (17*Pi^4*G[{1}, yw])/11520 - 
     (Pi^2*G[{0}, yv]^2*G[{1}, yw])/256 - 
     (5*Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw])/384 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/768 - 
     (9*G[{0}, yv]^2*G[{0}, yw]^2*G[{1}, yw])/256 + 
     (3*G[{0}, yv]*G[{0}, yw]^3*G[{1}, yw])/128 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/192 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/16 - 
     (9*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw])/32 + 
     (3*G[{0}, yw]^3*G[{1}, yu]*G[{1}, yw])/128 - 
     (Pi^2*G[{1}, yu]^2*G[{1}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw])/8 - 
     (9*G[{0}, yv]^2*G[{1}, yu]^2*G[{1}, yw])/256 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw])/32 - 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu]^2*G[{1}, yw])/256 + 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yu]^3*G[{1}, yw])/64 - (3*G[{1}, yu]^4*G[{1}, yw])/
      256 - (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/192 + 
     (11*Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/384 - 
     (9*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/128 + 
     (5*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw])/64 + 
     (5*Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/384 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/16 - 
     (9*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/128 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/64 + 
     (5*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/16 + 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/128 + 
     (G[{1}, yu]^3*G[{1}, yv]*G[{1}, yw])/128 + 
     (5*Pi^2*G[{1}, yv]^2*G[{1}, yw])/256 - 
     (9*G[{0}, yv]^2*G[{1}, yv]^2*G[{1}, yw])/256 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/32 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/128 - 
     (11*G[{1}, yu]^2*G[{1}, yv]^2*G[{1}, yw])/256 - 
     (G[{0}, yv]*G[{1}, yv]^3*G[{1}, yw])/24 - 
     (G[{1}, yu]*G[{1}, yv]^3*G[{1}, yw])/24 + (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/
      384 - (3*Pi^2*G[{0}, yw]*G[{1}, yw]^2)/512 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yw]^3*G[{1}, yw]^2)/256 + (Pi^2*G[{1}, yu]*G[{1}, yw]^2)/512 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]^2)/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2)/32 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/32 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]^2)/64 - 
     (17*Pi^2*G[{1}, yv]*G[{1}, yw]^2)/1536 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/32 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/32 + 
     (9*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]^2)/16 + 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]^2)/256 + 
     (25*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]^2)/256 + 
     (3*G[{1}, yv]^3*G[{1}, yw]^2)/256 + (Pi^2*G[{1}, yw]^3)/768 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^3)/384 - (G[{0}, yw]^2*G[{1}, yw]^3)/
      256 - (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^3)/96 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^3)/384 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^3)/192 - (G[{1}, yu]^2*G[{1}, yw]^3)/
      768 - (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^3)/128 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^3)/128 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^3)/64 - (G[{1}, yv]^2*G[{1}, yw]^3)/
      256 - (G[{0}, yw]*G[{1}, yw]^4)/768 - (G[{1}, yu]*G[{1}, yw]^4)/768 - 
     (G[{1}, yv]*G[{1}, yw]^4)/768 + (Pi^2*G[{0}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yv])/48 + (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv])/32 - (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/
      128 - (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (7*Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/384 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (7*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (5*G[{1}, yu]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (3*Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 + 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (19*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (11*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (11*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (5*G[{1}, yv]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/384 + 
     (G[{0}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (9*G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (7*G[{1}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 + 
     (G[{0}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 + 
     (G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/128 + 
     (G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/128 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/96 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/8 - 
     (5*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 - 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/16 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/64 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/32 + 
     (5*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/64 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/32 - 
     (G[{1}, yw]^3*G[{yu^(-1)}, yv]^2)/96 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/24 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/48 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/24 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/16 + 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yv]^3)/192 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^4)/192 - (17*Pi^4*G[{1/(yu*yv)}, yw])/
      11520 - (Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yv]^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yv]*G[{0}, yw]^3*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/192 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/4 - 
     (9*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]^3*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yv]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/32 - 
     (27*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/128 - 
     (27*G[{0}, yw]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/256 + 
     (11*G[{0}, yu]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yv]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yw]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu]^4*G[{1/(yu*yv)}, yw])/256 + 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/48 - 
     (5*Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (3*Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/768 - 
     (9*G[{0}, yv]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (21*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (21*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (33*G[{1}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{0}, yv]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (15*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yv]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/768 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (7*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (5*G[{1}, yu]^3*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (3*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/8 - 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (19*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (11*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (5*G[{1}, yv]^3*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 + (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/96 + 
     (G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/4 - (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/192 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yw]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (7*Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/512 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (29*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/12 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/12 + 
     (25*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/64 + 
     (41*G[{1}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (41*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (5*Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (5*Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (13*G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (23*G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (13*G[{1}, yu]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (5*Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (9*G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (13*Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (11*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (17*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (23*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{yu^(-1)}, yv]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (11*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{0}, yv]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (9*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (7*Pi^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/512 - (3*G[{0}, yv]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yv]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (7*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (7*G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (11*G[{1}, yu]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (7*G[{1}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (7*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (11*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 + 
     (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/192 + 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/384 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (7*Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/128 - 
     (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (17*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (7*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (31*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{1}, yu]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (7*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yv]^3*G[{1/(yu*yv)}, yw]^2)/32 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (13*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (13*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (9*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/64 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (15*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/64 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (9*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (27*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (15*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (19*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (15*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (3*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (7*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/4 - 
     (15*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (13*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (41*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (13*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (21*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (21*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (21*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (5*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (15*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (19*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (19*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{0}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/8 + (G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 + (17*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (33*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (15*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 + (15*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (11*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{0}, yu]*G[{0}, yv]*
       G[{1/(yu*yv)}, yw]^3)/48 + (G[{0}, yu]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]^3)/96 - (5*G[{0}, yv]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]^3)/384 - (G[{0}, yu]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw]^3)/96 - (5*G[{0}, yv]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw]^3)/384 - (5*G[{0}, yw]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw]^3)/384 - (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/
      384 + (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (13*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/24 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (13*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/192 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yu])/32 + 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/96 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yu])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yu])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu])/16 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yu])/32 - 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu])/32 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/32 - 
     (5*G[{1}, yv]^3*G[{0, 1}, yu])/96 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
       G[{0, 1}, yu])/16 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu])/
      16 - (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/32 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu])/32 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/32 - 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/32 + 
     (G[{1}, yw]^3*G[{0, 1}, yu])/96 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/96 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{0}, yv]*G[{0, 1}, yu]^2)/32 + (G[{0}, yw]*G[{0, 1}, yu]^2)/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]^2)/32 + (3*G[{1}, yv]*G[{0, 1}, yu]^2)/32 - 
     (3*G[{1}, yw]*G[{0, 1}, yu]^2)/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2)/
      32 + (7*Pi^2*G[{0}, yw]*G[{0, 1}, yv])/384 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yw]^3*G[{0, 1}, yv])/128 + (7*Pi^2*G[{1}, yu]*G[{0, 1}, yv])/
      384 - (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv])/8 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yv])/16 - 
     (7*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yv])/128 - 
     (5*G[{1}, yu]^3*G[{0, 1}, yv])/128 + (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/
      128 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv])/8 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/8 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/64 - 
     (15*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv])/128 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv])/32 - 
     (11*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yv])/128 - 
     (15*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/128 - 
     (5*G[{1}, yv]^3*G[{0, 1}, yv])/128 - (Pi^2*G[{1}, yw]*G[{0, 1}, yv])/
      128 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv])/8 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/8 + 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/64 + 
     (15*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (11*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/64 + 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/64 + 
     (15*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yv])/128 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/32 - 
     (9*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv])/128 - 
     (13*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/128 - 
     (13*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{1}, yw]^3*G[{0, 1}, yv])/96 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/
      32 - (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/16 - 
     (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0, 1}, yv]^2)/32 + (G[{0}, yw]*G[{0, 1}, yv]^2)/32 + 
     (G[{1}, yv]*G[{0, 1}, yv]^2)/32 - (G[{1}, yw]*G[{0, 1}, yv]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2)/32 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/768 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yw])/32 + 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yw])/768 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw])/16 - 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yw])/64 - 
     (3*G[{1}, yu]^3*G[{0, 1}, yw])/64 - (5*Pi^2*G[{1}, yv]*G[{0, 1}, yw])/
      256 + (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw])/64 - 
     (7*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw])/8 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw])/32 - 
     (11*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yw])/16 + 
     (11*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/768 - 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yw])/128 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (9*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yw]^3*G[{0, 1}, yw])/128 + (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/
      96 + (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/24 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/256 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      16 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/32 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/32 + 
     (9*G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1}, yw]^2)/32 - (G[{0}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, 1}, yw]^2)/32 + (7*G[{1}, yw]*G[{0, 1}, yw]^2)/128 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/48 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/32 - 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]^3*G[{0, yu^(-1)}, yv])/128 - 
     (7*Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/384 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv])/16 + 
     (7*G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv])/128 + 
     (5*G[{1}, yu]^3*G[{0, yu^(-1)}, yv])/128 + 
     (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/8 + 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/64 + 
     (15*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/32 + 
     (11*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/128 + 
     (15*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/128 + 
     (5*G[{1}, yv]^3*G[{0, yu^(-1)}, yv])/128 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (15*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (11*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (15*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 + 
     (9*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 + 
     (13*G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 + 
     (13*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yv])/96 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv])/16 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/32 + (3*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      32 - (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/64 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      32 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/32 - (3*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/32 + (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 - (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/16 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/16 + (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 + (G[{0}, yw]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/8 + (G[{1}, yu]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/8 - (G[{1}, yw]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/8 + (G[{0}, yu]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/16 - (G[{0}, yw]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/16 + (G[{0}, yu]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (G[{0}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/32 + (G[{1}, yu]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/32 + (3*G[{1}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/32 - (9*G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/64 - (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{0, yu^(-1)}, yv]^2)/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/768 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw])/32 - 
     (Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/768 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw])/4 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw])/16 + 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]^3*G[{0, yu^(-1)}, yw])/64 - 
     (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/768 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/32 + 
     (9*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/8 - 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]^3*G[{0, yu^(-1)}, yw])/16 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (9*G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yw])/32 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/256 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (9*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (3*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 + (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/96 - 
     (3*Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/256 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yu]^3*G[{0, yv^(-1)}, yw])/64 - 
     (Pi^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/16 + 
     (5*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (13*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (9*G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/256 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (3*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 + (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw])/64 + 
     (17*Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw])/16 - 
     (13*Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (9*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/24 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (9*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (9*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 - (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 - (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (G[{0}, yu]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yv]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (5*G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (5*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (5*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/16 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/128 + 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yv])/48 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]^3*G[{1, yu^(-1)}, yv])/128 + 
     (7*Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/384 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/16 - 
     (7*G[{0}, yw]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/128 - 
     (5*G[{1}, yu]^3*G[{1, yu^(-1)}, yv])/128 - 
     (3*Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/8 - 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 - 
     (19*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/32 - 
     (11*G[{0}, yw]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/128 - 
     (11*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/128 - 
     (5*G[{1}, yv]^3*G[{1, yu^(-1)}, yv])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (13*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (11*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (5*G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/384 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (7*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (11*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (9*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 + (3*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (5*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      32 - (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/4 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      32 + (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (5*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/8 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/16 - 
     (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (7*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (5*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (5*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1)}, yv]^2)/32 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yv]^2)/32 + 
     (3*G[{1}, yu]*G[{1, yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]^2)/16 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]^2)/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]^2)/16 + 
     (Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/768 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/32 + 
     (Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/768 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/4 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/16 - 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu]^3*G[{1, yu^(-1)}, yw])/64 + 
     (Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/768 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (9*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv]^3*G[{1, yu^(-1)}, yw])/16 + 
     (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/192 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/32 + 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/768 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (23*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (7*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (7*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/4 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 - (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 + (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 - (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 - (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 + (3*G[{0}, yu]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/16 - (5*G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yv]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/32 - (3*G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/32 - (3*G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/64 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 + (5*G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 - (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/64 - (G[{0}, yu]*G[{1, yu^(-1)}, yw]^2)/8 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yu]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]^2)/8 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/128 - 
     (13*Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^3*G[{1, yv^(-1)}, yw])/128 - 
     (13*Pi^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 - 
     (13*G[{0}, yw]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/16 - 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/128 - 
     (G[{1}, yu]^3*G[{1, yv^(-1)}, yw])/128 - 
     (13*Pi^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (9*G[{0}, yw]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/128 - 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/128 - 
     (9*G[{1}, yu]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yv]^3*G[{1, yv^(-1)}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/384 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^3*G[{1, yv^(-1)}, yw])/16 + 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/256 - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (11*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (11*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (11*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (7*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (3*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yu]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yw]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yu]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*Pi^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (19*G[{1}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (11*G[{1}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yv]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (17*G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (19*G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (15*G[{1}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (11*G[{1}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (5*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw])/48 - 
     (7*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/16 - (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (Pi^2*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/192 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (9*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (21*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (29*G[{1}, yv]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (25*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (41*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (41*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (13*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (9*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (5*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (13*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (5*G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (13*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (3*G[{0}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (5*G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (7*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (9*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/8 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (5*Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*Pi^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (23*G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (13*G[{1}, yu]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*Pi^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (13*Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/384 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (17*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{yu^(-1)}, yv]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{yu^(-1)}, yv]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{yu^(-1)}, yv]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{yu^(-1)}, yv]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (5*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (7*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      4 + (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (9*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (15*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (13*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (19*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (13*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (19*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (19*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (3*G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (7*G[{1}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0, 0, 1}, yu])/96 + (G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yu])/
      16 + (G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yu])/4 - 
     (G[{1}, yu]^2*G[{0, 0, 1}, yu])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu])/8 - 
     (G[{1}, yv]^2*G[{0, 0, 1}, yu])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yu])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/4 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/4 + 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/4 - 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yu])/16 - (G[{0, 1}, yv]*G[{0, 0, 1}, yu])/
      16 - (G[{0, 1}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yu])/16 + 
     (5*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/4 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yu])/16 - 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/4 + 
     (Pi^2*G[{0, 0, 1}, yv])/96 + (G[{0}, yw]^2*G[{0, 0, 1}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yv])/4 + 
     (G[{1}, yu]^2*G[{0, 0, 1}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yv])/4 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv])/4 + 
     (G[{1}, yv]^2*G[{0, 0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv])/4 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{1}, yw]^2*G[{0, 0, 1}, yv])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{0, 1}, yv]*G[{0, 0, 1}, yv])/8 + (G[{0, 1}, yw]*G[{0, 0, 1}, yv])/
      8 - (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (Pi^2*G[{0, 0, 1}, yw])/64 - (3*G[{0}, yv]^2*G[{0, 0, 1}, yw])/128 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yw])/16 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yw])/32 + 
     (15*G[{1}, yu]^2*G[{0, 0, 1}, yw])/128 + 
     (19*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yw])/32 + 
     (13*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{1}, yv]^2*G[{0, 0, 1}, yw])/64 - 
     (15*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw])/32 + 
     (9*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 - 
     (17*G[{1}, yw]^2*G[{0, 0, 1}, yw])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/4 + 
     (15*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (13*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0, 1}, yu]*G[{0, 0, 1}, yw])/16 - 
     (7*G[{0, 1}, yv]*G[{0, 0, 1}, yw])/64 + (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/
      32 + (7*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/32 - 
     (7*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 - 
     (19*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (Pi^2*G[{0, 0, yu^(-1)}, yv])/96 - (G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yv])/
      16 + (G[{0}, yu]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv])/4 - 
     (G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/4 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/4 - 
     (G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/4 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/64 - (G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yw])/
      16 - (G[{0}, yu]*G[{0}, yv]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (15*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (15*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (25*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (17*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (13*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (7*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (11*G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/192 + 
     (3*G[{0}, yv]^2*G[{0, 0, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (9*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]^2*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (9*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (17*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yv]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (7*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/192 + 
     (G[{0}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (19*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (25*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (17*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{0, 1, 1}, yu])/96 + (G[{0}, yu]^2*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu])/16 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yu])/8 + 
     (3*G[{0}, yw]^2*G[{0, 1, 1}, yu])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yu])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yu])/16 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yv]^2*G[{0, 1, 1}, yu])/32 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yu])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (Pi^2*G[{0, 1, 1}, yv])/96 - (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yv])/
      16 + (G[{0}, yw]^2*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yv])/8 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yv]^2*G[{0, 1, 1}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/8 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yw]^2*G[{0, 1, 1}, yv])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv])/16 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{0, 1}, yu]*G[{0, 1, 1}, yv])/16 - (G[{0, 1}, yv]*G[{0, 1, 1}, yv])/
      8 + (G[{0, 1}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yv])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 - 
     (5*Pi^2*G[{0, 1, 1}, yw])/256 + (3*G[{0}, yv]^2*G[{0, 1, 1}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{1}, yu]^2*G[{0, 1, 1}, yw])/128 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw])/64 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw])/64 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (13*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw])/8 - 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, 1, 1}, yw])/16 - (9*G[{0, 1}, yv]*G[{0, 1, 1}, yw])/
      64 - (5*G[{0, 1}, yw]*G[{0, 1, 1}, yw])/64 + 
     (9*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (5*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (Pi^2*G[{0, 1, yu^(-1)}, yv])/96 + (G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yv])/
      32 - (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (5*Pi^2*G[{0, 1, yu^(-1)}, yw])/768 + 
     (G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (3*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (17*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (13*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (25*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (11*Pi^2*G[{0, 1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yv]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (11*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (13*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{0, yu^(-1), 1}, yv])/48 - (G[{0}, yu]^2*G[{0, yu^(-1), 1}, yv])/
      32 + (G[{0}, yw]^2*G[{0, yu^(-1), 1}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yv])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 - 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/768 - 
     (G[{0}, yu]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{0, yu^(-1), 1}, yw])/128 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/8 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (7*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/48 - 
     (G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (5*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (5*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (7*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/256 - 
     (G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (9*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/2 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (21*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (29*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (7*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (17*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (33*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (7*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (11*Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yu]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*G[{0, yv^(-1), 1}, yw])/768 - 
     (3*G[{0}, yv]^2*G[{0, yv^(-1), 1}, yw])/128 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/64 - 
     (3*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw])/128 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/64 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw])/128 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (5*G[{0, 1}, yv]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (5*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (5*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (11*Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yu]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (5*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/768 + 
     (3*G[{0}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (17*G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (23*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0, 1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/256 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (3*G[{0}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (11*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (13*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (7*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (5*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/768 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (17*G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (17*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/16 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (5*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (17*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (19*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 + (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1, 1, yu^(-1)}, yv])/24 - (G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yv])/
      32 + (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/4 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/4 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/4 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/4 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (3*Pi^2*G[{1, 1, yu^(-1)}, yw])/256 - 
     (G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (17*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (13*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (19*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (11*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (15*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (15*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (11*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (15*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (11*G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (7*Pi^2*G[{1, 1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yv]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (23*G[{1}, yu]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (17*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (21*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (9*G[{0, 1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (9*G[{0, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (17*G[{1, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/24 + 
     (G[{0}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0, 1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/48 + 
     (G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/4 + 
     (5*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (5*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/2 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/
      16 + (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yv])/16 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (5*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/4 + 
     (5*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (7*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/256 + 
     (G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (9*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (21*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (29*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (9*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (31*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (33*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (15*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      32 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/16 + (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (7*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (11*Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]^2*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      32 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu]^2*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      32 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (11*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/768 - 
     (3*G[{0}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (13*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (21*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (29*G[{1}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      2 - (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      2 + (25*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (41*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (17*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0, 1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (11*Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/768 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      4 + (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      4 - (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 + (7*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (9*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (9*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 + (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      64 + (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/64 - (G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (3*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (13*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (9*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (25*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (25*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (25*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (41*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (7*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (11*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (7*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (17*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0, 1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 - (7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (29*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (23*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (39*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (5*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (15*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (23*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (7*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (23*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (43*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (23*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (43*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (15*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 + (9*G[{0}, yw]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 0, 1, 1}, yu])/8 - (G[{0}, yv]*G[{0, 0, 1, 1}, yu])/
      16 + (5*G[{0}, yw]*G[{0, 0, 1, 1}, yu])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, 1}, yu])/8 + (3*G[{1}, yv]*G[{0, 0, 1, 1}, yu])/
      8 - (3*G[{1}, yw]*G[{0, 0, 1, 1}, yu])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yu])/8 + 
     (G[{0}, yv]*G[{0, 0, 1, 1}, yv])/16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yv])/
      16 + (G[{1}, yv]*G[{0, 0, 1, 1}, yv])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yv])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv])/8 + 
     (3*G[{0}, yv]*G[{0, 0, 1, 1}, yw])/16 + (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/
      16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yw])/4 + 
     (G[{1}, yv]*G[{0, 0, 1, 1}, yw])/16 + (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/
      32 - (3*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yw])/16 - 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/32 + 
     (G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (13*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (25*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv])/8 + 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv])/8 + 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (5*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (9*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/8 - 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/4 - 
     (25*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 - 
     (41*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (19*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (9*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 - 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 - 
     (5*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (17*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (13*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (17*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (19*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yu])/8 + (G[{0}, yv]*G[{0, 1, 1, 1}, yu])/
      16 + (G[{0}, yw]*G[{0, 1, 1, 1}, yu])/4 + 
     (G[{1}, yu]*G[{0, 1, 1, 1}, yu])/8 + (3*G[{1}, yv]*G[{0, 1, 1, 1}, yu])/
      16 - (3*G[{1}, yw]*G[{0, 1, 1, 1}, yu])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu])/8 + 
     (3*G[{0}, yv]*G[{0, 1, 1, 1}, yv])/16 - (G[{0}, yw]*G[{0, 1, 1, 1}, yv])/
      16 + (G[{1}, yu]*G[{0, 1, 1, 1}, yv])/8 + 
     (G[{1}, yv]*G[{0, 1, 1, 1}, yv])/8 - (G[{1}, yw]*G[{0, 1, 1, 1}, yv])/
      8 - (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv])/8 + 
     (G[{0}, yv]*G[{0, 1, 1, 1}, yw])/8 + (9*G[{0}, yw]*G[{0, 1, 1, 1}, yw])/
      64 + (17*G[{1}, yu]*G[{0, 1, 1, 1}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, 1, 1, 1}, yw])/64 - (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (5*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv])/8 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv])/8 + 
     (3*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (17*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (5*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (17*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw])/32 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (13*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 + 
     (25*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (21*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (13*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (9*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (17*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (9*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (17*G[{1}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (7*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yv])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv])/8 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (5*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (13*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (25*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 + 
     (3*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (25*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (25*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 - 
     (3*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/2 - 
     (25*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (41*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (29*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (25*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (5*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (9*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (13*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (25*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1, 1}, yw])/8 - 
     (9*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (17*G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (5*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (13*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (15*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (15*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (23*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (15*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (5*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (9*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (17*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (13*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (5*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (13*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (25*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (13*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (11*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (15*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (15*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (23*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (15*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/4 - 
     (G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (29*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (41*G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (29*G[{1}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (25*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (41*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (21*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (21*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (9*G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (29*G[{1}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (3*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 + 
     (3*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/2 + 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/2 + 
     (25*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (41*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (23*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (25*G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (41*G[{1}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (9*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      64 - (G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (25*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (41*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 + (7*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, 
        yw])/32 + (7*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, 
        yw])/32 + (7*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, 
        yw])/32 - (7*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 
         yv^(-1)}, yw])/32 - (11*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (7*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (9*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      64 + (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, 
        yw])/32 + (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (7*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (23*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (7*G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{1}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (5*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (23*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (43*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (23*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (23*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (43*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (7*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (23*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 + (3*G[{0, 0, 0, 1, 1}, yu])/8 - 
     (9*G[{0, 0, 0, 1, 1}, yv])/16 + (3*G[{0, 0, 0, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0, 0, 0, 1, yu^(-1)}, yw])/8 + (9*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      16 - (3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 0, 0, yu^(-1), 1}, yv])/16 - (3*G[{0, 0, 0, yu^(-1), 1}, yw])/
      8 + (3*G[{0, 0, 0, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw])/4 - 
     (3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (9*G[{0, 0, 0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (9*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     G[{0, 0, 1, 0, 1}, yu]/8 - (3*G[{0, 0, 1, 0, 1}, yv])/16 - 
     (3*G[{0, 0, 1, 0, 1}, yw])/64 + G[{0, 0, 1, 0, yu^(-1)}, yv]/16 - 
     (5*G[{0, 0, 1, 0, yu^(-1)}, yw])/64 + (15*G[{0, 0, 1, 0, yv^(-1)}, yw])/
      64 - (7*G[{0, 0, 1, 0, 1/(yu*yv)}, yw])/64 + G[{0, 0, 1, 1, 1}, yu]/8 + 
     (3*G[{0, 0, 1, 1, 1}, yv])/8 + (3*G[{0, 0, 1, 1, 1}, yw])/8 + 
     (3*G[{0, 0, 1, 1, yu^(-1)}, yv])/16 - (3*G[{0, 0, 1, 1, yu^(-1)}, yw])/
      32 + (7*G[{0, 0, 1, 1, yv^(-1)}, yw])/32 - 
     (9*G[{0, 0, 1, 1, 1/(yu*yv)}, yw])/32 + G[{0, 0, 1, yu^(-1), 1}, yv]/8 + 
     (11*G[{0, 0, 1, yu^(-1), 1}, yw])/64 - 
     (5*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv])/16 - 
     (41*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (5*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 0, 1, yv^(-1), 1}, yw])/64 + 
     (5*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (15*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 0, 1, 1/(yu*yv), 1}, yw])/32 + 
     G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 + G[{0, 0, yu^(-1), 0, 1}, yv]/
      16 - (5*G[{0, 0, yu^(-1), 0, 1}, yw])/64 + 
     G[{0, 0, yu^(-1), 0, yu^(-1)}, yv]/16 + 
     (13*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw])/64 - 
     G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/64 + 
     (3*G[{0, 0, yu^(-1), 1, 1}, yw])/32 + G[{0, 0, yu^(-1), 1, yu^(-1)}, yv]/
      16 - (5*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, 0, yu^(-1), yu^(-1), 1}, yv])/8 - 
     (21*G[{0, 0, yu^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv])/16 + 
     (17*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (21*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (15*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (5*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/32 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (15*G[{0, 0, yv^(-1), 0, 1}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw])/64 - 
     (27*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw])/64 + 
     (19*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 0, yv^(-1), 1, 1}, yw])/32 + 
     G[{0, 0, yv^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, 0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, 0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw]/64 + 
     (33*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (27*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (7*G[{0, 0, 1/(yu*yv), 0, 1}, yw])/64 - 
     G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/64 + 
     (19*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw])/64 - 
     (11*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw])/64 - 
     (19*G[{0, 0, 1/(yu*yv), 1, 1}, yw])/32 + 
     (5*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw]/4 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/32 + 
     (19*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (17*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (27*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{0, 1, 0, 1, 1}, yv]/4 + (7*G[{0, 1, 0, 1, 1}, yw])/64 + 
     G[{0, 1, 0, 1, yu^(-1)}, yv]/8 - G[{0, 1, 0, 1, yu^(-1)}, yw]/64 + 
     (15*G[{0, 1, 0, 1, yv^(-1)}, yw])/64 - G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/
      4 + G[{0, 1, 0, yu^(-1), 1}, yv]/16 + G[{0, 1, 0, yu^(-1), 1}, yw]/16 - 
     (3*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/64 + 
     G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw]/64 + G[{0, 1, 0, yv^(-1), 1}, yw]/
      4 - G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/64 - 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, 1, 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/64 + 
     (3*G[{0, 1, 1, 0, yu^(-1)}, yv])/16 + (3*G[{0, 1, 1, 0, yu^(-1)}, yw])/
      64 + (15*G[{0, 1, 1, 0, yv^(-1)}, yw])/64 - 
     (11*G[{0, 1, 1, 0, 1/(yu*yv)}, yw])/64 + (3*G[{0, 1, 1, 1, 1}, yu])/16 - 
     (3*G[{0, 1, 1, 1, 1}, yv])/16 + (3*G[{0, 1, 1, 1, 1}, yw])/16 - 
     (3*G[{0, 1, 1, 1, yu^(-1)}, yv])/16 - (9*G[{0, 1, 1, 1, yu^(-1)}, yw])/
      64 - (17*G[{0, 1, 1, 1, yv^(-1)}, yw])/64 + 
     G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 - G[{0, 1, 1, yu^(-1), 1}, yv]/16 - 
     (5*G[{0, 1, 1, yu^(-1), 1}, yw])/32 + 
     (3*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (9*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1, 1, yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{0, 1, 1, yv^(-1), 1}, yw])/32 + 
     G[{0, 1, 1, yv^(-1), yu^(-1)}, yw]/64 + 
     (9*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1, 1, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/64 - 
     (13*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yv]/8 - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 1, yu^(-1), 1, 1}, yw])/32 + G[{0, 1, yu^(-1), 1, yu^(-1)}, yv]/
      8 + (17*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (5*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (21*G[{0, 1, yu^(-1), yu^(-1), 1}, yw])/64 - 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv]/8 - 
     (25*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1, yu^(-1), yv^(-1), 1}, yw])/64 - 
     G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/32 + 
     (7*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (9*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (11*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/64 + 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/16 - 
     (13*G[{0, 1, yv^(-1), 1, 1}, yw])/32 + 
     G[{0, 1, yv^(-1), 1, yu^(-1)}, yw]/64 + 
     (9*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1, yv^(-1), yu^(-1), 1}, yw])/64 - 
     G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/32 + 
     (7*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{0, 1, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (7*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw]/32 + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 - 
     (15*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/64 + 
     (5*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     (9*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (17*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (5*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (17*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/64 - 
     (7*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (15*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yv]/8 - 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw]/64 - 
     (3*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw]/8 - 
     (9*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw]/16 - 
     G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1, 1, 1}, yv])/16 + G[{0, yu^(-1), 1, 1, yu^(-1)}, yv]/
      4 + G[{0, yu^(-1), 1, 1, yu^(-1)}, yw]/64 + 
     (5*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw])/64 + 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yv]/16 + 
     (5*G[{0, yu^(-1), 1, yu^(-1), 1}, yw])/32 - 
     G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv]/16 - 
     (25*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yu^(-1), 1, yv^(-1), 1}, yw])/32 - 
     G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/64 + 
     (7*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/64 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/64 - 
     G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yv]/8 + 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/32 - 
     G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv]/16 - 
     (25*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw])/64 - 
     (9*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv]/4 - 
     (29*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw])/64 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv]/8 + 
     (41*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw])/64 + 
     (9*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (25*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw]/16 + 
     (5*G[{0, yu^(-1), yv^(-1), 1, 1}, yw])/32 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/64 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw])/64 + 
     (9*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/32 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 + 
     (15*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw]/64 - 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/64 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/64 + 
     (9*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/32 - 
     (25*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/64 + 
     (7*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     (15*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, yv^(-1), 0, yv^(-1), 1}, yw])/64 + 
     G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw]/16 + 
     (5*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (15*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1, 1, 1}, yw])/16 + 
     (9*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw])/64 + 
     (17*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0, yv^(-1), 1, yu^(-1), 1}, yw])/32 - 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/64 - 
     G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0, yv^(-1), 1, yv^(-1), 1}, yw])/32 - 
     G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/64 - 
     (9*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw]/16 - 
     (7*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (5*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{0, yv^(-1), yu^(-1), 1, 1}, yw])/32 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/64 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw])/64 + 
     (9*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/32 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 + 
     (15*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (13*G[{0, yv^(-1), yv^(-1), 1, 1}, yw])/32 - 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw]/64 - 
     (9*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (15*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (23*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw])/64 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw]/8 - 
     (7*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/64 + 
     (15*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     (15*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (23*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/8 - 
     (7*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/64 - 
     (5*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw])/64 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw])/32 + 
     (17*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw])/32 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw]/64 - 
     (7*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw]/8 + 
     (7*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw])/32 + 
     (9*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (13*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw])/64 - 
     (25*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw]/32 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw])/64 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw]/32 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (17*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (11*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw])/32 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw]/64 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw]/64 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw])/64 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw]/32 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (15*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (23*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw]/2 + 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (11*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (9*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (23*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/8 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1, 1, 1, 1, yu^(-1)}, yv])/16 - G[{1, 1, 1, 1, yu^(-1)}, yw]/16 - 
     (7*G[{1, 1, 1, 1, yv^(-1)}, yw])/16 + G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (25*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, 1, 1, yu^(-1), yv^(-1)}, yw]/16 + 
     (17*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     G[{1, 1, 1, yv^(-1), yu^(-1)}, yw]/16 - 
     (5*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (9*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, 1, yu^(-1), 1, yu^(-1)}, yv])/8 - 
     (33*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (3*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (5*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (13*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv])/16 - 
     G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/64 + 
     (7*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (17*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (11*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (13*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (7*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/64 - 
     (13*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (5*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (5*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     (7*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (5*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 + 
     (23*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     (13*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 + 
     (3*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv]/8 - 
     (41*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (23*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (9*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 - 
     (15*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     (9*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 + 
     G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (9*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 - 
     (15*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/16 + 
     (7*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     (9*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (3*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (3*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (41*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (129*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (17*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (11*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (123*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (17*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*Zeta[3])/256 - (3*G[{0}, yv]^2*Zeta[3])/64 + 
     (G[{0}, yv]*G[{0}, yw]*Zeta[3])/16 + (G[{0}, yw]^2*Zeta[3])/16 - 
     (G[{0}, yu]*G[{1}, yu]*Zeta[3])/16 + (3*G[{0}, yv]*G[{1}, yu]*Zeta[3])/
      32 + (G[{0}, yw]*G[{1}, yu]*Zeta[3])/8 + (7*G[{1}, yu]^2*Zeta[3])/64 + 
     (5*G[{0}, yv]*G[{1}, yv]*Zeta[3])/32 + (G[{0}, yw]*G[{1}, yv]*Zeta[3])/
      16 + (G[{1}, yu]*G[{1}, yv]*Zeta[3])/32 + (G[{1}, yv]^2*Zeta[3])/32 - 
     (5*G[{0}, yv]*G[{1}, yw]*Zeta[3])/32 - (G[{0}, yw]*G[{1}, yw]*Zeta[3])/
      16 - (G[{1}, yu]*G[{1}, yw]*Zeta[3])/32 - 
     (G[{1}, yv]*G[{1}, yw]*Zeta[3])/16 - (G[{1}, yw]^2*Zeta[3])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*Zeta[3])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (3*G[{1/(yu*yv)}, yw]^2*Zeta[3])/64 + (G[{0, 1}, yu]*Zeta[3])/16 - 
     (5*G[{0, 1}, yv]*Zeta[3])/32 + (5*G[{0, 1}, yw]*Zeta[3])/32 - 
     (G[{0, yu^(-1)}, yv]*Zeta[3])/32 + (G[{0, yu^(-1)}, yw]*Zeta[3])/32 - 
     (7*G[{0, yv^(-1)}, yw]*Zeta[3])/32 + (G[{0, 1/(yu*yv)}, yw]*Zeta[3])/
      32 + (G[{1, yu^(-1)}, yv]*Zeta[3])/32 - (G[{1, yu^(-1)}, yw]*Zeta[3])/
      32 + (5*G[{1, yv^(-1)}, yw]*Zeta[3])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/8 - Zeta[5]/64
 
QepvwuRegI = (17*Pi^4*G[{0}, yw])/11520 + (Pi^2*G[{0}, yu]^2*G[{0}, yw])/256 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw]^2)/96 + (Pi^2*G[{0}, yw]^3)/256 + 
     (3*G[{0}, yu]^2*G[{0}, yw]^3)/256 + (17*Pi^4*G[{1}, yu])/11520 + 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/256 + 
     (5*Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu])/384 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu])/768 + 
     (9*G[{0}, yu]^2*G[{0}, yw]^2*G[{1}, yu])/256 - 
     (3*G[{0}, yu]*G[{0}, yw]^3*G[{1}, yu])/128 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/384 - (11*Pi^2*G[{0}, yw]*G[{1}, yu]^2)/
      768 + (9*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]^2)/256 - 
     (5*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]^2)/128 - 
     (5*Pi^2*G[{1}, yu]^3)/768 + (3*G[{0}, yu]^2*G[{1}, yu]^3)/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^3)/384 + (G[{0}, yu]*G[{1}, yu]^4)/
      96 + (17*Pi^4*G[{1}, yv])/11520 + (Pi^2*G[{0}, yu]^2*G[{1}, yv])/256 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/192 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv])/32 + 
     (5*Pi^2*G[{0}, yw]^2*G[{1}, yv])/768 + 
     (9*G[{0}, yu]^2*G[{0}, yw]^2*G[{1}, yv])/256 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]^3*G[{1}, yv])/128 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/48 + 
     (5*Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/384 + 
     (9*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/8 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv])/16 - 
     (7*Pi^2*G[{1}, yu]^2*G[{1}, yv])/768 + 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yv])/256 - 
     (21*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv])/128 - 
     (7*G[{0}, yu]*G[{1}, yu]^3*G[{1}, yv])/192 + 
     (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/384 - (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/
      192 + (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]^2)/64 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/192 + 
     (9*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yv]^2)/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2)/8 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]^2)/64 + 
     (9*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yv]^2)/128 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]^2)/64 + 
     (3*G[{0}, yw]^3*G[{1}, yv]^2)/256 + (Pi^2*G[{1}, yu]*G[{1}, yv]^2)/96 + 
     (9*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2)/32 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]^2)/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2)/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2)/16 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]^2)/256 - 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]^2)/64 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]^2)/64 - 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]^2)/256 - 
     (5*G[{1}, yu]^3*G[{1}, yv]^2)/256 + (Pi^2*G[{1}, yv]^3)/384 + 
     (3*G[{0}, yu]^2*G[{1}, yv]^3)/256 - (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^3)/
      24 + (G[{0}, yv]^2*G[{1}, yv]^3)/96 + 
     (9*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]^3)/128 - 
     (7*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^3)/96 + 
     (9*G[{0}, yw]^2*G[{1}, yv]^3)/256 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^3)/
      64 - (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^3)/96 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^3)/384 - (7*G[{1}, yu]^2*G[{1}, yv]^3)/
      256 + (3*G[{0}, yu]*G[{1}, yv]^4)/128 - (11*G[{0}, yv]*G[{1}, yv]^4)/
      384 + (9*G[{0}, yw]*G[{1}, yv]^4)/256 + (5*G[{1}, yu]*G[{1}, yv]^4)/
      768 + (3*G[{1}, yv]^5)/256 - (17*Pi^4*G[{1}, yw])/11520 - 
     (Pi^2*G[{0}, yu]^2*G[{1}, yw])/256 - 
     (5*Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw])/384 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/768 - 
     (9*G[{0}, yu]^2*G[{0}, yw]^2*G[{1}, yw])/256 + 
     (3*G[{0}, yu]*G[{0}, yw]^3*G[{1}, yw])/128 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw])/192 + 
     (11*Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/384 - 
     (9*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/128 + 
     (5*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw])/64 + 
     (5*Pi^2*G[{1}, yu]^2*G[{1}, yw])/256 - 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yw])/256 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yw])/24 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/192 - 
     (9*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw])/32 + 
     (3*G[{0}, yw]^3*G[{1}, yv]*G[{1}, yw])/128 - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/192 - 
     (9*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/32 + 
     (13*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/64 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/128 - 
     (5*G[{1}, yu]^3*G[{1}, yv]*G[{1}, yw])/128 - 
     (Pi^2*G[{1}, yv]^2*G[{1}, yw])/384 - 
     (9*G[{0}, yu]^2*G[{1}, yv]^2*G[{1}, yw])/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw])/8 - 
     (9*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw])/32 + 
     (9*G[{0}, yw]^2*G[{1}, yv]^2*G[{1}, yw])/256 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/128 + 
     (G[{1}, yu]^2*G[{1}, yv]^2*G[{1}, yw])/256 - 
     (3*G[{0}, yu]*G[{1}, yv]^3*G[{1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]^3*G[{1}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]^3*G[{1}, yw])/32 - (3*G[{1}, yv]^4*G[{1}, yw])/
      256 + (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/384 - 
     (3*Pi^2*G[{0}, yw]*G[{1}, yw]^2)/512 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yw]^3*G[{1}, yw]^2)/256 - (17*Pi^2*G[{1}, yu]*G[{1}, yw]^2)/
      1536 + (3*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]^2)/16 + 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]^2)/256 + 
     (3*G[{1}, yu]^3*G[{1}, yw]^2)/256 + (Pi^2*G[{1}, yv]*G[{1}, yw]^2)/512 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]^2)/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]^2)/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/32 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]^2)/256 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/16 + 
     (15*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/128 + 
     (23*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]^2)/64 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]^2)/64 + (Pi^2*G[{1}, yw]^3)/768 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^3)/384 - (G[{0}, yw]^2*G[{1}, yw]^3)/
      256 - (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^3)/128 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^3)/128 - (G[{1}, yu]^2*G[{1}, yw]^3)/
      256 + (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^3)/384 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^3)/96 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^3)/192 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^3)/64 - (G[{1}, yv]^2*G[{1}, yw]^3)/
      768 - (G[{0}, yw]*G[{1}, yw]^4)/768 - (G[{1}, yu]*G[{1}, yw]^4)/768 - 
     (G[{1}, yv]*G[{1}, yw]^4)/768 + (Pi^2*G[{0}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv])/48 + (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw]*
       G[{yu^(-1)}, yv])/32 - (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/
      128 - (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/
      16 - (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (3*Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (5*G[{1}, yu]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (7*Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (7*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (5*G[{1}, yv]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (7*G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (9*G[{1}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 + 
     (G[{0}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 + 
     (G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/128 + 
     (G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/128 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/96 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/8 - 
     (5*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 - 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/64 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/16 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/32 + 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/64 - 
     (G[{1}, yw]^3*G[{yu^(-1)}, yv]^2)/96 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/48 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/24 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/24 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/16 + 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yv]^3)/192 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^4)/192 - (17*Pi^4*G[{1/(yu*yv)}, yw])/
      11520 - (Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/256 - 
     (Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/768 - 
     (9*G[{0}, yu]^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]^3*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/48 - 
     (5*Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/384 - 
     (9*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/16 + 
     (7*Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/768 - 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/256 + 
     (21*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/96 - 
     (9*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/48 - 
     (9*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (5*G[{1}, yu]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (27*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (27*G[{0}, yw]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (21*G[{1}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yv]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/96 - 
     (9*G[{0}, yw]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/192 - 
     (15*G[{1}, yv]^4*G[{1/(yu*yv)}, yw])/256 + 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (15*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/768 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{1}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (3*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (5*G[{1}, yu]^3*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 + (7*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/384 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yv]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/96 + 
     (G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (5*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (5*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (9*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (5*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (13*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (23*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (13*G[{1}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (13*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (11*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (17*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (23*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{yu^(-1)}, yv]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (7*Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/512 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (11*G[{1}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (11*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (5*G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/768 + (3*G[{0}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/4 - (3*G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (9*G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (5*G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yv]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/192 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (7*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (11*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/768 - (3*G[{0}, yu]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/192 - (7*Pi^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/512 - (3*G[{0}, yu]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 - (9*G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (15*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/8 - (21*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (29*G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (9*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/4 + (3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (13*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/12 + (G[{0}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/12 + (25*G[{0}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (41*G[{1}, yu]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (3*G[{1}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/64 - (41*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/
      768 + (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/384 + 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/192 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (7*Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yu]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]^3*G[{1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (17*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (7*G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (9*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{0}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (31*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{1}, yv]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (11*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (13*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (9*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/64 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (15*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (7*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (15*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/4 - 
     (13*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (41*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (13*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (13*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (21*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (21*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/8 - (21*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/8 + 
     (17*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (15*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (33*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (11*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (3*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (9*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (11*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (19*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (15*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (15*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{0}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (15*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (15*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (19*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (19*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (5*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{0}, yu]*G[{0}, yv]*
       G[{1/(yu*yv)}, yw]^3)/48 - (5*G[{0}, yu]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]^3)/384 + (G[{0}, yv]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]^3)/96 - (13*G[{0}, yu]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw]^3)/384 + (G[{0}, yv]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw]^3)/96 + (G[{0}, yw]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw]^3)/96 + (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/24 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/192 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (13*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (7*Pi^2*G[{0}, yw]*G[{0, 1}, yu])/384 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yw]^3*G[{0, 1}, yu])/128 + (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/
      128 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu])/8 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu])/32 - 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu])/128 - 
     (5*G[{1}, yu]^3*G[{0, 1}, yu])/128 + (Pi^2*G[{1}, yv]*G[{0, 1}, yu])/
      128 - (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (5*G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/8 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/64 - 
     (7*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yu])/128 + 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu])/128 + 
     (13*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/128 + 
     (5*G[{1}, yv]^3*G[{0, 1}, yu])/384 - (Pi^2*G[{1}, yw]*G[{0, 1}, yu])/
      128 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu])/8 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/64 + 
     (15*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/64 - 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/32 - 
     (9*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu])/128 - 
     (13*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/128 - 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/128 + 
     (G[{1}, yw]^3*G[{0, 1}, yu])/96 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (13*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/
      32 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{0, 1}, yu]^2)/32 + (G[{0}, yw]*G[{0, 1}, yu]^2)/32 + 
     (G[{1}, yu]*G[{0, 1}, yu]^2)/32 + (G[{1}, yv]*G[{0, 1}, yu]^2)/32 - 
     (G[{1}, yw]*G[{0, 1}, yu]^2)/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2)/
      32 - (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yv])/32 + 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yv])/48 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv])/8 + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/8 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/8 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv])/32 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/16 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/32 + 
     (G[{1}, yw]^3*G[{0, 1}, yv])/96 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/8 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 - 
     (G[{0}, yu]*G[{0, 1}, yv]^2)/32 + (G[{0}, yw]*G[{0, 1}, yv]^2)/16 + 
     (G[{1}, yu]*G[{0, 1}, yv]^2)/16 + (G[{1}, yv]*G[{0, 1}, yv]^2)/32 - 
     (3*G[{1}, yw]*G[{0, 1}, yv]^2)/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2)/
      32 + (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yw])/32 - 
     (5*Pi^2*G[{1}, yu]*G[{0, 1}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yw])/64 - 
     (7*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw])/16 + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yw])/16 - 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yw])/64 - 
     (3*G[{1}, yv]^3*G[{0, 1}, yw])/64 + (11*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/
      768 - (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (9*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yw]^3*G[{0, 1}, yw])/128 + (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/
      96 + (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/24 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      16 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 - 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/32 + 
     (9*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1}, yw]^2)/32 - (G[{0}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{1}, yu]*G[{0, 1}, yw]^2)/32 + (7*G[{1}, yw]*G[{0, 1}, yw]^2)/128 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/128 - 
     (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/96 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/16 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yv])/96 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv])/16 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/96 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 - (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/8 + (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/8 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 + (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/8 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/8 - (G[{1}, yw]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/16 - (G[{1}, yv]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1}, yw]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/16 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{0}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (3*G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1}, yu]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/8 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/8 + (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/8 + (G[{1}, yv]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/96 - 
     (3*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw])/16 - 
     (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yv]^3*G[{0, yu^(-1)}, yw])/64 + 
     (5*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (13*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (9*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yw])/32 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (9*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/32 + 
     (9*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]^3*G[{0, yv^(-1)}, yw])/16 - 
     (Pi^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/4 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/16 + 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]^3*G[{0, yv^(-1)}, yw])/64 - 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (11*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (9*G[{1}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (9*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (17*Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw])/64 - 
     (13*Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (11*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (9*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/24 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 - (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/64 - (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 - (G[{0}, yu]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{1}, yu]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yw]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{0}, yu]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (5*G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (5*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (5*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/128 + 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/48 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1, yu^(-1)}, yv])/32 - 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]^3*G[{1, yu^(-1)}, yv])/128 + 
     (3*Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/32 + 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/128 + 
     (5*G[{1}, yu]^3*G[{1, yu^(-1)}, yv])/128 - 
     (7*Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/16 + 
     (7*G[{0}, yw]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/128 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/128 + 
     (5*G[{1}, yv]^3*G[{1, yu^(-1)}, yv])/128 + 
     (7*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (13*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/8 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/8 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/384 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/8 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/4 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      32 + (5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (3*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      32 - (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (7*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (5*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1, yu^(-1)}, yv]^2)/32 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]^2)/16 + 
     (3*G[{1}, yv]*G[{1, yu^(-1)}, yv]^2)/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]^2)/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]^2)/16 - 
     (13*Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^3*G[{1, yu^(-1)}, yw])/128 - 
     (13*Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/32 - 
     (9*G[{0}, yw]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/128 - 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yu]^3*G[{1, yu^(-1)}, yw])/128 - 
     (13*Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (13*G[{0}, yw]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/16 - 
     (11*G[{0}, yw]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/128 - 
     (11*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{1}, yv]^3*G[{1, yu^(-1)}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yw])/16 + 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (11*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 - (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 + (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/32 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 + (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 - (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/8 - (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/8 - (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yw])/8 + (G[{0}, yu]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (5*G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 + (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 + (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (5*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (5*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (5*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 - (3*G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/32 - (3*G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 - (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yv]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu]*G[{1, yv^(-1)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{1, yv^(-1)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1, yv^(-1)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (Pi^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 - 
     (9*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]^3*G[{1, yv^(-1)}, yw])/16 + 
     (Pi^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/4 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/16 - 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv]^3*G[{1, yv^(-1)}, yw])/64 + 
     (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/192 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/32 + 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (11*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (7*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 - (7*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (3*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/4 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1, yv^(-1)}, yw]^2)/8 + 
     (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yv]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]^2)/8 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*Pi^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yu]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yw]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yv]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (17*G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/16 + 
     (19*G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (11*G[{1}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (15*G[{1}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (5*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw])/48 - 
     (7*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (9*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 - 
     (5*Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*Pi^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*Pi^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (13*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (23*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (13*G[{1}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (13*Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/384 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (17*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{yu^(-1)}, yv]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{yu^(-1)}, yv]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu^(-1)}, yv]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{yu^(-1)}, yv]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (13*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (15*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (15*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (9*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 + (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (19*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (9*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (9*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (3*G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (5*G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (9*G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/192 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (7*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (7*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (7*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (7*G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 + 
     (7*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (9*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (15*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (21*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (29*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (9*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (13*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (9*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (7*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (25*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (41*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (41*G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (9*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (9*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (3*G[{0}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (13*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (9*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (5*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (13*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (3*G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (5*G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yu]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (5*G[{1}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (7*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (5*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 - 
     (G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0, 0, 1}, yu])/96 + (G[{0}, yw]^2*G[{0, 0, 1}, yu])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yu])/4 + 
     (G[{1}, yu]^2*G[{0, 0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yu])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu])/4 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{1}, yw]^2*G[{0, 0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yu])/8 - (G[{0, 1}, yv]*G[{0, 0, 1}, yu])/
      8 + (G[{0, 1}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 + 
     (Pi^2*G[{0, 0, 1}, yv])/96 + (G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yv])/
      16 + (G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yv])/4 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv])/16 - 
     (G[{1}, yv]^2*G[{0, 0, 1}, yv])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yv])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/4 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/4 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yv])/16 - (G[{0, 1}, yv]*G[{0, 0, 1}, yv])/
      16 - (G[{0, 1}, yw]*G[{0, 0, 1}, yv])/16 + 
     (5*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/4 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yv])/16 - 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/4 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 - 
     (Pi^2*G[{0, 0, 1}, yw])/64 - (3*G[{0}, yu]^2*G[{0, 0, 1}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1}, yw])/64 + 
     (19*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{0, 0, 1}, yw])/64 + 
     (9*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw])/32 + 
     (15*G[{1}, yv]^2*G[{0, 0, 1}, yw])/128 - 
     (15*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw])/32 - 
     (17*G[{1}, yw]^2*G[{0, 0, 1}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/4 + 
     (15*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yw])/16 - 
     (13*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw])/64 - 
     (7*G[{0, 1}, yu]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0, 1}, yv]*G[{0, 0, 1}, yw])/16 + (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/
      32 - (3*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yw])/16 - 
     (7*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (19*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/4 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/4 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/4 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (5*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/4 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/4 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/192 + 
     (3*G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (9*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (17*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (7*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]^2*G[{0, 0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]^2*G[{0, 0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw])/64 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (9*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (11*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (15*G[{1}, yv]^2*G[{0, 0, yv^(-1)}, yw])/128 + 
     (15*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (25*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (17*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (13*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yv]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (7*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/192 - 
     (3*G[{0}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (11*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (25*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (17*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (17*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0, 1, 1}, yu])/96 - (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yu])/
      16 + (G[{0}, yw]^2*G[{0, 1, 1}, yu])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yu])/8 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yu]^2*G[{0, 1, 1}, yu])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/8 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yv]^2*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/8 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yw]^2*G[{0, 1, 1}, yu])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{0, 1}, yu]*G[{0, 1, 1}, yu])/8 - (3*G[{0, 1}, yv]*G[{0, 1, 1}, yu])/
      16 + (G[{0, 1}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yu])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (Pi^2*G[{0, 1, 1}, yv])/96 + (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yv])/
      16 + (G[{0}, yv]^2*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yv])/8 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yv])/16 + 
     (3*G[{0}, yw]^2*G[{0, 1, 1}, yv])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yv])/8 - 
     (5*G[{1}, yu]^2*G[{0, 1, 1}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv])/8 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv])/16 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yv])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (5*Pi^2*G[{0, 1, 1}, yw])/256 + (3*G[{0}, yu]^2*G[{0, 1, 1}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{0, 1, 1}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (13*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yw])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw])/8 - 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (9*G[{0, 1}, yu]*G[{0, 1, 1}, yw])/64 - (G[{0, 1}, yv]*G[{0, 1, 1}, yw])/
      16 - (5*G[{0, 1}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 + 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (Pi^2*G[{0, 1, yu^(-1)}, yv])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (11*Pi^2*G[{0, 1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (5*Pi^2*G[{0, 1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (3*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (11*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (17*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (13*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (25*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0, 1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0, yu^(-1), 1}, yv])/96 - (G[{0}, yv]^2*G[{0, yu^(-1), 1}, yv])/
      32 + (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/8 + 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yv])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (7*Pi^2*G[{0, yu^(-1), 1}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0, yu^(-1), 1}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/64 - 
     (3*G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (13*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 + 
     (5*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (5*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (5*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/
      32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/
      16 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (11*Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      16 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (17*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      64 - (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0, 1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0, yv^(-1), 1}, yw])/128 - 
     (G[{0}, yv]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw])/8 + 
     (9*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/8 + 
     (9*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (13*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1}, yw])/8 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0, 1}, yu]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{0, 1}, yv]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (7*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 - 
     (11*Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yv]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      16 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (7*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (9*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (21*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (29*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (13*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (7*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (17*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (33*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/
      32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/
      16 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (7*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      64 - (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/128 + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (11*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (13*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/128 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (3*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (7*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (5*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      32 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/32 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (11*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (17*G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      32 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (19*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (17*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (11*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (7*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1, 1, yu^(-1)}, yv])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/4 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (7*Pi^2*G[{1, 1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (17*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (11*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (23*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (9*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (17*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (3*Pi^2*G[{1, 1, yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/16 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (17*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (13*G[{1}, yv]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (7*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (19*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (15*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (15*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, yv^(-1)}, yw])/4 + 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (11*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (5*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (5*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (15*G[{1, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/24 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/48 - 
     (G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/4 - 
     (5*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (5*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/4 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/4 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/2 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/
      16 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yv])/8 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (5*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/4 - 
     (5*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (11*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (5*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (11*Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yu]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv]^2*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      32 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      16 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (7*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (13*G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      64 + (13*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, 1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yu]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      32 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      16 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (7*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (9*G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (21*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (29*G[{1}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (13*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (31*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (15*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (33*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      32 + (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/32 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (7*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (7*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 + (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, 1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/8 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (11*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 + (11*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (11*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (7*G[{0, 1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (11*Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 + (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 + (7*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (7*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      64 + (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 - (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/64 - (G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (23*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (29*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (11*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 - (5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (23*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (43*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (5*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (43*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 - (15*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 - (7*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (21*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (29*G[{1}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (25*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (41*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (41*G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (9*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (17*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (17*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (13*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (21*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (25*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (25*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (7*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (25*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (41*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (9*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (41*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (9*G[{0}, yw]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 0, 1, 1}, yu])/16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yu])/
      8 + (G[{1}, yv]*G[{0, 0, 1, 1}, yu])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yu])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yu])/8 - 
     (G[{0}, yu]*G[{0, 0, 1, 1}, yv])/16 - (G[{0}, yv]*G[{0, 0, 1, 1}, yv])/
      8 + (5*G[{0}, yw]*G[{0, 0, 1, 1}, yv])/16 + 
     (3*G[{1}, yu]*G[{0, 0, 1, 1}, yv])/16 + (G[{1}, yv]*G[{0, 0, 1, 1}, yv])/
      8 - (3*G[{1}, yw]*G[{0, 0, 1, 1}, yv])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv])/8 + 
     (3*G[{0}, yu]*G[{0, 0, 1, 1}, yw])/16 + (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/
      16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, 1, 1}, yw])/4 + (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/
      32 - (3*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yw])/16 - 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/32 + 
     (G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/16 - 
     (5*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv])/4 - 
     (G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/8 + 
     (3*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/8 - 
     (7*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (13*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (25*G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv])/4 - 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv])/16 + 
     (3*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (9*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw])/32 - 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/8 + 
     (7*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (5*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (9*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/4 - 
     (25*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 - 
     (41*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (19*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 - 
     (5*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (17*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (13*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (19*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, 1, 1, 1}, yu])/16 - (G[{0}, yw]*G[{0, 1, 1, 1}, yu])/
      16 + (G[{1}, yu]*G[{0, 1, 1, 1}, yu])/8 + 
     (G[{1}, yv]*G[{0, 1, 1, 1}, yu])/8 - (G[{1}, yw]*G[{0, 1, 1, 1}, yu])/
      8 - (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu])/8 + 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yv])/16 - (G[{0}, yv]*G[{0, 1, 1, 1}, yv])/
      8 + (G[{0}, yw]*G[{0, 1, 1, 1}, yv])/4 + 
     (G[{1}, yu]*G[{0, 1, 1, 1}, yv])/8 + (G[{1}, yv]*G[{0, 1, 1, 1}, yv])/
      8 - (3*G[{1}, yw]*G[{0, 1, 1, 1}, yv])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yw])/8 + (9*G[{0}, yw]*G[{0, 1, 1, 1}, yw])/
      64 + (9*G[{1}, yu]*G[{0, 1, 1, 1}, yw])/64 + 
     (17*G[{1}, yv]*G[{0, 1, 1, 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (5*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv])/16 + 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv])/16 - 
     (3*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yv])/8 - 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/2 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (7*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (13*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (17*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (17*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (5*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw])/32 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (13*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (25*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (21*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (7*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (9*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (9*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (17*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (7*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (9*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (17*G[{1}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yw])/8 - 
     (9*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (17*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/8 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/4 - 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/32 - 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (13*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (15*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (5*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (15*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (23*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (15*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (5*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (13*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (25*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (5*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (25*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (25*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/2 - 
     (25*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (41*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (29*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (25*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (9*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (13*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (25*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (5*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (9*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (17*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (7*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (13*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (5*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (13*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (25*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (13*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (15*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (11*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (15*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (23*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (15*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/4 + 
     (G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (29*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (29*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (41*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (3*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (5*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (9*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (29*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (9*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (9*G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (25*G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (41*G[{1}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (21*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (21*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 - 
     (3*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/2 + 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/2 + 
     (25*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (41*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (23*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{1}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (11*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (7*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      64 + (5*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (23*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (23*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (43*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (43*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/
      64 - (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      8 - (15*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      64 - (7*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      64 - (23*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      64 + (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      2 - (G[{0}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (25*G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (41*G[{1}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (25*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (41*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (7*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (23*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (9*G[{0, 0, 0, 1, 1}, yu])/16 + 
     (3*G[{0, 0, 0, 1, 1}, yv])/8 - (3*G[{0, 0, 0, 1, yu^(-1)}, yv])/16 + 
     (9*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 - (3*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      8 - (3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1}, yv])/16 + (9*G[{0, 0, 0, yu^(-1), 1}, yw])/
      16 - (9*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{0, 0, 0, yv^(-1), 1}, yw])/8 - 
     (3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0, 0, 1, 0, 1}, yu])/16 + G[{0, 0, 1, 0, 1}, yv]/8 - 
     (3*G[{0, 0, 1, 0, 1}, yw])/64 - G[{0, 0, 1, 0, yu^(-1)}, yv]/16 + 
     (15*G[{0, 0, 1, 0, yu^(-1)}, yw])/64 - (5*G[{0, 0, 1, 0, yv^(-1)}, yw])/
      64 - (7*G[{0, 0, 1, 0, 1/(yu*yv)}, yw])/64 + (3*G[{0, 0, 1, 1, 1}, yu])/
      8 + G[{0, 0, 1, 1, 1}, yv]/8 + (3*G[{0, 0, 1, 1, 1}, yw])/8 - 
     (3*G[{0, 0, 1, 1, yu^(-1)}, yv])/16 + (7*G[{0, 0, 1, 1, yu^(-1)}, yw])/
      32 - (3*G[{0, 0, 1, 1, yv^(-1)}, yw])/32 - 
     (9*G[{0, 0, 1, 1, 1/(yu*yv)}, yw])/32 - G[{0, 0, 1, yu^(-1), 1}, yv]/8 + 
     (11*G[{0, 0, 1, yu^(-1), 1}, yw])/64 - 
     (3*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (15*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 0, 1, yv^(-1), 1}, yw])/64 - 
     (3*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (41*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 0, 1, 1/(yu*yv), 1}, yw])/32 - 
     G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - G[{0, 0, yu^(-1), 0, 1}, yv]/
      16 + (15*G[{0, 0, yu^(-1), 0, 1}, yw])/64 - 
     (27*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw])/64 + 
     (19*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw])/64 - 
     G[{0, 0, yu^(-1), 1, 1}, yv]/4 + (11*G[{0, 0, yu^(-1), 1, 1}, yw])/32 - 
     G[{0, 0, yu^(-1), 1, yu^(-1)}, yv]/16 + 
     G[{0, 0, yu^(-1), 1, yv^(-1)}, yw]/16 - 
     (3*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     G[{0, 0, yu^(-1), yu^(-1), 1}, yv]/8 - 
     (5*G[{0, 0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (33*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (27*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (17*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw])/32 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/32 - 
     (5*G[{0, 0, yv^(-1), 0, 1}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw])/64 + 
     (13*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw])/64 - 
     G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/64 + 
     (3*G[{0, 0, yv^(-1), 1, 1}, yw])/32 - 
     (5*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (21*G[{0, 0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw]/64 + 
     (17*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (21*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (5*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (7*G[{0, 0, 1/(yu*yv), 0, 1}, yw])/64 + 
     (19*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw])/64 - 
     G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/64 - 
     (11*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw])/64 - 
     (19*G[{0, 0, 1/(yu*yv), 1, 1}, yw])/32 + 
     G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw]/4 + 
     (5*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/32 + 
     (27*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (19*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{0, 1, 0, 1, 1}, yu]/4 + (7*G[{0, 1, 0, 1, 1}, yw])/64 - 
     (3*G[{0, 1, 0, 1, yu^(-1)}, yv])/16 + (15*G[{0, 1, 0, 1, yu^(-1)}, yw])/
      64 - G[{0, 1, 0, 1, yv^(-1)}, yw]/64 - G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/
      4 - G[{0, 1, 0, yu^(-1), 1}, yv]/8 + G[{0, 1, 0, yu^(-1), 1}, yw]/4 - 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yv]/8 - 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yw]/16 - 
     (5*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, 1, 0, yv^(-1), 1}, yw]/16 - (5*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw])/
      64 - (3*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw]/64 - 
     (5*G[{0, 1, 0, 1/(yu*yv), 1}, yw])/16 + 
     G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/64 + 
     (15*G[{0, 1, 1, 0, yu^(-1)}, yw])/64 + (3*G[{0, 1, 1, 0, yv^(-1)}, yw])/
      64 - (11*G[{0, 1, 1, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1, 1, 1, 1}, yu])/16 + (3*G[{0, 1, 1, 1, 1}, yv])/16 + 
     (3*G[{0, 1, 1, 1, 1}, yw])/16 + G[{0, 1, 1, 1, yu^(-1)}, yv]/16 - 
     (17*G[{0, 1, 1, 1, yu^(-1)}, yw])/64 - (9*G[{0, 1, 1, 1, yv^(-1)}, yw])/
      64 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 + G[{0, 1, 1, yu^(-1), 1}, yv]/
      8 - (11*G[{0, 1, 1, yu^(-1), 1}, yw])/32 + 
     G[{0, 1, 1, yu^(-1), yu^(-1)}, yv]/4 + 
     (9*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1, 1, yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, 1, 1, yv^(-1), 1}, yw])/32 + G[{0, 1, 1, yv^(-1), yu^(-1)}, yw]/
      64 + (9*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1, 1, 1/(yu*yv), 1}, yw])/16 - 
     (13*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/64 - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yv]/8 + 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, yu^(-1), 0, yv^(-1)}, yw]/16 + (3*G[{0, 1, yu^(-1), 1, 1}, yv])/
      16 - (13*G[{0, 1, yu^(-1), 1, 1}, yw])/32 + 
     (3*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (9*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     G[{0, 1, yu^(-1), 1, yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, yu^(-1), yu^(-1), 1}, yv]/8 + 
     (13*G[{0, 1, yu^(-1), yu^(-1), 1}, yw])/64 - 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv]/4 + 
     (7*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (7*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw]/32 - 
     (15*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/64 - 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 1, yv^(-1), 1, 1}, yw])/32 + 
     (5*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (17*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (7*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (21*G[{0, 1, yv^(-1), yv^(-1), 1}, yw])/64 - 
     G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/32 - 
     (25*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (11*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/64 + 
     (5*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     (17*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (9*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (11*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (7*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/64 + 
     (17*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yv]/16 + 
     (3*G[{0, yu^(-1), 0, yu^(-1), 1}, yw])/64 + 
     (5*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (15*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw]/16 + 
     (3*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (7*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw]/64 + 
     (3*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1, 1, 1}, yw])/16 + 
     (17*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw])/64 + 
     (9*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yv]/8 + 
     (11*G[{0, yu^(-1), 1, yu^(-1), 1}, yw])/32 - 
     G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv]/8 - 
     (9*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, yu^(-1), 1, yv^(-1), 1}, yw])/32 - 
     G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/64 - 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw]/16 + 
     (5*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw]/16 + 
     (3*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yv]/4 + 
     (13*G[{0, yu^(-1), yu^(-1), 1, 1}, yw])/32 - 
     G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv]/8 - 
     (9*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (13*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (23*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw]/16 + 
     (5*G[{0, yu^(-1), yv^(-1), 1, 1}, yw])/32 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/64 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/32 + 
     (15*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw]/64 + 
     (3*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw]/8 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (7*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (5*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (23*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (15*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     (15*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/8 - 
     (7*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{0, yv^(-1), 0, yv^(-1), 1}, yw]/64 - 
     G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (9*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/64 + 
     (3*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw])/64 + 
     G[{0, yv^(-1), 1, 1, yv^(-1)}, yw]/64 + 
     (3*G[{0, yv^(-1), 1, yu^(-1), 1}, yw])/32 + 
     (7*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, yv^(-1), 1, yv^(-1), 1}, yw])/32 - 
     G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/64 - 
     (25*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/64 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (5*G[{0, yv^(-1), yu^(-1), 1, 1}, yw])/32 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/64 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/32 + 
     (15*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/32 - 
     (9*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (25*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (29*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw])/64 + 
     (9*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (41*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (7*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (25*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/64 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     (9*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/64 + 
     (7*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (7*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/32 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/64 - 
     (25*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw])/64 - 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/64 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw])/32 - 
     (7*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw])/32 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw]/64 + 
     (17*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw]/8 + 
     (7*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw])/32 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw]/64 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw]/64 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (23*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw])/32 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (9*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw])/64 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw]/32 - 
     (25*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (11*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (17*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw]/2 + 
     (11*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (9*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (23*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/8 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, 1, 1, 1, yu^(-1)}, yv]/16 - (7*G[{1, 1, 1, 1, yu^(-1)}, yw])/16 - 
     G[{1, 1, 1, 1, yv^(-1)}, yw]/16 + G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, 1, yu^(-1), yu^(-1)}, yv])/16 - 
     (5*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     G[{1, 1, 1, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, 1, yv^(-1), yu^(-1)}, yw]/16 - 
     (25*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (17*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (9*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{1, 1, yu^(-1), 1, yu^(-1)}, yv]/16 - 
     (13*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (11*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (15*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv])/16 - 
     (13*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (3*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (33*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (5*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (7*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/64 - 
     G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (21*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (17*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (5*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     (7*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     (5*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/16 - 
     G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (3*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (11*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 + 
     (5*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (23*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (3*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (7*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (41*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (11*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (123*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (17*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 - 
     (3*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (41*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (129*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (17*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*Zeta[3])/256 - (3*G[{0}, yu]^2*Zeta[3])/64 + 
     (G[{0}, yu]*G[{0}, yw]*Zeta[3])/16 + (G[{0}, yw]^2*Zeta[3])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*Zeta[3])/32 + (G[{0}, yw]*G[{1}, yu]*Zeta[3])/
      16 + (G[{1}, yu]^2*Zeta[3])/32 + (3*G[{0}, yu]*G[{1}, yv]*Zeta[3])/32 - 
     (G[{0}, yv]*G[{1}, yv]*Zeta[3])/16 + (G[{0}, yw]*G[{1}, yv]*Zeta[3])/8 + 
     (G[{1}, yu]*G[{1}, yv]*Zeta[3])/16 + (7*G[{1}, yv]^2*Zeta[3])/64 - 
     (5*G[{0}, yu]*G[{1}, yw]*Zeta[3])/32 - (G[{0}, yw]*G[{1}, yw]*Zeta[3])/
      16 - (G[{1}, yu]*G[{1}, yw]*Zeta[3])/16 - 
     (G[{1}, yv]*G[{1}, yw]*Zeta[3])/32 - (G[{1}, yw]^2*Zeta[3])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*Zeta[3])/32 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*Zeta[3])/64 - (5*G[{0, 1}, yu]*Zeta[3])/32 + 
     (G[{0, 1}, yv]*Zeta[3])/16 + (5*G[{0, 1}, yw]*Zeta[3])/32 - 
     (7*G[{0, yu^(-1)}, yw]*Zeta[3])/32 + (G[{0, yv^(-1)}, yw]*Zeta[3])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*Zeta[3])/32 - (G[{1, yu^(-1)}, yv]*Zeta[3])/32 + 
     (5*G[{1, yu^(-1)}, yw]*Zeta[3])/16 - (G[{1, yv^(-1)}, yw]*Zeta[3])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - Zeta[5]/64
 
QepvuwRegI = (17*Pi^4*G[{0}, yu])/11520 + (Pi^2*G[{0}, yu]^3)/256 + 
     (Pi^2*G[{0}, yu]^2*G[{0}, yw])/96 + (Pi^2*G[{0}, yu]*G[{0}, yw]^2)/256 + 
     (3*G[{0}, yu]^3*G[{0}, yw]^2)/256 - (17*Pi^4*G[{1}, yu])/11520 - 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/768 - 
     (5*Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu])/384 + 
     (3*G[{0}, yu]^3*G[{0}, yw]*G[{1}, yu])/128 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu])/256 - 
     (9*G[{0}, yu]^2*G[{0}, yw]^2*G[{1}, yu])/256 - 
     (3*Pi^2*G[{0}, yu]*G[{1}, yu]^2)/512 + (3*G[{0}, yu]^3*G[{1}, yu]^2)/
      256 + (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/384 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]^2)/128 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]^2)/256 + (Pi^2*G[{1}, yu]^3)/768 - 
     (G[{0}, yu]^2*G[{1}, yu]^3)/256 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^3)/
      384 - (G[{0}, yu]*G[{1}, yu]^4)/768 + (17*Pi^4*G[{1}, yv])/11520 + 
     (5*Pi^2*G[{0}, yu]^2*G[{1}, yv])/768 + (Pi^2*G[{0}, yv]^2*G[{1}, yv])/
      192 + (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv])/128 + 
     (3*G[{0}, yu]^3*G[{0}, yw]*G[{1}, yv])/128 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv])/32 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yv])/256 + 
     (9*G[{0}, yu]^2*G[{0}, yw]^2*G[{1}, yv])/256 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv])/256 + 
     (3*G[{0}, yu]^3*G[{1}, yu]*G[{1}, yv])/128 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/96 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/96 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv])/128 + 
     (Pi^2*G[{1}, yu]^2*G[{1}, yv])/768 - 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yv])/256 + 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yv])/96 + (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/
      192 + (3*G[{0}, yu]^3*G[{1}, yv]^2)/256 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/192 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]^2)/64 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]^2)/64 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/384 + 
     (9*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yv]^2)/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2)/8 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]^2)/64 + 
     (9*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yv]^2)/256 - 
     (7*Pi^2*G[{1}, yu]*G[{1}, yv]^2)/768 - 
     (9*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]^2)/256 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]^2)/64 - 
     (17*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2)/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2)/32 - 
     (5*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]^2)/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]^2)/32 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]^2)/64 + (G[{1}, yu]^3*G[{1}, yv]^2)/
      64 + (Pi^2*G[{1}, yv]^3)/384 + (9*G[{0}, yu]^2*G[{1}, yv]^3)/256 - 
     (7*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^3)/96 + (G[{0}, yv]^2*G[{1}, yv]^3)/
      96 + (9*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]^3)/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^3)/24 + (3*G[{0}, yw]^2*G[{1}, yv]^3)/
      256 - (9*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^3)/128 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^3)/48 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^3)/384 - 
     (5*G[{1}, yu]^2*G[{1}, yv]^3)/256 + (9*G[{0}, yu]*G[{1}, yv]^4)/256 - 
     (11*G[{0}, yv]*G[{1}, yv]^4)/384 + (3*G[{0}, yw]*G[{1}, yv]^4)/128 - 
     (G[{1}, yu]*G[{1}, yv]^4)/192 + (3*G[{1}, yv]^5)/256 + 
     (17*Pi^4*G[{1}, yw])/11520 + (Pi^2*G[{0}, yu]^2*G[{1}, yw])/768 + 
     (5*Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw])/384 - 
     (3*G[{0}, yu]^3*G[{0}, yw]*G[{1}, yw])/128 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/256 + 
     (9*G[{0}, yu]^2*G[{0}, yw]^2*G[{1}, yw])/256 + 
     (3*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw])/256 - 
     (3*G[{0}, yu]^3*G[{1}, yu]*G[{1}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/192 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw])/128 - 
     (Pi^2*G[{1}, yu]^2*G[{1}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yw])/256 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yw])/192 + 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw])/192 - 
     (3*G[{0}, yu]^3*G[{1}, yv]*G[{1}, yw])/128 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/32 + 
     (9*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw])/128 + 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/384 + 
     (15*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/8 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/32 - 
     (11*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/64 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/16 - 
     (5*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/32 + 
     (G[{1}, yu]^3*G[{1}, yv]*G[{1}, yw])/32 + (Pi^2*G[{1}, yv]^2*G[{1}, yw])/
      384 - (9*G[{0}, yu]^2*G[{1}, yv]^2*G[{1}, yw])/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw])/32 + 
     (9*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw])/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw])/8 + 
     (9*G[{0}, yw]^2*G[{1}, yv]^2*G[{1}, yw])/256 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/8 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/128 - 
     (23*G[{1}, yu]^2*G[{1}, yv]^2*G[{1}, yw])/256 - 
     (G[{0}, yv]*G[{1}, yv]^3*G[{1}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv]^3*G[{1}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yv]^3*G[{1}, yw])/64 + (3*G[{1}, yv]^4*G[{1}, yw])/
      256 - (11*Pi^2*G[{0}, yu]*G[{1}, yw]^2)/768 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/384 - 
     (5*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]^2)/256 + 
     (Pi^2*G[{1}, yu]*G[{1}, yw]^2)/192 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]^2)/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/128 - 
     (5*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]^2)/256 - 
     (5*Pi^2*G[{1}, yv]*G[{1}, yw]^2)/768 - 
     (5*G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]^2)/128 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]^2)/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/128 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/32 + 
     (9*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/8 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/128 - 
     (19*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]^2)/256 - 
     (11*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]^2)/32 + 
     (5*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]^2)/64 - 
     (G[{1}, yv]^3*G[{1}, yw]^2)/256 - (5*Pi^2*G[{1}, yw]^3)/768 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^3)/384 + (3*G[{0}, yw]^2*G[{1}, yw]^3)/
      256 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^3)/32 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^3)/128 + 
     (3*G[{1}, yu]^2*G[{1}, yw]^3)/256 + (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^3)/
      384 + (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^3)/96 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^3)/192 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^3)/64 + 
     (11*G[{1}, yv]^2*G[{1}, yw]^3)/768 + (G[{0}, yw]*G[{1}, yw]^4)/96 + 
     (G[{1}, yu]*G[{1}, yw]^4)/96 + (G[{1}, yv]*G[{1}, yw]^4)/96 - 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/768 - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/96 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/192 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (G[{1}, yu]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/4 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/4 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (11*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (9*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/16 + 
     (3*G[{1}, yv]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (5*Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 - 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 - 
     (13*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (19*G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 + 
     (7*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 - 
     (17*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (17*G[{1}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 - 
     (11*G[{0}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 - 
     (5*G[{0}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 - 
     (7*G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/128 - 
     (G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/32 + 
     (7*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/512 + 
     (9*G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (9*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/4 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 + 
     (35*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/256 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/8 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/64 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/64 + 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/256 + 
     (31*G[{1}, yw]^3*G[{yu^(-1)}, yv]^2)/768 - 
     (25*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/192 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/12 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/12 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/64 - 
     (67*G[{1}, yw]^2*G[{yu^(-1)}, yv]^3)/768 + 
     (41*G[{1}, yw]*G[{yu^(-1)}, yv]^4)/768 - (17*Pi^4*G[{1/(yu*yv)}, yw])/
      11520 - (5*Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]^3*G[{0}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu]^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^3*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/768 + 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/256 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yu]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/192 - 
     (9*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/384 + 
     (9*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (17*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (27*G[{0}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (27*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yw]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (27*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (15*G[{1}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yv]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yw]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/48 - 
     (15*G[{1}, yv]^4*G[{1/(yu*yv)}, yw])/256 - 
     (5*Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/384 + 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (19*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/768 + 
     (21*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{1}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (21*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (33*G[{1}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/768 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/192 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu]^3*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 + (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/768 - (3*G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      4 - (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{1}, yv]^3*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 + (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 + (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 + (9*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 + (9*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      4 - (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (19*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (7*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (11*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 + (13*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (25*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (21*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (7*Pi^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/512 - 
     (9*G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 + 
     (9*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/32 - 
     (35*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (31*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (25*G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/192 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/12 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/12 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/64 + 
     (67*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/384 - 
     (41*G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/768 + 
     (5*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (13*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 - 
     (11*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (5*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (13*G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (23*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (13*G[{1}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (5*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (7*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (7*Pi^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/512 + (G[{0}, yu]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (7*G[{0}, yu]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (7*G[{0}, yu]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 - (G[{0}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 - (G[{1}, yu]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 - (11*G[{1}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 - (7*G[{1}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (7*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (11*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/
      768 + (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (7*Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 - 
     (17*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (19*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yu]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (7*Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/384 + (G[{0}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (19*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (11*G[{0}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (5*G[{1}, yw]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (5*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yu]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{1}, yv]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/96 + 
     (5*G[{0}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 - (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/24 - (G[{0}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/24 + (G[{0}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 - (G[{1}, yu]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 + (G[{1}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/16 + (G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/192 - 
     (7*Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/384 + 
     (7*G[{0}, yu]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (11*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (13*G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu]^3*G[{1/(yu*yv)}, yw]^2)/64 - 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (7*G[{0}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (17*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (31*G[{0}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (17*G[{1}, yv]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (17*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (9*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (19*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (15*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (19*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (23*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (5*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (7*G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (13*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (13*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (21*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (13*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/4 - 
     (15*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (17*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (41*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (11*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (15*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (5*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (19*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 + 
     (33*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (15*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (15*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (11*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (9*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (5*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 + (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      64 + (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/48 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (13*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/192 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/24 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/768 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yu])/64 + 
     (11*Pi^2*G[{1}, yu]*G[{0, 1}, yu])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yu])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yu])/128 + 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu])/128 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu])/64 + 
     (G[{1}, yu]^3*G[{0, 1}, yu])/128 - (Pi^2*G[{1}, yv]*G[{0, 1}, yu])/256 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yu])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yu])/32 + 
     (5*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu])/64 - 
     (7*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/128 + 
     (13*G[{1}, yv]^3*G[{0, 1}, yu])/192 - (11*Pi^2*G[{1}, yw]*G[{0, 1}, yu])/
      768 + (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yu])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu])/128 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/64 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/64 + 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/128 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu])/64 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/16 - 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/128 - 
     (11*G[{1}, yw]^3*G[{0, 1}, yu])/384 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/32 + 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/128 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu])/16 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/256 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (13*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (17*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/
      16 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/64 + 
     (9*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/64 - 
     (G[{0}, yu]*G[{0, 1}, yu]^2)/32 + (G[{0}, yw]*G[{0, 1}, yu]^2)/32 + 
     (7*G[{1}, yu]*G[{0, 1}, yu]^2)/128 + (G[{1}, yv]*G[{0, 1}, yu]^2)/128 - 
     (7*G[{1}, yw]*G[{0, 1}, yu]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2)/128 - 
     (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yv])/16 - 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yv])/96 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv])/16 + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yv])/8 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/16 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/16 - 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/4 - 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv])/32 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/8 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/32 - 
     (5*G[{1}, yw]^3*G[{0, 1}, yv])/96 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv])/8 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/4 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/4 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, 1}, yv]^2)/16 - (G[{0}, yw]*G[{0, 1}, yv]^2)/32 - 
     (G[{1}, yu]*G[{0, 1}, yv]^2)/32 + (G[{1}, yv]*G[{0, 1}, yv]^2)/32 + 
     (3*G[{1}, yw]*G[{0, 1}, yv]^2)/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2)/
      32 + (7*Pi^2*G[{0}, yu]*G[{0, 1}, yw])/384 + 
     (3*G[{0}, yu]^3*G[{0, 1}, yw])/128 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yw])/16 - 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yw])/128 - 
     (5*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]*G[{0, 1}, yw])/384 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yw])/32 - 
     (7*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yw])/16 - 
     (5*G[{1}, yv]^3*G[{0, 1}, yw])/128 + (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/
      128 + (G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (7*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (15*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw])/128 - 
     (11*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (15*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{0, 1}, yw])/128 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/48 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/32 + 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/64 - 
     (G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/12 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/64 - 
     (5*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yw]^2)/32 - (G[{0}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{1}, yu]*G[{0, 1}, yw]^2)/32 + (G[{1}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/32 - 
     (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/96 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/16 + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/96 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/4 + 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 + 
     (5*G[{1}, yw]^3*G[{0, yu^(-1)}, yv])/96 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/96 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 - (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/4 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 + (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/4 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/8 - (G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/8 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (11*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/384 - 
     (3*G[{0}, yu]^3*G[{0, yu^(-1)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (7*Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/384 + 
     (5*G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw])/128 - 
     (7*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/384 - 
     (13*G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/16 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw])/64 - 
     (17*G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]^3*G[{0, yu^(-1)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (11*G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (15*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/32 - 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yw])/64 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 - (3*G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/16 + (7*G[{1}, yu]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/64 - (7*G[{1}, yv]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/64 - (3*G[{1}, yw]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yw])/64 - (G[{0}, yu]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yw])/8 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yu]^3*G[{0, yv^(-1)}, yw])/128 + 
     (Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/48 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (7*Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/384 + 
     (17*G[{0}, yu]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw])/16 - 
     (19*G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]^3*G[{0, yv^(-1)}, yw])/32 - 
     (7*Pi^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/32 + 
     (7*G[{0}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yv]^3*G[{0, yv^(-1)}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (7*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (15*G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (11*G[{0}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (15*G[{1}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/32 - 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1)}, yw])/64 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (11*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (3*G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 + (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, 1}, yu]*
       G[{0, yv^(-1)}, yw])/32 + (G[{0}, yw]*G[{0, 1}, yu]*
       G[{0, yv^(-1)}, yw])/16 + (3*G[{1}, yu]*G[{0, 1}, yu]*
       G[{0, yv^(-1)}, yw])/64 + (5*G[{1}, yv]*G[{0, 1}, yu]*
       G[{0, yv^(-1)}, yw])/64 + (5*G[{1}, yw]*G[{0, 1}, yu]*
       G[{0, yv^(-1)}, yw])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{0, yv^(-1)}, yw])/64 + (G[{0}, yu]*G[{0, 1}, yv]*
       G[{0, yv^(-1)}, yw])/8 + (G[{1}, yv]*G[{0, 1}, yv]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yv]*
       G[{0, yv^(-1)}, yw])/8 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yv]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/8 - (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (7*Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/384 + 
     (3*G[{0}, yu]^3*G[{0, 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/48 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (11*Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/384 - 
     (17*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (19*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw])/32 + 
     (7*Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/384 + 
     (13*G[{0}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (17*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (11*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (15*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/48 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/12 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (3*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yv])/768 - 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/96 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1, yu^(-1)}, yv])/32 + 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/192 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yu]^3*G[{1, yu^(-1)}, yv])/32 - 
     (Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/4 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/4 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (11*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 + 
     (9*G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yv]^3*G[{1, yu^(-1)}, yv])/64 - 
     (5*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/768 - 
     (9*G[{0}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (7*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/4 + 
     (11*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (7*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (25*G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (5*G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (19*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{1}, yw]^3*G[{1, yu^(-1)}, yv])/128 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/4 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/4 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (7*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/16 - 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/768 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (11*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (9*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (9*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/4 + (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/4 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (7*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (13*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      64 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (3*G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      64 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/32 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 - (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 - (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 + (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 + (G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 - (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/32 + (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/32 + (7*G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/64 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{0}, yv]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/4 + (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/16 + (3*G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{0}, yu]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (G[{0}, yv]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/8 - (3*G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (3*G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (3*G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/16 + (3*G[{0}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/16 + (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/4 - (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/16 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{0}, yu]*G[{1, yu^(-1)}, yv]^2)/32 - 
     (G[{0}, yv]*G[{1, yu^(-1)}, yv]^2)/8 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]^2)/8 + 
     (3*G[{1}, yv]*G[{1, yu^(-1)}, yv]^2)/32 + 
     (5*G[{1}, yw]*G[{1, yu^(-1)}, yv]^2)/128 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]^2)/128 + 
     (13*Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^3*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/384 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/128 + 
     (13*Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/768 + 
     (13*G[{0}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (11*G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]^3*G[{1, yu^(-1)}, yw])/128 + 
     (13*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/768 + 
     (9*G[{0}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (11*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/128 - 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/8 + 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yw])/64 - 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/256 - 
     (11*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (9*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (11*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (9*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/128 + (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (3*G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (5*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/32 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 - 
     (5*G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (7*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yv]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu]*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu]^3*G[{1, yv^(-1)}, yw])/128 - 
     (Pi^2*G[{0}, yv]*G[{1, yv^(-1)}, yw])/48 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (7*Pi^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/384 - 
     (17*G[{0}, yu]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/16 + 
     (19*G[{0}, yu]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]^3*G[{1, yv^(-1)}, yw])/32 + 
     (7*Pi^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/384 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (7*G[{0}, yu]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yv]^3*G[{1, yv^(-1)}, yw])/128 - 
     (3*Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (11*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (19*G[{1}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (11*G[{0}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/32 - 
     (11*G[{1}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/128 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/64 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/384 - 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (19*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (15*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 - (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 - (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 - (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/64 - (5*G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/64 - (G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/64 - (G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yv]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 - (3*G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/64 + (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yu]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (5*G[{1}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yu]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yv]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/16 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/16 + 
     (Pi^2*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (Pi^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/192 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]^3*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{1}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]^3*G[{1, 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/16 - 
     (7*Pi^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/2 + 
     (9*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (15*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (25*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (27*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw])/192 - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (5*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (9*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (13*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/32 - (5*G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{0}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/4 - (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (5*G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/4 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (5*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/128 - 
     (5*Pi^2*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*Pi^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/384 + 
     (11*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*Pi^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (13*G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (7*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (7*G[{0}, yu]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (11*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (7*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (11*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (11*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (13*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (19*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (9*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (19*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (19*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (13*G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*Pi^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/384 + 
     (17*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (19*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*Pi^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (19*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (5*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yu]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (3*G[{1}, yv]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (5*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (5*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (7*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/384 + 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (5*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (Pi^2*G[{0, 0, 1}, yu])/64 - (3*G[{0}, yu]^2*G[{0, 0, 1}, yu])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yu])/16 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1}, yu])/128 + 
     (9*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yu])/64 - 
     (15*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yu])/64 - 
     (17*G[{1}, yu]^2*G[{0, 0, 1}, yu])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yu])/16 + 
     (13*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu])/64 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu])/64 + 
     (17*G[{1}, yv]^2*G[{0, 0, 1}, yu])/128 - 
     (9*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu])/64 + 
     (15*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu])/64 + 
     (17*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu])/64 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yu])/8 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{0, 0, 1}, yu])/32 - (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yu])/64 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yu])/16 - (13*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yu])/64 + (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yu])/64 - (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yu])/64 - (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yu])/32 + (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yu])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 0, 1}, yu])/64 + (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yu])/64 + 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yu])/32 + (G[{0, 1}, yv]*G[{0, 0, 1}, yu])/
      16 + (G[{0, 1}, yw]*G[{0, 0, 1}, yu])/64 - 
     (13*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (13*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yu])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu])/64 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/32 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (Pi^2*G[{0, 0, 1}, yv])/96 + (G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yv])/
      16 - (G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv])/4 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yv])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv])/16 - 
     (G[{1}, yv]^2*G[{0, 0, 1}, yv])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yv])/32 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/4 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/4 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yv])/16 - (G[{0, 1}, yv]*G[{0, 0, 1}, yv])/
      16 - (G[{0, 1}, yw]*G[{0, 0, 1}, yv])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 + 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yv])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv])/16 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (Pi^2*G[{0, 0, 1}, yw])/96 + (G[{0}, yu]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yv]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, 0, 1}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/4 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/4 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/4 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv])/32 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/4 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (5*G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/96 + (G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yw])/
      16 - (G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/96 - (G[{0}, yu]^2*G[{0, 0, yv^(-1)}, yw])/
      8 + (G[{0}, yu]*G[{0}, yv]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]^2*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (5*Pi^2*G[{0, 1, 1}, yu])/256 - (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yu])/
      16 + (3*G[{0}, yw]^2*G[{0, 1, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yu])/8 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yu])/64 - 
     (G[{1}, yu]^2*G[{0, 1, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/8 + 
     (7*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yu])/64 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/64 + 
     (5*G[{1}, yv]^2*G[{0, 1, 1}, yu])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/8 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu])/64 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yu])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 - 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/32 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/32 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 - 
     (5*G[{0, 1}, yu]*G[{0, 1, 1}, yu])/64 + 
     (3*G[{0, 1}, yw]*G[{0, 1, 1}, yu])/64 - 
     (11*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yu])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yu])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/32 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 - 
     (Pi^2*G[{0, 1, 1}, yv])/96 + (3*G[{0}, yu]^2*G[{0, 1, 1}, yv])/32 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yv]^2*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yv])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yv])/16 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yu]^2*G[{0, 1, 1}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv])/4 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yv])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (3*G[{0, 1}, yu]*G[{0, 1, 1}, yv])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (Pi^2*G[{0, 1, 1}, yw])/96 + (G[{0}, yu]^2*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1, 1}, yw])/32 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw])/8 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, 1, 1}, yw])/16 - (G[{0, 1}, yv]*G[{0, 1, 1}, yw])/
      16 - (G[{0, 1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (Pi^2*G[{0, 1, yu^(-1)}, yv])/48 + 
     (3*G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv])/32 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/96 + (G[{0}, yu]^2*G[{0, 1, yv^(-1)}, yw])/
      16 - (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0, yu^(-1), 1}, yv])/96 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yv]^2*G[{0, yu^(-1), 1}, yv])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/16 - 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/4 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yv])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yu]^2*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/48 + 
     (G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/48 + (G[{0}, yu]^2*G[{0, yv^(-1), 1}, yw])/
      32 - (G[{0}, yv]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yu]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/48 - 
     (5*G[{0}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (5*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/96 - 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/48 - 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/8 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/96 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/8 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yv])/64 + 
     (7*G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yv])/128 + 
     (27*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (33*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv])/128 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/4 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (9*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (21*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (5*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yv])/32 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (9*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 - 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (7*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (5*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (9*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (5*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (Pi^2*G[{1, 1, yu^(-1)}, yw])/192 - 
     (7*G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (9*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (11*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (27*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (7*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (15*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (29*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/64 + 
     (15*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (23*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (7*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (7*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (7*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (9*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (Pi^2*G[{1, 1, yv^(-1)}, yw])/24 + (G[{0}, yu]^2*G[{1, 1, yv^(-1)}, yw])/
      8 - (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (13*G[{0}, yu]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (17*G[{0}, yw]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (19*G[{1}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (25*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (41*G[{yu^(-1)}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (21*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (21*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (29*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (29*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{1, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/256 + 
     (9*G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (9*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/2 - 
     (9*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (17*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/2 - 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (7*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (31*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (33*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/
      16 - (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yv])/32 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/4 + 
     (5*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (11*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/768 - 
     (5*G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      32 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/32 - (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (7*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yu]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      16 - (13*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (13*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/48 + 
     (5*G[{0}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/2 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      16 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/8 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (11*Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (9*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (11*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/256 + 
     (7*G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (21*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (9*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (25*G[{1}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (25*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (41*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 - (11*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (11*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (11*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (11*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 + (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 - (G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/4 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (29*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (23*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (39*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (15*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (23*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (7*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 - (23*G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (43*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (23*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (43*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (15*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (5*G[{0}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0, 1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 - (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (9*G[{0}, yu]*G[{0, 0, 0, 1}, yu])/64 - 
     (9*G[{1}, yu]*G[{0, 0, 0, 1}, yu])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 0, 1}, yu])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, 1}, yu])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yu])/64 + 
     (G[{0}, yu]*G[{0, 0, 1, 1}, yu])/16 + (3*G[{0}, yw]*G[{0, 0, 1, 1}, yu])/
      16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yu])/32 + 
     (7*G[{1}, yv]*G[{0, 0, 1, 1}, yu])/32 - (G[{1}, yw]*G[{0, 0, 1, 1}, yu])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yu])/32 + 
     (5*G[{0}, yu]*G[{0, 0, 1, 1}, yv])/16 - (G[{0}, yv]*G[{0, 0, 1, 1}, yv])/
      8 - (G[{0}, yw]*G[{0, 0, 1, 1}, yv])/16 - 
     (3*G[{1}, yu]*G[{0, 0, 1, 1}, yv])/16 + (G[{1}, yv]*G[{0, 0, 1, 1}, yv])/
      8 + (3*G[{1}, yw]*G[{0, 0, 1, 1}, yv])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv])/8 + 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yw])/
      16 + (G[{1}, yv]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (5*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv])/8 + 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv])/8 + 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv])/16 - 
     (3*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw])/4 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (7*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yu]*G[{0, 1, 1, 1}, yu])/64 + (G[{0}, yw]*G[{0, 1, 1, 1}, yu])/
      8 - (G[{1}, yu]*G[{0, 1, 1, 1}, yu])/16 + 
     (G[{1}, yv]*G[{0, 1, 1, 1}, yu])/8 + (G[{1}, yw]*G[{0, 1, 1, 1}, yu])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu])/8 + 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yv])/4 - (G[{0}, yv]*G[{0, 1, 1, 1}, yv])/
      8 + (G[{0}, yw]*G[{0, 1, 1, 1}, yv])/16 - 
     (G[{1}, yu]*G[{0, 1, 1, 1}, yv])/16 + (G[{1}, yv]*G[{0, 1, 1, 1}, yv])/
      8 + (3*G[{1}, yw]*G[{0, 1, 1, 1}, yv])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yw])/16 + (3*G[{0}, yw]*G[{0, 1, 1, 1}, yw])/
      16 + (3*G[{1}, yu]*G[{0, 1, 1, 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 1, 1}, yw])/8 + (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/
      8 + (G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (5*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/4 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv])/8 - 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv])/16 - 
     (3*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv])/16 + 
     (3*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yv])/8 - 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (3*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (5*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/4 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv])/4 - 
     (3*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/2 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1, 1}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw])/4 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/4 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/16 - 
     (5*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (15*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (23*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/8 - 
     (7*G[{0}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu^(-1)}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (25*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/4 - 
     (9*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (27*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (23*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (35*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (23*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (23*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (5*G[{0}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (9*G[{0}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (7*G[{1}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     (G[{1}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     (5*G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (25*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/2 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/2 - 
     (9*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     (61*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 + 
     (7*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (5*G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (7*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/2 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (7*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (23*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (43*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (43*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (7*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (23*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/8 + (3*G[{0, 0, 0, 1, 1}, yv])/8 - 
     (9*G[{0, 0, 0, 1, 1}, yw])/16 - (3*G[{0, 0, 0, 1, yu^(-1)}, yv])/16 + 
     (9*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 + (3*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      16 - (3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1}, yv])/16 + (9*G[{0, 0, 0, yu^(-1), 1}, yw])/
      16 - (9*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 0, 0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 1, 0, 1}, yu])/64 + G[{0, 0, 1, 0, 1}, yv]/8 - 
     (3*G[{0, 0, 1, 0, 1}, yw])/16 - G[{0, 0, 1, 0, yu^(-1)}, yv]/16 + 
     (3*G[{0, 0, 1, 0, yu^(-1)}, yw])/16 + G[{0, 0, 1, 0, yv^(-1)}, yw]/16 - 
     G[{0, 0, 1, 0, 1/(yu*yv)}, yw]/16 + (3*G[{0, 0, 1, 1, 1}, yu])/8 + 
     G[{0, 0, 1, 1, 1}, yv]/8 + (3*G[{0, 0, 1, 1, 1}, yw])/8 - 
     (3*G[{0, 0, 1, 1, yu^(-1)}, yv])/16 + (5*G[{0, 0, 1, 1, yu^(-1)}, yw])/
      16 + (3*G[{0, 0, 1, 1, yv^(-1)}, yw])/16 - G[{0, 0, 1, yu^(-1), 1}, yv]/
      8 + G[{0, 0, 1, yu^(-1), 1}, yw]/8 + 
     (3*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw]/8 + G[{0, 0, 1, yv^(-1), 1}, yw]/
      8 + (3*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - G[{0, 0, yu^(-1), 0, 1}, yv]/
      16 + (3*G[{0, 0, yu^(-1), 0, 1}, yw])/16 - 
     (3*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw])/16 - 
     G[{0, 0, yu^(-1), 0, yv^(-1)}, yw]/16 + 
     G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/16 - G[{0, 0, yu^(-1), 1, 1}, yv]/
      4 + G[{0, 0, yu^(-1), 1, 1}, yw]/4 + 
     (5*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv])/16 - 
     (3*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{0, 0, yu^(-1), yu^(-1), 1}, yv]/8 - 
     G[{0, 0, yu^(-1), yu^(-1), 1}, yw]/8 + 
     (9*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), yv^(-1), 1}, yw]/4 - 
     G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw]/16 + 
     (5*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     G[{0, 0, yv^(-1), 0, 1}, yw]/16 - G[{0, 0, yv^(-1), 0, yu^(-1)}, yw]/
      16 + G[{0, 0, yv^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), yu^(-1), 1}, yw]/4 - 
     G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (7*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw]/8 - 
     (3*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, 1/(yu*yv), 0, 1}, yw]/16 + G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/
      16 - G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1}, yw]/8 + 
     (7*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 + 
     G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     (7*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0, 1, 0, 1, 1}, yu])/64 + G[{0, 1, 0, 1, 1}, yw]/4 + 
     (3*G[{0, 1, 0, 1, yu^(-1)}, yw])/16 + G[{0, 1, 0, 1, yv^(-1)}, yw]/8 - 
     G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/16 - G[{0, 1, 0, yu^(-1), 1}, yv]/8 + 
     G[{0, 1, 0, yu^(-1), 1}, yw]/16 + G[{0, 1, 0, yu^(-1), yu^(-1)}, yv]/4 - 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/16 + G[{0, 1, 0, yv^(-1), 1}, yw]/
      16 + G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw]/16 - G[{0, 1, 0, 1/(yu*yv), 1}, yw]/
      8 + G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     (3*G[{0, 1, 1, 0, yu^(-1)}, yw])/16 + (3*G[{0, 1, 1, 0, yv^(-1)}, yw])/
      16 - G[{0, 1, 1, 0, 1/(yu*yv)}, yw]/8 + (3*G[{0, 1, 1, 1, 1}, yu])/16 + 
     (3*G[{0, 1, 1, 1, 1}, yv])/16 - (3*G[{0, 1, 1, 1, 1}, yw])/16 - 
     G[{0, 1, 1, 1, yu^(-1)}, yv]/8 - G[{0, 1, 1, 1, yu^(-1)}, yw]/8 - 
     (3*G[{0, 1, 1, 1, yv^(-1)}, yw])/16 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, 1, yu^(-1), 1}, yv]/8 - G[{0, 1, 1, yu^(-1), 1}, yw]/16 - 
     G[{0, 1, 1, yu^(-1), yu^(-1)}, yv]/2 + 
     (3*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{0, 1, 1, yu^(-1), yv^(-1)}, yw]/16 - G[{0, 1, 1, yv^(-1), 1}, yw]/
      16 + G[{0, 1, 1, yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{0, 1, 1, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yv]/16 + 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, yu^(-1), 0, yv^(-1)}, yw]/16 + (3*G[{0, 1, yu^(-1), 1, 1}, yv])/
      16 - G[{0, 1, yu^(-1), 1, 1}, yw]/8 - 
     (3*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv])/8 + 
     (3*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     G[{0, 1, yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, 1, yu^(-1), yu^(-1), 1}, yv]/8 + 
     G[{0, 1, yu^(-1), yu^(-1), 1}, yw]/4 + 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv]/2 + 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, 1, yv^(-1), 1, yu^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 1, yv^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 + 
     (5*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw]/8 - 
     (3*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yv]/16 + 
     (5*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw]/8 + (3*G[{0, yu^(-1), 1, 1, 1}, yw])/
      16 + G[{0, yu^(-1), 1, 1, yu^(-1)}, yw]/8 + 
     (3*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yv]/8 + 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yw]/16 + 
     G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv]/4 - 
     (3*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1, yv^(-1), 1}, yw]/16 - 
     G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw]/16 + 
     (3*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yv]/4 + 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv]/4 - 
     (3*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/8 + 
     (5*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw])/16 - 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw]/16 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/16 + 
     (5*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw])/16 + 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 0, yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, yv^(-1), 1, 1, 1}, yw])/16 - G[{0, yv^(-1), 1, 1, yu^(-1)}, yw]/
      16 + G[{0, yv^(-1), 1, 1, yv^(-1)}, yw]/4 - 
     (3*G[{0, yv^(-1), 1, yu^(-1), 1}, yw])/16 + 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw]/16 - 
     G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/8 - 
     (3*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw])/16 - 
     G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw]/4 + 
     (3*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1, 1, 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/4 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw])/16 - 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw]/16 - 
     (5*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw]/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{1, 1, 1, 1, yu^(-1)}, yv]/16 + (5*G[{1, 1, 1, 1, yu^(-1)}, yw])/16 - 
     (7*G[{1, 1, 1, 1, yv^(-1)}, yw])/16 + G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/2 + 
     (5*G[{1, 1, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     G[{1, 1, 1, yu^(-1), yu^(-1)}, yw]/8 + 
     (5*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (7*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (7*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (19*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (9*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     3*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (13*G[{1, 1, yu^(-1), 1, yu^(-1)}, yv])/64 + 
     (5*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (5*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (9*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (81*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (19*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/16 - 
     (5*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (5*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     (3*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (3*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/8 - 
     (7*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (13*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (9*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (7*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (61*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 - 
     (5*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/2 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (5*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/16 + 
     (41*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     (9*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     (7*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw]/4 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (3*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (17*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (7*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/2 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (11*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (123*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (17*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (7*Pi^2*Zeta[3])/256 + (G[{0}, yu]^2*Zeta[3])/16 + 
     (G[{0}, yu]*G[{0}, yw]*Zeta[3])/16 - (3*G[{0}, yw]^2*Zeta[3])/64 - 
     (G[{0}, yu]*G[{1}, yu]*Zeta[3])/16 - (5*G[{0}, yw]*G[{1}, yu]*Zeta[3])/
      32 - (G[{1}, yu]^2*Zeta[3])/8 + (G[{0}, yu]*G[{1}, yv]*Zeta[3])/8 - 
     (G[{0}, yv]*G[{1}, yv]*Zeta[3])/16 + (3*G[{0}, yw]*G[{1}, yv]*Zeta[3])/
      32 - (G[{1}, yu]*G[{1}, yv]*Zeta[3])/16 + (7*G[{1}, yv]^2*Zeta[3])/64 + 
     (G[{0}, yu]*G[{1}, yw]*Zeta[3])/16 + (5*G[{0}, yw]*G[{1}, yw]*Zeta[3])/
      32 + (G[{1}, yu]*G[{1}, yw]*Zeta[3])/4 + 
     (G[{1}, yv]*G[{1}, yw]*Zeta[3])/32 + (G[{1}, yw]^2*Zeta[3])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*Zeta[3])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*Zeta[3])/64 + (5*G[{0, 1}, yu]*Zeta[3])/32 + 
     (G[{0, 1}, yv]*Zeta[3])/16 - (5*G[{0, 1}, yw]*Zeta[3])/32 + 
     (3*G[{0, yu^(-1)}, yw]*Zeta[3])/32 - (G[{0, yv^(-1)}, yw]*Zeta[3])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*Zeta[3])/32 + (G[{1, yu^(-1)}, yv]*Zeta[3])/
      32 - (5*G[{1, yu^(-1)}, yw]*Zeta[3])/16 + (G[{1, yv^(-1)}, yw]*Zeta[3])/
      32 - (G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - Zeta[5]/64
 
QepwuvRegI = (17*Pi^4*G[{0}, yu])/11520 + (Pi^2*G[{0}, yu]^3)/256 + 
     (Pi^2*G[{0}, yu]^2*G[{0}, yv])/96 + (Pi^2*G[{0}, yu]*G[{0}, yv]^2)/256 + 
     (3*G[{0}, yu]^3*G[{0}, yv]^2)/256 - (17*Pi^4*G[{1}, yu])/11520 - 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/768 - 
     (5*Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu])/384 + 
     (3*G[{0}, yu]^3*G[{0}, yv]*G[{1}, yu])/128 - 
     (Pi^2*G[{0}, yv]^2*G[{1}, yu])/256 - 
     (9*G[{0}, yu]^2*G[{0}, yv]^2*G[{1}, yu])/256 - 
     (3*Pi^2*G[{0}, yu]*G[{1}, yu]^2)/512 + (3*G[{0}, yu]^3*G[{1}, yu]^2)/
      256 + (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/384 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]^2)/128 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]^2)/256 + (Pi^2*G[{1}, yu]^3)/768 - 
     (G[{0}, yu]^2*G[{1}, yu]^3)/256 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^3)/
      384 - (G[{0}, yu]*G[{1}, yu]^4)/768 + (17*Pi^4*G[{1}, yv])/11520 + 
     (Pi^2*G[{0}, yu]^2*G[{1}, yv])/768 + 
     (5*Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv])/384 - 
     (3*G[{0}, yu]^3*G[{0}, yv]*G[{1}, yv])/128 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/256 + 
     (9*G[{0}, yu]^2*G[{0}, yv]^2*G[{1}, yv])/256 + 
     (3*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv])/256 - 
     (3*G[{0}, yu]^3*G[{1}, yu]*G[{1}, yv])/128 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/192 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv])/128 - 
     (Pi^2*G[{1}, yu]^2*G[{1}, yv])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yv])/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yv])/192 - 
     (11*Pi^2*G[{0}, yu]*G[{1}, yv]^2)/768 + (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/
      384 - (5*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]^2)/128 + 
     (9*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]^2)/256 + 
     (Pi^2*G[{1}, yu]*G[{1}, yv]^2)/192 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]^2)/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2)/128 - 
     (5*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]^2)/256 - 
     (5*Pi^2*G[{1}, yv]^3)/768 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^3)/384 + 
     (3*G[{0}, yv]^2*G[{1}, yv]^3)/256 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^3)/
      32 + (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^3)/128 + 
     (3*G[{1}, yu]^2*G[{1}, yv]^3)/256 + (G[{0}, yv]*G[{1}, yv]^4)/96 + 
     (G[{1}, yu]*G[{1}, yv]^4)/96 + (17*Pi^4*G[{1}, yw])/11520 + 
     (5*Pi^2*G[{0}, yu]^2*G[{1}, yw])/768 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw])/128 + 
     (3*G[{0}, yu]^3*G[{0}, yv]*G[{1}, yw])/128 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yw])/256 + 
     (9*G[{0}, yu]^2*G[{0}, yv]^2*G[{1}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw])/32 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/192 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw])/32 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw])/256 + 
     (3*G[{0}, yu]^3*G[{1}, yu]*G[{1}, yw])/128 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/96 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/16 + 
     (Pi^2*G[{1}, yu]^2*G[{1}, yw])/768 - 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yw])/256 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yw])/96 + 
     (5*Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw])/384 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/16 + 
     (9*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/8 - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/64 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/128 - 
     (7*Pi^2*G[{1}, yv]^2*G[{1}, yw])/768 - 
     (21*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yv]^2*G[{1}, yv]^2*G[{1}, yw])/256 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/128 + 
     (9*G[{1}, yu]^2*G[{1}, yv]^2*G[{1}, yw])/256 - 
     (7*G[{0}, yv]*G[{1}, yv]^3*G[{1}, yw])/192 - 
     (7*G[{1}, yu]*G[{1}, yv]^3*G[{1}, yw])/192 + 
     (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/192 + (3*G[{0}, yu]^3*G[{1}, yw]^2)/256 + 
     (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/384 + 
     (9*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw]^2)/256 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/192 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]^2)/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2)/8 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]^2)/64 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]^2)/64 - 
     (7*Pi^2*G[{1}, yu]*G[{1}, yw]^2)/768 - 
     (9*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]^2)/256 - 
     (17*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2)/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]^2)/64 - 
     (5*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]^2)/32 + (G[{1}, yu]^3*G[{1}, yw]^2)/
      64 + (Pi^2*G[{1}, yv]*G[{1}, yw]^2)/96 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]^2)/256 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]^2)/64 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/128 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/128 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/16 - 
     (11*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]^2)/256 - 
     (11*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]^2)/256 - 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]^2)/64 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]^2)/64 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]^2)/8 - (5*G[{1}, yv]^3*G[{1}, yw]^2)/
      256 + (Pi^2*G[{1}, yw]^3)/384 + (9*G[{0}, yu]^2*G[{1}, yw]^3)/256 + 
     (9*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^3)/128 + 
     (3*G[{0}, yv]^2*G[{1}, yw]^3)/256 - 
     (7*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^3)/96 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^3)/24 + (G[{0}, yw]^2*G[{1}, yw]^3)/
      96 - (9*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^3)/128 - 
     (7*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^3)/384 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^3)/48 - (5*G[{1}, yu]^2*G[{1}, yw]^3)/
      256 - (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^3)/384 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^3)/64 - 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^3)/96 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^3)/192 - 
     (7*G[{1}, yv]^2*G[{1}, yw]^3)/256 + (9*G[{0}, yu]*G[{1}, yw]^4)/256 + 
     (3*G[{0}, yv]*G[{1}, yw]^4)/128 - (11*G[{0}, yw]*G[{1}, yw]^4)/384 - 
     (G[{1}, yu]*G[{1}, yw]^4)/192 + (5*G[{1}, yv]*G[{1}, yw]^4)/768 + 
     (3*G[{1}, yw]^5)/256 - (5*Pi^2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/
      256 - (3*G[{0}, yu]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 + 
     (13*Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/384 + 
     (11*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (5*Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/256 - 
     (9*G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (9*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (3*G[{1}, yv]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (3*Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 - 
     (3*G[{0}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 - 
     (9*G[{0}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/8 - 
     (G[{0}, yw]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 + 
     (25*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (7*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 + 
     (15*G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 + 
     (17*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 + 
     (25*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (3*G[{1}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 - 
     (7*G[{0}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 - 
     (31*G[{0}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 + 
     (11*G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 + 
     (13*G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 + 
     (G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/24 - 
     (15*G[{1}, yw]^4*G[{yu^(-1)}, yv])/256 + 
     (7*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/512 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 + 
     (3*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/256 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/8 - 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/32 - 
     (29*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/256 + 
     (59*G[{1}, yw]^3*G[{yu^(-1)}, yv]^2)/768 + 
     (7*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/192 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/48 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/48 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/192 - 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]^3)/768 - 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]^4)/768 - (17*Pi^4*G[{1/(yu*yv)}, yw])/
      11520 - (5*Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]^3*G[{0}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu]^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/192 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^3*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/768 + 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/256 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/96 - 
     (5*Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/8 + 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/768 + 
     (21*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yv]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{1}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{0}, yv]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yu]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/192 - 
     (9*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (7*Pi^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/384 + 
     (9*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (17*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yv]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (27*G[{0}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (27*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (27*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (15*G[{1}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (21*G[{1}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 + 
     (G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (5*G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (15*G[{1}, yw]^4*G[{1/(yu*yv)}, yw])/256 + 
     (5*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (13*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/384 - 
     (11*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      128 + (5*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      64 - (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 + (9*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/4 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (25*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (7*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (15*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/16 - (17*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (25*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 + (7*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 + (31*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (11*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 - (13*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 - (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/8 + (15*G[{1}, yw]^3*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (7*Pi^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/512 + (G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/4 + (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/16 + (29*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 - (59*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/256 - (7*G[{0}, yu]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/192 - (G[{0}, yv]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/48 - (G[{1}, yu]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/48 - (7*G[{1}, yv]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/192 + (11*G[{1}, yw]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/384 + (11*G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/
      768 + (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/192 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (5*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yv]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/768 - (3*G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      4 - (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/4 - (11*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/4 + (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/192 - 
     (7*Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/512 - 
     (9*G[{0}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (9*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (21*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (29*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 + (7*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (25*G[{0}, yu]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 - (G[{0}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/12 + (G[{0}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/12 + (41*G[{1}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/64 - (41*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/
      768 + (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (7*Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 - 
     (17*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (19*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (3*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (11*G[{0}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (7*G[{0}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/96 + 
     (5*G[{0}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/24 + (G[{0}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 - (G[{0}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/24 - (G[{1}, yu]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 + (G[{1}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/16 + (G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/192 - 
     (7*Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/384 + 
     (7*G[{0}, yu]^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (13*G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yu]^3*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (17*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{0}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yv]^3*G[{1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (7*G[{0}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (17*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (9*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (31*G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (7*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (13*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (21*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (11*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (21*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (51*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (15*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (43*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (11*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (11*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (11*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (19*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (9*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (15*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (15*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (15*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (19*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (19*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (5*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (5*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{0}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 - (3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 - (5*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      64 - (5*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (13*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/192 - 
     (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (13*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/24 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/768 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yu])/64 + 
     (11*Pi^2*G[{1}, yu]*G[{0, 1}, yu])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yu])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yu])/128 + 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu])/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yu])/64 + 
     (G[{1}, yu]^3*G[{0, 1}, yu])/128 - (11*Pi^2*G[{1}, yv]*G[{0, 1}, yu])/
      768 + (3*G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yu])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu])/128 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yu])/128 + 
     (5*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/128 + 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yu])/64 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/16 - 
     (11*G[{1}, yv]^3*G[{0, 1}, yu])/384 - (Pi^2*G[{1}, yw]*G[{0, 1}, yu])/
      256 - (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yu])/128 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/32 - 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/128 + 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu])/32 - 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/128 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/32 + 
     (13*G[{1}, yw]^3*G[{0, 1}, yu])/192 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/8 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/64 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/64 - 
     (21*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/128 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu])/32 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/256 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (11*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 - 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (21*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/
      16 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/32 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 + 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/64 - 
     (G[{0}, yu]*G[{0, 1}, yu]^2)/32 + (G[{0}, yv]*G[{0, 1}, yu]^2)/32 + 
     (7*G[{1}, yu]*G[{0, 1}, yu]^2)/128 - (7*G[{1}, yv]*G[{0, 1}, yu]^2)/
      128 + (G[{1}, yw]*G[{0, 1}, yu]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2)/128 + 
     (7*Pi^2*G[{0}, yu]*G[{0, 1}, yv])/384 + (3*G[{0}, yu]^3*G[{0, 1}, yv])/
      128 - (G[{0}, yu]^2*G[{0}, yv]*G[{0, 1}, yv])/16 - 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yv])/128 - 
     (5*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yv])/128 + 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yv])/128 + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yv])/8 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/64 - 
     (11*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/128 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv])/32 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/32 - 
     (5*G[{1}, yv]^3*G[{0, 1}, yv])/128 + (Pi^2*G[{1}, yw]*G[{0, 1}, yv])/
      128 + (5*G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv])/32 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/32 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/8 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 - 
     (7*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yv])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/128 + 
     (13*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/128 + 
     (5*G[{1}, yw]^3*G[{0, 1}, yv])/384 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/32 - 
     (13*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/128 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv])/64 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 - 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (13*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/
      32 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/16 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 - 
     (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/16 - 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/64 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv])/64 + 
     (3*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/64 + 
     (G[{0}, yu]*G[{0, 1}, yv]^2)/32 - (G[{0}, yv]*G[{0, 1}, yv]^2)/32 - 
     (G[{1}, yu]*G[{0, 1}, yv]^2)/32 + (G[{1}, yv]*G[{0, 1}, yv]^2)/32 + 
     (G[{1}, yw]*G[{0, 1}, yv]^2)/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2)/
      32 + (3*G[{0}, yu]^2*G[{0}, yv]*G[{0, 1}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yw])/16 - 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yw])/16 + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw])/8 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/16 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/4 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1}, yw]^2)/16 - (G[{0}, yv]*G[{0, 1}, yw]^2)/32 - 
     (G[{1}, yu]*G[{0, 1}, yw]^2)/32 + (G[{1}, yv]*G[{0, 1}, yw]^2)/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]^2)/32 - (G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2)/
      32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/32 - 
     (11*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/384 - 
     (3*G[{0}, yu]^3*G[{0, yu^(-1)}, yv])/128 - 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/96 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/32 + 
     (7*Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/384 + 
     (5*G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv])/128 - 
     (7*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/384 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/64 + 
     (11*G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/32 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/32 + 
     (5*G[{1}, yv]^3*G[{0, yu^(-1)}, yv])/128 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (5*G[{0}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (7*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (13*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (5*G[{1}, yw]^3*G[{0, yu^(-1)}, yv])/384 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/8 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/32 + 
     (13*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/128 - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv])/64 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (13*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      32 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/8 + (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      32 - (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/64 + (7*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/64 + (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (3*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      32 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/32 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/16 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 + 
     (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/16 + 
     (7*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]^2)/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/96 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/96 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 + (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (13*Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yv])/768 + 
     (3*G[{0}, yu]^3*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1, yu^(-1)}, yv])/64 - 
     (Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/384 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/128 + 
     (13*Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/768 + 
     (9*G[{0}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 + 
     (9*G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/128 + 
     (3*G[{1}, yv]^3*G[{1, yu^(-1)}, yv])/128 + 
     (3*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/256 + 
     (11*G[{0}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (11*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (3*G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (9*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yw]^3*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/64 - 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/256 - 
     (11*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (11*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (9*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (21*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/8 - (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      64 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 - (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/32 + (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 + (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 - (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 + (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/16 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yv])/64 + (G[{0}, yu]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/32 - (G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/16 - (5*G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/64 + (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/64 + (G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, yu^(-1)}, yv])/32 + (G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/32 + (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/32 + (G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/64 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/32 - (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/32 - (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yu^(-1)}, yv])/64 + (G[{0}, yv]*G[{1, yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]^2)/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]^2)/128 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]^2)/128 - 
     (Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yw])/768 + 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1, yu^(-1)}, yw])/64 - 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/96 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/192 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]^3*G[{1, yu^(-1)}, yw])/32 - 
     (Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (9*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]^3*G[{1, yu^(-1)}, yw])/16 - 
     (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (11*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (9*G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/64 - 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yw])/192 - 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (11*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (9*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (11*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (7*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 - 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (21*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (7*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (11*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/4 + (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 - (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]^2)/8 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]^2)/8 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu]*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yu]^3*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/48 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (7*Pi^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/384 + 
     (17*G[{0}, yu]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 - 
     (19*G[{0}, yu]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]^3*G[{1, yv^(-1)}, yw])/32 + 
     (3*Pi^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (11*G[{0}, yu]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv]^3*G[{1, yv^(-1)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/16 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^3*G[{1, yv^(-1)}, yw])/48 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/384 + 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (19*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (7*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (11*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (3*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 - (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/64 + (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/64 + (5*G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/64 - (G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 - (9*G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yu]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{1}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yu]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yv]*G[{1, yv^(-1)}, yw]^2)/16 + 
     (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/16 + 
     (5*Pi^2*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (13*Pi^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (11*G[{0}, yu]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (5*Pi^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (5*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/256 + 
     (13*G[{0}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (23*G[{0}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (13*G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (39*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (11*G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (11*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (19*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      8 - (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/8 - (9*G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/64 + (5*G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/64 + (17*G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 + (3*G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (3*G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 - (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (11*G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (3*G[{1}, yu]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (7*G[{1}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yu]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{1}, yu]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (5*G[{1}, yv]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (3*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/192 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (11*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 + 
     (7*Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (9*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (21*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (15*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (29*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (13*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - (9*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (7*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (25*G[{0}, yu]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yv]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - (41*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (41*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (9*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (13*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (9*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (9*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (7*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (13*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (5*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (5*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (7*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (5*G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (5*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (3*G[{0}, yu]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*Pi^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/384 + 
     (17*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (19*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*Pi^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (5*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yu]*G[{yv^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (7*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/384 + 
     (5*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (13*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (Pi^2*G[{0, 0, 1}, yu])/64 - (3*G[{0}, yu]^2*G[{0, 0, 1}, yu])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yu])/16 - 
     (3*G[{0}, yv]^2*G[{0, 0, 1}, yu])/128 + 
     (9*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yu])/64 - 
     (15*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu])/64 - 
     (17*G[{1}, yu]^2*G[{0, 0, 1}, yu])/128 - 
     (9*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu])/64 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yu])/64 + 
     (17*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu])/64 - 
     (G[{1}, yv]^2*G[{0, 0, 1}, yu])/8 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu])/64 + 
     (13*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu])/16 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu])/64 + 
     (17*G[{1}, yw]^2*G[{0, 0, 1}, yu])/128 - 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu])/64 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 - 
     (13*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 + 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 - 
     (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (11*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yu])/64 + 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yu])/32 + (G[{0, 1}, yv]*G[{0, 0, 1}, yu])/
      64 + (G[{0, 1}, yw]*G[{0, 0, 1}, yu])/16 - 
     (13*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yu])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yu])/64 + 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yu])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/64 + 
     (Pi^2*G[{0, 0, 1}, yv])/96 + (G[{0}, yu]^2*G[{0, 0, 1}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv])/4 + 
     (G[{1}, yv]^2*G[{0, 0, 1}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 + 
     (G[{0, 1}, yv]*G[{0, 0, 1}, yv])/8 - (G[{0, 1}, yw]*G[{0, 0, 1}, yv])/
      8 - (G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yv])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/8 + 
     (Pi^2*G[{0, 0, 1}, yw])/96 + (G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yw])/
      16 - (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yw])/16 + (G[{0, 1}, yv]*G[{0, 0, 1}, yw])/
      16 - (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (Pi^2*G[{0, 0, yu^(-1)}, yv])/96 + (G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yv])/
      16 - (G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (5*Pi^2*G[{0, 1, 1}, yu])/256 - (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu])/
      16 + (3*G[{0}, yv]^2*G[{0, 1, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yu])/8 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yu])/64 - 
     (G[{1}, yu]^2*G[{0, 1, 1}, yu])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/8 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu])/64 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/64 - 
     (G[{1}, yv]^2*G[{0, 1, 1}, yu])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/8 + 
     (7*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu])/64 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu])/32 + 
     (5*G[{1}, yw]^2*G[{0, 1, 1}, yu])/128 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu])/64 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/32 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 - 
     (5*G[{0, 1}, yu]*G[{0, 1, 1}, yu])/64 + 
     (3*G[{0, 1}, yv]*G[{0, 1, 1}, yu])/64 - 
     (11*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yu])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/64 - 
     (Pi^2*G[{0, 1, 1}, yv])/96 + (G[{0}, yu]^2*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yv])/16 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/8 + 
     (G[{1}, yv]^2*G[{0, 1, 1}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/8 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{0, 1}, yu]*G[{0, 1, 1}, yv])/16 - (G[{0, 1}, yv]*G[{0, 1, 1}, yv])/
      8 - (3*G[{0, 1}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yv])/16 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/16 - 
     (Pi^2*G[{0, 1, 1}, yw])/96 + (3*G[{0}, yu]^2*G[{0, 1, 1}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yw])/8 - 
     (5*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{0, 1, 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/4 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0, 1}, yu]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (Pi^2*G[{0, 1, yu^(-1)}, yw])/48 + 
     (3*G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw])/16 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/96 - 
     (3*G[{0}, yu]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw])/16 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]^2*G[{0, yu^(-1), 1}, yv])/16 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/96 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 + 
     (5*G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/48 + 
     (G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/96 - 
     (3*G[{0}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/48 - 
     (3*G[{0}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (11*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1, 1, yu^(-1)}, yv])/192 - 
     (7*G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yv])/128 - 
     (9*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv])/128 - 
     (7*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/32 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (9*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yv])/128 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yv])/64 + 
     (G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (7*G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (7*G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (5*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (Pi^2*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (7*G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (27*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (33*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (11*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (19*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (15*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (11*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (5*G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (Pi^2*G[{1, 1, yv^(-1)}, yw])/48 - (G[{0}, yu]^2*G[{1, 1, yv^(-1)}, yw])/
      32 - (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]^2*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yv]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (33*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (33*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (21*G[{yu^(-1)}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (11*Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/768 - 
     (5*G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (5*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (7*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/256 + 
     (9*G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (9*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (21*G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (29*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (13*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (31*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (15*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (33*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (33*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      64 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/16 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (7*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (19*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/48 - 
     (5*G[{0}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/2 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/2 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      16 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/16 - (G[{0, 1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (11*Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (5*G[{1}, yu]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (7*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (11*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (17*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{0, 1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (23*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (15*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (29*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (23*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (23*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (29*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (43*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (29*G[{1}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (7*G[{yu^(-1)}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (25*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (41*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (41*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (17*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (9*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (17*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/4 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{yv^(-1), 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (21*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (25*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (15*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (7*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (25*G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (41*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (9*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (5*G[{0}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0, 1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (3*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 - (G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (9*G[{0}, yu]*G[{0, 0, 0, 1}, yu])/64 - 
     (9*G[{1}, yu]*G[{0, 0, 0, 1}, yu])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 0, 1}, yu])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, 1}, yu])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yu])/64 + 
     (G[{0}, yu]*G[{0, 0, 1, 1}, yu])/16 + (3*G[{0}, yv]*G[{0, 0, 1, 1}, yu])/
      16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yu])/32 - 
     (G[{1}, yv]*G[{0, 0, 1, 1}, yu])/32 + (7*G[{1}, yw]*G[{0, 0, 1, 1}, yu])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yu])/32 + 
     (G[{0}, yv]*G[{0, 0, 1, 1}, yv])/16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yv])/
      16 + (G[{1}, yv]*G[{0, 0, 1, 1}, yv])/8 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yv])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv])/8 + 
     (5*G[{0}, yu]*G[{0, 0, 1, 1}, yw])/16 - (G[{0}, yv]*G[{0, 0, 1, 1}, yw])/
      16 - (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, 0, 1, 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 0, 1, 1}, yw])/16 + (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/
      8 - (G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/8 - 
     (5*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 - 
     (5*G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (5*G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv])/4 - 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv])/16 - 
     (3*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (5*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (5*G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/4 + 
     (9*G[{0}, yu]*G[{0, 1, 1, 1}, yu])/64 + (G[{0}, yv]*G[{0, 1, 1, 1}, yu])/
      8 - (G[{1}, yu]*G[{0, 1, 1, 1}, yu])/16 + 
     (G[{1}, yv]*G[{0, 1, 1, 1}, yu])/16 + (G[{1}, yw]*G[{0, 1, 1, 1}, yu])/
      8 - (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yv])/16 + (3*G[{0}, yv]*G[{0, 1, 1, 1}, yv])/
      16 + (3*G[{1}, yu]*G[{0, 1, 1, 1}, yv])/16 + 
     (G[{1}, yv]*G[{0, 1, 1, 1}, yv])/8 + (G[{1}, yw]*G[{0, 1, 1, 1}, yv])/
      8 - (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yw])/4 + (G[{0}, yv]*G[{0, 1, 1, 1}, yw])/
      16 - (G[{0}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, 1, 1}, yw])/16 + (G[{1}, yv]*G[{0, 1, 1, 1}, yw])/
      8 + (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/16 + 
     (5*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/2 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv])/16 + 
     (3*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/4 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/8 - 
     (3*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/2 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (5*G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yv])/16 - 
     (3*G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv])/16 - 
     (3*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv])/16 - 
     (3*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 - 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (5*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/4 - 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 - 
     (5*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/4 - 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/4 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/2 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/4 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (7*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/2 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (5*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (5*G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/16 + 
     (5*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/64 - 
     (G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{yu^(-1)}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/4 - 
     (3*G[{1}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/8 + 
     (25*G[{0}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (29*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (41*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu^(-1)}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (23*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (23*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (5*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (25*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/4 - 
     (41*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (7*G[{1}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 + 
     (7*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (25*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/2 - 
     (41*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (23*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (9*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (5*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (9*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (5*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (5*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 + 
     (9*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (3*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (15*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (7*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (23*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (25*G[{0}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (41*G[{1}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 - (25*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (41*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (41*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/32 - (G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/2 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (7*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (23*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/8 - (9*G[{0, 0, 0, 1, 1}, yv])/16 + 
     (3*G[{0, 0, 0, 1, 1}, yw])/8 + (9*G[{0, 0, 0, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 - (3*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      16 + (9*G[{0, 0, 0, yu^(-1), 1}, yv])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1}, yw])/16 - 
     (9*G[{0, 0, 0, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0, 0, 1, 0, 1}, yu])/64 - (3*G[{0, 0, 1, 0, 1}, yv])/16 + 
     G[{0, 0, 1, 0, 1}, yw]/8 + (3*G[{0, 0, 1, 0, yu^(-1)}, yv])/16 - 
     G[{0, 0, 1, 0, yu^(-1)}, yw]/16 - G[{0, 0, 1, 0, yv^(-1)}, yw]/16 + 
     (3*G[{0, 0, 1, 1, 1}, yu])/8 + (3*G[{0, 0, 1, 1, 1}, yv])/8 + 
     G[{0, 0, 1, 1, 1}, yw]/8 + (5*G[{0, 0, 1, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0, 0, 1, 1, yu^(-1)}, yw])/16 - (3*G[{0, 0, 1, 1, yv^(-1)}, yw])/
      16 + G[{0, 0, 1, 1, 1/(yu*yv)}, yw]/4 + G[{0, 0, 1, yu^(-1), 1}, yv]/
      8 - G[{0, 0, 1, yu^(-1), 1}, yw]/8 + 
     (3*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     G[{0, 0, 1, yu^(-1), yv^(-1)}, yw]/8 - 
     (3*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     G[{0, 0, 1, yv^(-1), 1}, yw]/8 + G[{0, 0, 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     G[{0, 0, 1, 1/(yu*yv), 1}, yw]/4 - 
     (5*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, yu^(-1), 0, 1}, yv])/16 - G[{0, 0, yu^(-1), 0, 1}, yw]/16 - 
     (3*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv])/16 + 
     G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/16 + G[{0, 0, yu^(-1), 1, 1}, yv]/
      4 - G[{0, 0, yu^(-1), 1, 1}, yw]/4 - 
     (3*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv])/16 + 
     (5*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, yu^(-1), yu^(-1), 1}, yv]/8 + 
     G[{0, 0, yu^(-1), yu^(-1), 1}, yw]/8 + 
     (9*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv])/16 + 
     G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     G[{0, 0, yv^(-1), 0, 1}, yw]/16 + G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/
      16 - G[{0, 0, yv^(-1), 1, 1}, yw]/4 + 
     (3*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (5*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     (5*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*G[{0, 1, 0, 1, 1}, yu])/64 + G[{0, 1, 0, 1, 1}, yv]/4 + 
     (3*G[{0, 1, 0, 1, yu^(-1)}, yv])/16 - (3*G[{0, 1, 0, 1, yv^(-1)}, yw])/
      16 + G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/16 + G[{0, 1, 0, yu^(-1), 1}, yv]/
      16 - G[{0, 1, 0, yu^(-1), 1}, yw]/8 - 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yv]/16 + 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yw]/4 + 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw]/8 - G[{0, 1, 0, yv^(-1), 1}, yw]/
      8 + G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw]/16 + G[{0, 1, 0, 1/(yu*yv), 1}, yw]/
      4 - (5*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     (3*G[{0, 1, 1, 0, yu^(-1)}, yv])/16 + (3*G[{0, 1, 1, 1, 1}, yu])/16 - 
     (3*G[{0, 1, 1, 1, 1}, yv])/16 + (3*G[{0, 1, 1, 1, 1}, yw])/16 - 
     G[{0, 1, 1, 1, yu^(-1)}, yv]/8 - G[{0, 1, 1, 1, yu^(-1)}, yw]/8 + 
     G[{0, 1, 1, 1, yv^(-1)}, yw]/16 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, 1, yu^(-1), 1}, yv]/16 + G[{0, 1, 1, yu^(-1), 1}, yw]/8 + 
     (3*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv])/16 - 
     G[{0, 1, 1, yu^(-1), yu^(-1)}, yw]/2 + G[{0, 1, 1, yv^(-1), 1}, yw]/8 + 
     G[{0, 1, 1, yv^(-1), yv^(-1)}, yw]/4 - G[{0, 1, 1, 1/(yu*yv), 1}, yw]/
      16 + G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yv]/16 + 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/16 + 
     G[{0, 1, yu^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw]/8 - G[{0, 1, yu^(-1), 1, 1}, yv]/
      8 + (3*G[{0, 1, yu^(-1), 1, 1}, yw])/16 + 
     (3*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv])/16 - 
     (3*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (3*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 1, yu^(-1), yu^(-1), 1}, yv]/4 - 
     G[{0, 1, yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv]/8 + 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/2 - 
     G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     (3*G[{0, 1, yv^(-1), 1, 1}, yw])/16 + 
     (3*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 1, yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/4 - 
     G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 + 
     G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw]/16 + 
     (5*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv])/16 + 
     G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw]/16 + (3*G[{0, yu^(-1), 1, 1, 1}, yv])/
      16 + G[{0, yu^(-1), 1, 1, yu^(-1)}, yv]/8 + 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yv]/16 - 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yw]/8 - 
     (3*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv])/16 + 
     G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/4 - 
     G[{0, yu^(-1), 1, yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/4 + 
     G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yv]/8 - 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/4 - 
     (3*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv])/16 + 
     G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv]/4 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv]/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, 1}, yw]/4 + 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/4 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/4 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 0, yv^(-1), 1}, yw]/16 + 
     G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), 1, yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, 1}, yw]/4 + 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/4 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/4 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/4 + 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1, 1, 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw]/4 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/2 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw])/16 - 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw]/4 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw]/4 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/4 - 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/8 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/2 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     (5*G[{1, 1, 1, 1, yu^(-1)}, yv])/16 + G[{1, 1, 1, 1, yu^(-1)}, yw]/16 + 
     G[{1, 1, 1, 1, yv^(-1)}, yw]/16 - G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/2 - 
     G[{1, 1, 1, yu^(-1), yu^(-1)}, yv]/8 + 
     (5*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (7*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw]/4 + 
     G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (5*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (15*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, 1, yu^(-1), 1, yu^(-1)}, yv])/64 + 
     (13*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     G[{1, 1, yu^(-1), 1, yv^(-1)}, yw]/16 + 
     (7*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (19*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 + 
     (81*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/4 + 
     (27*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/4 + 
     G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (7*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{1, 1, yv^(-1), 1, yu^(-1)}, yw]/16 + 
     G[{1, 1, yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/4 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/4 - 
     (15*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (15*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (23*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv]/8 + 
     (5*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 + 
     (11*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/8 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv])/32 + 
     (41*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (9*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/2 - 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/4 - 
     G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (5*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (7*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (3*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/4 - 
     G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     (3*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (17*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (7*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (41*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (129*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/2 - 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (17*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/2 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (7*Pi^2*Zeta[3])/256 + (G[{0}, yu]^2*Zeta[3])/16 + 
     (G[{0}, yu]*G[{0}, yv]*Zeta[3])/16 - (3*G[{0}, yv]^2*Zeta[3])/64 - 
     (G[{0}, yu]*G[{1}, yu]*Zeta[3])/16 - (5*G[{0}, yv]*G[{1}, yu]*Zeta[3])/
      32 - (G[{1}, yu]^2*Zeta[3])/8 + (G[{0}, yu]*G[{1}, yv]*Zeta[3])/16 + 
     (5*G[{0}, yv]*G[{1}, yv]*Zeta[3])/32 + (G[{1}, yu]*G[{1}, yv]*Zeta[3])/
      4 + (G[{1}, yv]^2*Zeta[3])/32 + (G[{0}, yu]*G[{1}, yw]*Zeta[3])/8 + 
     (3*G[{0}, yv]*G[{1}, yw]*Zeta[3])/32 - (G[{0}, yw]*G[{1}, yw]*Zeta[3])/
      16 - (G[{1}, yu]*G[{1}, yw]*Zeta[3])/16 + 
     (G[{1}, yv]*G[{1}, yw]*Zeta[3])/16 + (7*G[{1}, yw]^2*Zeta[3])/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*Zeta[3])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*Zeta[3])/64 + (5*G[{0, 1}, yu]*Zeta[3])/32 - 
     (5*G[{0, 1}, yv]*Zeta[3])/32 + (G[{0, 1}, yw]*Zeta[3])/16 + 
     (3*G[{0, yu^(-1)}, yv]*Zeta[3])/32 - (G[{0, 1/(yu*yv)}, yw]*Zeta[3])/
      16 - (5*G[{1, yu^(-1)}, yv]*Zeta[3])/16 + (G[{1, yu^(-1)}, yw]*Zeta[3])/
      32 - (G[{1, yv^(-1)}, yw]*Zeta[3])/32 + (G[{1, 1/(yu*yv)}, yw]*Zeta[3])/
      8 + (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - Zeta[5]/64
 
QepwvuRegI = (17*Pi^4*G[{0}, yv])/11520 + (Pi^2*G[{0}, yu]^2*G[{0}, yv])/256 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]^2)/96 + (Pi^2*G[{0}, yv]^3)/256 + 
     (3*G[{0}, yu]^2*G[{0}, yv]^3)/256 + (17*Pi^4*G[{1}, yu])/11520 + 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/256 + 
     (5*Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu])/384 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yu])/768 + 
     (9*G[{0}, yu]^2*G[{0}, yv]^2*G[{1}, yu])/256 - 
     (3*G[{0}, yu]*G[{0}, yv]^3*G[{1}, yu])/128 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/384 - (11*Pi^2*G[{0}, yv]*G[{1}, yu]^2)/
      768 + (9*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]^2)/256 - 
     (5*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]^2)/128 - 
     (5*Pi^2*G[{1}, yu]^3)/768 + (3*G[{0}, yu]^2*G[{1}, yu]^3)/256 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^3)/384 + (G[{0}, yu]*G[{1}, yu]^4)/
      96 - (17*Pi^4*G[{1}, yv])/11520 - (Pi^2*G[{0}, yu]^2*G[{1}, yv])/256 - 
     (5*Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv])/384 - 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/768 - 
     (9*G[{0}, yu]^2*G[{0}, yv]^2*G[{1}, yv])/256 + 
     (3*G[{0}, yu]*G[{0}, yv]^3*G[{1}, yv])/128 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv])/192 + 
     (11*Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/384 - 
     (9*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/128 + 
     (5*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv])/64 + 
     (5*Pi^2*G[{1}, yu]^2*G[{1}, yv])/256 - 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yv])/256 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yv])/24 + (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/
      384 - (3*Pi^2*G[{0}, yv]*G[{1}, yv]^2)/512 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]^2)/128 + 
     (3*G[{0}, yv]^3*G[{1}, yv]^2)/256 - (17*Pi^2*G[{1}, yu]*G[{1}, yv]^2)/
      1536 + (3*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]^2)/256 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2)/128 + 
     (9*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]^2)/256 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]^2)/16 + 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]^2)/256 + 
     (3*G[{1}, yu]^3*G[{1}, yv]^2)/256 + (Pi^2*G[{1}, yv]^3)/768 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^3)/384 - (G[{0}, yv]^2*G[{1}, yv]^3)/
      256 - (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^3)/128 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^3)/128 - (G[{1}, yu]^2*G[{1}, yv]^3)/
      256 - (G[{0}, yv]*G[{1}, yv]^4)/768 - (G[{1}, yu]*G[{1}, yv]^4)/768 + 
     (17*Pi^4*G[{1}, yw])/11520 + (Pi^2*G[{0}, yu]^2*G[{1}, yw])/256 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw])/128 + 
     (5*Pi^2*G[{0}, yv]^2*G[{1}, yw])/768 + 
     (9*G[{0}, yu]^2*G[{0}, yv]^2*G[{1}, yw])/256 + 
     (3*G[{0}, yu]*G[{0}, yv]^3*G[{1}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw])/32 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/192 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw])/32 + 
     (5*Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/384 + 
     (9*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw])/16 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/8 - 
     (7*Pi^2*G[{1}, yu]^2*G[{1}, yw])/768 + 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yw])/256 - 
     (21*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw])/128 - 
     (7*G[{0}, yu]*G[{1}, yu]^3*G[{1}, yw])/192 - 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/128 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw])/32 + 
     (3*G[{0}, yv]^3*G[{1}, yv]*G[{1}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/16 - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/128 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/64 + 
     (9*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/128 + 
     (3*G[{1}, yu]^3*G[{1}, yv]*G[{1}, yw])/128 + 
     (Pi^2*G[{1}, yv]^2*G[{1}, yw])/768 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw])/128 - 
     (9*G[{0}, yv]^2*G[{1}, yv]^2*G[{1}, yw])/256 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/128 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/128 - 
     (9*G[{1}, yu]^2*G[{1}, yv]^2*G[{1}, yw])/256 + 
     (G[{0}, yv]*G[{1}, yv]^3*G[{1}, yw])/96 + 
     (G[{1}, yu]*G[{1}, yv]^3*G[{1}, yw])/96 + (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/
      384 + (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/192 + 
     (9*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw]^2)/256 + 
     (9*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yv]^3*G[{1}, yw]^2)/256 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/192 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2)/8 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]^2)/64 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]^2)/64 + 
     (Pi^2*G[{1}, yu]*G[{1}, yw]^2)/96 + 
     (9*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2)/128 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2)/16 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]^2)/64 - 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]^2)/64 - 
     (11*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]^2)/256 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]^2)/64 - 
     (5*G[{1}, yu]^3*G[{1}, yw]^2)/256 - (7*Pi^2*G[{1}, yv]*G[{1}, yw]^2)/
      768 - (17*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2)/128 - 
     (9*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]^2)/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]^2)/64 - 
     (13*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/128 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2)/32 - 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]^2)/256 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]^2)/64 - 
     (5*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]^2)/32 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]^2)/128 + (G[{1}, yv]^3*G[{1}, yw]^2)/
      64 + (Pi^2*G[{1}, yw]^3)/384 + (3*G[{0}, yu]^2*G[{1}, yw]^3)/256 + 
     (9*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^3)/128 + 
     (9*G[{0}, yv]^2*G[{1}, yw]^3)/256 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^3)/
      24 - (7*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^3)/96 + 
     (G[{0}, yw]^2*G[{1}, yw]^3)/96 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^3)/
      64 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^3)/384 - 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^3)/96 - 
     (7*G[{1}, yu]^2*G[{1}, yw]^3)/256 - 
     (7*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^3)/384 - 
     (9*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^3)/128 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^3)/48 - 
     (35*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^3)/384 - 
     (5*G[{1}, yv]^2*G[{1}, yw]^3)/256 + (3*G[{0}, yu]*G[{1}, yw]^4)/128 + 
     (9*G[{0}, yv]*G[{1}, yw]^4)/256 - (11*G[{0}, yw]*G[{1}, yw]^4)/384 + 
     (5*G[{1}, yu]*G[{1}, yw]^4)/768 - (G[{1}, yv]*G[{1}, yw]^4)/192 + 
     (3*G[{1}, yw]^5)/256 - (5*Pi^2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/
      256 - (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (5*Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/256 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 - 
     (9*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/8 - 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (3*G[{1}, yu]^3*G[{1}, yw]*G[{yu^(-1)}, yv])/128 + 
     (13*Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/384 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (11*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/32 + 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/64 + 
     (11*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/128 - 
     (3*Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 - 
     (9*G[{0}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/8 - 
     (G[{0}, yw]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 + 
     (17*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 + 
     (3*G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/64 + 
     (7*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (25*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/16 + 
     (33*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv])/128 + 
     (15*G[{1}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/256 - 
     (31*G[{0}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 - 
     (7*G[{0}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 + 
     (11*G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/96 + 
     (G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/24 + 
     (13*G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/384 - 
     (15*G[{1}, yw]^4*G[{yu^(-1)}, yv])/256 + 
     (7*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/512 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/64 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/32 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/128 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/32 + 
     (3*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/256 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/8 - 
     (29*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/256 - 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2)/32 + 
     (59*G[{1}, yw]^3*G[{yu^(-1)}, yv]^2)/768 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/48 + 
     (7*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/192 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/192 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3)/48 - 
     (11*G[{1}, yw]^2*G[{yu^(-1)}, yv]^3)/768 - 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]^4)/768 - (17*Pi^4*G[{1/(yu*yv)}, yw])/
      11520 - (Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/256 - 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (5*Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/768 - 
     (9*G[{0}, yu]^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]*G[{0}, yv]^3*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/192 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/384 - 
     (9*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/8 + 
     (7*Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/768 - 
     (9*G[{0}, yu]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/256 + 
     (21*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/768 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yv]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{1}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yv]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (9*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (9*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/384 + 
     (17*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (13*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (27*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (27*G[{0}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (21*G[{1}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (27*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (35*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (15*G[{1}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (5*G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (15*G[{1}, yw]^4*G[{1/(yu*yv)}, yw])/256 + 
     (5*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 + (5*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 + (9*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 - 
     (13*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 - (11*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/4 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (17*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      32 - (7*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (25*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/
      8 - (33*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (15*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 + (31*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 + (7*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/8 - (13*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/128 + (15*G[{1}, yw]^3*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw])/64 - (7*Pi^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/512 - (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 + (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/4 + (29*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/16 - (59*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw])/256 - (G[{0}, yu]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/48 - (7*G[{0}, yv]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/192 - (7*G[{1}, yu]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/192 - (G[{1}, yv]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/48 + (11*G[{1}, yw]*G[{yu^(-1)}, yv]^3*
       G[{1/(yu*yv)}, yw])/384 + (11*G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/
      768 + (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (3*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (17*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (19*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (7*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/96 + 
     (5*G[{0}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 + (G[{0}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/24 - (G[{0}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/24 - (G[{1}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 + (G[{1}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yu]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/192 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (11*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (9*G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/192 - 
     (7*Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/512 - 
     (3*G[{0}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 - 
     (29*G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (13*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 + (7*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/12 + (25*G[{0}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (G[{0}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/12 + (41*G[{1}, yu]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (3*G[{1}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/64 - (41*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/
      768 + (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/384 - 
     (7*Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (7*G[{0}, yu]*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (7*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu]^3*G[{1/(yu*yv)}, yw]^2)/32 + 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (13*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{1}, yv]^3*G[{1/(yu*yv)}, yw]^2)/64 - 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (7*G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (9*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (31*G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (17*G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (7*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (21*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (21*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (21*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (51*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/16 + 
     (17*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (15*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/16 + 
     (43*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (11*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/64 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (3*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (9*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (19*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (15*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (15*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (15*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (19*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (19*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (5*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      256 - (5*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (13*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/48 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/192 - 
     (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/24 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (13*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (7*Pi^2*G[{0}, yv]*G[{0, 1}, yu])/384 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yu])/16 + 
     (3*G[{0}, yv]^3*G[{0, 1}, yu])/128 + (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/
      128 - (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yu])/8 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu])/32 - 
     (11*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yu])/128 - 
     (5*G[{1}, yu]^3*G[{0, 1}, yu])/128 - (Pi^2*G[{1}, yv]*G[{0, 1}, yu])/
      128 + (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu])/8 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/16 + 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu])/64 + 
     (15*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/32 - 
     (9*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yu])/128 - 
     (13*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/128 + 
     (G[{1}, yv]^3*G[{0, 1}, yu])/96 + (Pi^2*G[{1}, yw]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (5*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/16 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu])/8 - 
     (7*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yu])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu])/64 + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/32 + 
     (5*G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/128 + 
     (13*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/128 + 
     (5*G[{1}, yw]^3*G[{0, 1}, yu])/384 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/8 - 
     (13*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/128 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu])/64 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (5*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (13*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/128 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/8 + 
     (13*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 - 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/32 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/
      32 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/16 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/16 - 
     (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/128 - 
     (G[{0}, yu]*G[{0, 1}, yu]^2)/32 + (G[{0}, yv]*G[{0, 1}, yu]^2)/32 + 
     (G[{1}, yu]*G[{0, 1}, yu]^2)/32 - (G[{1}, yv]*G[{0, 1}, yu]^2)/32 + 
     (G[{1}, yw]*G[{0, 1}, yu]^2)/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2)/
      32 + (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/768 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0, 1}, yv])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yv])/32 - 
     (5*Pi^2*G[{1}, yu]*G[{0, 1}, yv])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yv])/64 - 
     (7*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yv])/16 + 
     (11*Pi^2*G[{1}, yv]*G[{0, 1}, yv])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yv])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yv])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv])/32 - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/64 + 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv])/128 + 
     (7*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/128 + 
     (G[{1}, yv]^3*G[{0, 1}, yv])/128 - (Pi^2*G[{1}, yw]*G[{0, 1}, yv])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yv])/64 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv])/32 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/64 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv])/32 - 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/16 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv])/64 + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yv])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv])/32 - 
     (13*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/128 - 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/128 + 
     (13*G[{1}, yw]^3*G[{0, 1}, yv])/192 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/8 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/32 + 
     (9*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/64 - 
     (21*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/128 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv])/32 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/256 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/8 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (21*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/64 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/
      16 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/32 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/16 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/64 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/32 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/64 + 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 - 
     (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/128 - 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/16 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv])/32 - 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv])/32 + 
     (9*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv])/64 + 
     (3*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv])/64 + 
     (G[{0}, yu]*G[{0, 1}, yv]^2)/32 - (G[{0}, yv]*G[{0, 1}, yv]^2)/32 - 
     (G[{1}, yu]*G[{0, 1}, yv]^2)/32 + (7*G[{1}, yv]*G[{0, 1}, yv]^2)/128 + 
     (G[{1}, yw]*G[{0, 1}, yv]^2)/128 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2)/
      128 + (3*G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yw])/16 + 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yw])/8 - 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw])/16 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/16 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/4 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1}, yw]^2)/32 + (G[{0}, yv]*G[{0, 1}, yw]^2)/16 + 
     (G[{1}, yu]*G[{0, 1}, yw]^2)/16 - (G[{1}, yv]*G[{0, 1}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, 1}, yw]^2)/32 - (G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2)/
      32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/96 - 
     (3*Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/256 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/64 - 
     (Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv])/16 + 
     (5*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/64 - 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/128 - 
     (7*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/128 - 
     (G[{1}, yv]^3*G[{0, yu^(-1)}, yv])/128 + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/256 - 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/32 + 
     (13*G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 + 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/128 - 
     (13*G[{1}, yw]^3*G[{0, yu^(-1)}, yv])/192 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/32 - 
     (9*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/64 + 
     (21*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/128 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv])/32 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/256 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (13*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/32 + (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/8 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      32 + (9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/64 - (21*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/64 + 
     (3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 + (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/32 + (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      64 + (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/64 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/
      32 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/32 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/64 + (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/32 + (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/64 - (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 + (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/64 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yv])/128 + (G[{0}, yu]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/16 - (3*G[{0}, yv]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/32 - (G[{1}, yu]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/32 - (G[{1}, yv]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/64 - (3*G[{1}, yw]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{0, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/8 + (G[{0}, yv]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1}, yu]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/64 - (G[{1}, yw]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/64 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{0, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 - (G[{0}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/16 + (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yv])/8 - (G[{0}, yv]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]^2)/32 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]^2)/128 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]^2)/128 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/96 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/96 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 + (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      4 - (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (13*Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/768 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]^3*G[{1, yu^(-1)}, yv])/128 - 
     (13*Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/768 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yv])/32 - 
     (9*G[{0}, yv]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/128 - 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{1}, yu]^3*G[{1, yu^(-1)}, yv])/128 + 
     (Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv])/128 - 
     (3*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (11*G[{0}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (5*G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/32 - 
     (9*G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (7*G[{1}, yw]^3*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/64 + 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/256 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (11*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (11*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (21*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 + (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/8 + (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/64 - (G[{0}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/16 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      32 + (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      64 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/32 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      32 - (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/
      16 - (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yv])/16 - (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/32 + 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/32 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/64 - 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/16 - 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (5*G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/64 - 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (5*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1, yu^(-1)}, yv]^2)/32 + 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]^2)/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]^2)/128 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]^2)/128 - 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]^3*G[{1, yu^(-1)}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/32 + 
     (3*Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/32 + 
     (11*G[{0}, yv]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu]^3*G[{1, yu^(-1)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (17*G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/32 - 
     (19*G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/16 - 
     (11*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{1}, yv]^3*G[{1, yu^(-1)}, yw])/32 - 
     (7*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/8 - 
     (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yw])/48 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (7*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (11*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (19*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (11*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (7*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (7*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{0}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/32 + 
     (9*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]^2)/16 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/16 + 
     (Pi^2*G[{0}, yu]*G[{1, yv^(-1)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{1, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu]^3*G[{1, yv^(-1)}, yw])/16 - 
     (Pi^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/192 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]^3*G[{1, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/64 - 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 + 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/8 - 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/32 - 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/64 + 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]^3*G[{1, yv^(-1)}, yw])/192 - 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (11*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (7*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (11*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (9*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (21*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (7*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (11*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (3*G[{1}, yu]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/4 + (G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/32 + (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/64 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{0}, yu]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/32 + (3*G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/32 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, yv^(-1)}, yw])/64 - (G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, yv^(-1)}, yw])/64 - (G[{0}, yu]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yv]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/4 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/64 + (G[{0}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/4 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/4 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/4 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/8 - (G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yu]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (5*G[{0}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (5*G[{1}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yv]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]^2)/8 - 
     (G[{1}, yu]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yv]*G[{1, yv^(-1)}, yw]^2)/8 + 
     (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/128 + 
     (5*Pi^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (5*Pi^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yv]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (13*Pi^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yv]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yv]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (5*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (13*G[{0}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (15*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (23*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (23*G[{0}, yv]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (13*G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (39*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (11*G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (13*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (15*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (19*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (9*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{0}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/8 + (3*G[{1}, yu]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/8 + (3*G[{1}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 - (3*G[{1}, yu]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 - (9*G[{1}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 + (17*G[{1}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/8 + (3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 + (9*G[{1}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 - (17*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/16 + (11*G[{1}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (5*G[{1}, yu]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 - (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (7*G[{1}, yu]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*Pi^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (17*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (19*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (15*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 - 
     (5*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yu]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (7*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/384 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (13*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (7*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (9*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (Pi^2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/192 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (7*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (7*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (9*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (7*G[{yu^(-1)}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 + 
     (7*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (9*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (21*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (29*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yv]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (25*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (41*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (41*G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (13*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (9*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (5*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (13*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (9*G[{0}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (5*G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (5*G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (13*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (13*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (5*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (7*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (9*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0, 0, 1}, yu])/96 + (G[{0}, yv]^2*G[{0, 0, 1}, yu])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu])/4 + 
     (G[{1}, yu]^2*G[{0, 0, 1}, yu])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yu])/4 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu])/8 + 
     (G[{1}, yv]^2*G[{0, 0, 1}, yu])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 + 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yu])/8 + (G[{0, 1}, yv]*G[{0, 0, 1}, yu])/
      8 - (G[{0, 1}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yu])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu])/8 - 
     (Pi^2*G[{0, 0, 1}, yv])/64 - (3*G[{0}, yu]^2*G[{0, 0, 1}, yv])/128 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yv])/16 - 
     (3*G[{0}, yv]^2*G[{0, 0, 1}, yv])/64 + 
     (19*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yv])/64 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yv])/32 - 
     (3*G[{1}, yu]^2*G[{0, 0, 1}, yv])/64 - 
     (15*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv])/64 + 
     (9*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv])/64 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv])/64 - 
     (17*G[{1}, yv]^2*G[{0, 0, 1}, yv])/128 + 
     (13*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/64 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv])/64 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv])/64 + 
     (17*G[{1}, yw]^2*G[{0, 0, 1}, yv])/128 - 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv])/64 - 
     (13*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 + 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 - 
     (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 + 
     (11*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv])/64 - 
     (7*G[{0, 1}, yu]*G[{0, 0, 1}, yv])/64 + (G[{0, 1}, yv]*G[{0, 0, 1}, yv])/
      32 + (G[{0, 1}, yw]*G[{0, 0, 1}, yv])/16 - 
     (7*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yv])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yv])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv])/32 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv])/32 + 
     (Pi^2*G[{0, 0, 1}, yw])/96 + (G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yw])/
      16 + (G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{0, 1}, yu]*G[{0, 0, 1}, yw])/16 + (G[{0, 1}, yv]*G[{0, 0, 1}, yw])/
      16 - (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (Pi^2*G[{0, 0, yu^(-1)}, yv])/192 + 
     (3*G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yv])/128 + 
     (3*G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (9*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (17*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (17*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv])/128 + 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (11*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yv])/64 + 
     (3*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv])/32 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yv])/16 + 
     (7*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv])/32 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/64 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{0, 1, 1}, yu])/96 - (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu])/
      16 + (G[{0}, yv]^2*G[{0, 1, 1}, yu])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yu])/8 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yu]^2*G[{0, 1, 1}, yu])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/8 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yv]^2*G[{0, 1, 1}, yu])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/8 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{0, 1}, yu]*G[{0, 1, 1}, yu])/8 + (G[{0, 1}, yv]*G[{0, 1, 1}, yu])/
      8 - (3*G[{0, 1}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu])/16 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu])/16 - 
     (5*Pi^2*G[{0, 1, 1}, yv])/256 + (3*G[{0}, yu]^2*G[{0, 1, 1}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yv])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv])/64 - 
     (5*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv])/8 - 
     (G[{1}, yv]^2*G[{0, 1, 1}, yv])/128 + 
     (7*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv])/64 + 
     (5*G[{1}, yw]^2*G[{0, 1, 1}, yv])/128 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv])/64 - 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/32 - 
     (9*G[{0, 1}, yu]*G[{0, 1, 1}, yv])/64 - 
     (5*G[{0, 1}, yv]*G[{0, 1, 1}, yv])/64 - 
     (5*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yv])/32 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yv])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv])/32 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv])/32 - 
     (Pi^2*G[{0, 1, 1}, yw])/96 + (G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yw])/
      8 + (3*G[{0}, yv]^2*G[{0, 1, 1}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{1}, yu]^2*G[{0, 1, 1}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/4 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0, 1}, yv]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (11*Pi^2*G[{0, 1, yu^(-1)}, yv])/768 - 
     (3*G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yv])/64 + 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (9*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/64 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv])/64 - 
     (G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv])/8 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (11*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (7*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (11*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yv])/64 + 
     (G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv])/16 - 
     (Pi^2*G[{0, 1, yu^(-1)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{0, 1}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (7*Pi^2*G[{0, yu^(-1), 1}, yv])/768 - 
     (3*G[{0}, yu]^2*G[{0, yu^(-1), 1}, yv])/128 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv])/64 + 
     (5*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1}, yv])/128 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (5*G[{1}, yw]^2*G[{0, yu^(-1), 1}, yv])/128 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/64 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/32 + 
     (5*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yv])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv])/32 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv])/32 + 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/96 + 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (5*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/768 + 
     (3*G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (9*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (9*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (7*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (7*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/64 + 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/
      32 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/
      32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/
      16 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw])/8 + 
     (5*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/96 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*Pi^2*G[{1, 1, yu^(-1)}, yv])/768 - 
     (3*G[{0}, yu]^2*G[{1, 1, yu^(-1)}, yv])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yv])/32 - 
     (17*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv])/16 - 
     (G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv])/32 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yv])/128 - 
     (7*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (5*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yv])/128 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (9*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (3*G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv])/32 + 
     (Pi^2*G[{1, 1, yu^(-1)}, yw])/48 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (Pi^2*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]^2*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (7*G[{0}, yv]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (19*G[{1}, yu]^2*G[{1, 1, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (27*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (33*G[{1}, yv]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (15*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (11*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (9*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yv]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yu]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (13*G[{1}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{1}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{1}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (33*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (33*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (21*G[{yu^(-1)}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{0, 1}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (11*Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/768 - 
     (3*G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (5*G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (5*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (5*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/
      32 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/
      8 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/16 - 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv])/8 - 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/48 - 
     (5*G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/2 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      16 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/16 - (G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (5*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (7*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (9*G[{0}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (15*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (21*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (29*G[{1}, yu]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (9*G[{1}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/2 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (7*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (31*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (15*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (33*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (33*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/32 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (7*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/16 + (G[{0, 1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (11*Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{1}, yu]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (7*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (11*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (17*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (29*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (23*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (29*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (43*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (15*G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (15*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (5*G[{0}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0, 1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 - (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/4 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/4 - (G[{yv^(-1), 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (21*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (29*G[{1}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{1}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (13*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (7*G[{yu^(-1)}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      2 + (25*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (41*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (41*G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (17*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (17*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (17*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1, yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (15*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (25*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (9*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (7*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (3*G[{0}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/2 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (25*G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (41*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (9*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (9*G[{0}, yv]*G[{0, 0, 0, 1}, yv])/64 + 
     (9*G[{1}, yu]*G[{0, 0, 0, 1}, yv])/64 - 
     (9*G[{1}, yv]*G[{0, 0, 0, 1}, yv])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, 1}, yv])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yv])/64 - 
     (9*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yv])/64 - 
     (9*G[{1}, yu]*G[{0, 0, 0, yu^(-1)}, yv])/64 + 
     (9*G[{1}, yv]*G[{0, 0, 0, yu^(-1)}, yv])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, yu^(-1)}, yv])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0, 0, 1, 1}, yu])/16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yu])/
      8 - (G[{1}, yv]*G[{0, 0, 1, 1}, yu])/8 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yu])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yu])/8 + 
     (3*G[{0}, yu]*G[{0, 0, 1, 1}, yv])/16 + (G[{0}, yv]*G[{0, 0, 1, 1}, yv])/
      16 + (G[{1}, yu]*G[{0, 0, 1, 1}, yv])/16 + 
     (G[{1}, yv]*G[{0, 0, 1, 1}, yv])/32 + (7*G[{1}, yw]*G[{0, 0, 1, 1}, yv])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv])/32 - 
     (G[{0}, yu]*G[{0, 0, 1, 1}, yw])/16 + (5*G[{0}, yv]*G[{0, 0, 1, 1}, yw])/
      16 - (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/8 + 
     (3*G[{1}, yu]*G[{0, 0, 1, 1}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 0, 1, 1}, yw])/16 + (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/
      8 - (G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (7*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv])/64 - 
     (11*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv])/64 - 
     (5*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yv])/64 + 
     (G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (5*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1, yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (5*G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1, yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv])/16 - 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv])/16 - 
     (G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv])/16 - 
     (9*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv])/32 - 
     (3*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yv])/32 - 
     (G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (7*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 + 
     (7*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 + 
     (11*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (5*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yv])/8 - 
     (G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yu]*G[{0, 1, 1, 1}, yu])/16 - (G[{0}, yv]*G[{0, 1, 1, 1}, yu])/
      16 + (G[{1}, yu]*G[{0, 1, 1, 1}, yu])/8 - 
     (G[{1}, yv]*G[{0, 1, 1, 1}, yu])/8 + (G[{1}, yw]*G[{0, 1, 1, 1}, yu])/
      8 - (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu])/8 + 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yv])/8 + (9*G[{0}, yv]*G[{0, 1, 1, 1}, yv])/
      64 + (9*G[{1}, yu]*G[{0, 1, 1, 1}, yv])/64 - 
     (G[{1}, yv]*G[{0, 1, 1, 1}, yv])/16 + (G[{1}, yw]*G[{0, 1, 1, 1}, yv])/
      8 - (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv])/8 + 
     (G[{0}, yu]*G[{0, 1, 1, 1}, yw])/16 + (G[{0}, yv]*G[{0, 1, 1, 1}, yw])/
      4 - (G[{0}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, 1, 1}, yw])/8 - (G[{1}, yv]*G[{0, 1, 1, 1}, yw])/
      16 + (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/64 - 
     (G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yv])/64 + 
     (7*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv])/32 + 
     (3*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (5*G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw])/2 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv])/8 - 
     (G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv])/64 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv])/64 + 
     (9*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yv])/32 + 
     (3*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yv])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yv])/32 + 
     (3*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (7*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/32 - 
     (7*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/32 - 
     (13*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (11*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu]*G[{0, 1, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw])/8 + 
     (3*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (3*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/2 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yv])/8 - 
     (9*G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv])/64 - 
     (9*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv])/64 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv])/16 + 
     (G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/64 - 
     (7*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/32 - 
     (3*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv])/32 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv])/64 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv])/64 - 
     (9*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv])/32 - 
     (3*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv])/32 - 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (7*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 + 
     (7*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 + 
     (13*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 - 
     (5*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 - 
     (5*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 - 
     (3*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/4 - 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (5*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/2 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/2 + 
     (3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/16 + 
     (29*G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (29*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yv])/64 + 
     (3*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yv])/8 + 
     (G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/4 - 
     (3*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{yu^(-1)}, yv]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (25*G[{0}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (29*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (41*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu^(-1)}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (9*G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (9*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     (5*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/16 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv])/32 - 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/2 - 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/2 - 
     (G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/4 - 
     (25*G[{0}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/4 - 
     (41*G[{1}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (7*G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 - 
     (7*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     (7*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 + 
     (G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/8 - 
     (3*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/2 - 
     (25*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/2 - 
     (41*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (23*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (9*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (23*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (9*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (9*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (15*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (7*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (23*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (7*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/
      8 - (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      2 - (25*G[{0}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (41*G[{1}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (25*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (41*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (41*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (23*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (23*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (9*G[{0, 0, 0, 1, 1}, yu])/16 + 
     (3*G[{0, 0, 0, 1, 1}, yw])/8 + (9*G[{0, 0, 0, 1, yu^(-1)}, yv])/16 - 
     (3*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 - (3*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      16 + (9*G[{0, 0, 0, yu^(-1), 1}, yv])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1}, yw])/16 - 
     (9*G[{0, 0, 0, yu^(-1), yu^(-1)}, yv])/8 + 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0, 0, 1, 0, 1}, yu])/16 - (3*G[{0, 0, 1, 0, 1}, yv])/64 + 
     G[{0, 0, 1, 0, 1}, yw]/8 + (15*G[{0, 0, 1, 0, yu^(-1)}, yv])/64 - 
     G[{0, 0, 1, 0, yu^(-1)}, yw]/16 - G[{0, 0, 1, 0, yv^(-1)}, yw]/16 + 
     (3*G[{0, 0, 1, 1, 1}, yu])/8 + (3*G[{0, 0, 1, 1, 1}, yv])/8 + 
     G[{0, 0, 1, 1, 1}, yw]/8 + (7*G[{0, 0, 1, 1, yu^(-1)}, yv])/32 - 
     (3*G[{0, 0, 1, 1, yu^(-1)}, yw])/16 - (3*G[{0, 0, 1, 1, yv^(-1)}, yw])/
      16 + G[{0, 0, 1, 1, 1/(yu*yv)}, yw]/4 + 
     (11*G[{0, 0, 1, yu^(-1), 1}, yv])/64 - G[{0, 0, 1, yu^(-1), 1}, yw]/8 + 
     (15*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv])/64 - 
     (3*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     G[{0, 0, 1, yu^(-1), yv^(-1)}, yw]/8 - G[{0, 0, 1, yv^(-1), 1}, yw]/8 + 
     G[{0, 0, 1, yv^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     G[{0, 0, 1, 1/(yu*yv), 1}, yw]/4 + G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/
      16 - (5*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (15*G[{0, 0, yu^(-1), 0, 1}, yv])/64 - G[{0, 0, yu^(-1), 0, 1}, yw]/16 - 
     (27*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv])/64 + 
     G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     (11*G[{0, 0, yu^(-1), 1, 1}, yv])/32 - G[{0, 0, yu^(-1), 1, 1}, yw]/4 - 
     G[{0, 0, yu^(-1), 1, yu^(-1)}, yw]/16 + 
     (3*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (5*G[{0, 0, yu^(-1), yu^(-1), 1}, yv])/64 + 
     G[{0, 0, yu^(-1), yu^(-1), 1}, yw]/8 + 
     (33*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 + 
     G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     G[{0, 0, yv^(-1), 0, 1}, yw]/16 + G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/
      16 - G[{0, 0, yv^(-1), 1, 1}, yw]/4 - 
     (3*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (5*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, 1/(yu*yv), 1, 1}, yw])/8 + 
     G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw]/16 - 
     (5*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     (5*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     G[{0, 1, 0, 1, 1}, yu]/4 + (7*G[{0, 1, 0, 1, 1}, yv])/64 + 
     (15*G[{0, 1, 0, 1, yu^(-1)}, yv])/64 - (3*G[{0, 1, 0, 1, yu^(-1)}, yw])/
      16 + G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/16 + G[{0, 1, 0, yu^(-1), 1}, yv]/
      4 - G[{0, 1, 0, yu^(-1), 1}, yw]/8 - G[{0, 1, 0, yu^(-1), yu^(-1)}, yv]/
      16 - G[{0, 1, 0, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw]/16 - G[{0, 1, 0, yv^(-1), 1}, yw]/
      8 + G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw]/4 - 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw]/8 + G[{0, 1, 0, 1/(yu*yv), 1}, yw]/
      4 + G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (5*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     (15*G[{0, 1, 1, 0, yu^(-1)}, yv])/64 - (3*G[{0, 1, 1, 1, 1}, yu])/16 + 
     (3*G[{0, 1, 1, 1, 1}, yv])/16 + (3*G[{0, 1, 1, 1, 1}, yw])/16 - 
     (17*G[{0, 1, 1, 1, yu^(-1)}, yv])/64 + G[{0, 1, 1, 1, yu^(-1)}, yw]/16 - 
     G[{0, 1, 1, 1, yv^(-1)}, yw]/8 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 - 
     (11*G[{0, 1, 1, yu^(-1), 1}, yv])/32 + G[{0, 1, 1, yu^(-1), 1}, yw]/8 + 
     (9*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv])/64 + 
     G[{0, 1, 1, yu^(-1), yu^(-1)}, yw]/4 + G[{0, 1, 1, yv^(-1), 1}, yw]/8 - 
     G[{0, 1, 1, yv^(-1), yv^(-1)}, yw]/2 - G[{0, 1, 1, 1/(yu*yv), 1}, yw]/
      16 + G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yv]/16 - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     (13*G[{0, 1, yu^(-1), 1, 1}, yv])/32 + (3*G[{0, 1, yu^(-1), 1, 1}, yw])/
      16 + (9*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv])/64 + 
     (3*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (13*G[{0, 1, yu^(-1), yu^(-1), 1}, yv])/64 - 
     G[{0, 1, yu^(-1), yu^(-1), 1}, yw]/8 + 
     (7*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/4 - 
     G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 1, yv^(-1), 1, 1}, yw])/16 + 
     (3*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     G[{0, 1, yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/2 - 
     G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), 0, yu^(-1), 1}, yv])/64 + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw]/16 + 
     (5*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv])/16 + 
     G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw]/16 - (3*G[{0, yu^(-1), 1, 1, 1}, yv])/
      16 + (17*G[{0, yu^(-1), 1, 1, yu^(-1)}, yv])/64 + 
     (11*G[{0, yu^(-1), 1, yu^(-1), 1}, yv])/32 - 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yw]/8 - 
     (9*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv])/64 - 
     G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1, yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/8 + 
     (13*G[{0, yu^(-1), yu^(-1), 1, 1}, yv])/32 - 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/4 - 
     (9*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv])/64 - 
     G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/8 - 
     (13*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv])/64 - 
     (7*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, 1}, yw]/4 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/4 + 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 0, yv^(-1), 1}, yw]/16 + 
     G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), 1, yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/4 - 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/4 + 
     G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, 1}, yw]/4 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/4 + 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw]/4 + 
     G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1, 1, 1}, yw])/16 - 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/4 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw])/16 - 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw]/4 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw]/4 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/2 - 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/8 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/2 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (7*G[{1, 1, 1, 1, yu^(-1)}, yv])/16 + G[{1, 1, 1, 1, yu^(-1)}, yw]/16 + 
     G[{1, 1, 1, 1, yv^(-1)}, yw]/16 - G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/2 - 
     (5*G[{1, 1, 1, yu^(-1), yu^(-1)}, yv])/4 + 
     (7*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw]/4 + 
     (3*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (15*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (13*G[{1, 1, yu^(-1), 1, yu^(-1)}, yv])/64 + 
     G[{1, 1, yu^(-1), 1, yu^(-1)}, yw]/16 + 
     G[{1, 1, yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (13*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv])/64 - 
     (15*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/2 + 
     (3*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/2 - 
     G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/2 + 
     (5*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (7*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     G[{1, 1, yv^(-1), 1, yu^(-1)}, yw]/16 + 
     (13*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (7*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/2 + 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/2 + 
     (81*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (27*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (15*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (23*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv]/8 - 
     (7*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/4 + 
     (5*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/4 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/8 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv])/32 - 
     G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/4 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/4 - 
     G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (5*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/4 + 
     (5*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (11*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/4 - 
     G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (41*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/2 - 
     (9*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (17*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (9*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (3*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     (7*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (41*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (129*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (17*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*Zeta[3])/256 - (3*G[{0}, yu]^2*Zeta[3])/64 + 
     (G[{0}, yu]*G[{0}, yv]*Zeta[3])/16 + (G[{0}, yv]^2*Zeta[3])/16 + 
     (5*G[{0}, yu]*G[{1}, yu]*Zeta[3])/32 + (G[{0}, yv]*G[{1}, yu]*Zeta[3])/
      16 + (G[{1}, yu]^2*Zeta[3])/32 - (5*G[{0}, yu]*G[{1}, yv]*Zeta[3])/32 - 
     (G[{0}, yv]*G[{1}, yv]*Zeta[3])/16 - (G[{1}, yu]*G[{1}, yv]*Zeta[3])/
      16 - (G[{1}, yv]^2*Zeta[3])/8 + (3*G[{0}, yu]*G[{1}, yw]*Zeta[3])/32 + 
     (G[{0}, yv]*G[{1}, yw]*Zeta[3])/8 - (G[{0}, yw]*G[{1}, yw]*Zeta[3])/16 + 
     (G[{1}, yu]*G[{1}, yw]*Zeta[3])/16 - (G[{1}, yv]*G[{1}, yw]*Zeta[3])/
      16 + (7*G[{1}, yw]^2*Zeta[3])/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*Zeta[3])/8 - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*Zeta[3])/64 - (5*G[{0, 1}, yu]*Zeta[3])/32 + 
     (5*G[{0, 1}, yv]*Zeta[3])/32 + (G[{0, 1}, yw]*Zeta[3])/16 - 
     (7*G[{0, yu^(-1)}, yv]*Zeta[3])/32 - (G[{0, 1/(yu*yv)}, yw]*Zeta[3])/
      16 + (5*G[{1, yu^(-1)}, yv]*Zeta[3])/16 - (G[{1, yu^(-1)}, yw]*Zeta[3])/
      32 + (G[{1, yv^(-1)}, yw]*Zeta[3])/32 + (G[{1, 1/(yu*yv)}, yw]*Zeta[3])/
      8 - (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - Zeta[5]/64
 
M1uvwRegI = -(Pi^4*G[{1}, yu])/30 + (Pi^2*G[{0}, yw]^2*G[{1}, yu])/3 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/6 + (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/6 - 
     G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]^2 + (Pi^2*G[{1}, yu]^3)/18 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^3 - (G[{0}, yu]*G[{1}, yu]^4)/3 + 
     (23*Pi^4*G[{yu^(-1)}, yv])/180 + (Pi^2*G[{0}, yv]*G[{0}, yw]*
       G[{yu^(-1)}, yv])/3 - (Pi^2*G[{0}, yw]^2*G[{yu^(-1)}, yv])/3 - 
     (2*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv] + 
     (Pi^2*G[{1}, yu]^2*G[{yu^(-1)}, yv])/6 - G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]^2*G[{yu^(-1)}, yv] - (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{yu^(-1)}, yv])/3 - (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv])/
      3 + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv] - 
     (Pi^2*G[{1}, yv]^2*G[{yu^(-1)}, yv])/6 - G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]^2*G[{yu^(-1)}, yv] + G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] - G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] - G[{1}, yu]^2*G[{1}, yv]^2*G[{yu^(-1)}, yv] - 
     (2*G[{0}, yv]*G[{1}, yv]^3*G[{yu^(-1)}, yv])/3 - 
     (2*G[{1}, yu]*G[{1}, yv]^3*G[{yu^(-1)}, yv])/3 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]^2)/2 + 
     (2*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]^2)/3 - 
     (2*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]^2)/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{yu^(-1)}, yv]^2 - G[{0}, yu]*G[{0}, yw]^2*
      G[{yu^(-1)}, yv]^2 + (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]^2)/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2 + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2)/2 - 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2)/6 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{yu^(-1)}, yv]^2 - G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 
     G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2 - G[{0}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv]^2 - 2*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2 - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2 - 
     G[{1}, yv]^3*G[{yu^(-1)}, yv]^2 - (5*Pi^2*G[{yu^(-1)}, yv]^3)/9 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{yu^(-1)}, yv]^3 - (2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^3)/3 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]^3)/3 + 
     (8*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^3)/3 - 
     (2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^3)/3 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]^3)/3 - 2*G[{0}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]^3 + 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^3 - 
     (4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 + 
     (2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 - 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]^3)/3 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]^4)/6 - (2*G[{0}, yv]*G[{yu^(-1)}, yv]^4)/
      3 + (2*G[{0}, yw]*G[{yu^(-1)}, yv]^4)/3 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^4)/2 + (11*G[{yu^(-1)}, yv]^5)/30 + 
     (Pi^4*G[{yu^(-1)}, yw])/30 - (Pi^2*G[{0}, yw]^2*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yu]^2*G[{yu^(-1)}, yw])/6 + 3*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]^2*G[{yu^(-1)}, yw] + (4*G[{0}, yu]*G[{1}, yu]^3*
       G[{yu^(-1)}, yw])/3 - (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw])/
      3 + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yv]^2*G[{yu^(-1)}, yw])/6 - G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]^2*G[{yu^(-1)}, yw] + G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yw] - G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yw] - G[{1}, yu]^2*G[{1}, yv]^2*G[{yu^(-1)}, yw] - 
     (2*G[{0}, yv]*G[{1}, yv]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{1}, yu]*G[{1}, yv]^3*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     (2*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 + 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{1}, yv]^3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     (2*G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 - 
     (4*G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 + 
     (4*G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 + 
     (2*G[{1}, yv]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 + 
     (G[{yu^(-1)}, yv]^4*G[{yu^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]^2)/6 - G[{0}, yu]*G[{0}, yw]^2*
      G[{yu^(-1)}, yw]^2 - (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]^2)/6 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/6 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]*G[{yu^(-1)}, yw]^2 - G[{0}, yw]^2*G[{1}, yv]*
      G[{yu^(-1)}, yw]^2 - G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]^2 - G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yv]^2*
      G[{yu^(-1)}, yw]^2 - 2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yv]^3*G[{yu^(-1)}, yw]^2 + (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/
      6 + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 3*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 - G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]^2 + 2*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 + 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2 + 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]^2)/3 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^3)/3 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^3)/3 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/3 - 
     (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^3)/3 + 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^4)/6 + (G[{1}, yv]*G[{yu^(-1)}, yw]^4)/6 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^4)/6 - 
     (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^4)/6 - G[{yu^(-1)}, yw]^5/30 - 
     (23*Pi^4*G[{1/(yu*yv)}, yw])/180 - (Pi^2*G[{0}, yv]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]^2*G[{1/(yu*yv)}, yw] + (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yw]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] + (Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/6 + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{0}, yv]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (4*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     (4*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/3 - 
     6*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (14*G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (8*G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (8*G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/6 - 
     (2*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]^3*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - (2*G[{0}, yu]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 - (2*G[{1}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 - (2*G[{1}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 + (2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 + (G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (2*Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/3 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yu]*G[{0}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/6 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]^3*G[{1/(yu*yv)}, yw]^2 + 
     (7*Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (7*Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/6 + 
     6*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     5*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     5*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     (11*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (19*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/6 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/2 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (2*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/3 + G[{0}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^3 - (5*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/
      3 + G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3 + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 - (4*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 - 2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (5*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 + G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 - (G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (2*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/
      3 - (2*Pi^2*G[{1}, yu]*G[{0, 1}, yu])/3 + 2*G[{0}, yw]^2*G[{1}, yu]*
      G[{0, 1}, yu] + G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu] + (G[{1}, yu]^3*G[{0, 1}, yu])/3 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] + 4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] + G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] - 
     (8*G[{yu^(-1)}, yv]^3*G[{0, 1}, yu])/3 + 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu])/3 - 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yu] - G[{1}, yv]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] + 4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] + G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] - 
     G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] - 
     G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1}, yu])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] - 4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] - G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     8*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yu]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv] + G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] - 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yv])/3 + 2*G[{0}, yw]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + G[{1}, yv]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - 2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yv]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2 - 
     (2*Pi^2*G[{1}, yu]*G[{0, 1}, yw])/3 + 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, 1}, yw] + (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/3 - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 - 4*G[{0}, yv]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu]*G[{0, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{0, 1}, yw] + 4*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]^2 - G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw]^2 - (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/3 + 
     (Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, yu^(-1)}, yv] - (2*Pi^2*G[{yu^(-1)}, yv]*
       G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] - 2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] - G[{1}, yv]^2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*
      G[{0, yu^(-1)}, yv] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
      G[{0, yu^(-1)}, yv] + (2*G[{yu^(-1)}, yv]^3*G[{0, yu^(-1)}, yv])/3 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yv] + G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yv] + G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yv] - G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yv] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yv] + 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yv] + G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yv] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]^2 - G[{1}, yu]*G[{0, yu^(-1)}, yv]^2 + 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]^2 + 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, yu^(-1)}, yw] + (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]^2 - G[{1}, yu]*G[{0, yu^(-1)}, yw]^2 - 
     G[{1}, yv]*G[{0, yu^(-1)}, yw]^2 + G[{yu^(-1)}, yw]*
      G[{0, yu^(-1)}, yw]^2 + (Pi^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] - (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/
      3 - 2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]^2 + (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{1, yu^(-1)}, yv] + 
     (Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]*G[{1, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yv] + 2*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     6*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv] + 
     7*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yv] - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     6*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     (2*G[{yu^(-1)}, yw]^3*G[{1, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     6*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     6*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     14*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yv] + 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yv] + 3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 5*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1, yu^(-1)}, yv]^2 - 2*G[{1}, yu]*
      G[{1, yu^(-1)}, yv]^2 - 2*G[{1}, yv]*G[{1, yu^(-1)}, yv]^2 - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]^2 + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yv]^2 - (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     (2*Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{1, yu^(-1)}, yw] + 3*G[{0}, yu]*G[{1}, yu]^2*
      G[{1, yu^(-1)}, yw] - (Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] - 
     (G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yw])/3 - Pi^2*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 8*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 8*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 5*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{1, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yu]^2*
      G[{1, 1/(yu*yv)}, yw] + (Pi^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     Pi^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw] + 
     (4*Pi^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 - 
     (4*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{yu^(-1)}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw]^2 + (Pi^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]^2*G[{0, 0, 1}, yu] + 2*G[{yu^(-1)}, yv]^2*
      G[{0, 0, 1}, yu] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{yu^(-1)}, yw]^2*G[{0, 0, 1}, yu] - 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1}, yu] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     (2*Pi^2*G[{0, 0, yu^(-1)}, yw])/3 + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yw] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     8*G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{1, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + Pi^2*G[{0, 1, 1}, yu] - 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yu] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yu] + 2*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 
     3*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yu] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yu] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     G[{yu^(-1)}, yw]^2*G[{0, 1, 1}, yu] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0, 1}, yu]*G[{0, 1, 1}, yu] + 4*G[{0, 1}, yw]*G[{0, 1, 1}, yu] - 
     4*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 6*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     (Pi^2*G[{0, 1, yu^(-1)}, yv])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv] + 2*G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + (2*Pi^2*G[{0, 1, yu^(-1)}, yw])/3 - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw] - 4*G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, yu^(-1), 1}, yv])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv] + 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     (2*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yu]^2*G[{0, yu^(-1), yv^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{1}, yu]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      3 + 2*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1, 1, yu^(-1)}, yv])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yv] - 2*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv] + 2*G[{0, 1}, yv]*
      G[{1, 1, yu^(-1)}, yv] - 2*G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/3 - 2*G[{0}, yw]^2*
      G[{1, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yv] - 2*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     10*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     3*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     10*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     10*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     (5*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/3 - 2*G[{0}, yw]^2*
      G[{1, yu^(-1), yu^(-1)}, yw] - 6*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 8*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 6*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 6*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), yu^(-1)}, yw] - G[{yu^(-1)}, yv]^2*
      G[{1, yu^(-1), yu^(-1)}, yw] + 6*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 10*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 6*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 3*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1), yu^(-1)}, yw] - 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1), yu^(-1)}, yw] + 6*G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     14*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yu]^2*G[{1, yu^(-1), yv^(-1)}, 
       yw] + 4*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     (2*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/
      3 + 2*G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, 
       yw] - 2*G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 3*G[{yu^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - (Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      3 - 2*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 8*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 10*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yv]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (2*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1}, yu] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1}, yu] - 4*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1}, yw] + 4*G[{yu^(-1)}, yv]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yv] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yv] - 4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw] - 8*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 12*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1, 0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{0, 1, 1, 1}, yu] + 
     2*G[{1}, yu]*G[{0, 1, 1, 1}, yu] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yu] - 2*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yu] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yv] - 2*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv] - 
     4*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yv] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] + 6*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] + 4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 8*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 4*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] + 4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1}, yv] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yv] + 4*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] + 2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     6*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yv] + 4*G[{yu^(-1)}, yv]*
      G[{1, 1, 1, yu^(-1)}, yv] + 4*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, 
       yv] + 4*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     12*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     16*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, yu^(-1), 1}, yw] - 24*G[{0, 0, 0, yu^(-1), yu^(-1)}, 
       yw] - 12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 24*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1, 1}, yu] + 4*G[{0, 0, 1, 1, yu^(-1)}, yw] - 
     4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 8*G[{0, 0, 1, yu^(-1), yu^(-1)}, 
       yv] + 24*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     16*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 16*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1}, yw] - 8*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] + 
     12*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 8*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 0, 1, 1}, yu] - 2*G[{0, 1, 0, 1, yu^(-1)}, yv] + 
     4*G[{0, 1, 0, 1, yu^(-1)}, yw] - 2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), 1}, yv] - 4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] + 
     12*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] - 
     10*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0, 1, 1, 1, 1}, yu] + 
     2*G[{0, 1, 1, 1, yu^(-1)}, yv] + 2*G[{0, 1, 1, yu^(-1), 1}, yv] + 
     8*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] - 
     12*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] + 
     8*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     12*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     16*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yv] + 
     8*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, 1, yu^(-1)}, yv] + 
     2*G[{0, yu^(-1), 1, yu^(-1), 1}, yv] - 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] + 
     12*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] + 
     12*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv] - 
     16*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] + 
     6*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     20*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     60*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     12*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] + 
     20*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     24*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*Zeta[3])/3 + 2*G[{0}, yu]*G[{1}, yu]*Zeta[3] - 
     6*G[{0}, yw]*G[{1}, yu]*Zeta[3] - 4*G[{1}, yu]^2*Zeta[3] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*Zeta[3] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      Zeta[3] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*Zeta[3] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*Zeta[3] + 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      Zeta[3] + 3*G[{yu^(-1)}, yv]^2*Zeta[3] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      Zeta[3] + 6*G[{0}, yw]*G[{yu^(-1)}, yw]*Zeta[3] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*Zeta[3] + 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      Zeta[3] - 6*G[{1}, yw]*G[{yu^(-1)}, yw]*Zeta[3] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*Zeta[3] - 
     G[{yu^(-1)}, yw]^2*Zeta[3] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 6*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      Zeta[3] - 2*G[{0, 1}, yu]*Zeta[3] + 4*G[{0, yu^(-1)}, yv]*Zeta[3] - 
     4*G[{0, yu^(-1)}, yw]*Zeta[3] + 4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{1, yu^(-1)}, yv]*Zeta[3] + 6*G[{1, yu^(-1)}, yw]*Zeta[3] - 
     6*G[{1, 1/(yu*yv)}, yw]*Zeta[3] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      Zeta[3] + 2*Zeta[5]
 
M1uwvRegI = -(Pi^4*G[{1}, yu])/30 + (Pi^2*G[{0}, yv]^2*G[{1}, yu])/3 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/6 + (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/6 - 
     G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]^2 + (Pi^2*G[{1}, yu]^3)/18 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^3 - (G[{0}, yu]*G[{1}, yu]^4)/3 + 
     (Pi^4*G[{yu^(-1)}, yv])/30 - (Pi^2*G[{0}, yv]^2*G[{yu^(-1)}, yv])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yv] - 
     (Pi^2*G[{1}, yu]^2*G[{yu^(-1)}, yv])/6 + 3*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]^2*G[{yu^(-1)}, yv] + (4*G[{0}, yu]*G[{1}, yu]^3*
       G[{yu^(-1)}, yv])/3 + (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv])/
      3 + (2*Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv] - 
     3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]^2)/6 - G[{0}, yu]*G[{0}, yv]^2*
      G[{yu^(-1)}, yv]^2 - (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]^2)/6 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2 - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2)/2 + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2)/6 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{yu^(-1)}, yv]^2 - G[{0}, yv]^2*G[{1}, yv]*
      G[{yu^(-1)}, yv]^2 + 3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]^2 - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]^2 - G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2 + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]^3)/3 - 
     (2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^3)/3 + 
     (2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^3)/3 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]^3)/3 - 
     (2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 + 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^4)/6 + (G[{1}, yv]*G[{yu^(-1)}, yv]^4)/6 - 
     G[{yu^(-1)}, yv]^5/30 + (23*Pi^4*G[{yu^(-1)}, yw])/180 - 
     (Pi^2*G[{0}, yv]^2*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yu]^2*G[{yu^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]^2*G[{yu^(-1)}, yw] - (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{yu^(-1)}, yw])/3 + (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw])/
      3 - (2*Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yw])/6 - G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]^2*G[{yu^(-1)}, yw] + G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] - G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] - G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 + 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     (2*G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 + 
     (2*G[{1}, yv]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 - 
     (G[{yu^(-1)}, yv]^4*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]^2)/2 - 
     (2*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]^2)/3 - G[{0}, yu]*G[{0}, yv]^2*
      G[{yu^(-1)}, yw]^2 + (2*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]^2)/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^2 + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]^2)/2 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{yu^(-1)}, yw]^2 - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yw]^2 - (G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2)/2 + 
     (7*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/6 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{yu^(-1)}, yw]^2 - G[{0}, yv]^2*G[{1}, yv]*
      G[{yu^(-1)}, yw]^2 + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{yu^(-1)}, yw]^2 - 3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]^2 + G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/6 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{yu^(-1)}, yw]^2 - G[{0}, yv]^2*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 + G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 + G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 2*G[{0}, yv]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]^2 - 2*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yw]^3*G[{yu^(-1)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2 + 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]^2)/3 - (5*Pi^2*G[{yu^(-1)}, yw]^3)/
      9 - 2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]^3 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]^3)/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{yu^(-1)}, yw]^3 - (2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (8*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^3)/3 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]^3)/3 + 2*G[{0}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]^3 - (8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]^3 - 2*G[{0}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^3 - (4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^3 + 
     (2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/3 + 
     (4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/3 - 
     (4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/3 - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3 + 
     (10*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/3 - 
     (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^3)/3 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yw]^4)/6 + (2*G[{0}, yv]*G[{yu^(-1)}, yw]^4)/
      3 - (2*G[{0}, yw]*G[{yu^(-1)}, yw]^4)/3 - 
     (11*G[{1}, yv]*G[{yu^(-1)}, yw]^4)/6 - (G[{1}, yw]*G[{yu^(-1)}, yw]^4)/
      2 + (G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^4)/2 + 
     (11*G[{yu^(-1)}, yw]^5)/30 - (23*Pi^4*G[{1/(yu*yv)}, yw])/180 + 
     (Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]^2*G[{1/(yu*yv)}, yw] + (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{1/(yu*yv)}, yw])/3 - (Pi^2*G[{0}, yv]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 + (2*Pi^2*G[{1}, yu]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] + (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      3 - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{1}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     (2*G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/6 - 
     Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (4*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (4*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (7*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 8*G[{0}, yv]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 6*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (2*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/3 + (5*Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      3 + 6*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     10*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (14*G[{0}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (8*G[{0}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (8*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (22*G[{1}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - G[{0}, yu]*G[{0}, yv]^2*
      G[{1/(yu*yv)}, yw]^2 + (2*Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/6 + 3*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 + (7*Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/6 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2 - G[{0}, yu]*G[{0}, yv]*
      G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + G[{0}, yv]^2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/
      2 - (7*Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     5*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     5*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (3*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (11*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (19*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (19*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (2*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 + 
     G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]^3 + (G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^3 + (4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/
      3 - 2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3 + G[{0}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^3 + G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3 - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 - G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 + (5*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 + G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 + G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 - (G[{0}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (2*G[{1}, yu]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/
      3 - (2*Pi^2*G[{1}, yu]*G[{0, 1}, yu])/3 + 2*G[{0}, yv]^2*G[{1}, yu]*
      G[{0, 1}, yu] + G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu] + 
     G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yu] + (G[{1}, yu]^3*G[{0, 1}, yu])/3 + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/3 - 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yu] + G[{0}, yu]*G[{yu^(-1)}, yv]^2*
      G[{0, 1}, yu] - G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] + 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yu])/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu])/3 - 2*G[{0}, yv]^2*
      G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yu] + G[{1}, yu]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] + 
     5*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] - 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] - 
     (8*G[{yu^(-1)}, yw]^3*G[{0, 1}, yu])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/3 + 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     10*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     5*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yu]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2 - 
     (2*Pi^2*G[{1}, yu]*G[{0, 1}, yv])/3 + 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] + 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yv])/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] + G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - 2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu]*G[{0, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{0, 1}, yv] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]^2 + 
     G[{yu^(-1)}, yw]*G[{0, 1}, yv]^2 - G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] + 2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] + G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 + 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/3 + 
     (Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, yu^(-1)}, yv] + (Pi^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] - 
     (2*G[{yu^(-1)}, yv]^3*G[{0, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]^2 - G[{1}, yu]*G[{0, yu^(-1)}, yv]^2 + 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]^2 - 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, yu^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yw]^2 - G[{1}, yu]*G[{0, yu^(-1)}, yw]^2 + 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*
      G[{0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*
      G[{0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2 + 
     G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2 + 
     (Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2 + G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw]^2 - (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/3 - 
     (2*Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1, yu^(-1)}, yv] + 3*G[{0}, yu]*G[{1}, yu]^2*
      G[{1, yu^(-1)}, yv] - Pi^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv] - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     (8*G[{yu^(-1)}, yw]^3*G[{1, yu^(-1)}, yv])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     6*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]^2 + 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1, yu^(-1)}, yw] - G[{0}, yu]*G[{1}, yu]^2*
      G[{1, yu^(-1)}, yw] + (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] + 
     (G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 6*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] - G[{1}, yv]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 7*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 7*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]^3*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     14*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     14*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 6*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1, yu^(-1)}, yw]^2 - 2*G[{1}, yu]*
      G[{1, yu^(-1)}, yw]^2 - 2*G[{1}, yw]*G[{1, yu^(-1)}, yw]^2 + 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]^2 - 4*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw]^2 + 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{1, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*
      G[{1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*
      G[{1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*
      G[{1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
      G[{1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - (Pi^2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yu]^2*G[{1, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv)}, yw] + G[{1}, yv]*G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv)}, yw] - (G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     (8*G[{yu^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 10*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yu]*
      G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw]^2 + 2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw]^2 - (Pi^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      3 + (2*Pi^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{yu^(-1)}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^3*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (4*Pi^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]^2*G[{0, 0, 1}, yu] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1}, yu] - 2*G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yu] + 
     2*G[{yu^(-1)}, yw]^2*G[{0, 0, 1}, yu] - 4*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1}, yu] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yv] + 4*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 4*G[{1, yu^(-1)}, yv]*
      G[{0, 0, 1}, yv] - 4*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] - 4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     (2*Pi^2*G[{0, 0, yu^(-1)}, yv])/3 + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     Pi^2*G[{0, 1, 1}, yu] - 2*G[{0}, yv]^2*G[{0, 1, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yu] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, 1}, yu] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 
     G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yu] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yu] - 6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     3*G[{yu^(-1)}, yw]^2*G[{0, 1, 1}, yu] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0, 1}, yu]*G[{0, 1, 1}, yu] + 4*G[{0, 1}, yv]*G[{0, 1, 1}, yu] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     (2*Pi^2*G[{0, 1, yu^(-1)}, yv])/3 - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yv] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     (Pi^2*G[{0, 1, yu^(-1)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     (2*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/3 + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, 
       yv] + 4*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, 
       yw] - 2*G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yu]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      3 - 2*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yv] - 
     (Pi^2*G[{1, 1, yu^(-1)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/3 - 2*G[{0}, yv]^2*
      G[{1, yu^(-1), yu^(-1)}, yv] - 6*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yv] - 2*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, 
       yv] + 8*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     3*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     14*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/3 - 2*G[{0}, yv]^2*
      G[{1, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     10*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yu]^2*G[{1, yu^(-1), yv^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yv]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/
      3 - 2*G[{0}, yv]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, 
       yw] + 2*G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/3 + 
     2*G[{0}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     (Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/3 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     (2*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     10*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     10*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 10*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1}, yu] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1}, yu] + 4*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, 1, 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yw] - 4*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yu^(-1)}, yv] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv] - 8*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yv] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yv] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] + 4*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0}, yv]*G[{0, 1, 1, 1}, yu] + 
     2*G[{1}, yu]*G[{0, 1, 1, 1}, yu] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yu] - 2*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yu] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw] + 
     6*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 6*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yv] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 8*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yv] + 4*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] - 4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 8*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{1}, yu]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] - 4*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] - 6*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] - 6*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 6*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 8*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 6*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 8*G[{0}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] - 8*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     12*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     16*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, yu^(-1)}, yv] + 12*G[{0, 0, 0, yu^(-1), 1}, yv] - 
     24*G[{0, 0, 0, yu^(-1), yu^(-1)}, yv] + 4*G[{0, 0, 1, 0, yu^(-1)}, yv] - 
     12*G[{0, 0, 1, 1, 1}, yu] + 4*G[{0, 0, 1, 1, yu^(-1)}, yv] + 
     24*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1}, yv] - 8*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv] + 
     12*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1, 1}, yu] + 4*G[{0, 1, 0, 1, yu^(-1)}, yv] - 
     2*G[{0, 1, 0, 1, yu^(-1)}, yw] + 2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), 1}, yw] + 12*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 1, 1, 1}, yu] + 2*G[{0, 1, 1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1, 1, yu^(-1), 1}, yw] - 
     12*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] + 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] + 
     16*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     12*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] - 
     6*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     6*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     60*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     20*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     16*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     20*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     24*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*Zeta[3])/3 + 2*G[{0}, yu]*G[{1}, yu]*Zeta[3] - 
     6*G[{0}, yv]*G[{1}, yu]*Zeta[3] - 4*G[{1}, yu]^2*Zeta[3] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*Zeta[3] + 6*G[{0}, yv]*G[{yu^(-1)}, yv]*
      Zeta[3] + 8*G[{1}, yu]*G[{yu^(-1)}, yv]*Zeta[3] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*Zeta[3] - G[{yu^(-1)}, yv]^2*Zeta[3] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*Zeta[3] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      Zeta[3] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*Zeta[3] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*Zeta[3] - 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      Zeta[3] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*Zeta[3] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*Zeta[3] + 3*G[{yu^(-1)}, yw]^2*
      Zeta[3] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      Zeta[3] - 2*G[{0, 1}, yu]*Zeta[3] - 4*G[{0, yu^(-1)}, yv]*Zeta[3] + 
     4*G[{0, yu^(-1)}, yw]*Zeta[3] - 4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 
     6*G[{1, yu^(-1)}, yv]*Zeta[3] - 2*G[{1, yu^(-1)}, yw]*Zeta[3] + 
     2*G[{1, 1/(yu*yv)}, yw]*Zeta[3] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      Zeta[3] + 2*Zeta[5]
 
M1vwuRegI = -(Pi^4*G[{1}, yv])/30 + (Pi^2*G[{0}, yu]^2*G[{1}, yv])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv])/3 + 
     (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/6 + (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/6 - 
     G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]^2 + (Pi^2*G[{1}, yu]*G[{1}, yv]^2)/
      6 - G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]^2 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1}, yv]^2 + 2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]^2 + 
     (Pi^2*G[{1}, yv]^3)/18 - G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^3 - 
     (2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^3)/3 - (G[{0}, yv]*G[{1}, yv]^4)/3 - 
     (G[{1}, yu]*G[{1}, yv]^4)/3 + (Pi^4*G[{yu^(-1)}, yv])/30 - 
     (Pi^2*G[{0}, yu]^2*G[{yu^(-1)}, yv])/3 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv] - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv] - 
     (Pi^2*G[{1}, yv]^2*G[{yu^(-1)}, yv])/6 + 3*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]^2*G[{yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] + (4*G[{0}, yv]*G[{1}, yv]^3*G[{yu^(-1)}, yv])/3 + 
     (4*G[{1}, yu]*G[{1}, yv]^3*G[{yu^(-1)}, yv])/3 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]^2)/6 - G[{0}, yu]^2*G[{0}, yv]*
      G[{yu^(-1)}, yv]^2 + (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]^2)/6 - 
     G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]^2 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{yu^(-1)}, yv]^2 + 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{yu^(-1)}, yv]^2 - (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2)/6 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2)/2 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2)/2 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]^3)/3 - 
     (2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^3)/3 + 
     (2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 - 
     (2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]^3)/3 + (G[{0}, yv]*G[{yu^(-1)}, yv]^4)/
      6 + (G[{1}, yu]*G[{yu^(-1)}, yv]^4)/6 - G[{yu^(-1)}, yv]^5/30 + 
     (23*Pi^4*G[{yv^(-1)}, yw])/180 - (Pi^2*G[{0}, yu]^2*G[{yv^(-1)}, yw])/
      3 + (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw] + 2*G[{0}, yu]^2*G[{1}, yu]*
      G[{1}, yv]*G[{yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{1}, yv]*G[{yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*
      G[{yv^(-1)}, yw] + (Pi^2*G[{1}, yv]^2*G[{yv^(-1)}, yw])/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw] - 
     (2*G[{0}, yv]*G[{1}, yv]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{1}, yu]*G[{1}, yv]^3*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]^2*G[{yv^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]^2*G[{yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] - G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] - G[{1}, yv]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{1}, yu]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{1}, yv]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     (2*G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 - 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 - 
     (G[{yu^(-1)}, yv]^4*G[{yv^(-1)}, yw])/6 - 
     (2*Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]^2)/3 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]^2)/2 - G[{0}, yu]^2*G[{0}, yv]*
      G[{yv^(-1)}, yw]^2 + (2*Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]^2)/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]^2 + 
     (7*Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]^2)/6 - G[{0}, yu]^2*G[{1}, yu]*
      G[{yv^(-1)}, yw]^2 + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{yv^(-1)}, yw]^2 + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{yv^(-1)}, yw]^2 + 2*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]^2 + 
     (Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2)/2 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{yv^(-1)}, yw]^2 - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{yv^(-1)}, yw]^2 + 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{yv^(-1)}, yw]^2 - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{yv^(-1)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{yv^(-1)}, yw]^2 - 2*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/6 - G[{0}, yu]^2*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 + G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 + 3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 + G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - G[{1}, yu]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]^2 - 2*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yw]^3*G[{yv^(-1)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/3 + 
     G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]^2)/3 - (5*Pi^2*G[{yv^(-1)}, yw]^3)/
      9 + (G[{0}, yu]^2*G[{yv^(-1)}, yw]^3)/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{yv^(-1)}, yw]^3 - (2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]^3 - 
     (8*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]^3)/3 + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^3 + 2*G[{0}, yw]*G[{1}, yu]*
      G[{yv^(-1)}, yw]^3 + 2*G[{1}, yu]^2*G[{yv^(-1)}, yw]^3 + 
     (8*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^3)/3 + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^3 - 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (4*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^3 + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^3 + (2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (5*G[{1}, yw]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/3 - 
     (4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/3 - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3 + 
     (10*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yu]*G[{yv^(-1)}, yw]^4)/3 - (7*G[{0}, yv]*G[{yv^(-1)}, yw]^4)/
      6 - (2*G[{0}, yw]*G[{yv^(-1)}, yw]^4)/3 - 
     (11*G[{1}, yu]*G[{yv^(-1)}, yw]^4)/6 - (G[{1}, yw]*G[{yv^(-1)}, yw]^4)/
      2 + (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^4)/2 + 
     (11*G[{yv^(-1)}, yw]^5)/30 - (23*Pi^4*G[{1/(yu*yv)}, yw])/180 + 
     (Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]^2*G[{1/(yu*yv)}, yw] + (2*G[{0}, yv]*G[{1}, yv]^3*
       G[{1/(yu*yv)}, yw])/3 + (2*G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/
      3 + (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{1}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     (2*G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/6 + 
     (4*Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (4*Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (7*Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 8*G[{0}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 6*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (2*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/3 + (5*Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      3 - G[{0}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     10*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (8*G[{0}, yu]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (14*G[{0}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (8*G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (22*G[{1}, yu]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] - 
     (11*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - G[{0}, yu]^2*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]^2 + (2*Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (7*Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/6 - G[{0}, yu]^2*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/6 + 3*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2 + G[{0}, yu]^2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - G[{1}, yv]^2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^2 + (3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (3*G[{1}, yu]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/
      2 - (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (2*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 - 
     (7*Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     5*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     8*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     5*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (3*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (11*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (19*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (19*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/3 + G[{0}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^3 + G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3 - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 - G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 + (5*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 + G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yu] + G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yu] - 2*G[{1}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yu] - (G[{1}, yv]^3*G[{0, 1}, yu])/3 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] + 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yu])/3 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu] - G[{1}, yv]^2*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] - 2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] - G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     2*G[{1}, yv]*G[{0, 1}, yu]^2 + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]^2 + 
     G[{yv^(-1)}, yw]*G[{0, 1}, yu]^2 - G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2 - 
     (2*Pi^2*G[{1}, yv]*G[{0, 1}, yv])/3 + 2*G[{0}, yu]^2*G[{1}, yv]*
      G[{0, 1}, yv] - 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yv] + G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yv] + 
     (G[{1}, yv]^3*G[{0, 1}, yv])/3 + (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/
      3 - 2*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] + 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yv])/3 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv])/3 - 2*G[{0}, yu]^2*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 2*G[{1}, yu]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] + G[{1}, yv]^2*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] - G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] + 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] + 
     3*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] - 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] - 
     (8*G[{yv^(-1)}, yw]^3*G[{0, 1}, yv])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/3 + 
     2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     8*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu]*G[{0, 1}, yv] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*
      G[{0, 1}, yv] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yv]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] + 2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] + G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 + 
     (2*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]^2*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] - G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - G[{1}, yu]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yv] - (G[{1}, yv]^3*G[{0, yu^(-1)}, yv])/3 - 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] - 
     (2*G[{yu^(-1)}, yv]^3*G[{0, yu^(-1)}, yv])/3 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     (8*G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yv])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     8*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv]^2 - (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*
      G[{0, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*
      G[{0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{0, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yw] - G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]^2 + 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2 - 
     (Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, yv^(-1)}, yw]^2 - G[{1}, yv]*G[{0, yv^(-1)}, yw]^2 + 
     G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]^2 + 
     (Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2 + G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw]^2 + (Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yv])/3 + 
     (2*Pi^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{1, yu^(-1)}, yv] - 3*G[{0}, yv]*G[{1}, yv]^2*
      G[{1, yu^(-1)}, yv] - 3*G[{1}, yu]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv] + 
     Pi^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv] + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     (8*G[{yv^(-1)}, yw]^3*G[{1, yu^(-1)}, yv])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     8*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]^2 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{1, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*
      G[{1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*
      G[{1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yw] + (Pi^2*G[{0}, yu]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw] - G[{1}, yu]*G[{1}, yv]^2*
      G[{1, yv^(-1)}, yw] + (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] + 
     (G[{yu^(-1)}, yv]^3*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     6*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     6*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     7*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]^3*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     6*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     6*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     6*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     14*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     14*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 6*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1, yv^(-1)}, yw]^2 - 2*G[{1}, yv]*
      G[{1, yv^(-1)}, yw]^2 - 2*G[{1}, yw]*G[{1, yv^(-1)}, yw]^2 + 
     2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]^2 - 4*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw]^2 + 4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2 - 
     (Pi^2*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yv]^2*
      G[{1, 1/(yu*yv)}, yw] + G[{1}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]^2*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv)}, yw] + G[{1}, yu]*G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv)}, yw] - (G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     (8*G[{yv^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 10*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 8*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yv]*
      G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw]^2 + 2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw]^2 - (Pi^2*G[{yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (2*G[{yv^(-1)}, yw]^3*
       G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{yu^(-1)}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (4*G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (4*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yu] - 2*G[{1}, yv]^2*G[{0, 0, 1}, yu] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yu] + 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1}, yu] - 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yu] - 4*G[{1, yv^(-1)}, yw]*
      G[{0, 0, 1}, yu] + 4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yv] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1}, yv] - 2*G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yv] + 
     2*G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yv] - 4*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1}, yv] - 4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{yu^(-1)}, yv]^2*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu] - 6*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1}, yu] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     Pi^2*G[{0, 1, 1}, yv] - 2*G[{0}, yu]^2*G[{0, 1, 1}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yv] - 2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1}, yv] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yv] - 6*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     3*G[{yv^(-1)}, yw]^2*G[{0, 1, 1}, yv] + 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     4*G[{0, 1}, yu]*G[{0, 1, 1}, yv] + 2*G[{0, 1}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1}, yv] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     Pi^2*G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 3*G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     5*G[{yv^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     10*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv] - 2*G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     Pi^2*G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yu]^2*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yv] + 
     6*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), 1}, yv] - 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     4*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv] - 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     Pi^2*G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yu]^2*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     3*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     5*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     10*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yv]^2*G[{0, yu^(-1), yv^(-1)}, 
       yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{0, yv^(-1), 1}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yv]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1, 1, yu^(-1)}, yv])/3 + 2*G[{0}, yu]^2*
      G[{1, 1, yu^(-1)}, yv] - 8*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 6*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 6*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     3*G[{yv^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yv] - 
     8*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv] - 6*G[{0, 1}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 6*G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] + 
     6*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     (Pi^2*G[{1, 1, yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{1}, yv]^2*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, 1, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/3 + 2*G[{0}, yu]^2*
      G[{1, yu^(-1), yu^(-1)}, yv] - 8*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), yu^(-1)}, yv] + 6*G[{0}, yv]*G[{1}, yv]*
      G[{1, yu^(-1), yu^(-1)}, yv] + 6*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), yu^(-1)}, yv] + 2*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     3*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     5*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     10*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     14*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]^2*G[{1, yu^(-1), yv^(-1)}, 
       yw] - 4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/
      3 - 2*G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, 
       yw] - 2*G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     (Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu]^2*
      G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]^2*G[{1, yv^(-1), yv^(-1)}, 
       yw] - 4*G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      3 + 2*G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     (2*Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     10*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     (2*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     10*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     10*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1, yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 10*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, 1}, yu] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1}, yu] + 4*G[{1}, yv]*G[{0, 0, 1, 1}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yv] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yu^(-1)}, yv] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{0, 1, 1, 1}, yv] + 
     2*G[{1}, yv]*G[{0, 1, 1, 1}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yv] - 2*G[{yv^(-1)}, yw]*G[{0, 1, 1, 1}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw] + 
     2*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yv] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yv] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yv] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 8*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] + 8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{1}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 6*G[{0}, yu]*
      G[{0, yu^(-1), 1, 1}, yv] - 2*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] + 4*G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, 
       yw] + 4*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 8*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 6*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 6*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yv] - 
     8*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yv] - 8*G[{yu^(-1)}, yv]*
      G[{1, 1, 1, yu^(-1)}, yv] - 8*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] - 8*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, 1, yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1, 1, yu^(-1), yu^(-1)}, yv] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yu]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 8*G[{1}, yv]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 8*G[{1}, yv]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yu]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 8*G[{1}, yv]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{1}, yv]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{0}, yu]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 8*G[{0}, yu]*
      G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     16*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1, 1}, yv] + 4*G[{0, 0, 1, 1, yu^(-1)}, yv] + 
     4*G[{0, 0, 1, yu^(-1), 1}, yv] + 4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1}, yv] - 4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, yu^(-1), yu^(-1), 1}, yv] + 
     12*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 0, 1, 1}, yv] - 2*G[{0, 1, 0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 4*G[{0, 1, 0, yu^(-1), yu^(-1)}, 
       yv] - 2*G[{0, 1, 0, yv^(-1), 1}, yw] - 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, 0, yu^(-1)}, yv] - 8*G[{0, 1, 1, 1, 1}, yv] + 
     8*G[{0, 1, 1, 1, yu^(-1)}, yv] + 2*G[{0, 1, 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1, 1, yu^(-1), yv^(-1)}, 
       yw] - 2*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, yv^(-1), 1}, yw] + 2*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] + 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), 1}, yv] + 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), 1, 1, 1}, yv] - 8*G[{0, yu^(-1), 1, 1, yu^(-1)}, yv] - 
     2*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] + 
     6*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] - 
     6*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     6*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     16*G[{1, 1, 1, 1, yu^(-1)}, yv] - 44*G[{1, 1, 1, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     20*G[{1, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     36*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     20*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     16*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     20*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     24*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*Zeta[3])/3 - 6*G[{0}, yu]*G[{1}, yv]*Zeta[3] + 
     2*G[{0}, yv]*G[{1}, yv]*Zeta[3] + 6*G[{1}, yu]*G[{1}, yv]*Zeta[3] - 
     4*G[{1}, yv]^2*Zeta[3] + 6*G[{0}, yu]*G[{yu^(-1)}, yv]*Zeta[3] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*Zeta[3] - 6*G[{1}, yu]*G[{yu^(-1)}, yv]*
      Zeta[3] + 8*G[{1}, yv]*G[{yu^(-1)}, yv]*Zeta[3] - 
     G[{yu^(-1)}, yv]^2*Zeta[3] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*Zeta[3] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*Zeta[3] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      Zeta[3] - 6*G[{1}, yu]*G[{yv^(-1)}, yw]*Zeta[3] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*Zeta[3] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      Zeta[3] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*Zeta[3] + 
     3*G[{yv^(-1)}, yw]^2*Zeta[3] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      Zeta[3] - 2*G[{0, 1}, yv]*Zeta[3] + 2*G[{0, yu^(-1)}, yv]*Zeta[3] + 
     4*G[{0, yv^(-1)}, yw]*Zeta[3] - 4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 
     6*G[{1, yu^(-1)}, yv]*Zeta[3] - 2*G[{1, yv^(-1)}, yw]*Zeta[3] + 
     2*G[{1, 1/(yu*yv)}, yw]*Zeta[3] + 6*G[{yv^(-1), 1/(yu*yv)}, yw]*
      Zeta[3] + 2*Zeta[5]
 
M1vuwRegI = -(Pi^4*G[{1}, yv])/30 + (Pi^2*G[{0}, yw]^2*G[{1}, yv])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/3 + 
     (Pi^2*G[{1}, yu]^2*G[{1}, yv])/6 + G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*
      G[{1}, yv] + (2*G[{0}, yu]*G[{1}, yu]^3*G[{1}, yv])/3 + 
     (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/6 + (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/6 - 
     G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]^2 + (Pi^2*G[{1}, yu]*G[{1}, yv]^2)/
      3 + G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2 - 
     G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]^2 + G[{0}, yu]*G[{1}, yu]^2*
      G[{1}, yv]^2 - G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]^2 - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]^2 - G[{1}, yu]^3*G[{1}, yv]^2 + 
     (Pi^2*G[{1}, yv]^3)/18 - G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^3 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^3)/3 - G[{0}, yv]*G[{1}, yu]*
      G[{1}, yv]^3 - G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^3 - 
     G[{1}, yu]^2*G[{1}, yv]^3 - (G[{0}, yv]*G[{1}, yv]^4)/3 - 
     (G[{1}, yu]*G[{1}, yv]^4)/3 + (23*Pi^4*G[{yu^(-1)}, yv])/180 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv])/3 - 
     (Pi^2*G[{0}, yw]^2*G[{yu^(-1)}, yv])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv])/3 - 
     (Pi^2*G[{1}, yu]^2*G[{yu^(-1)}, yv])/6 - G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]^2*G[{yu^(-1)}, yv] - (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{yu^(-1)}, yv])/3 - (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv])/
      3 - (2*Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     2*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     2*G[{1}, yu]^3*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     (Pi^2*G[{1}, yv]^2*G[{yu^(-1)}, yv])/6 - G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]^2*G[{yu^(-1)}, yv] + G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] - G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] - G[{1}, yu]^2*G[{1}, yv]^2*G[{yu^(-1)}, yv] - 
     (2*G[{0}, yv]*G[{1}, yv]^3*G[{yu^(-1)}, yv])/3 - 
     (2*G[{1}, yu]*G[{1}, yv]^3*G[{yu^(-1)}, yv])/3 + 
     (2*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]^2)/3 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]^2)/2 - 
     (2*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]^2)/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{yu^(-1)}, yv]^2 - G[{0}, yv]*G[{0}, yw]^2*
      G[{yu^(-1)}, yv]^2 - (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]^2)/6 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2 - 
     G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv]^2 - G[{0}, yv]*G[{1}, yu]^2*
      G[{yu^(-1)}, yv]^2 - 2*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2 - 
     G[{1}, yu]^3*G[{yu^(-1)}, yv]^2 + (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2)/
      2 - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 
     4*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2)/2 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2)/2 - 
     (5*Pi^2*G[{yu^(-1)}, yv]^3)/9 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{yu^(-1)}, yv]^3 - (2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^3)/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^3 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]^3)/3 + 2*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yv]^3 - 2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^3 - 
     (4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^3)/3 - 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]^3)/3 - 
     (2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 + 
     (8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 + 
     (8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]^3)/3 - (2*G[{0}, yu]*G[{yu^(-1)}, yv]^4)/
      3 - (7*G[{0}, yv]*G[{yu^(-1)}, yv]^4)/6 + 
     (2*G[{0}, yw]*G[{yu^(-1)}, yv]^4)/3 - (G[{1}, yu]*G[{yu^(-1)}, yv]^4)/
      2 + (11*G[{yu^(-1)}, yv]^5)/30 + (Pi^4*G[{yv^(-1)}, yw])/30 - 
     (Pi^2*G[{0}, yw]^2*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu]^2*G[{yv^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]^2*G[{yv^(-1)}, yw] - (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{yv^(-1)}, yw])/3 - (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw])/
      3 - (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     (2*Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu]^3*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yv]^2*G[{yv^(-1)}, yw])/6 + 3*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]^2*G[{yv^(-1)}, yw] - G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yv^(-1)}, yw] + 3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yv^(-1)}, yw] + 3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yv^(-1)}, yw] + 3*G[{1}, yu]^2*G[{1}, yv]^2*G[{yv^(-1)}, yw] + 
     (4*G[{0}, yv]*G[{1}, yv]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{1}, yu]*G[{1}, yv]^3*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     (2*Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     3*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu]^3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     (4*G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 + 
     (G[{yu^(-1)}, yv]^4*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]^2)/6 - G[{0}, yv]*G[{0}, yw]^2*
      G[{yv^(-1)}, yw]^2 + (Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]^2)/6 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw]^2 - G[{0}, yv]*G[{1}, yu]^2*
      G[{yv^(-1)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yu]^3*G[{yv^(-1)}, yw]^2 - (Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2)/
      6 - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/6 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]*G[{yv^(-1)}, yw]^2 - G[{0}, yw]^2*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 + G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]^2 + 2*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]^2)/3 + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{0}, yv]*G[{yv^(-1)}, yw]^4)/6 + (G[{1}, yu]*G[{yv^(-1)}, yw]^4)/6 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]^4)/6 - 
     (G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^4)/6 - G[{yv^(-1)}, yw]^5/30 - 
     (23*Pi^4*G[{1/(yu*yv)}, yw])/180 - (Pi^2*G[{0}, yu]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]^2*G[{1/(yu*yv)}, yw] + (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yu]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 + (2*Pi^2*G[{0}, yv]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 - (2*Pi^2*G[{0}, yw]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]^2*G[{1/(yu*yv)}, yw] - G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*
      G[{1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*
      G[{1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2*
      G[{1/(yu*yv)}, yw] + G[{1}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{0}, yv]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     (4*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (4*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     8*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/3 - 
     6*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (8*G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (14*G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (8*G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{1}, yv]^2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - (2*G[{0}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 - (2*G[{1}, yu]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 - (2*G[{1}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 + (2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 + (G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 + 
     (2*Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/3 + 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv]*G[{0}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]^3*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/6 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     (7*Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (7*Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/6 + 
     6*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     5*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     5*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     (11*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (19*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (2*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/2 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]^3 + (G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3 + G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^3 + G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{0}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3 + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 - (4*G[{0}, yw]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yv]*G[{yu^(-1)}, yv]*
       G[{1/(yu*yv)}, yw]^3)/3 + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]^3 - 2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (5*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yu] - G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu] - G[{1}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yu] - (G[{1}, yv]^3*G[{0, 1}, yu])/3 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yu] + G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] - 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] - G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu] - 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yu])/3 + 2*G[{0}, yw]*G[{1}, yu]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu] + G[{1}, yu]^2*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yu]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2 - 
     (2*Pi^2*G[{1}, yv]*G[{0, 1}, yv])/3 + 2*G[{0}, yw]^2*G[{1}, yv]*
      G[{0, 1}, yv] + 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yv] + G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yv] + (G[{1}, yv]^3*G[{0, 1}, yv])/
      3 + (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] - 
     (8*G[{yu^(-1)}, yv]^3*G[{0, 1}, yv])/3 + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv])/3 - 
     2*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yv] + G[{0}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, 1}, yv] + G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] - 
     G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] - 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yv])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     8*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     8*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yv]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2 - 
     (2*Pi^2*G[{1}, yv]*G[{0, 1}, yw])/3 + 2*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yw] + 2*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/3 - 4*G[{0}, yv]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*
      G[{0, 1}, yw] + 2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 - 4*G[{0}, yu]*G[{1}, yu]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv]*G[{0, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{0, 1}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]^2 - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 + Pi^2*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - G[{0}, yw]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - 
     (G[{1}, yv]^3*G[{0, yu^(-1)}, yv])/3 - 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/3 - 
     4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] + 
     5*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] + 
     (8*G[{yu^(-1)}, yv]^3*G[{0, yu^(-1)}, yv])/3 - 
     Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 2*G[{0}, yw]^2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + 4*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + G[{1}, yv]^2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yv] - G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yv] + G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yv] + G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yv] - (2*G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yv])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/3 + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     8*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     10*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     8*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]^2 + G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv]^2 + (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]^2 + 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, yv^(-1)}, yw] + (Pi^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]^2 - G[{1}, yu]*G[{0, yv^(-1)}, yw]^2 - 
     G[{1}, yv]*G[{0, yv^(-1)}, yw]^2 + G[{yv^(-1)}, yw]*
      G[{0, yv^(-1)}, yw]^2 - (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, 1/(yu*yv)}, yw] + (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]^2 - (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yv])/3 - 
     (Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{1, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1)}, yv] + 2*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yv]^2*G[{1, yu^(-1)}, yv] + G[{1}, yu]*G[{1}, yv]^2*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] - 6*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] - 4*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*
      G[{1, yu^(-1)}, yv] - 3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*
      G[{1, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*
      G[{1, yu^(-1)}, yv] - 7*G[{1}, yu]*G[{yu^(-1)}, yv]^2*
      G[{1, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yv] + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     6*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     8*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     14*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     6*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yv] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 5*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1, yu^(-1)}, yv]^2 - 2*G[{1}, yu]*
      G[{1, yu^(-1)}, yv]^2 - 2*G[{1}, yv]*G[{1, yu^(-1)}, yv]^2 - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]^2 + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yv]^2 - (Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{1, yv^(-1)}, yw] - (2*Pi^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1}, yv]^2*G[{1, yv^(-1)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] - 
     (G[{yu^(-1)}, yv]^3*G[{1, yv^(-1)}, yw])/3 - Pi^2*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 8*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 8*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] + (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 5*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]^2 + 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{1, 1/(yu*yv)}, yw] - (2*Pi^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     Pi^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]^2*
      G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw] + 
     (4*Pi^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 - 
     (4*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     6*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - (2*G[{yv^(-1)}, yw]^3*
       G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{yu^(-1)}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (4*G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1}, yu] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yv] + 2*G[{yu^(-1)}, yv]^2*
      G[{0, 0, 1}, yv] + 4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yv] - 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1}, yv] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yv]^2*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{yv^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, 0, yv^(-1)}, yw])/3 - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0, 1}, yu]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 0, yv^(-1)}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{1, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{1, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yu] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     Pi^2*G[{0, 1, 1}, yv] - 2*G[{0}, yw]^2*G[{0, 1, 1}, yv] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yu]^2*G[{0, 1, 1}, yv] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1}, yv] + 2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yv] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 
     3*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yv] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     G[{yv^(-1)}, yw]^2*G[{0, 1, 1}, yv] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0, 1}, yv]*G[{0, 1, 1}, yv] + 4*G[{0, 1}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 6*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     (2*Pi^2*G[{0, 1, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv] - 
     6*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     5*G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     3*G[{yv^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     10*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv] - 4*G[{0, 1}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     (2*Pi^2*G[{0, 1, yv^(-1)}, yw])/3 + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 8*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0, 1}, yu]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1}, yv]*G[{0, 1, yv^(-1)}, yw] - 4*G[{0, 1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{0, yu^(-1), 1}, yv])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yv] - 6*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yv] + 3*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), 1}, yv] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv] - 4*G[{0, 1}, yw]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/3 + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     10*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]^2*G[{0, yu^(-1), yv^(-1)}, 
       yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{1}, yv]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 8*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0, 1}, yu]*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 4*G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      3 + 2*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{1, 1, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yv] - 6*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 6*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 6*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 3*G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yv] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv] - 4*G[{0, 1}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yv])/3 + 2*G[{0}, yw]^2*
      G[{1, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yv] + 2*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, 
       yv] - 2*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     5*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     3*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     10*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     10*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yv]^2*G[{1, yu^(-1), yv^(-1)}, 
       yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/
      3 + 2*G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, 
       yw] + 2*G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     (5*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yw]^2*
      G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yu]^2*G[{1, yv^(-1), yv^(-1)}, 
       yw] - 6*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 8*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 6*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 6*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), yv^(-1)}, yw] - G[{yu^(-1)}, yv]^2*
      G[{1, yv^(-1), yv^(-1)}, yw] + 6*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 10*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 6*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 6*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 3*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1), yv^(-1)}, yw] - 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{0, 1}, yu]*G[{1, yv^(-1), yv^(-1)}, 
       yw] + 6*G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     14*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     (2*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      3 - 2*G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     (2*Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 8*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 10*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1, yu^(-1)}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yu] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yu] + 4*G[{1}, yv]*G[{0, 0, 1, 1}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yv] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1}, yw] - 4*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{0}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 12*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*
      G[{0, 1, 0, yu^(-1)}, yv] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yu^(-1)}, yv] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{0, 1, 1, 1}, yu] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yu] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, 1}, yu] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu] - 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yv] - 6*G[{1}, yu]*G[{0, 1, 1, 1}, yv] + 
     2*G[{1}, yv]*G[{0, 1, 1, 1}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yv] - 2*G[{yv^(-1)}, yw]*G[{0, 1, 1, 1}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv] - 
     4*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] + 6*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 6*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yv] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] + 8*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 4*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1}, yv] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yv] + 4*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] - 2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yv] + 4*G[{yu^(-1)}, yv]*
      G[{1, 1, 1, yu^(-1)}, yv] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     12*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, yv^(-1)}, yw] - 12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] - 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] - 24*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 24*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 0, yv^(-1)}, yw] - 4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1, 1}, yv] + 4*G[{0, 0, 1, 1, yu^(-1)}, yv] + 
     4*G[{0, 0, 1, 1, yv^(-1)}, yw] - 4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1}, yv] - 4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] + 
     12*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     24*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     16*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 16*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1}, yv] + 8*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yu^(-1), 1}, yv] - 
     12*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, 1}, yw] - 4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     16*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 8*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 0, 1, 1}, yv] + 2*G[{0, 1, 0, 1, yu^(-1)}, yv] + 
     4*G[{0, 1, 0, 1, yv^(-1)}, yw] - 2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1}, yv] - 4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] + 
     6*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] - 
     10*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0, 1, 1, 1, 1}, yv] + 
     2*G[{0, 1, 1, 1, yu^(-1)}, yv] - 2*G[{0, 1, 1, yu^(-1), 1}, yv] + 
     4*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] - 
     6*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] + 
     4*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, 1}, yv] + 4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     8*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     12*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     16*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yv] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, 1, 1}, yv] + 6*G[{0, yu^(-1), 1, 1, yu^(-1)}, yv] + 
     6*G[{0, yu^(-1), 1, yu^(-1), 1}, yv] - 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] + 
     6*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yv] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] + 
     8*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] + 
     6*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, 1, 1, 1, yu^(-1)}, yv] - 8*G[{1, 1, 1, yu^(-1), yu^(-1)}, yv] - 
     12*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     24*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     60*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     12*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     12*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     12*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     20*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     24*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     12*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*Zeta[3])/3 + 2*G[{0}, yv]*G[{1}, yv]*Zeta[3] - 
     6*G[{0}, yw]*G[{1}, yv]*Zeta[3] - 2*G[{1}, yu]*G[{1}, yv]*Zeta[3] - 
     4*G[{1}, yv]^2*Zeta[3] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*Zeta[3] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*Zeta[3] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      Zeta[3] + 2*G[{1}, yu]*G[{yu^(-1)}, yv]*Zeta[3] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*Zeta[3] + 3*G[{yu^(-1)}, yv]^2*Zeta[3] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*Zeta[3] + 6*G[{0}, yw]*G[{yv^(-1)}, yw]*
      Zeta[3] + 2*G[{1}, yu]*G[{yv^(-1)}, yw]*Zeta[3] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*Zeta[3] - 6*G[{1}, yw]*G[{yv^(-1)}, yw]*
      Zeta[3] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*Zeta[3] - 
     G[{yv^(-1)}, yw]^2*Zeta[3] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 6*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      Zeta[3] - 2*G[{0, 1}, yv]*Zeta[3] + 2*G[{0, yu^(-1)}, yv]*Zeta[3] - 
     4*G[{0, yv^(-1)}, yw]*Zeta[3] + 4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 
     2*G[{1, yu^(-1)}, yv]*Zeta[3] + 6*G[{1, yv^(-1)}, yw]*Zeta[3] - 
     6*G[{1, 1/(yu*yv)}, yw]*Zeta[3] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      Zeta[3] + 2*Zeta[5]
 
M1wuvRegI = -(Pi^4*G[{1}, yw])/30 + (Pi^2*G[{0}, yv]^2*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/3 + 
     (Pi^2*G[{1}, yu]^2*G[{1}, yw])/6 + G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*
      G[{1}, yw] + (2*G[{0}, yu]*G[{1}, yu]^3*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/3 - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1}, yv]*G[{1}, yw] - 2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*
      G[{1}, yw] + (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/6 - G[{0}, yv]^2*G[{0}, yw]*
      G[{1}, yw]^2 + (Pi^2*G[{1}, yu]*G[{1}, yw]^2)/3 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2 - 
     G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]^2 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu]*G[{1}, yw]^2 + G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]^2 - G[{0}, yw]*G[{1}, yu]^2*
      G[{1}, yw]^2 - G[{1}, yu]^3*G[{1}, yw]^2 + 
     (Pi^2*G[{1}, yv]*G[{1}, yw]^2)/6 - G[{0}, yv]^2*G[{1}, yv]*
      G[{1}, yw]^2 + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2 + 
     G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]^2 + 2*G[{0}, yv]*G[{1}, yv]^2*
      G[{1}, yw]^2 + 2*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]^2 + 
     (Pi^2*G[{1}, yw]^3)/18 - G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^3 + 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^3)/3 - G[{0}, yv]*G[{1}, yu]*
      G[{1}, yw]^3 - G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^3 - 
     G[{1}, yu]^2*G[{1}, yw]^3 - (2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^3)/3 - (G[{0}, yw]*G[{1}, yw]^4)/3 - 
     (G[{1}, yu]*G[{1}, yw]^4)/3 - (G[{1}, yv]*G[{1}, yw]^4)/3 - 
     (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]^2*G[{yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*
      G[{yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*
      G[{yu^(-1)}, yv] - (G[{0}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/3 - 
     (G[{0}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/3 + 
     G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yv] + 
     (2*G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/3 + 
     (2*G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/3 + 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2 + G[{0}, yv]*G[{1}, yw]^2*
      G[{yu^(-1)}, yv]^2 + G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2 + 
     G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2 + 
     (G[{1}, yw]^3*G[{yu^(-1)}, yv]^2)/3 - 
     (2*G[{1}, yw]^2*G[{yu^(-1)}, yv]^3)/3 + (23*Pi^4*G[{yu^(-1)}, yw])/180 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv]^2*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu]^2*G[{yu^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]^2*G[{yu^(-1)}, yw] - (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{yu^(-1)}, yw])/3 + (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw])/
      3 + (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu]^3*G[{1}, yw]*G[{yu^(-1)}, yw] - Pi^2*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yw] + 2*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yw] - 2*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*
      G[{yu^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*
      G[{yu^(-1)}, yw] + (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yw])/6 - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] - 
     (4*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]^2)/3 - 
     (2*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]^2)/3 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]^2)/2 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{yu^(-1)}, yw]^2 - G[{0}, yv]^2*G[{0}, yw]*
      G[{yu^(-1)}, yw]^2 - (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]^2)/6 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yw]^2 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu]*G[{yu^(-1)}, yw]^2 - 2*G[{0}, yv]*G[{1}, yu]^2*
      G[{yu^(-1)}, yw]^2 - G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yu]^3*G[{yu^(-1)}, yw]^2 + (7*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/
      6 + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]*G[{yu^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]^2 + G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 + 4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 + 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 + 4*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2)/2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     (5*Pi^2*G[{yu^(-1)}, yw]^3)/9 - (2*G[{0}, yu]*G[{0}, yv]*
       G[{yu^(-1)}, yw]^3)/3 + (G[{0}, yv]^2*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]^3 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yw]^3 + 2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^3 - 
     (4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]^3)/3 - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^3 - 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yw]^3)/3 + 2*G[{0}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]^3 - (8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]^3 - 
     (2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (8*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (8*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^3 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu]*G[{yu^(-1)}, yw]^4)/3 + (2*G[{0}, yv]*G[{yu^(-1)}, yw]^4)/
      3 - (7*G[{0}, yw]*G[{yu^(-1)}, yw]^4)/6 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^4)/2 - (11*G[{1}, yv]*G[{yu^(-1)}, yw]^4)/
      6 + (11*G[{yu^(-1)}, yw]^5)/30 + (Pi^4*G[{yv^(-1)}, yw])/30 - 
     (Pi^2*G[{0}, yv]^2*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu]^2*G[{yv^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]^2*G[{yv^(-1)}, yw] - (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{yv^(-1)}, yw])/3 + (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw])/
      3 + (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (2*Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu]^3*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]^2*G[{yv^(-1)}, yw])/6 + 3*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]^2*G[{yv^(-1)}, yw] - G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] + 3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] + 3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] + 3*G[{1}, yu]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     (4*G[{0}, yw]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{1}, yu]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{1}, yv]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     (4*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu]^3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     G[{0}, yv]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     (4*G[{0}, yu]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{0}, yv]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw] + 
     (G[{yu^(-1)}, yw]^4*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]^2)/6 - G[{0}, yv]^2*G[{0}, yw]*
      G[{yv^(-1)}, yw]^2 + (Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]^2)/6 - 
     G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw]^2 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu]*G[{yv^(-1)}, yw]^2 - 2*G[{0}, yv]*G[{1}, yu]^2*
      G[{yv^(-1)}, yw]^2 - G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yu]^3*G[{yv^(-1)}, yw]^2 + (Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2)/
      6 - G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2 + 2*G[{0}, yv]*G[{1}, yv]^2*
      G[{yv^(-1)}, yw]^2 + 2*G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/6 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 - 2*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2)/2 + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     (G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]^2)/3 + 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^4)/6 + (G[{1}, yu]*G[{yv^(-1)}, yw]^4)/6 + 
     (G[{1}, yv]*G[{yv^(-1)}, yw]^4)/6 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^4)/6 - G[{yv^(-1)}, yw]^5/30 - 
     (23*Pi^4*G[{1/(yu*yv)}, yw])/180 - (Pi^2*G[{0}, yu]*G[{0}, yv]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]^2*G[{1/(yu*yv)}, yw] + (2*G[{0}, yu]*G[{1}, yu]^3*
       G[{1/(yu*yv)}, yw])/3 - (Pi^2*G[{0}, yv]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 - (Pi^2*G[{1}, yu]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] + (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      3 - (2*Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] + G[{1}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (4*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (4*Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (4*Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (7*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (8*G[{0}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (8*G[{0}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (14*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] + 
     (22*G[{1}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (11*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (2*G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yu]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 + 
     (2*Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/3 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv]^2*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]^3*G[{1/(yu*yv)}, yw]^2 + 
     (7*Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/6 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv]^2*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 + G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     (2*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/3 - 
     (7*Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     5*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     5*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (11*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (19*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (19*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/6 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3 + G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^3 + G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3 + 
     (4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 + 
     (5*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1}, yw]*G[{0, 1}, yu] - G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yu] - G[{1}, yu]*G[{1}, yw]^2*
      G[{0, 1}, yu] - (G[{1}, yw]^3*G[{0, 1}, yu])/3 + 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yu] + G[{1}, yu]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - 4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu] - G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1}, yu])/3 + 2*G[{0}, yv]*G[{1}, yu]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu] + G[{1}, yu]^2*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] - 2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + 2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yu]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2 + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]^2*
      G[{0, 1}, yv] - G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yv] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yv] - (G[{1}, yw]^3*G[{0, 1}, yv])/
      3 + G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] - G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] + 4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] + 2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] + 4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv] + G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yv])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     4*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu]*G[{0, 1}, yv] + 4*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*
      G[{0, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     2*G[{1}, yw]*G[{0, 1}, yv]^2 + G[{yu^(-1)}, yw]*G[{0, 1}, yv]^2 + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]^2 - G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv]^2 - (2*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 + 
     2*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{1}, yw]*G[{0, 1}, yw] + 2*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yw]^2*
      G[{0, 1}, yw] + 2*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yw] + (G[{1}, yw]^3*G[{0, 1}, yw])/3 - 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] - 2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (8*G[{yu^(-1)}, yw]^3*G[{0, 1}, yw])/3 + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/3 - 
     2*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     8*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv]*G[{0, 1}, yw] - 4*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*
      G[{0, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 2*G[{1}, yv]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yv] + (G[{1}, yw]^3*G[{0, yu^(-1)}, yv])/3 - 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yv])/3 + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yv]^2 + G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv]^2 + Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/3 + G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yw] - (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (8*G[{yu^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 
     Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]^2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - (2*G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     8*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     10*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]^2 + G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw]^2 + (2*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     (G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/3 + G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] - (Pi^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (8*G[{yu^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     10*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw]^2 - Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw] + (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      3 + 4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (8*G[{yu^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     Pi^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]^2*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + (2*G[{yv^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/
      3 - (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw]^2 + (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv] - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1, yu^(-1)}, yv])/3 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1, yu^(-1)}, yv])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yv] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yv] - 2*G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + G[{1}, yu]*G[{1}, yw]^2*
      G[{1, yu^(-1)}, yw] + G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] + 
     (4*G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     7*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]^3*G[{1, yu^(-1)}, yw] + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + (2*G[{yv^(-1)}, yw]^3*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     14*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     5*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1, yu^(-1)}, yw]^2 - 2*G[{1}, yu]*
      G[{1, yu^(-1)}, yw]^2 - 2*G[{1}, yw]*G[{1, yu^(-1)}, yw]^2 + 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]^2 - 4*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw]^2 + 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2 + 
     (Pi^2*G[{0}, yv]*G[{1, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu]*G[{1, yv^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{1, yv^(-1)}, yw] + (2*Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] - 
     (4*G[{yu^(-1)}, yv]^3*G[{1, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     (8*G[{yu^(-1)}, yw]^3*G[{1, yv^(-1)}, yw])/3 + 
     Pi^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 3*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] - (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     8*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 5*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]^2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw]^2 - (Pi^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      3 - (Pi^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (4*G[{yu^(-1)}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (4*Pi^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (4*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     6*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 8*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (4*G[{yu^(-1)}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yu] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yw]^2*G[{0, 0, 1}, yv] - 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv] + 4*G[{1, yu^(-1)}, yw]*
      G[{0, 0, 1}, yv] - 4*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yw]^2*G[{0, 0, 1}, yw] + 2*G[{yu^(-1)}, yw]^2*
      G[{0, 0, 1}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1}, yw] + 4*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]^2*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]^2*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     6*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv] + 6*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     6*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     Pi^2*G[{0, 1, 1}, yw] - 2*G[{0}, yv]^2*G[{0, 1, 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     3*G[{yu^(-1)}, yw]^2*G[{0, 1, 1}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 1, 1}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] - 2*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     (2*Pi^2*G[{0, 1, yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     Pi^2*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1}, yv]*G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (2*Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 6*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*G[{0, 1, 1/(yu*yv)}, 
       yw] - 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 6*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yv] - 6*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 6*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 6*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - (2*Pi^2*G[{0, yu^(-1), 1}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]^2*G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), 1}, yw] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     (2*Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0, yu^(-1), yv^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, 
       yw] + 6*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/3 - 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - Pi^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]^2*G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0, 1}, yv]*G[{0, yv^(-1), 1}, yw] - 2*G[{0, 1}, yw]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     (2*Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] + 6*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     Pi^2*G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 4*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (2*Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + (2*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     3*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 5*G[{yu^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     (2*Pi^2*G[{1, 1, yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 6*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 6*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 6*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 3*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     (5*Pi^2*G[{1, 1, yv^(-1)}, yw])/3 + 2*G[{0}, yv]^2*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1, yv^(-1)}, yw] + 2*G[{1}, yu]^2*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     10*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]^2*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw] + 8*G[{0, 1}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 6*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yv]^2*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     (2*Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]^2*G[{1, yu^(-1), yv^(-1)}, 
       yw] + 4*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 6*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 6*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 6*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 5*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 3*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] + 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, 
       yw] + 2*G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yv]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, 1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - (2*Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/
      3 - 2*G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yu]^2*G[{1, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     (5*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yv]^2*
      G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 2*G[{1}, yu]^2*G[{1, yv^(-1), yv^(-1)}, 
       yw] - 8*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     14*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     (2*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      3 - 2*G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     (Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/3 - 
     8*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     10*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 3*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 6*G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 3*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     8*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1, yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, 1, 1}, yu] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yu] - 4*G[{1}, yw]*G[{0, 0, 1, 1}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yv] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1}, yw] + 4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] + 4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1, 1, 1}, yu] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yu] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, 1}, yu] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu] - 
     6*G[{0}, yv]*G[{0, 1, 1, 1}, yw] - 6*G[{1}, yu]*G[{0, 1, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1, 1}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yw] - 6*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), 1}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 8*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 4*G[{0}, yu]*
      G[{0, yu^(-1), 1, 1}, yw] + 2*G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] + 6*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{0, yv^(-1), 1, 1}, yw] + 
     6*G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1, 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] + 4*G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, 
       yw] - 6*G[{0}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 8*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{1, 1, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] - 8*G[{0}, yv]*G[{1, 1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{1, 1, 1, yv^(-1)}, yw] - 8*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] + 8*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     16*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1, 1}, yw] + 4*G[{0, 0, 1, 1, yu^(-1)}, yw] + 
     4*G[{0, 0, 1, 1, yv^(-1)}, yw] - 4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1}, yw] - 4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0, 0, 1, yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{0, 0, yu^(-1), 1, 1}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] - 
     12*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, 1}, yw] - 4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, 
       yw] + 4*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1, 1}, yw] + 2*G[{0, 1, 0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1, 0, yu^(-1), 1}, yw] - 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, 0, yv^(-1)}, yw] - 8*G[{0, 1, 1, 1, 1}, yw] + 
     2*G[{0, 1, 1, 1, yu^(-1)}, yw] + 8*G[{0, 1, 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1, 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, 1}, yw] + 4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - 6*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, 1, 1}, yw] + 6*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, 1}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), 1, 1, 1}, yw] - 2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, 1}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 6*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] + 2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, 1, 1, 1, yu^(-1)}, yw] + 16*G[{1, 1, 1, 1, yv^(-1)}, yw] + 
     8*G[{1, 1, 1, 1, 1/(yu*yv)}, yw] - 8*G[{1, 1, 1, yu^(-1), yu^(-1)}, 
       yw] - 16*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     44*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     28*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     28*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     12*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     20*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     12*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     12*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     36*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     12*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     20*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     24*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*Zeta[3])/3 - 6*G[{0}, yv]*G[{1}, yw]*Zeta[3] + 
     2*G[{0}, yw]*G[{1}, yw]*Zeta[3] - 2*G[{1}, yu]*G[{1}, yw]*Zeta[3] + 
     6*G[{1}, yv]*G[{1}, yw]*Zeta[3] - 4*G[{1}, yw]^2*Zeta[3] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*Zeta[3] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      Zeta[3] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*Zeta[3] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*Zeta[3] - 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      Zeta[3] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*Zeta[3] + 
     3*G[{yu^(-1)}, yw]^2*Zeta[3] + 6*G[{0}, yv]*G[{yv^(-1)}, yw]*Zeta[3] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*Zeta[3] + 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      Zeta[3] - 6*G[{1}, yv]*G[{yv^(-1)}, yw]*Zeta[3] + 
     8*G[{1}, yw]*G[{yv^(-1)}, yw]*Zeta[3] + 2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*Zeta[3] - G[{yv^(-1)}, yw]^2*Zeta[3] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 6*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      Zeta[3] - 2*G[{0, 1}, yw]*Zeta[3] + 2*G[{0, yu^(-1)}, yw]*Zeta[3] + 
     2*G[{0, yv^(-1)}, yw]*Zeta[3] - 2*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 
     2*G[{1, yu^(-1)}, yw]*Zeta[3] - 6*G[{1, yv^(-1)}, yw]*Zeta[3] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      Zeta[3] + 2*Zeta[5]
 
NuvwRegI = (11*Pi^4*G[{0}, yu])/180 + (11*Pi^4*G[{0}, yv])/180 + 
     (11*Pi^4*G[{0}, yw])/180 + (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw])/3 + 
     (11*Pi^4*G[{1}, yu])/180 + (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu])/3 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu])/3 - 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu])/3 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/2 - (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu]^2 - (Pi^2*G[{1}, yu]^3)/9 + 
     (2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^3)/3 + 
     (2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^3)/3 + (G[{0}, yu]*G[{1}, yu]^4)/2 + 
     (11*Pi^4*G[{1}, yv])/180 + (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv])/3 - 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv])/3 + 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yu]*G[{1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]^2*
      G[{1}, yv] - (2*G[{0}, yu]*G[{1}, yu]^3*G[{1}, yv])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/6 + (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/2 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]^2 + (Pi^2*G[{1}, yu]*G[{1}, yv]^2)/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^2 - 
     G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]^2 - (Pi^2*G[{1}, yv]^3)/9 + 
     (2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^3)/3 + 
     (2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^3)/3 + 
     (4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^3)/3 + 
     (2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]^3)/3 + (2*G[{1}, yu]^2*G[{1}, yv]^3)/
      3 + (G[{0}, yv]*G[{1}, yv]^4)/2 + (G[{1}, yu]*G[{1}, yv]^4)/2 + 
     (11*Pi^4*G[{1}, yw])/180 - (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yu]*G[{1}, yw] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]^2*
      G[{1}, yw] - (2*G[{0}, yu]*G[{1}, yu]^3*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yv]*G[{1}, yw] - (2*Pi^2*G[{1}, yu]*G[{1}, yv]*
       G[{1}, yw])/3 + 2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw] - 
     (2*G[{0}, yv]*G[{1}, yv]^3*G[{1}, yw])/3 - 
     (2*G[{1}, yu]*G[{1}, yv]^3*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/6 - (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/2 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]^2 + (Pi^2*G[{1}, yu]*G[{1}, yw]^2)/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2 - 
     G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]^2 + (Pi^2*G[{1}, yv]*G[{1}, yw]^2)/
      3 + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2 - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]^2 - G[{0}, yv]*G[{1}, yv]^2*
      G[{1}, yw]^2 - G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]^2 - 
     (Pi^2*G[{1}, yw]^3)/9 + (2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^3)/3 + 
     (4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^3)/3 + (2*G[{1}, yu]^2*G[{1}, yw]^3)/
      3 + (2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^3)/3 + 
     (4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^3)/3 + 2*G[{1}, yu]*G[{1}, yv]*
      G[{1}, yw]^3 + (2*G[{1}, yv]^2*G[{1}, yw]^3)/3 + 
     (G[{0}, yw]*G[{1}, yw]^4)/2 + (G[{1}, yu]*G[{1}, yw]^4)/2 + 
     (G[{1}, yv]*G[{1}, yw]^4)/2 + (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv] + 
     2*G[{1}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yv] - 
     (2*G[{0}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/3 - 
     (2*G[{0}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/3 - 
     (4*G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yv])/3 - 
     2*G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yv] - 2*G[{1}, yv]*G[{1}, yw]^3*
      G[{yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2 + 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2 - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2 + 
     (2*G[{1}, yw]^3*G[{yu^(-1)}, yv]^2)/3 - 
     (4*G[{1}, yw]^2*G[{yu^(-1)}, yv]^3)/3 - (11*Pi^4*G[{1/(yu*yv)}, yw])/
      60 - (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{0}, yu]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]^2*G[{1/(yu*yv)}, yw] - (2*G[{0}, yv]*G[{1}, yv]^3*
       G[{1/(yu*yv)}, yw])/3 - (2*G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/
      3 + (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw] - (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (8*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 3*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     (4*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (4*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (4*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 + 
     (2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3 - 
     (4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/3 - (Pi^2*G[{0}, yv]*G[{0, 1}, yu])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu])/3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1}, yu] - Pi^2*G[{1}, yu]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu] - 
     3*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu] - G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yu] - G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu] - 
     (2*G[{1}, yu]^3*G[{0, 1}, yu])/3 + (Pi^2*G[{1}, yv]*G[{0, 1}, yu])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu] + 3*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yu] - G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu] + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yu] - (2*G[{1}, yv]^3*G[{0, 1}, yu])/
      3 + (Pi^2*G[{1}, yw]*G[{0, 1}, yu])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, 1}, yu] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu] - G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yu] + 3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yu] + 2*G[{1}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yu] - (2*G[{1}, yw]^3*G[{0, 1}, yu])/3 + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu] + 2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{0, 1}, yu]^2 - G[{0}, yv]*G[{0, 1}, yu]^2 - 
     G[{0}, yw]*G[{0, 1}, yu]^2 - 3*G[{1}, yu]*G[{0, 1}, yu]^2 + 
     G[{1}, yv]*G[{0, 1}, yu]^2 + G[{1}, yw]*G[{0, 1}, yu]^2 + 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2 - (Pi^2*G[{0}, yu]*G[{0, 1}, yv])/3 - 
     (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/3 - (Pi^2*G[{0}, yw]*G[{0, 1}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yv] - 
     Pi^2*G[{1}, yv]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv] - G[{0}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yv] - 3*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yv] - 4*G[{1}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yv] - (2*G[{1}, yv]^3*G[{0, 1}, yv])/3 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv])/3 + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{1}, yw]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yv] + 3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv] + 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yv] + 2*G[{1}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yv] - (2*G[{1}, yw]^3*G[{0, 1}, yv])/3 + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] + 2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv] - 2*G[{0}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yv] - 2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     6*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] + 2*G[{1}, yw]*G[{0, 1}, yu]*
      G[{0, 1}, yv] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{0, 1}, yv]^2 + G[{0}, yv]*G[{0, 1}, yv]^2 - 
     G[{0}, yw]*G[{0, 1}, yv]^2 - 3*G[{1}, yv]*G[{0, 1}, yv]^2 + 
     G[{1}, yw]*G[{0, 1}, yv]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2 - 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yw])/3 - (Pi^2*G[{0}, yv]*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1}, yw] - Pi^2*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw] - G[{0}, yu]*G[{1}, yw]^2*
      G[{0, 1}, yw] - G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw] - 4*G[{1}, yu]*G[{1}, yw]^2*
      G[{0, 1}, yw] - 4*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     (2*G[{1}, yw]^3*G[{0, 1}, yw])/3 - 4*G[{0}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     6*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{0, 1}, yv]*
      G[{0, 1}, yw] + 2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 6*G[{1}, yw]*G[{0, 1}, yv]*
      G[{0, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{0, 1}, yw]^2 - G[{0}, yv]*G[{0, 1}, yw]^2 + 
     G[{0}, yw]*G[{0, 1}, yw]^2 - 3*G[{1}, yw]*G[{0, 1}, yw]^2 + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw]^2 + (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] + 3*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yv] + G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] + 
     (2*G[{1}, yv]^3*G[{0, yu^(-1)}, yv])/3 + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yv] - 3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     (2*G[{1}, yw]^3*G[{0, yu^(-1)}, yv])/3 - 2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yv] - (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     6*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]^2 - G[{1}, yw]*G[{0, yu^(-1)}, yv]^2 + 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]^2 + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + G[{0}, yv]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] + 3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (2*G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yw] - (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw]^2 + (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yw]^2*
      G[{0, yv^(-1)}, yw] + 3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (2*G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] - (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw]^2 + (Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 4*G[{0}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*
      G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 
     6*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 8*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     16*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 8*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + (2*Pi^2*G[{0, 0, 1}, yu])/3 + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yu] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1}, yu] + 4*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yu] + 
     6*G[{1}, yu]^2*G[{0, 0, 1}, yu] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yu] - 4*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yu] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yu] + 4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yu] - 2*G[{1}, yw]^2*G[{0, 0, 1}, yu] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yu] - 4*G[{0, 1}, yu]*
      G[{0, 0, 1}, yu] - 4*G[{0, 1}, yv]*G[{0, 0, 1}, yu] - 
     4*G[{0, 1}, yw]*G[{0, 0, 1}, yu] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] + (2*Pi^2*G[{0, 0, 1}, yv])/3 + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yv] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yv] + 4*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv] + 
     6*G[{1}, yv]^2*G[{0, 0, 1}, yv] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yv] + 4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yv] - 2*G[{1}, yw]^2*G[{0, 0, 1}, yv] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv] + 4*G[{0, 1}, yu]*
      G[{0, 0, 1}, yv] - 4*G[{0, 1}, yv]*G[{0, 0, 1}, yv] - 
     4*G[{0, 1}, yw]*G[{0, 0, 1}, yv] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] + (2*Pi^2*G[{0, 0, 1}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 6*G[{1}, yw]^2*G[{0, 0, 1}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] + 4*G[{0, 1}, yu]*
      G[{0, 0, 1}, yw] + 4*G[{0, 1}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{0, 1}, yw]*G[{0, 0, 1}, yw] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     6*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv] + 4*G[{0, 1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 6*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 6*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - (2*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + Pi^2*G[{0, 1, 1}, yu] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yu] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yu] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yu] + 4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yu] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     6*G[{0, 1}, yu]*G[{0, 1, 1}, yu] - 4*G[{0, 1}, yv]*G[{0, 1, 1}, yu] - 
     4*G[{0, 1}, yw]*G[{0, 1, 1}, yu] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + Pi^2*G[{0, 1, 1}, yv] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1}, yv] + 2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yv] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yu]^2*G[{0, 1, 1}, yv] + 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1}, yv] + 8*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yv] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     6*G[{0, 1}, yu]*G[{0, 1, 1}, yv] + 6*G[{0, 1}, yv]*G[{0, 1, 1}, yv] - 
     4*G[{0, 1}, yw]*G[{0, 1, 1}, yv] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] + Pi^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, 1, 1}, yw] + 8*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yw] + 8*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw] + 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{0, 1}, yu]*G[{0, 1, 1}, yw] + 6*G[{0, 1}, yv]*G[{0, 1, 1}, yw] + 
     6*G[{0, 1}, yw]*G[{0, 1, 1}, yw] - 6*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 8*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 6*G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - (Pi^2*G[{0, yu^(-1), 1}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] - 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yv] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yv] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yv] - (Pi^2*G[{0, yu^(-1), 1}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw] - 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     6*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{0, yv^(-1), 1}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yv^(-1), 1}, yw] - 2*G[{0, 1}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 6*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - (2*Pi^2*G[{1, 1, yu^(-1)}, yv])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yv] - 4*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1, yu^(-1)}, yv] - 4*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yv] + 4*G[{0, yu^(-1)}, yv]*
      G[{1, 1, yu^(-1)}, yv] - (2*Pi^2*G[{1, 1, yu^(-1)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 8*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1}, yv]*G[{1, 1, yu^(-1)}, yw] - 4*G[{0, 1}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     (2*Pi^2*G[{1, 1, yv^(-1)}, yw])/3 - 4*G[{0}, yu]*G[{0}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{1}, yu]^2*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]^2*G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw] - 4*G[{0, 1}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     (2*Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0, 1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     (2*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yw]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     (2*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     16*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 1, 1}, yu] - 4*G[{1}, yu]*G[{0, 0, 1, 1}, yu] + 
     4*G[{1}, yv]*G[{0, 0, 1, 1}, yu] + 4*G[{1}, yw]*G[{0, 0, 1, 1}, yu] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yu] - 
     4*G[{0}, yv]*G[{0, 0, 1, 1}, yv] - 4*G[{1}, yu]*G[{0, 0, 1, 1}, yv] - 
     4*G[{1}, yv]*G[{0, 0, 1, 1}, yv] + 4*G[{1}, yw]*G[{0, 0, 1, 1}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 4*G[{1}, yu]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, 1}, yw] - 4*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yv] + 4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     12*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv] + 12*G[{1}, yv]*
      G[{0, 0, yu^(-1), 1}, yv] - 4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw] + 12*G[{1}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw] + 12*G[{1}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     20*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 12*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     10*G[{0}, yu]*G[{0, 1, 1, 1}, yu] + 2*G[{0}, yv]*G[{0, 1, 1, 1}, yu] + 
     2*G[{0}, yw]*G[{0, 1, 1, 1}, yu] + 4*G[{1}, yv]*G[{0, 1, 1, 1}, yu] + 
     4*G[{1}, yw]*G[{0, 1, 1, 1}, yu] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yu] + 2*G[{0}, yu]*G[{0, 1, 1, 1}, yv] - 
     10*G[{0}, yv]*G[{0, 1, 1, 1}, yv] + 2*G[{0}, yw]*G[{0, 1, 1, 1}, yv] - 
     8*G[{1}, yu]*G[{0, 1, 1, 1}, yv] + 4*G[{1}, yw]*G[{0, 1, 1, 1}, yv] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv] + 
     2*G[{0}, yu]*G[{0, 1, 1, 1}, yw] + 2*G[{0}, yv]*G[{0, 1, 1, 1}, yw] - 
     10*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 8*G[{1}, yu]*G[{0, 1, 1, 1}, yw] - 
     8*G[{1}, yv]*G[{0, 1, 1, 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yw] - 8*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 
     8*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv] - 12*G[{1}, yv]*
      G[{0, 1, yu^(-1), 1}, yv] + 4*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] - 12*G[{1}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 8*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] + 8*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] - 12*G[{1}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] + 8*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, 
       yw] + 4*G[{1}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     8*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     8*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 8*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, yu^(-1), 1, 1}, yv] + 10*G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yv] + 
     8*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yw] + 10*G[{0}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] + 8*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1}, yw] - 4*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] - 4*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     8*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     12*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     12*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, 1}, yw] + 10*G[{0}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] + 8*G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1, 1}, yw] + 8*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, 
       yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     12*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     10*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 8*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 8*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 10*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 8*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 8*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 12*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yv] - 20*G[{0}, yv]*
      G[{1, 1, 1, yu^(-1)}, yv] + 8*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yv] - 
     12*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yv] + 
     12*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yv] - 
     8*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yv] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1, 1, 1, yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yw] - 20*G[{0}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] - 12*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yw] - 
     16*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw] - 12*G[{yu^(-1)}, yv]*
      G[{1, 1, 1, yu^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] + 8*G[{0}, yu]*G[{1, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, 1, 1, yv^(-1)}, yw] - 20*G[{0}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] - 16*G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw] - 
     12*G[{1}, yv]*G[{1, 1, 1, yv^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw] - 12*G[{yu^(-1)}, yv]*
      G[{1, 1, 1, yv^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] - 8*G[{0}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 
     20*G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 
     12*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 
     12*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     16*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 16*G[{yu^(-1)}, yv]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 8*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     24*G[{0, 0, 0, 1, 1}, yu] + 24*G[{0, 0, 0, 1, 1}, yv] + 
     24*G[{0, 0, 0, 1, 1}, yw] - 12*G[{0, 0, 0, 1, yu^(-1)}, yv] - 
     12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 12*G[{0, 0, 0, 1, yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1}, yv] - 12*G[{0, 0, 0, yu^(-1), 1}, yw] + 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] + 12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, 
       yw] + 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0, 0, 1, 0, 1}, yu] + 
     8*G[{0, 0, 1, 0, 1}, yv] + 8*G[{0, 0, 1, 0, 1}, yw] - 
     4*G[{0, 0, 1, 0, yu^(-1)}, yv] - 4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 
     4*G[{0, 0, 1, 0, yv^(-1)}, yw] - 16*G[{0, 0, 1, 1, 1}, yu] - 
     16*G[{0, 0, 1, 1, 1}, yv] - 16*G[{0, 0, 1, 1, 1}, yw] - 
     8*G[{0, 0, 1, 1, yu^(-1)}, yv] - 8*G[{0, 0, 1, 1, yu^(-1)}, yw] - 
     8*G[{0, 0, 1, 1, yv^(-1)}, yw] + 12*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), 1}, yv] - 4*G[{0, 0, 1, yu^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{0, 0, 1, yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, 1}, yv] - 4*G[{0, 0, yu^(-1), 0, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, yu^(-1), 1, 1}, yv] - 12*G[{0, 0, yu^(-1), 1, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1}, yw] + 4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, 
       yw] - 12*G[{0, 0, yv^(-1), 1, 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     20*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     12*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     10*G[{0, 1, 0, 1, 1}, yu] - 10*G[{0, 1, 0, 1, 1}, yv] - 
     10*G[{0, 1, 0, 1, 1}, yw] - 6*G[{0, 1, 0, 1, yu^(-1)}, yv] - 
     6*G[{0, 1, 0, 1, yu^(-1)}, yw] - 6*G[{0, 1, 0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 4*G[{0, 1, 0, yu^(-1), 1}, yv] - 
     4*G[{0, 1, 0, yu^(-1), 1}, yw] + 4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, yv^(-1), 1}, yw] - 2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{0, 1, 1, 0, yu^(-1)}, yv] - 
     6*G[{0, 1, 1, 0, yu^(-1)}, yw] - 6*G[{0, 1, 1, 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1, 1, 1, 1}, yu] + 
     4*G[{0, 1, 1, 1, 1}, yv] + 4*G[{0, 1, 1, 1, 1}, yw] + 
     8*G[{0, 1, 1, 1, yu^(-1)}, yv] + 8*G[{0, 1, 1, 1, yu^(-1)}, yw] + 
     8*G[{0, 1, 1, 1, yv^(-1)}, yw] + 8*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 1, yu^(-1), 1}, yv] + 8*G[{0, 1, 1, yu^(-1), 1}, yw] - 
     8*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 1, yv^(-1), 1}, yw] - 8*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 8*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 8*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 1, yu^(-1), 1, 1}, yv] + 12*G[{0, 1, yu^(-1), 1, 1}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 12*G[{0, 1, yv^(-1), 1, 1}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 8*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 8*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yv] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] + 
     6*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, 1, 1}, yv] - 4*G[{0, yu^(-1), 1, 1, 1}, yw] - 
     8*G[{0, yu^(-1), 1, 1, yu^(-1)}, yv] - 
     8*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, yu^(-1), 1}, yv] - 
     8*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, yu^(-1), yu^(-1), 1, 1}, yv] - 
     12*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] + 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, yu^(-1), yv^(-1), 1, 1}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] + 
     6*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1, 1, 1}, yw] - 8*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] - 
     12*G[{0, yv^(-1), yu^(-1), 1, 1}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1, 1}, yw] + 8*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] + 8*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, 1, 1, yu^(-1)}, yv] - 12*G[{1, 1, 1, 1, yu^(-1)}, yw] - 
     12*G[{1, 1, 1, 1, yv^(-1)}, yw] + 16*G[{1, 1, 1, 1, 1/(yu*yv)}, yw] + 
     16*G[{1, 1, 1, yu^(-1), yu^(-1)}, yv] + 
     16*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw] + 
     12*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] - 
     16*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     16*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     16*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     16*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     16*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     16*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     16*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (Pi^2*Zeta[3])/3 - 2*G[{0}, yu]*G[{0}, yv]*Zeta[3] - 
     2*G[{0}, yu]*G[{0}, yw]*Zeta[3] - 2*G[{0}, yv]*G[{0}, yw]*Zeta[3] - 
     4*G[{0}, yu]*G[{1}, yu]*Zeta[3] + 2*G[{1}, yu]^2*Zeta[3] - 
     4*G[{0}, yv]*G[{1}, yv]*Zeta[3] - 4*G[{1}, yu]*G[{1}, yv]*Zeta[3] + 
     2*G[{1}, yv]^2*Zeta[3] - 4*G[{0}, yw]*G[{1}, yw]*Zeta[3] - 
     4*G[{1}, yu]*G[{1}, yw]*Zeta[3] - 4*G[{1}, yv]*G[{1}, yw]*Zeta[3] + 
     2*G[{1}, yw]^2*Zeta[3] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 6*G[{1/(yu*yv)}, yw]^2*
      Zeta[3] + 7*Zeta[5]
 
OuvwRegI = (-31*Pi^4*G[{1}, yu])/360 - (Pi^2*G[{0}, yu]^2*G[{1}, yu])/6 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/12 + (Pi^2*G[{1}, yu]^3)/18 + 
     (G[{0}, yu]^2*G[{1}, yu]^3)/6 - (G[{0}, yu]*G[{1}, yu]^4)/12 - 
     (31*Pi^4*G[{1}, yv])/360 - (Pi^2*G[{0}, yv]^2*G[{1}, yv])/6 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv])/3 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv])/2 + 
     (G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yv])/2 - 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yv])/6 + (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/
      12 + (Pi^2*G[{1}, yu]*G[{1}, yv]^2)/12 + (Pi^2*G[{1}, yv]^3)/18 + 
     (G[{0}, yv]^2*G[{1}, yv]^3)/6 + (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^3)/3 + 
     (G[{1}, yu]^2*G[{1}, yv]^3)/6 - (G[{0}, yv]*G[{1}, yv]^4)/12 - 
     (G[{1}, yu]*G[{1}, yv]^4)/12 - (31*Pi^4*G[{1}, yw])/360 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/6 + (Pi^2*G[{0}, yu]*G[{1}, yu]*
       G[{1}, yw])/3 + (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw])/2 + 
     (G[{0}, yu]^2*G[{1}, yu]^2*G[{1}, yw])/2 - 
     (G[{0}, yu]*G[{1}, yu]^3*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/3 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw])/2 + 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/3 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw] + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw] + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw])/2 + 
     G[{1}, yu]^3*G[{1}, yv]*G[{1}, yw] + 
     (G[{0}, yv]^2*G[{1}, yv]^2*G[{1}, yw])/2 - 
     (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw] + 
     (G[{1}, yu]^2*G[{1}, yv]^2*G[{1}, yw])/2 - 
     (G[{0}, yv]*G[{1}, yv]^3*G[{1}, yw])/6 - 
     (G[{1}, yu]*G[{1}, yv]^3*G[{1}, yw])/6 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      12 + (Pi^2*G[{1}, yu]*G[{1}, yw]^2)/12 + (Pi^2*G[{1}, yv]*G[{1}, yw]^2)/
      12 + (Pi^2*G[{1}, yw]^3)/18 + (G[{0}, yw]^2*G[{1}, yw]^3)/6 + 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^3)/3 + (G[{1}, yu]^2*G[{1}, yw]^3)/6 + 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^3)/3 + 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^3)/3 + (G[{1}, yv]^2*G[{1}, yw]^3)/6 - 
     (G[{0}, yw]*G[{1}, yw]^4)/12 - (G[{1}, yu]*G[{1}, yw]^4)/12 - 
     (G[{1}, yv]*G[{1}, yw]^4)/12 + (31*Pi^4*G[{yu^(-1)}, yv])/180 + 
     (Pi^2*G[{0}, yu]^2*G[{yu^(-1)}, yv])/6 + 
     (Pi^2*G[{0}, yv]^2*G[{yu^(-1)}, yv])/6 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv])/2 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yv])/2 - 
     (Pi^2*G[{1}, yu]^2*G[{yu^(-1)}, yv])/6 - G[{0}, yu]^2*G[{1}, yu]^2*
      G[{yu^(-1)}, yv] + (G[{0}, yu]*G[{1}, yu]^3*G[{yu^(-1)}, yv])/2 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv])/2 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv])/2 - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv])/6 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv] + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv])/2 - 
     (Pi^2*G[{1}, yv]^2*G[{yu^(-1)}, yv])/6 - G[{0}, yv]^2*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] + G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv] - G[{1}, yu]^2*G[{1}, yv]^2*G[{yu^(-1)}, yv] + 
     (G[{0}, yv]*G[{1}, yv]^3*G[{yu^(-1)}, yv])/2 + 
     (G[{1}, yu]*G[{1}, yv]^3*G[{yu^(-1)}, yv])/2 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/3 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/3 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     G[{1}, yu]^3*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/3 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 - 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv])/2 + 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv] - 
     G[{1}, yv]^3*G[{1}, yw]*G[{yu^(-1)}, yv] + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]^2)/4 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]^2)/4 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]^2)/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]^2)/2 + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]^2)/4 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]^2)/4 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2)/2 - 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2 + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2)/4 - 
     (G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2)/2 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2)/4 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2 + 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2)/2 + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]^2)/4 - 
     G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2 - G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yv]^2 - (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yv]^2)/2 - (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yv]^2)/2 + (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/
      2 - (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/2 - 
     (3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/2 - 
     G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2 - 
     (3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/2 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/2 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2)/2 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2 - 
     G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]^2 - (Pi^2*G[{yu^(-1)}, yv]^3)/
      6 - (G[{0}, yu]^2*G[{yu^(-1)}, yv]^3)/4 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^3)/3 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]^3)/4 + 
     (4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^3)/3 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^3)/2 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]^3)/4 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/2 + 
     (4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 + 
     (4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^3)/3 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]^3)/4 + G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yv]^3 + G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^3 + 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^3 - 
     (5*G[{0}, yu]*G[{yu^(-1)}, yv]^4)/24 - (5*G[{0}, yv]*G[{yu^(-1)}, yv]^4)/
      24 - (5*G[{1}, yu]*G[{yu^(-1)}, yv]^4)/24 - 
     (5*G[{1}, yv]*G[{yu^(-1)}, yv]^4)/24 + G[{yu^(-1)}, yv]^5/12 + 
     (31*Pi^4*G[{yu^(-1)}, yw])/180 + (Pi^2*G[{0}, yu]^2*G[{yu^(-1)}, yw])/
      6 + (Pi^2*G[{0}, yw]^2*G[{yu^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yw])/2 - 
     (Pi^2*G[{1}, yu]^2*G[{yu^(-1)}, yw])/6 - G[{0}, yu]^2*G[{1}, yu]^2*
      G[{yu^(-1)}, yw] + (G[{0}, yu]*G[{1}, yu]^3*G[{yu^(-1)}, yw])/2 - 
     (2*Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw])/3 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw])/2 - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw])/3 + 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw])/2 + 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw])/2 - 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw])/2 - 
     G[{1}, yu]^3*G[{1}, yv]*G[{yu^(-1)}, yw] - G[{0}, yv]^2*G[{1}, yv]^2*
      G[{yu^(-1)}, yw] + (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*
       G[{yu^(-1)}, yw])/2 - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yu^(-1)}, yw] - G[{1}, yu]^2*G[{1}, yv]^2*G[{yu^(-1)}, yw] + 
     (G[{0}, yv]*G[{1}, yv]^3*G[{yu^(-1)}, yw])/3 + 
     (G[{1}, yu]*G[{1}, yv]^3*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw])/6 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw])/2 + 
     3*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw])/2 + 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     G[{1}, yv]^3*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yw])/6 - G[{0}, yw]^2*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] + G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] - G[{1}, yu]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     (G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw])/2 - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw])/2 - 
     G[{1}, yv]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/2 + 
     (G[{1}, yu]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/2 + 
     (G[{1}, yv]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     (2*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 + 
     G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     5*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     G[{1}, yu]^3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     4*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     (5*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 + 
     G[{1}, yv]^3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/3 - 
     G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw])/2 - 
     G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/4 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/4 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/2 + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw] - 
     (4*G[{1}, yu]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/2 - 
     (2*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw])/3 + 
     (5*G[{yu^(-1)}, yv]^4*G[{yu^(-1)}, yw])/24 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]^2)/4 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]^2)/4 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]^2)/4 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yw]^2)/4 - 
     (G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2)/2 - 
     G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2 + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2)/2 - 
     3*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2 + 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (3*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]^2)/2 + 
     G[{1}, yv]^3*G[{yu^(-1)}, yw]^2 + (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/
      4 - (G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/4 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     (3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/4 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/4 - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - G[{1}, yu]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]^2 - G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/4 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/4 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (9*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/4 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2)/2 + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2 - 
     (5*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2)/4 - 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2 - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2 - 
     (9*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2)/4 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]^2)/4 - (Pi^2*G[{yu^(-1)}, yw]^3)/
      6 - (G[{0}, yu]^2*G[{yu^(-1)}, yw]^3)/4 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^3)/4 + 
     (4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^3)/2 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]^3)/4 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^3)/6 + 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^3 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^3)/6 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^3)/6 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]^3)/6 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/2 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (5*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/6 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^3)/4 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/2 - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3 - 
     (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/3 - 
     (4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/3 - 
     (5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/6 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3)/2 + 
     (3*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^3)/4 - 
     (5*G[{0}, yu]*G[{yu^(-1)}, yw]^4)/24 - (5*G[{0}, yw]*G[{yu^(-1)}, yw]^4)/
      24 - (5*G[{1}, yu]*G[{yu^(-1)}, yw]^4)/24 - 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]^4)/12 - (5*G[{1}, yw]*G[{yu^(-1)}, yw]^4)/
      24 + (5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^4)/24 + 
     G[{yu^(-1)}, yw]^5/12 + (31*Pi^4*G[{yv^(-1)}, yw])/180 + 
     (Pi^2*G[{0}, yv]^2*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yw]^2*G[{yv^(-1)}, yw])/6 - 
     (2*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw])/3 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw])/2 - 
     G[{0}, yu]^2*G[{1}, yu]^2*G[{yv^(-1)}, yw] + 
     (G[{0}, yu]*G[{1}, yu]^3*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1)}, yw])/2 - 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw])/2 - 
     G[{1}, yu]^3*G[{1}, yv]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yv]^2*G[{yv^(-1)}, yw])/6 - G[{0}, yv]^2*G[{1}, yv]^2*
      G[{yv^(-1)}, yw] + (G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*
       G[{yv^(-1)}, yw])/2 - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*
      G[{yv^(-1)}, yw] - G[{1}, yu]^2*G[{1}, yv]^2*G[{yv^(-1)}, yw] + 
     (G[{0}, yv]*G[{1}, yv]^3*G[{yv^(-1)}, yw])/2 + 
     (G[{1}, yu]*G[{1}, yv]^3*G[{yv^(-1)}, yw])/2 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     G[{1}, yu]^3*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw])/6 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     (Pi^2*G[{1}, yw]^2*G[{yv^(-1)}, yw])/6 - G[{0}, yw]^2*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] + (G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*
       G[{yv^(-1)}, yw])/2 - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] - G[{1}, yu]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yv]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/2 + 
     (G[{1}, yu]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/2 + 
     (G[{1}, yv]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/6 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     4*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     G[{1}, yu]^3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (2*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     5*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     (7*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 + 
     G[{1}, yv]^3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw] - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw])/2 - 
     (Pi^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/4 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/4 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/2 + 
     3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/2 - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw] - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/2 - 
     (4*G[{1}, yv]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw])/3 + 
     (5*G[{yu^(-1)}, yv]^4*G[{yv^(-1)}, yw])/24 + 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/6 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     4*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     G[{1}, yu]^3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     4*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     (5*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     G[{1}, yv]^3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (2*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     6*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     5*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (7*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     (7*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 - 
     G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] - G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + 8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 8*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 6*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     7*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + 7*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - G[{1}, yw]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (4*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 + 
     (7*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (9*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     G[{0}, yv]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw] - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/2 - 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/2 - 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/6 - 
     (4*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (5*G[{yu^(-1)}, yw]^4*G[{yv^(-1)}, yw])/24 + 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]^2)/4 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]^2)/4 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2)/2 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw]^2)/2 - 
     3*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]^2 + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]^2)/2 + 
     G[{1}, yu]^3*G[{yv^(-1)}, yw]^2 + (Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2)/
      4 + (3*G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2)/4 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]^2)/4 - 
     G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]^2 - G[{1}, yu]*G[{1}, yv]^2*
      G[{yv^(-1)}, yw]^2 + (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     (3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - G[{1}, yu]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]^2 - G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/4 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/4 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     (9*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/4 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2)/2 + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2 - 
     (5*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2)/4 - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2 - 
     (9*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2)/4 - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]^2)/4 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 + 
     (9*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (7*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     (9*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 + 
     (G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2)/4 - 
     (9*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2)/4 - 
     (9*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2)/4 - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     (3*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]^2)/4 - (Pi^2*G[{yv^(-1)}, yw]^3)/
      6 - (G[{0}, yv]^2*G[{yv^(-1)}, yw]^3)/4 + 
     (G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]^3)/4 + G[{0}, yu]*G[{1}, yu]*
      G[{yv^(-1)}, yw]^3 - (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^3)/6 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^3)/6 - 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]^3)/6 + 
     (4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]^3)/2 + 
     (5*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^3)/6 - 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]^3)/4 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/2 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (5*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/6 + 
     (4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]^3)/4 - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]^3 - (G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/
      2 - (G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/3 - 
     (5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/6 - 
     (4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3)/2 + 
     (3*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^3)/4 - 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3 - 
     (G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/2 - 
     (5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/6 - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/2 - 
     (4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^3)/4 - 
     (5*G[{0}, yv]*G[{yv^(-1)}, yw]^4)/24 - (5*G[{0}, yw]*G[{yv^(-1)}, yw]^4)/
      24 - (5*G[{1}, yu]*G[{yv^(-1)}, yw]^4)/12 - 
     (5*G[{1}, yv]*G[{yv^(-1)}, yw]^4)/24 - (5*G[{1}, yw]*G[{yv^(-1)}, yw]^4)/
      24 + (5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^4)/24 + 
     (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^4)/24 + G[{yv^(-1)}, yw]^5/12 - 
     (31*Pi^4*G[{1/(yu*yv)}, yw])/120 - 
     (Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/6 + 
     (5*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw])/2 + 
     (Pi^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yu]^2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw])/2 - 
     (2*G[{0}, yu]*G[{1}, yu]^3*G[{1/(yu*yv)}, yw])/3 + 
     (5*Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (Pi^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     G[{1}, yu]^3*G[{1}, yv]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yv]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     (2*G[{0}, yv]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yu]*G[{1}, yv]^3*G[{1/(yu*yv)}, yw])/3 + 
     (5*Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (Pi^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (7*G[{0}, yu]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{1}, yu]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (7*G[{0}, yv]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yv]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yu]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yv]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (5*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/6 - 
     2*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (11*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     G[{1}, yu]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     6*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (11*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv]^3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     7*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw] + 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw])/2 + 
     (Pi^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 - 
     (11*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/2 - 
     6*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/4 - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     5*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     5*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw] - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw])/2 + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/6 + 
     (5*G[{0}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/6 + 
     G[{0}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw] + 
     (11*G[{1}, yu]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/6 + 
     (11*G[{1}, yv]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/6 + 
     (4*G[{1}, yw]*G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw])/3 - 
     (5*G[{yu^(-1)}, yv]^4*G[{1/(yu*yv)}, yw])/12 - 
     (Pi^2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (5*Pi^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     2*G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (11*G[{0}, yu]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{1}, yu]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     7*G[{0}, yv]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (11*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 - 3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 - 11*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 12*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 12*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 8*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (5*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + (7*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + 6*G[{1}, yu]*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (13*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + 2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - (11*G[{yu^(-1)}, yv]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/6 + (Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 + (3*G[{0}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (11*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     6*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     6*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (11*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 + (5*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + 6*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (11*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 + (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 - (13*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 + 
     G[{0}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] + 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 + 
     (11*G[{1}, yu]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (11*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 - 
     (11*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 - 
     (5*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/12 - 
     (Pi^2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     7*G[{0}, yu]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     6*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (11*G[{0}, yv]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (11*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 - 3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 3*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 - 12*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 11*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     12*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 8*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 8*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + 3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (7*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + (13*G[{1}, yu]*G[{yu^(-1)}, yv]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu^(-1)}, yv]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     (5*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 - 4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (3*G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 - 3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 3*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     12*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     12*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 13*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 11*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     12*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 12*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 6*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 12*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     12*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]^2*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (5*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + (7*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + 3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (13*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + (11*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + 6*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     6*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{1}, yu]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     6*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 + 3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + (5*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + (11*G[{1}, yu]*G[{yu^(-1)}, yv]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (13*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (7*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 + (5*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (11*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 + (13*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (13*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     G[{0}, yu]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] + 
     (5*G[{0}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 + 
     (5*G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 + 
     (5*G[{1}, yu]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (11*G[{1}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 + 
     (11*G[{1}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 - 
     (11*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 - 
     (11*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 - 
     (5*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/12 + 
     (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/4 + 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (2*Pi^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/3 + 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yv]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (9*G[{0}, yu]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yu]^3*G[{1/(yu*yv)}, yw]^2 + 
     (2*Pi^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/3 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]^2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (9*G[{0}, yv]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{1}, yu]*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv]^3*G[{1/(yu*yv)}, yw]^2 + 
     (2*Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/3 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{1}, yv]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{0}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{0}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (9*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{1}, yu]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yv]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2 - 
     (5*Pi^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     (13*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     (3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     6*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 + 
     (9*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (9*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2 - 
     (13*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (13*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{yu^(-1)}, yv]^3*G[{1/(yu*yv)}, yw]^2)/6 - 
     (5*Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (11*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     8*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (13*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      2 - 3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - (13*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (13*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     3*G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (13*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (13*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (13*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/6 - 
     (5*Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     8*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (11*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (13*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (13*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (13*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      2 - 3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - (13*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 - 6*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (13*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/4 - 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      2 - (13*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 - (13*G[{1}, yv]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + (13*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/4 - 3*G[{0}, yu]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - (G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 - (G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 - (G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (13*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 - (13*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 + (13*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 + (13*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 + (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      6 + (Pi^2*G[{1/(yu*yv)}, yw]^3)/6 + (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]^3)/
      6 - (2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]^3)/6 - 
     (2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^3)/6 - 
     (5*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{1}, yu]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (5*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]^3 - 
     (G[{1}, yv]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^4)/12 - (G[{0}, yv]*G[{1/(yu*yv)}, yw]^4)/
      12 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^4)/12 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^4)/6 - (G[{1}, yv]*G[{1/(yu*yv)}, yw]^4)/
      6 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^4)/6 + 
     (G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^4)/6 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^4)/6 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^4)/6 + 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/3 - (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/6 - 
     G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yu] - 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu])/2 + (G[{1}, yu]^3*G[{0, 1}, yu])/
      3 - (Pi^2*G[{1}, yv]*G[{0, 1}, yu])/3 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1}, yu] - (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu])/2 - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yu])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu])/3 - G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yu] - (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu])/2 - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{1}, yv]*
      G[{1}, yw]*G[{0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] + 
     3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/2 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/2 + G[{0}, yu]^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu] + G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/2 + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu])/2 - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yu] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*
      G[{0, 1}, yu] + (3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu])/2 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu])/2 + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yu])/2 - 
     G[{yu^(-1)}, yv]^3*G[{0, 1}, yu] + (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu])/
      2 + G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu])/2 + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu])/2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yu] - 
     (3*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu])/2 + 
     (3*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu])/2 + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu] + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu])/2 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu])/2 - 
     G[{yu^(-1)}, yw]^3*G[{0, 1}, yu] + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu])/3 + G[{0}, yu]*G[{0}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu] + (G[{0}, yv]^2*G[{yv^(-1)}, yw]*
       G[{0, 1}, yu])/2 + G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] + (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu])/2 + 
     6*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + G[{0}, yu]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu] - G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] - 3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu] - (G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu])/2 - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     (3*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu])/2 - 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu] - 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu])/2 - 
     G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu] + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu])/2 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu])/2 + 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu] + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu])/2 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu])/2 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu])/2 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu])/2 - 
     G[{yv^(-1)}, yw]^3*G[{0, 1}, yu] - (5*Pi^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu])/6 - G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/2 - 
     7*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     6*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/2 + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     6*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     (3*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/2 + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/2 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/2 - 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/2 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu])/2 - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     (G[{1/(yu*yv)}, yw]^3*G[{0, 1}, yu])/3 - G[{0}, yu]*G[{0, 1}, yu]^2 + 
     (G[{1}, yu]*G[{0, 1}, yu]^2)/2 - G[{1}, yv]*G[{0, 1}, yu]^2 - 
     G[{1}, yw]*G[{0, 1}, yu]^2 + (G[{yu^(-1)}, yv]*G[{0, 1}, yu]^2)/2 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu]^2)/2 + 2*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu]^2 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2)/2 + 
     (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/3 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, 1}, yv] - (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/6 - 
     G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1}, yv] - G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv] - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv])/2 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/2 + (G[{1}, yv]^3*G[{0, 1}, yv])/
      3 - (Pi^2*G[{1}, yw]*G[{0, 1}, yv])/3 - G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yv] - (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv])/2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/2 - 3*G[{0}, yv]*G[{1}, yv]*
      G[{1}, yw]*G[{0, 1}, yv] + G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yv] - 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yv])/2 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/2 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yv] + G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yv] - G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yv])/2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yv] + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv])/2 - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv] + 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yv])/2 - 
     G[{yu^(-1)}, yv]^3*G[{0, 1}, yv] + 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv])/3 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv])/2 - 
     3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     6*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - G[{0}, yu]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv] - G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv])/2 + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yv] - 
     (3*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv])/2 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv])/2 - 
     G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv] + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv])/2 + 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv])/2 + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv] + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv])/2 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv])/2 - 
     G[{yu^(-1)}, yw]^3*G[{0, 1}, yv] + (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv])/
      2 + G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv])/2 + 
     3*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     (5*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv])/2 + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     (3*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv])/2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     (3*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv])/2 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv] - 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv])/2 - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv] + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv])/2 - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv])/2 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv])/2 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv])/2 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv])/2 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yv])/2 - 
     G[{yv^(-1)}, yw]^3*G[{0, 1}, yv] - (5*Pi^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv])/6 - (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     3*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     7*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     6*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/2 - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/2 + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/2 + 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/2 - 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/2 - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv])/2 + 
     (G[{1/(yu*yv)}, yw]^3*G[{0, 1}, yv])/3 + G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yv] + G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv] + 2*G[{1}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yv] - 2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{0, 1}, yv]^2 - G[{1}, yu]*G[{0, 1}, yv]^2 + 
     (G[{1}, yv]*G[{0, 1}, yv]^2)/2 - G[{1}, yw]*G[{0, 1}, yv]^2 + 
     (G[{yu^(-1)}, yv]*G[{0, 1}, yv]^2)/2 + 2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv]^2 + (G[{yv^(-1)}, yw]*G[{0, 1}, yv]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2)/2 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/3 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yw])/2 - G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1}, yw] - (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw])/2 - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yw])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/6 - G[{0}, yw]^2*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yw] - 4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/2 + (G[{1}, yw]^3*G[{0, 1}, yw])/
      3 + (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/3 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/2 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/2 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw])/2 - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yv]^3*G[{0, 1}, yw] + (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/
      2 + (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yw] + G[{1}, yu]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] + 3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] + 3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw] + (5*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     (G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/2 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw])/2 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     G[{yu^(-1)}, yw]^3*G[{0, 1}, yw] + (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/
      2 + (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 3*G[{0}, yw]*G[{1}, yu]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + (5*G[{1}, yu]^2*G[{yv^(-1)}, yw]*
       G[{0, 1}, yw])/2 + G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] + 3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] + G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/2 - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     (G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/2 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/2 + 
     (3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     G[{yv^(-1)}, yw]^3*G[{0, 1}, yw] - (5*Pi^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/6 - (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/2 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     7*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     6*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     6*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 + 
     (G[{1/(yu*yv)}, yw]^3*G[{0, 1}, yw])/3 + G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yw] + G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw] - G[{1}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yw] + 2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] + G[{0}, yw]*G[{0, 1}, yv]*
      G[{0, 1}, yw] + 2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] + 2*G[{1}, yw]*G[{0, 1}, yv]*
      G[{0, 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]^2 - G[{1}, yu]*G[{0, 1}, yw]^2 - 
     G[{1}, yv]*G[{0, 1}, yw]^2 + (G[{1}, yw]*G[{0, 1}, yw]^2)/2 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]^2)/2 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/2 - 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/3 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yv] + 
     (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/2 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, yu^(-1)}, yv] + G[{0}, yv]^2*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 - 
     (G[{1}, yv]^3*G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/2 + 
     3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     (5*Pi^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/6 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/2 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv])/2 + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv] - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv])/2 + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv] - 
     (3*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yv])/2 + 
     G[{yu^(-1)}, yv]^3*G[{0, yu^(-1)}, yv] - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv])/3 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 + 
     3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     6*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     (3*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 
     G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     (G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 
     G[{yu^(-1)}, yw]^3*G[{0, yu^(-1)}, yv] - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     3*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     (5*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     (3*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     (3*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yv] + (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{0, yu^(-1)}, yv])/2 + 2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yv] - (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yv])/2 + (G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yv])/2 - (3*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yv])/2 - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yv])/2 + (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yv])/2 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yv])/2 + G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yv] + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/6 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/2 + 
     3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     7*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/2 + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] - 3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] + 3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] - G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] + 5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] + 5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yv] - 5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 5*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     (3*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 
     (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     (G[{1/(yu*yv)}, yw]^3*G[{0, yu^(-1)}, yv])/3 - 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     3*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]^2 - G[{0}, yv]*G[{0, yu^(-1)}, yv]^2 - 
     G[{1}, yu]*G[{0, yu^(-1)}, yv]^2 - (G[{1}, yv]*G[{0, yu^(-1)}, yv]^2)/
      2 + (3*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]^2)/2 + 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]^2 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]^2)/2 - 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] + G[{0}, yw]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/3 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw])/2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yw])/2 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yw] - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{yu^(-1)}, yv]^3*G[{0, yu^(-1)}, yw] - 
     (5*Pi^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/6 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     5*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     (9*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     (3*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{yu^(-1)}, yw]^3*G[{0, yu^(-1)}, yw] - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     (5*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     (3*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{0, yu^(-1)}, yw])/2 - (3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yw])/2 + 2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] + (G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yw])/2 + 2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yw])/2 + (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yw])/2 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yw])/2 + G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yw] + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/6 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     (5*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     (9*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     7*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{1/(yu*yv)}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]^2 - G[{0}, yw]*G[{0, yu^(-1)}, yw]^2 - 
     G[{1}, yu]*G[{0, yu^(-1)}, yw]^2 - 2*G[{1}, yv]*G[{0, yu^(-1)}, yw]^2 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + G[{yu^(-1)}, yv]*
      G[{0, yu^(-1)}, yw]^2 + (3*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/2 - 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]*G[{0, yv^(-1)}, yw] + G[{0}, yw]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 3*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/3 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw])/2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1)}, yw])/2 - 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1)}, yw] - 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1)}, yw])/2 + 
     G[{yu^(-1)}, yv]^3*G[{0, yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     (3*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     G[{yu^(-1)}, yw]^3*G[{0, yv^(-1)}, yw] - 
     (5*Pi^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/6 - 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     5*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     (9*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     (3*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] + (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/2 - (3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1)}, yw])/2 + 2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] + (G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1)}, yw])/2 + 2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1)}, yw])/2 + (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1)}, yw])/2 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1)}, yw])/2 + G[{yv^(-1)}, yw]^3*G[{0, yv^(-1)}, yw] + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/6 + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     (9*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     (5*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     7*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{1/(yu*yv)}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yv^(-1)}, yw]^2 - G[{0}, yw]*G[{0, yv^(-1)}, yw]^2 - 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]^2 - G[{1}, yv]*G[{0, yv^(-1)}, yw]^2 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + G[{yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw]^2 + (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + 
     (3*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (5*Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     (G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (9*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (7*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{yu^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (9*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (7*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/2 + (3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/2 - 2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - (G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/2 - 2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/2 - (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/2 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/2 - G[{yv^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (9*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (9*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     7*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 3*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{1/(yu*yv)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw]^2 + (3*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/
      2 + (3*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yv])/3 + 
     (Pi^2*G[{0}, yv]*G[{1, yu^(-1)}, yv])/3 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yv] + 
     (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yv] + 
     (3*G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yv])/2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yv] - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/2 + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv])/2 + 
     (7*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/2 - 
     (7*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/2 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/2 + 
     (7*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yv])/2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/6 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     5*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     (7*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv])/2 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     5*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     (7*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv])/2 - 
     G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     (7*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yv])/2 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/2 - 
     3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     (7*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/2 - 
     3*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     5*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv])/2 + 
     5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     5*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] - 
     (7*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv])/2 - 
     (7*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv])/2 + 
     G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yv] + 
     (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/2 - 
     (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/2 + 
     3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/2 + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv])/2 + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     7*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     7*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     6*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     7*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     7*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/2 - 
     (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/2 - 
     (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/2 + 
     (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/2 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/2 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yv])/2 + 
     3*G[{0}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] + 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     3*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1, yu^(-1)}, yv]^2 - 2*G[{0}, yv]*
      G[{1, yu^(-1)}, yv]^2 - 2*G[{1}, yu]*G[{1, yu^(-1)}, yv]^2 - 
     2*G[{1}, yv]*G[{1, yu^(-1)}, yv]^2 + G[{yu^(-1)}, yv]*
      G[{1, yu^(-1)}, yv]^2 + (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]^2)/2 + 
     (G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]^2)/2 - G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yv]^2 - (Pi^2*G[{0}, yu]*G[{1, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     (3*G[{0}, yu]^2*G[{1}, yu]*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu]^2*G[{1}, yv]*G[{1, yu^(-1)}, yw] + G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{1, yu^(-1)}, yw] + (3*G[{0}, yw]^2*G[{1}, yw]*
       G[{1, yu^(-1)}, yw])/2 + G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] + 3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] + (3*G[{1}, yu]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/
      2 + G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     5*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     (5*G[{1}, yv]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/3 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw] + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1)}, yw])/2 - 
     (G[{yu^(-1)}, yv]^3*G[{1, yu^(-1)}, yw])/3 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (7*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (7*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (7*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/6 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     3*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (7*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (3*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + G[{0}, yu]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] - (7*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1, yu^(-1)}, yw])/2 - (7*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1, yu^(-1)}, yw])/2 - (5*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1, yu^(-1)}, yw])/2 + G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] - G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + (G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/2 + 3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 3*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/2 + 2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 3*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - (7*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/2 + G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 3*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/2 - 3*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 3*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 3*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 7*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 3*G[{yu^(-1)}, yv]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 7*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 7*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 7*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 7*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 7*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     7*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + (5*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/2 - (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/2 - (5*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/2 + (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/2 - (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/2 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/2 + 3*G[{0}, yu]*G[{0, 1}, yu]*
      G[{1, yu^(-1)}, yw] + G[{0}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1, yu^(-1)}, yw]^2 - 2*G[{0}, yw]*
      G[{1, yu^(-1)}, yw]^2 - 2*G[{1}, yu]*G[{1, yu^(-1)}, yw]^2 - 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yw]^2 - 2*G[{1}, yw]*
      G[{1, yu^(-1)}, yw]^2 + 2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]^2 + 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]^2 + 
     (G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]^2)/2 - G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw]^2 - (Pi^2*G[{0}, yv]*G[{1, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/3 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{1, yv^(-1)}, yw] - G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{1, yv^(-1)}, yw] - (3*G[{0}, yv]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/
      2 - G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1)}, yw] - 
     (5*G[{1}, yu]^2*G[{1}, yv]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     (5*G[{1}, yu]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/3 - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     (3*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     (5*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw] + 
     (G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1)}, yw])/2 - 
     (G[{yu^(-1)}, yv]^3*G[{1, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/6 - 
     3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (7*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (5*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (7*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     5*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + (7*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 - (7*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 - (7*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 + (7*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 - (7*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 + 3*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + (G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/2 - 3*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/2 + G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 3*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - (7*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/2 + 3*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/2 - 3*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 3*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 3*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 7*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 3*G[{yu^(-1)}, yv]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 6*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 7*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 7*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     7*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     7*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     7*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + (5*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 - (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 - (5*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 + (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 - (5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/2 - G[{0}, yv]*G[{0, 1}, yu]*
      G[{1, yv^(-1)}, yw] + G[{0}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1, yv^(-1)}, yw]^2 - 2*G[{0}, yw]*
      G[{1, yv^(-1)}, yw]^2 - 4*G[{1}, yu]*G[{1, yv^(-1)}, yw]^2 - 
     2*G[{1}, yv]*G[{1, yv^(-1)}, yw]^2 - 2*G[{1}, yw]*
      G[{1, yv^(-1)}, yw]^2 + 2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]^2 + 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]^2)/2 + 
     G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]^2 - G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw]^2 - (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv)}, yw] - 
     (4*G[{yu^(-1)}, yv]^3*G[{1, 1/(yu*yv)}, yw])/3 + 
     (5*Pi^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 + 
     6*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (5*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     (3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     2*G[{yu^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/6 + 
     3*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (9*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - (G[{0}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/2 + 3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + (5*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/2 + 2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/2 + (3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/2 - 3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/3 - 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     6*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     9*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     9*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     18*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 10*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 6*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     (2*G[{1/(yu*yv)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 + 
     G[{0}, yu]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     5*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yu]*
      G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]^2 + 
     (5*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/2 + 
     (5*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/2 - 
     5*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (5*G[{yu^(-1)}, yv]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (4*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     (5*Pi^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (9*G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (5*G[{1}, yu]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yv]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{yv^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (3*G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     9*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - (3*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      2 - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      2 - (2*G[{1/(yu*yv)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (5*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/2 - 
     5*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]^2*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (5*G[{yu^(-1)}, yv]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     5*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (5*G[{1}, yv]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 5*G[{1}, yv]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (5*G[{yu^(-1)}, yw]^3*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (4*G[{yv^(-1)}, yw]^3*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 + (5*Pi^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 + G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (3*G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - G[{0}, yu]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     6*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 5*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 + G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - (3*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (3*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      2 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/2 - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - (2*G[{1/(yu*yv)}, yw]^3*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 4*G[{0}, yu]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yv]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yv]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yv]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yv]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 5*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yv]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 5*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yv]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 5*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 5*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 3*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 9*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu^(-1)}, yv]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 5*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 - (Pi^2*G[{0, 0, 1}, yu])/3 + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yu] + G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yu] + 5*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu] + 5*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yu] + G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yu] + 
     (7*G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yu])/2 - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 0, 1}, yu])/2 - G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yu] - G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     10*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu] + 
     G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yu] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] + G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     10*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yu] + 2*G[{0, 1}, yu]*
      G[{0, 0, 1}, yu] - G[{0, 1}, yv]*G[{0, 0, 1}, yu] - 
     G[{0, 1}, yw]*G[{0, 0, 1}, yu] + G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yu] + 
     G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu] + G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1}, yu] - G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     3*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yu] - 3*G[{1, yu^(-1)}, yw]*
      G[{0, 0, 1}, yu] - 3*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     (Pi^2*G[{0, 0, 1}, yv])/3 + G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yv] + G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv] + 
     G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv] + 5*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yv] - G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv] - 
     5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yv] + 
     (7*G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yv])/2 - G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv] - G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     10*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     G[{yu^(-1)}, yw]^2*G[{0, 0, 1}, yv] - 4*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yv] - G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yv])/2 + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     10*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv] - 
     G[{0, 1}, yu]*G[{0, 0, 1}, yv] + 2*G[{0, 1}, yv]*G[{0, 0, 1}, yv] - 
     G[{0, 1}, yw]*G[{0, 0, 1}, yv] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yv] + G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] + 3*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yv] - 
     3*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 3*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     (Pi^2*G[{0, 0, 1}, yw])/3 + G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yw] + G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yw] - G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 0, 1}, yw])/2 - G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yw])/2 + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] - 
     G[{0, 1}, yu]*G[{0, 0, 1}, yw] - G[{0, 1}, yv]*G[{0, 0, 1}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yw] + G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] - 2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 3*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     3*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     (Pi^2*G[{0, 0, yu^(-1)}, yv])/3 - G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     5*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     (7*G[{yu^(-1)}, yv]^2*G[{0, 0, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     10*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yv])/2 - 
     5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     10*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 
     G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv] - 2*G[{0, 1}, yv]*
      G[{0, 0, yu^(-1)}, yv] + G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - G[{0, yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     3*G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     3*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     3*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/3 - G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] - G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{0, 0, yu^(-1)}, yw] + 
     5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     9*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yw])/2 + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yw])/2 - 
     5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw] + G[{0, 1}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/3 - G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{0, 0, yv^(-1)}, yw] + G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 8*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 5*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 5*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - (7*G[{yu^(-1)}, yw]^2*G[{0, 0, yv^(-1)}, yw])/
      2 + 5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     9*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 0, yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{0, 0, yv^(-1)}, yw] + G[{0, 1}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     3*G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     3*G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*G[{0, 0, 1/(yu*yv)}, 
       yw] - 5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     9*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     9*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     9*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     9*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 + 
     5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     9*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     9*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     10*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - G[{0, 1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{1, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{1, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1, 1}, yu])/6 + 2*G[{0}, yu]^2*G[{0, 1, 1}, yu] - 
     G[{1}, yu]^2*G[{0, 1, 1}, yu] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yu] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     8*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu] - G[{0, 1}, yu]*G[{0, 1, 1}, yu] + 
     2*G[{0, 1}, yv]*G[{0, 1, 1}, yu] + 2*G[{0, 1}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yu] - 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 2*G[{1, yu^(-1)}, yv]*
      G[{0, 1, 1}, yu] + 2*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + (Pi^2*G[{0, 1, 1}, yv])/6 + 
     2*G[{0}, yv]^2*G[{0, 1, 1}, yv] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yv] + 4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yu]^2*G[{0, 1, 1}, yv] - G[{1}, yv]^2*G[{0, 1, 1}, yv] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yv] + 2*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     8*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv] - 4*G[{0, 1}, yu]*
      G[{0, 1, 1}, yv] - G[{0, 1}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yv] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 2*G[{1, yu^(-1)}, yv]*
      G[{0, 1, 1}, yv] + 2*G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] + (Pi^2*G[{0, 1, 1}, yw])/6 + 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, 1, 1}, yw] - G[{1}, yw]^2*G[{0, 1, 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yw] - 4*G[{0, 1}, yu]*
      G[{0, 1, 1}, yw] - 4*G[{0, 1}, yv]*G[{0, 1, 1}, yw] - 
     G[{0, 1}, yw]*G[{0, 1, 1}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] - 2*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     (5*Pi^2*G[{0, 1, yu^(-1)}, yv])/6 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yv] - 
     3*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     5*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     (7*G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     10*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     7*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yv])/2 + 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     12*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yv] + 
     G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv] - G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 3*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     3*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     3*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     5*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     5*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     (5*Pi^2*G[{0, 1, yu^(-1)}, yw])/6 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 
     3*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     7*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 6*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yw] - 
     5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw] + G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     5*G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     (5*Pi^2*G[{0, 1, yv^(-1)}, yw])/6 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw] - 3*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 7*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw] + G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 3*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 3*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - G[{yu^(-1)}, yv]^2*G[{0, 1, yv^(-1)}, yw] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 1, yv^(-1)}, yw])/2 - 
     5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 1, yv^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{0, 1, yv^(-1)}, yw] + G[{0, 1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] + G[{0, yu^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     5*G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (7*Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/6 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 5*G[{0, 1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - (Pi^2*G[{0, yu^(-1), 1}, yv])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yv]^2*G[{0, yu^(-1), 1}, yv] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] + 
     G[{1}, yv]^2*G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yv] + 6*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 6*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] + G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv] - G[{0, 1}, yv]*
      G[{0, yu^(-1), 1}, yv] + G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/2 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] - 6*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1}, yw] - G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     (7*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/6 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] + 3*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     5*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     (7*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     10*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     7*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv])/2 - 
     5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     12*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 
     G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     3*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 3*G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 5*G[{1, yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 5*G[{1, yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + G[{1, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + (7*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/
      6 + 4*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 3*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 6*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/2 + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/2 - 
     5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     (5*Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/6 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, yu^(-1), yv^(-1)}, 
       yw] + G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 6*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 7*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yv]^2*G[{0, yu^(-1), yv^(-1)}, 
       yw] - 2*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 3*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 3*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{yu^(-1)}, yv]^2*
      G[{0, yu^(-1), yv^(-1)}, yw] + 5*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 3*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 7*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - (7*G[{yu^(-1)}, yw]^2*
       G[{0, yu^(-1), yv^(-1)}, yw])/2 + 5*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 3*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 7*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - (7*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1), yv^(-1)}, yw])/2 - 3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 3*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{0, 1}, yu]*G[{0, yu^(-1), yv^(-1)}, 
       yw] - G[{0, 1}, yv]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 5*G[{1, yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 5*G[{1, yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 6*G[{1, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - (7*Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      6 - 4*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/2 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1}, yu]*G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yv^(-1), 1}, yw] - G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     (5*Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/6 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] + G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 6*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 7*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] - 2*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 3*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 3*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{yu^(-1)}, yv]^2*
      G[{0, yv^(-1), yu^(-1)}, yw] + 5*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 3*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 7*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - (7*G[{yu^(-1)}, yw]^2*
       G[{0, yv^(-1), yu^(-1)}, yw])/2 + 5*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 3*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 7*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - (7*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1), yu^(-1)}, yw])/2 - 3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 3*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{0, 1}, yu]*G[{0, yv^(-1), yu^(-1)}, 
       yw] - G[{0, 1}, yv]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 5*G[{1, yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 5*G[{1, yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 6*G[{1, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + (7*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/
      6 + 4*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 8*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 6*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 3*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 6*G[{1}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] + G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/2 + 
     5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     3*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (7*Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/6 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 5*G[{0, 1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 5*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 5*G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + (5*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/6 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1}, yw] + 6*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), 1}, yw] + 3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     3*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     3*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     (7*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/6 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 7*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 3*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 3*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 3*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 3*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 3*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 5*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 3*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 7*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     5*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (7*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/6 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 7*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 3*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 3*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 3*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 7*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (7*Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/6 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{1}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 5*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 5*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 5*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 5*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - (Pi^2*G[{1, 1, yu^(-1)}, yv])/6 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]^2*G[{1, 1, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1, yu^(-1)}, yv] - 2*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     5*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     5*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] + 
     7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] - 
     (7*G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yv])/2 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     10*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     13*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     5*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     (7*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yv])/2 + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     5*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     9*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     12*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yv] + 3*G[{0, 1}, yw]*
      G[{1, 1, yu^(-1)}, yv] - 3*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     3*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     3*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     5*G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yv] + 
     3*G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     5*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     8*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     (Pi^2*G[{1, 1, yu^(-1)}, yw])/6 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1, 1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 3*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 9*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{1}, yv]^2*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     5*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] - 
     (5*G[{yu^(-1)}, yv]^2*G[{1, 1, yu^(-1)}, yw])/2 + 
     7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     7*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     7*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     9*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     12*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     11*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, 1, yu^(-1)}, yw] + 3*G[{0, 1}, yv]*
      G[{1, 1, yu^(-1)}, yw] - 3*G[{0, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 
     G[{1, yu^(-1)}, yv]*G[{1, 1, yu^(-1)}, yw] + 5*G[{1, yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     3*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     (Pi^2*G[{1, 1, yv^(-1)}, yw])/6 - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]^2*G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{1}, yv]^2*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 
     5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     (5*G[{yu^(-1)}, yv]^2*G[{1, 1, yv^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     7*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     7*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     9*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     11*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     12*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     3*G[{0, 1}, yu]*G[{1, 1, yv^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] - 
     G[{1, yu^(-1)}, yv]*G[{1, 1, yv^(-1)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 5*G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     3*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + G[{1}, yu]*G[{1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     7*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     7*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     9*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     (9*G[{yu^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     7*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     7*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     9*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     (9*G[{yv^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/2 + 
     9*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     9*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     11*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     11*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     18*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     18*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     13*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     13*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     3*G[{0, 1}, yu]*G[{1, 1, 1/(yu*yv)}, yw] + 3*G[{0, 1}, yv]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     3*G[{0, yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     3*G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     3*G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     9*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     9*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yv] - 2*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, 
       yv] + 4*G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yv] - 
     7*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     7*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     7*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     7*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     (5*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/2 - 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     (5*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yv])/2 + 
     7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     5*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     5*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yu]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yu]^2*G[{1, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     7*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     9*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     (5*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     7*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     5*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     (5*Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/6 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1, yu^(-1), yv^(-1)}, 
       yw] - G[{0}, yu]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - G[{0}, yv]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 7*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yv]^2*G[{1, yu^(-1), yv^(-1)}, 
       yw] + 2*G[{0}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 
     5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/2 - 
     5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     G[{0, 1}, yv]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - G[{0, yu^(-1)}, yv]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 5*G[{1, yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yu]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yu]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 7*G[{1}, yv]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     (5*G[{yu^(-1)}, yv]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/2 + 
     6*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 1}, yu]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1, yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/6 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1, yv^(-1), yu^(-1)}, 
       yw] - G[{0}, yu]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - G[{0}, yv]*G[{1}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 7*G[{1}, yu]*G[{1}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yv]^2*G[{1, yv^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/2 - 
     5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     G[{0, 1}, yv]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - G[{0, yu^(-1)}, yv]*
      G[{1, yv^(-1), yu^(-1)}, yw] + G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]^2*G[{1, yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 6*G[{1}, yu]*G[{1}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 2*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     (5*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/2 - 
     7*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     5*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     7*G[{1}, yu]*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1}, yu]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yv]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     (5*G[{yu^(-1)}, yv]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 1}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1, yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/6 - 
     2*G[{0}, yu]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1}, yu]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     (5*Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/6 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - G[{0}, yu]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yv]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{0}, yv]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - G[{1}, yu]*G[{1}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yv]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 7*G[{1}, yu]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{1}, yv]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 3*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 5*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 5*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 3*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - G[{0}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 3*G[{1}, yu]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 3*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + G[{yu^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 5*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 5*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/2 + 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     (7*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     5*G[{1}, yu]*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yu]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yv]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     5*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     5*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     24*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yv]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, 1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, 1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     14*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (7*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     10*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (9*G[{yv^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 13*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/6 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     7*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/2 - 
     3*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 7*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (7*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     5*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (3*G[{yu^(-1)}, yv]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     5*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 5*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 7*G[{0, 1}, yu]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 7*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 7*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 7*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 7*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 3*G[{1, yu^(-1)}, yv]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 11*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 14*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (7*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 8*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 5*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 5*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yv]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (7*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0}, yv]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0}, yw]*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yu]*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yu]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     5*G[{1}, yv]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (3*G[{yu^(-1)}, yv]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{0}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yu]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      2 + 4*G[{0}, yu]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 5*G[{0}, yv]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 10*G[{1}, yu]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 9*G[{1}, yv]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 9*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 9*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 5*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 12*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     14*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{0, 0, 0, 1}, yu] + 6*G[{yu^(-1)}, yv]*
      G[{0, 0, 0, 1}, yu] + 6*G[{yu^(-1)}, yw]*G[{0, 0, 0, 1}, yu] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yu] - 
     6*G[{1}, yv]*G[{0, 0, 0, 1}, yv] + 6*G[{yu^(-1)}, yv]*
      G[{0, 0, 0, 1}, yv] + 6*G[{yv^(-1)}, yw]*G[{0, 0, 0, 1}, yv] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yv] - 
     6*G[{1}, yw]*G[{0, 0, 0, 1}, yw] + 6*G[{yu^(-1)}, yw]*
      G[{0, 0, 0, 1}, yw] + 6*G[{yv^(-1)}, yw]*G[{0, 0, 0, 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yw] + 
     6*G[{1}, yv]*G[{0, 0, 0, yu^(-1)}, yv] - 6*G[{yu^(-1)}, yv]*
      G[{0, 0, 0, yu^(-1)}, yv] - 6*G[{yv^(-1)}, yw]*
      G[{0, 0, 0, yu^(-1)}, yv] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 0, yu^(-1)}, yv] + 6*G[{1}, yw]*G[{0, 0, 0, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, 0, 0, yu^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, 0, 0, yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{0, 0, 0, yv^(-1)}, yw] - 6*G[{yu^(-1)}, yw]*
      G[{0, 0, 0, yv^(-1)}, yw] - 6*G[{yv^(-1)}, yw]*
      G[{0, 0, 0, yv^(-1)}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 0, yv^(-1)}, yw] - 6*G[{1}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 1, 1}, yu] - 4*G[{1}, yv]*G[{0, 0, 1, 1}, yu] - 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yu] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1}, yu] + 4*G[{yu^(-1)}, yw]*G[{0, 0, 1, 1}, yu] + 
     8*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yu] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yu] - 4*G[{0}, yv]*G[{0, 0, 1, 1}, yv] - 
     4*G[{1}, yu]*G[{0, 0, 1, 1}, yv] - 4*G[{1}, yw]*G[{0, 0, 1, 1}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yv] + 8*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1}, yv] + 4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yv] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 4*G[{1}, yu]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, 1}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1}, yw] + 4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw] + 
     4*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv] - 
     6*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv] + 2*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yu^(-1)}, yv] - 8*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yv] + 2*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 8*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yv] + 4*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     6*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     6*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] - 4*G[{0}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     8*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     8*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{0, 1, 1, 1}, yu] + 
     2*G[{1}, yu]*G[{0, 1, 1, 1}, yu] - 2*G[{1}, yv]*G[{0, 1, 1, 1}, yu] - 
     2*G[{1}, yw]*G[{0, 1, 1, 1}, yu] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, 1}, yu] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu] + 
     G[{0}, yv]*G[{0, 1, 1, 1}, yv] + G[{1}, yu]*G[{0, 1, 1, 1}, yv] + 
     2*G[{1}, yv]*G[{0, 1, 1, 1}, yv] - 2*G[{1}, yw]*G[{0, 1, 1, 1}, yv] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yv] + G[{0}, yw]*G[{0, 1, 1, 1}, yw] + 
     G[{1}, yu]*G[{0, 1, 1, 1}, yw] + G[{1}, yv]*G[{0, 1, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yw] - 6*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yv] - 4*G[{1}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yv] + 6*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] - 6*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yw] - 7*G[{1}, yv]*
      G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] - 6*G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 7*G[{1}, yu]*
      G[{0, 1, 1, yv^(-1)}, yw] - G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     7*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 12*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv] - 
     3*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] - 
     3*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     2*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yv] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yv] + 8*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] - 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw] - 
     3*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     3*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] - 
     7*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 8*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] + 3*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     12*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw] - 
     3*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     7*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] - 
     3*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1), 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     3*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 3*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv] - 
     G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] - 2*G[{1}, yv]*
      G[{0, yu^(-1), 1, 1}, yv] - 2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, 1}, yv] - 
     G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] + 6*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] + G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     6*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     7*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 7*G[{0}, yw]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 5*G[{1}, yu]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 5*G[{1}, yv]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] + 3*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] + 3*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] - 2*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] + 4*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] - 8*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] + 4*G[{0}, yu]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 3*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 3*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 7*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 8*G[{0}, yu]*
      G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     3*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     3*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     11*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     3*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     3*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     11*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yu]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     11*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw] - 
     G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw] - 2*G[{1}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] + 2*G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, 
       yw] + G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     7*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 7*G[{0}, yw]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 5*G[{1}, yu]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 5*G[{1}, yv]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 3*G[{0}, yw]*
      G[{0, yv^(-1), yu^(-1), 1}, yw] + 3*G[{1}, yu]*
      G[{0, yv^(-1), yu^(-1), 1}, yw] + 3*G[{1}, yv]*
      G[{0, yv^(-1), yu^(-1), 1}, yw] - 2*G[{1}, yw]*
      G[{0, yv^(-1), yu^(-1), 1}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1), 1}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1), 1}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1), 1}, yw] - 8*G[{0}, yu]*
      G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     11*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yu]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     3*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     7*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     3*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     11*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     11*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     7*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     7*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     7*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1, 1, 1, yu^(-1)}, yv] + 
     3*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yv] - 2*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] - 6*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yv] + 3*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1, 1, 1, yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1, 1, 1, yu^(-1)}, yw] - 6*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] + 3*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1, 1, 1, yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1, 1, 1, yv^(-1)}, yw] - 6*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] + 6*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 12*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, 
       yv] - G[{0}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] - 
     10*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     G[{1}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yu]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yu]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     24*G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     24*G[{yu^(-1)}, yv]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     5*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     5*G[{0}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     5*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     5*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     12*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     12*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     5*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     5*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     5*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     5*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     12*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     9*G[{0}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yu]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yu]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     9*G[{0}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yu]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{yu^(-1)}, yv]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yu]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yu]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     5*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     5*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     5*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     12*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     9*G[{0}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{yu^(-1)}, yv]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yu]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     9*G[{0}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{yu^(-1)}, yv]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     5*G[{0}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     13*G[{0}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{0}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{1}, yu]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{1}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     26*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     26*G[{yu^(-1)}, yv]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{0}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     11*G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     11*G[{1}, yu]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     22*G[{1}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     11*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     11*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     22*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     11*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     11*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     13*G[{0}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     17*G[{1}, yu]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     26*G[{1}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     17*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{yu^(-1)}, yv]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     26*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{0}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     11*G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     22*G[{1}, yu]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     11*G[{1}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     11*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     11*G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     11*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     22*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{0}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     26*G[{1}, yu]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     17*G[{1}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     17*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{yu^(-1)}, yv]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     26*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, 1, 0, 1}, yu] - 2*G[{0, 0, 1, 0, 1}, yv] - 
     2*G[{0, 0, 1, 0, 1}, yw] + 2*G[{0, 0, 1, 0, yu^(-1)}, yv] + 
     2*G[{0, 0, 1, 0, yu^(-1)}, yw] + 2*G[{0, 0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{0, 0, 1, 1, 1}, yu] + 
     2*G[{0, 0, 1, 1, 1}, yv] + 2*G[{0, 0, 1, 1, 1}, yw] + 
     8*G[{0, 0, 1, 1, yu^(-1)}, yv] + 8*G[{0, 0, 1, 1, yu^(-1)}, yw] + 
     8*G[{0, 0, 1, 1, yv^(-1)}, yw] - 8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     10*G[{0, 0, 1, yu^(-1), 1}, yv] + 10*G[{0, 0, 1, yu^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     10*G[{0, 0, 1, yv^(-1), 1}, yw] - 6*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1/(yu*yv), 1}, yw] + 
     18*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yu^(-1), 0, 1}, yv] + 2*G[{0, 0, yu^(-1), 0, 1}, yw] - 
     2*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv] - 
     2*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), 1, 1}, yv] + 8*G[{0, 0, yu^(-1), 1, 1}, yw] - 
     8*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] - 
     8*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     16*G[{0, 0, yu^(-1), yu^(-1), 1}, yv] - 
     16*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] + 
     24*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     24*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     2*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     18*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yv^(-1), 0, 1}, yw] - 2*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), 1, 1}, yw] - 4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     2*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     10*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     16*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     24*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     18*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 2*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 2*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 12*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 12*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     14*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     10*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     14*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     14*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     14*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     10*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     18*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     18*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     18*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     10*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 1, 0, 1, 1}, yu] + G[{0, 1, 0, 1, 1}, yv] + 
     G[{0, 1, 0, 1, 1}, yw] + 4*G[{0, 1, 0, 1, yu^(-1)}, yv] + 
     4*G[{0, 1, 0, 1, yu^(-1)}, yw] + 4*G[{0, 1, 0, 1, yv^(-1)}, yw] - 
     8*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 4*G[{0, 1, 0, yu^(-1), 1}, yv] + 
     4*G[{0, 1, 0, yu^(-1), 1}, yw] - G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] - 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] + 4*G[{0, 1, 0, yv^(-1), 1}, yw] - 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] - 8*G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 
     7*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0, 1, 1, 0, yu^(-1)}, 
      yv] + G[{0, 1, 1, 0, yu^(-1)}, yw] + G[{0, 1, 1, 0, yv^(-1)}, yw] - 
     G[{0, 1, 1, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1, 1, 1, 1}, yu] - 
     2*G[{0, 1, 1, 1, 1}, yv] - 2*G[{0, 1, 1, 1, 1}, yw] - 
     G[{0, 1, 1, 1, yu^(-1)}, yv] - G[{0, 1, 1, 1, yu^(-1)}, yw] - 
     G[{0, 1, 1, 1, yv^(-1)}, yw] + 2*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1, yu^(-1), 1}, yv] - 6*G[{0, 1, 1, yu^(-1), 1}, yw] + 
     5*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] + 
     5*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1, yv^(-1), 1}, yw] - 3*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     5*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     10*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 3*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 3*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] + 
     3*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     3*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] - 
     3*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, yu^(-1), 1, 1}, yv] - 6*G[{0, 1, yu^(-1), 1, 1}, yw] + 
     5*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] + 
     5*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + G[{0, 1, yu^(-1), 1, yv^(-1)}, 
      yw] + 6*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     12*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] + 
     12*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     7*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     7*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] - 
     3*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] - 
     7*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] - 
     3*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, yv^(-1), 1, 1}, yw] + G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     5*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     6*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] - 
     3*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     3*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     7*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] - 
     7*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     7*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     10*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     15*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     15*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, yu^(-1), 0, yu^(-1), 1}, yv] - 
     3*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv] + 
     7*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] - 
     7*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] - 
     3*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1}, yv] + 2*G[{0, yu^(-1), 1, 1, 1}, yw] + 
     G[{0, yu^(-1), 1, 1, yu^(-1)}, yv] + G[{0, yu^(-1), 1, 1, yu^(-1)}, 
      yw] - 3*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, yu^(-1), 1}, yv] + 
     6*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] - 
     5*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] - 
     5*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     3*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] - 
     7*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), yu^(-1), 1, 1}, yv] + 
     6*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] - 
     5*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] - 
     5*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     12*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv] - 
     12*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     7*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     11*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] + 
     3*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 1, 1}, yw] - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw] + 
     7*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     7*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] - 
     7*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] - 
     7*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     3*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     7*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     15*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     15*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] + 
     3*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1}, yw] - 3*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] + 
     G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] - 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     3*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     5*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] - 
     7*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), yu^(-1), 1, 1}, yw] - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     7*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw] + 
     7*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] - 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     5*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] + 
     11*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] - 
     3*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     7*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + 
     3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     7*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     15*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     15*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] + 
     7*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     7*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, 1}, yw] + 3*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] + 3*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] - 
     3*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] + 
     11*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     11*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     7*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     3*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] - 
     7*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     11*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     3*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     3*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     7*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] - 
     11*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     14*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     11*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     11*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] - 
     7*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     11*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] - 
     11*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     7*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     15*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     15*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1, 1, 1, yu^(-1)}, yv] + 2*G[{1, 1, 1, 1, yu^(-1)}, yw] + 
     2*G[{1, 1, 1, 1, yv^(-1)}, yw] - 24*G[{1, 1, 1, yu^(-1), yu^(-1)}, yv] - 
     24*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     12*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     24*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     48*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     7*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     5*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     25*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     25*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     10*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     15*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     6*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     5*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     7*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     6*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     13*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     25*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     10*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     12*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     2*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     6*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     10*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     10*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     28*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     14*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] + 
     14*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     5*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     7*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     7*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     15*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     5*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     7*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     11*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     7*G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     14*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     7*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     7*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     7*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     15*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     7*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     11*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     18*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     7*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     19*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     19*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     14*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     7*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     26*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     9*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     18*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     7*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     19*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     14*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     26*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     24*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     18*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (11*Pi^2*Zeta[3])/6 + 4*G[{0}, yu]*G[{1}, yu]*Zeta[3] + 
     G[{1}, yu]^2*Zeta[3] + 4*G[{0}, yv]*G[{1}, yv]*Zeta[3] + 
     6*G[{1}, yu]*G[{1}, yv]*Zeta[3] + G[{1}, yv]^2*Zeta[3] + 
     4*G[{0}, yw]*G[{1}, yw]*Zeta[3] + 6*G[{1}, yu]*G[{1}, yw]*Zeta[3] + 
     6*G[{1}, yv]*G[{1}, yw]*Zeta[3] + G[{1}, yw]^2*Zeta[3] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*Zeta[3] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      Zeta[3] - 8*G[{1}, yu]*G[{yu^(-1)}, yv]*Zeta[3] - 
     8*G[{1}, yv]*G[{yu^(-1)}, yv]*Zeta[3] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      Zeta[3] + 8*G[{yu^(-1)}, yv]^2*Zeta[3] - 4*G[{0}, yu]*G[{yu^(-1)}, yw]*
      Zeta[3] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*Zeta[3] - 
     8*G[{1}, yu]*G[{yu^(-1)}, yw]*Zeta[3] - 12*G[{1}, yv]*G[{yu^(-1)}, yw]*
      Zeta[3] - 8*G[{1}, yw]*G[{yu^(-1)}, yw]*Zeta[3] + 
     12*G[{yu^(-1)}, yv]*G[{yu^(-1)}, yw]*Zeta[3] + 
     8*G[{yu^(-1)}, yw]^2*Zeta[3] - 4*G[{0}, yv]*G[{yv^(-1)}, yw]*Zeta[3] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*Zeta[3] - 12*G[{1}, yu]*G[{yv^(-1)}, yw]*
      Zeta[3] - 8*G[{1}, yv]*G[{yv^(-1)}, yw]*Zeta[3] - 
     8*G[{1}, yw]*G[{yv^(-1)}, yw]*Zeta[3] + 12*G[{yu^(-1)}, yv]*
      G[{yv^(-1)}, yw]*Zeta[3] + 12*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      Zeta[3] + 8*G[{yv^(-1)}, yw]^2*Zeta[3] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     14*G[{1}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     14*G[{1}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     14*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 20*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 20*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      Zeta[3] - 20*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     9*G[{1/(yu*yv)}, yw]^2*Zeta[3] - 4*G[{0, 1}, yu]*Zeta[3] - 
     4*G[{0, 1}, yv]*Zeta[3] - 4*G[{0, 1}, yw]*Zeta[3] + 
     4*G[{0, yu^(-1)}, yv]*Zeta[3] + 4*G[{0, yu^(-1)}, yw]*Zeta[3] + 
     4*G[{0, yv^(-1)}, yw]*Zeta[3] - 4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 
     8*G[{1, 1/(yu*yv)}, yw]*Zeta[3] + 8*G[{yu^(-1), 1/(yu*yv)}, yw]*
      Zeta[3] + 8*G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3] + (13*Zeta[5])/2
 
GuvwRegI = (23*Pi^4*G[{0}, yu])/360 + (23*Pi^4*G[{0}, yv])/360 + 
     (23*Pi^4*G[{0}, yw])/360 + (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw])/2 - 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/2 + (Pi^2*G[{0}, yv]*G[{0, 1}, yu])/2 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1}, yu] + (G[{0}, yu]*G[{0, 1}, yu]^2)/2 + 
     (G[{0}, yv]*G[{0, 1}, yu]^2)/2 + (G[{0}, yw]*G[{0, 1}, yu]^2)/2 + 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yv])/2 - (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/2 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yv] - G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yv] - G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] + 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + (G[{0}, yu]*G[{0, 1}, yv]^2)/
      2 + (G[{0}, yv]*G[{0, 1}, yv]^2)/2 + (G[{0}, yw]*G[{0, 1}, yv]^2)/2 + 
     G[{1}, yu]*G[{0, 1}, yv]^2 + (Pi^2*G[{0}, yu]*G[{0, 1}, yw])/2 + 
     (Pi^2*G[{0}, yv]*G[{0, 1}, yw])/2 - (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1}, yw] - G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yw] - 
     G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yw] - Pi^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     (4*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 - G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yw] + G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yu]*G[{0, 1}, yw] + G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] - G[{0}, yw]*G[{0, 1}, yv]*
      G[{0, 1}, yw] - 2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     (G[{0}, yu]*G[{0, 1}, yw]^2)/2 + (G[{0}, yv]*G[{0, 1}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, 1}, yw]^2)/2 + G[{1}, yu]*G[{0, 1}, yw]^2 + 
     G[{1}, yv]*G[{0, 1}, yw]^2 - G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2 + 
     (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/2 + 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/2 - 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]^2)/2 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]^2)/2 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]^2)/2 + 
     G[{1}, yu]*G[{0, yu^(-1)}, yv]^2 + (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/
      2 - (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] + G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] + 
     Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + 
     G[{1}, yu]*G[{0, yu^(-1)}, yw]^2 - (Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/
      2 + (Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, yv^(-1)}, yw] + Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + 
     G[{1}, yv]*G[{0, yv^(-1)}, yw]^2 - 
     (Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] - Pi^2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     (4*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{0}, yu]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     Pi^2*G[{0, 0, 1}, yu] + 2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{0, 1}, yu]*G[{0, 0, 1}, yu] + 2*G[{0, 1}, yv]*G[{0, 0, 1}, yu] + 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yu] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yu] + 2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] + Pi^2*G[{0, 0, 1}, yv] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1}, yv] + 2*G[{0, 1}, yu]*G[{0, 0, 1}, yv] - 
     2*G[{0, 1}, yv]*G[{0, 0, 1}, yv] + 2*G[{0, 1}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yv] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yv] + 2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + Pi^2*G[{0, 0, 1}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 0, 1}, yw] + 2*G[{0, 1}, yv]*G[{0, 0, 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] + 2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - Pi^2*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv] + 2*G[{0, 1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     Pi^2*G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     Pi^2*G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0, 1}, yu]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 0, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     Pi^2*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + Pi^2*G[{0, 1, 1}, yu] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{0, 1}, yu]*G[{0, 1, 1}, yu] + 
     Pi^2*G[{0, 1, 1}, yv] - 2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yv] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yv] - 2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yu]^2*G[{0, 1, 1}, yv] + 2*G[{0, 1}, yu]*G[{0, 1, 1}, yv] + 
     2*G[{0, 1}, yv]*G[{0, 1, 1}, yv] + Pi^2*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1}, yw] - 2*G[{1}, yu]^2*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1, 1}, yw] + 2*G[{0, 1}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv] + 2*G[{0, 1}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     Pi^2*G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 2*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     Pi^2*G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - Pi^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0, 1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     Pi^2*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{1, 1, yu^(-1)}, yv] - 2*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 0, 1, 1}, yu] + 2*G[{0}, yv]*G[{0, 0, 1, 1}, yu] + 
     2*G[{0}, yw]*G[{0, 0, 1, 1}, yu] + 2*G[{0}, yu]*G[{0, 0, 1, 1}, yv] - 
     2*G[{0}, yv]*G[{0, 0, 1, 1}, yv] + 2*G[{0}, yw]*G[{0, 0, 1, 1}, yv] + 
     2*G[{0}, yu]*G[{0, 0, 1, 1}, yw] + 2*G[{0}, yv]*G[{0, 0, 1, 1}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1}, yw] - 2*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     2*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yw] - 2*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] - 2*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] - 2*G[{0}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{0, 1, 1, 1}, yu] - 
     6*G[{0}, yv]*G[{0, 1, 1, 1}, yv] - 6*G[{1}, yu]*G[{0, 1, 1, 1}, yv] - 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 6*G[{1}, yu]*G[{0, 1, 1, 1}, yw] - 
     6*G[{1}, yv]*G[{0, 1, 1, 1}, yw] + 4*G[{0}, yu]*
      G[{0, 1, 1, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] + 
     2*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1), 1}, yw] - 2*G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, 
       yw] - 2*G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{1}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*
      G[{0, yu^(-1), 1, 1}, yv] + 2*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yu] + 12*G[{0, 0, 0, 1, 1}, yv] + 
     12*G[{0, 0, 0, 1, 1}, yw] - 12*G[{0, 0, 0, 1, yu^(-1)}, yv] - 
     12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 12*G[{0, 0, 0, 1, yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 12*G[{0, 0, 0, yu^(-1), 1}, yv] - 
     12*G[{0, 0, 0, yu^(-1), 1}, yw] + 12*G[{0, 0, 0, yu^(-1), yu^(-1)}, 
       yv] + 12*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] + 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] - 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 0, 1, 0, 1}, yu] + 
     4*G[{0, 0, 1, 0, 1}, yv] + 4*G[{0, 0, 1, 0, 1}, yw] - 
     4*G[{0, 0, 1, 0, yu^(-1)}, yv] - 4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 
     4*G[{0, 0, 1, 0, yv^(-1)}, yw] + 4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1, 1, yu^(-1)}, yv] - 8*G[{0, 0, 1, 1, yu^(-1)}, yw] - 
     8*G[{0, 0, 1, 1, yv^(-1)}, yw] + 4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), 1}, yv] - 4*G[{0, 0, 1, yu^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), 1}, yw] - 4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, yu^(-1), 0, 1}, yv] - 
     4*G[{0, 0, yu^(-1), 0, 1}, yw] + 4*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv] + 
     4*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1}, yv] - 4*G[{0, 0, yu^(-1), 1, 1}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1}, yw] + 4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1}, yw] + 4*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 0, 1, 1}, yu] - 2*G[{0, 1, 0, 1, 1}, yv] - 
     2*G[{0, 1, 0, 1, 1}, yw] - 4*G[{0, 1, 0, 1, yu^(-1)}, yv] - 
     4*G[{0, 1, 0, 1, yu^(-1)}, yw] - 4*G[{0, 1, 0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1, 0, yu^(-1), 1}, yv] - 
     2*G[{0, 1, 0, yu^(-1), 1}, yw] - 2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, yv^(-1), 1}, yw] - 2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 0, yu^(-1)}, yv] - 2*G[{0, 1, 1, 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1, 0, yv^(-1)}, yw] + 2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1, 1, yu^(-1)}, yv] + 6*G[{0, 1, 1, 1, yu^(-1)}, yw] + 
     6*G[{0, 1, 1, 1, yv^(-1)}, yw] + 6*G[{0, 1, 1, yu^(-1), 1}, yv] + 
     6*G[{0, 1, 1, yu^(-1), 1}, yw] - 8*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 6*G[{0, 1, 1, yv^(-1), 1}, yw] - 
     6*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 4*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 4*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1}, yv] + 4*G[{0, 1, yu^(-1), 1, 1}, yw] - 
     4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1}, yw] - 4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 2*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 2*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yu^(-1)}, yv] - 
     2*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1}, yv] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1}, yv] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*Zeta[3] + 2*G[{0}, yu]*G[{0}, yw]*Zeta[3] + 
     2*G[{0}, yv]*G[{0}, yw]*Zeta[3] + 2*G[{0, 1}, yu]*Zeta[3] + 
     2*G[{0, 1}, yv]*Zeta[3] + 2*G[{0, 1}, yw]*Zeta[3] + 
     2*G[{0, yu^(-1)}, yv]*Zeta[3] + 2*G[{0, yu^(-1)}, yw]*Zeta[3] + 
     2*G[{0, yv^(-1)}, yw]*Zeta[3] - 6*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 
     9*Zeta[5]
 
H1uvwRegI = (Pi^4*G[{0}, yu])/18 + (7*Pi^4*G[{0}, yv])/120 + 
     (Pi^2*G[{0}, yu]^2*G[{0}, yv])/12 + (Pi^4*G[{0}, yw])/18 + 
     (Pi^2*G[{0}, yu]^2*G[{0}, yw])/12 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw])/6 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw]^2)/12 + (Pi^2*G[{0}, yv]*G[{0}, yw]^2)/12 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]^2)/4 + 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/12 + (G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*
       G[{1}, yu])/2 - (Pi^2*G[{0}, yw]^2*G[{1}, yu])/12 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu])/2 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/12 - (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/12 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/12 - (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
       G[{1}, yu]^2)/2 - (Pi^2*G[{0}, yu]^2*G[{1}, yw])/12 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw])/2 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/12 + (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*
       G[{1}, yw])/2 + (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yu]*G[{1}, yw] - (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/12 - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/12 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/12 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2)/2 + 
     (Pi^2*G[{0}, yv]*G[{0, 1}, yu])/6 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1}, yu] + (G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yu])/2 - 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/6 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yu])/2 + G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1}, yu] - (G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yu])/2 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu])/2 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu])/6 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yu] + (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu])/2 + 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yv])/6 - (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/6 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv])/6 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1}, yv] + (G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yv])/2 + 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yv])/6 + G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1}, yv] - G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yv] - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, 1}, yv] - G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yv] + (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv])/2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv])/2 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/2 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv])/2 - G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yv] - G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] + 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + G[{1}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yv] - G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + 
     (G[{0}, yv]*G[{0, 1}, yv]^2)/2 + (G[{1}, yu]*G[{0, 1}, yv]^2)/2 + 
     (Pi^2*G[{0}, yv]*G[{0, 1}, yw])/6 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, 1}, yw])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1}, yw] + (G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yw])/2 + 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yw])/6 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yw])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, 1}, yw] - G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1}, yw] + G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yw])/2 - G[{0}, yu]*G[{1}, yu]^2*
      G[{0, 1}, yw] + (G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yw])/2 + 
     G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yw] + (G[{1}, yu]^3*G[{0, 1}, yw])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/6 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yw])/2 + G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yw] - (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw])/2 - G[{0}, yv]*G[{1}, yv]*
      G[{1}, yw]*G[{0, 1}, yw] - G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yw] - (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/6 - 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/2 - 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 + G[{0}, yv]*G[{0, 1}, yv]*
      G[{0, 1}, yw] + G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] + G[{yu^(-1)}, yv]*G[{0, 1}, yv]*
      G[{0, 1}, yw] - (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/6 - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 
     G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yv]^2)/2 + 
     (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/3 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/6 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] - 
     (G[{1}, yu]^3*G[{0, yu^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/3 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/2 + 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{1}, yv]^3*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + 
     G[{1}, yu]*G[{0, yu^(-1)}, yw]^2 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/
      2 + (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/6 + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - G[{1}, yw]*G[{0, 1}, yv]*
      G[{0, yv^(-1)}, yw] + G[{1}, yw]*G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1)}, yw] - (Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/6 - G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + G[{0}, yv]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yv] + G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     (Pi^2*G[{0, 0, 1}, yu])/6 + (G[{0}, yu]^2*G[{0, 0, 1}, yu])/2 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yu] - G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1}, yu] + 2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yu] + 
     (G[{0}, yw]^2*G[{0, 0, 1}, yu])/2 + G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yu] + G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu] - 
     G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yu] - G[{1}, yu]^2*G[{0, 0, 1}, yu] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu] - G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yu] + G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yu] - 
     G[{1}, yw]^2*G[{0, 0, 1}, yu] + G[{0, 1}, yv]*G[{0, 0, 1}, yu] + 
     G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] + (Pi^2*G[{0, 0, 1}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv] - 
     G[{1}, yw]^2*G[{0, 0, 1}, yv] + 2*G[{0, 1}, yu]*G[{0, 0, 1}, yv] - 
     2*G[{0, 1}, yv]*G[{0, 0, 1}, yv] - 2*G[{0, 1}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + (Pi^2*G[{0, 0, 1}, yw])/6 + 
     (G[{0}, yu]^2*G[{0, 0, 1}, yw])/2 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1}, yw] - G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yw] + 
     (G[{0}, yw]^2*G[{0, 0, 1}, yw])/2 + G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yw] - 
     (3*G[{1}, yu]^2*G[{0, 0, 1}, yw])/2 + G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yw] + G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw] + G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw] - 
     G[{1}, yw]^2*G[{0, 0, 1}, yw] - 3*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] - 3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] + 
     3*G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yw] - G[{0, 1}, yv]*G[{0, 0, 1}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yw] + G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yw] - G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv] + 2*G[{0, 1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - (Pi^2*G[{0, 0, yu^(-1)}, yw])/3 - 
     (G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yw])/2 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yw] - (G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yw])/2 - 3*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 3*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] - G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw] + G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] - G[{0, 1}, yu]*
      G[{0, 0, yu^(-1)}, yw] - G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/6 - (G[{0}, yu]^2*G[{0, 0, yv^(-1)}, yw])/
      2 + G[{0}, yu]*G[{0}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw])/2 + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - G[{0}, yv]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw])/2 - G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yv^(-1)}, yw] - G[{1}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] + G[{0, 1}, yv]*
      G[{0, 0, yv^(-1)}, yw] - G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + G[{1, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 3*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + (G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 + 3*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 3*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yv]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{1, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1, 1}, yu])/3 + G[{0}, yu]^2*G[{0, 1, 1}, yu] - 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1}, yu] + G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yu] + 
     G[{0}, yw]^2*G[{0, 1, 1}, yu] + G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yu] - 
     G[{1}, yu]^2*G[{0, 1, 1}, yu] - G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu] - 
     G[{1}, yw]^2*G[{0, 1, 1}, yu] - G[{0, 1}, yv]*G[{0, 1, 1}, yu] - 
     G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + (Pi^2*G[{0, 1, 1}, yv])/3 + 
     (G[{0}, yu]^2*G[{0, 1, 1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1}, yv] + 2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yv] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yv] + (G[{0}, yw]^2*G[{0, 1, 1}, yv])/
      2 - G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv] - 
     (G[{1}, yu]^2*G[{0, 1, 1}, yv])/2 - G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1}, yv] + G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv] + 
     G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] - G[{1}, yw]^2*G[{0, 1, 1}, yv] + 
     G[{0, 1}, yu]*G[{0, 1, 1}, yv] + (Pi^2*G[{0, 1, 1}, yw])/3 + 
     G[{0}, yu]^2*G[{0, 1, 1}, yw] + G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw] - G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yw] + G[{0}, yw]^2*G[{0, 1, 1}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yw] - G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, 1}, yw] + G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yw] + G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw] - G[{1}, yw]^2*G[{0, 1, 1}, yw] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     3*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1, 1}, yw] + 2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     (Pi^2*G[{0, 1, yu^(-1)}, yv])/6 - (G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yv])/
      2 - G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv])/2 + G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] + (G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yv] - 2*G[{0, 1}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/6 - (G[{0}, yu]^2*G[{0, 1, yv^(-1)}, yw])/
      2 + G[{0}, yu]*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/2 + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] - G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw])/2 - G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0, 1}, yv]*G[{0, 1, yv^(-1)}, yw] - G[{0, yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yv] - G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] - 
     G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] - 
     G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] - G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] - G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] + 2*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     (2*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 - 
     G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] - G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yv]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{0, 1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{0, 1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{1, yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{0, yv^(-1), 1}, yw])/6 - 
     (G[{0}, yu]^2*G[{0, yv^(-1), 1}, yw])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1), 1}, yw] + G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw])/2 + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), 1}, yw] - G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     (3*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw])/2 - G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] - G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     G[{0, 1}, yv]*G[{0, yv^(-1), 1}, yw] - G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/6 - 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/2 - G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw] - G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + (2*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + 
     G[{0}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      6 + (G[{0}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] - 2*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     3*G[{0}, yu]*G[{0, 0, 0, 1}, yu] + 3*G[{0}, yv]*G[{0, 0, 0, 1}, yu] + 
     3*G[{0}, yw]*G[{0, 0, 0, 1}, yu] + 3*G[{0}, yu]*G[{0, 0, 0, 1}, yw] + 
     3*G[{0}, yv]*G[{0, 0, 0, 1}, yw] - 3*G[{0}, yw]*G[{0, 0, 0, 1}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{0, 0, 0, 1}, yw] + 
     3*G[{0}, yu]*G[{0, 0, 0, yu^(-1)}, yw] - 
     3*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, 0, 0, yu^(-1)}, yw] - 
     3*G[{0}, yu]*G[{0, 0, 0, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{0, 0, 0, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 0, 0, yv^(-1)}, yw] - 
     3*G[{0}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0, 0, 1, 1}, yu] + 
     G[{0}, yv]*G[{0, 0, 1, 1}, yu] + 4*G[{0}, yw]*G[{0, 0, 1, 1}, yu] + 
     2*G[{1}, yu]*G[{0, 0, 1, 1}, yu] - 2*G[{1}, yw]*G[{0, 0, 1, 1}, yu] + 
     2*G[{0}, yu]*G[{0, 0, 1, 1}, yv] - 2*G[{0}, yv]*G[{0, 0, 1, 1}, yv] + 
     2*G[{0}, yw]*G[{0, 0, 1, 1}, yv] + 4*G[{0}, yu]*G[{0, 0, 1, 1}, yw] + 
     G[{0}, yv]*G[{0, 0, 1, 1}, yw] - 4*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 
     3*G[{1}, yu]*G[{0, 0, 1, 1}, yw] + 2*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yw] + 
     2*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 0, 1, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw] + 
     G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw] + 2*G[{0}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] + 3*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yw] - 2*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] + 2*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw] + 2*G[{0}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] + G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     3*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] - G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] - 2*G[{0}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, 
       yw] + 2*G[{0}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     3*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 5*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yv] - 
     G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 1, 0, yu^(-1)}, yw] - G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{0, 1, 1, 1}, yu] + 3*G[{0}, yw]*G[{0, 1, 1, 1}, yu] + 
     3*G[{1}, yu]*G[{0, 1, 1, 1}, yu] - 3*G[{1}, yw]*G[{0, 1, 1, 1}, yu] + 
     3*G[{0}, yu]*G[{0, 1, 1, 1}, yv] - 2*G[{0}, yv]*G[{0, 1, 1, 1}, yv] + 
     3*G[{0}, yw]*G[{0, 1, 1, 1}, yv] + G[{1}, yu]*G[{0, 1, 1, 1}, yv] + 
     3*G[{0}, yu]*G[{0, 1, 1, 1}, yw] - 3*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 
     3*G[{1}, yu]*G[{0, 1, 1, 1}, yw] + 3*G[{1}, yw]*G[{0, 1, 1, 1}, yw] - 
     3*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw] + 
     G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{1}, yu]*
      G[{0, 1, 1, yv^(-1)}, yw] - G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] - 
     G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 2*G[{0}, yu]*
      G[{0, 1, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yv]*
      G[{0, 1, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yv] + 2*G[{1}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yv] + G[{0}, yu]*G[{0, 1, yv^(-1), 1}, 
       yw] - G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] - G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1), 1}, yw] - 2*G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, 
       yw] + 2*G[{0}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, 
       yw] - G[{0}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] + G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1}, yw] + G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] + G[{0}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yv^(-1), 1, 1}, yw] + 
     G[{0}, yv]*G[{0, yv^(-1), 1, 1}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, 
       yw] + 2*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, 
       yw] - G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0, 0, 0, 0, 1}, yu] + 6*G[{0, 0, 0, 0, 1}, yw] - 
     6*G[{0, 0, 0, 0, yu^(-1)}, yw] - 6*G[{0, 0, 0, 0, yv^(-1)}, yw] + 
     6*G[{0, 0, 0, 0, 1/(yu*yv)}, yw] + 6*G[{0, 0, 0, 1, 1}, yu] + 
     12*G[{0, 0, 0, 1, 1}, yv] + 6*G[{0, 0, 0, 1, 1}, yw] - 
     6*G[{0, 0, 0, 1, yu^(-1)}, yv] - 3*G[{0, 0, 0, 1, yu^(-1)}, yw] + 
     3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 6*G[{0, 0, 0, yu^(-1), 1}, yv] - 
     3*G[{0, 0, 0, yu^(-1), 1}, yw] + 3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, 
       yw] + 6*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 0, 1}, yv] - 2*G[{0, 0, 1, 0, yu^(-1)}, yv] - 
     G[{0, 0, 1, 0, yu^(-1)}, yw] + G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 
     3*G[{0, 0, 1, 1, 1}, yu] + 4*G[{0, 0, 1, 1, 1}, yv] + 
     3*G[{0, 0, 1, 1, 1}, yw] - 6*G[{0, 0, 1, 1, yu^(-1)}, yv] + 
     2*G[{0, 0, 1, 1, yu^(-1)}, yw] + 3*G[{0, 0, 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 0, 1, yu^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 1, yv^(-1), 1}, yw] - 4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - G[{0, 0, 1, 1/(yu*yv), 1}, 
      yw] + G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, yu^(-1), 0, 1}, yv] - G[{0, 0, yu^(-1), 0, 1}, yw] + 
     2*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] + G[{0, 0, yu^(-1), 0, yv^(-1)}, 
      yw] - 2*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0, 0, yu^(-1), 1, 1}, yw] - 3*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] - 
     12*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] - G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, 
      yw] + 3*G[{0, 0, yv^(-1), 1, 1}, yw] - 
     3*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     3*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 2*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     7*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 3*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, 
       yw] + 4*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, 1, 0, 1, yu^(-1)}, yv] + G[{0, 1, 0, 1, yu^(-1)}, yw] - 
     G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + G[{0, 1, 0, yu^(-1), 1}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, 
      yw] - 2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0, 1, 1, 0, yu^(-1)}, yw] - 
     G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 6*G[{0, 1, 1, 1, 1}, yv] - 
     G[{0, 1, 1, 1, yu^(-1)}, yv] + 3*G[{0, 1, 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] + G[{0, 1, 1, yv^(-1), 1}, yw] + 
     2*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, 
       yw] - G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + G[{0, 1, yu^(-1), 1, yu^(-1)}, 
      yv] - 4*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + G[{0, 1, yv^(-1), 1, 1}, yw] + 
     G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] - G[{0, yu^(-1), 1, 1, yv^(-1)}, 
      yw] - G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 3*G[{0, yv^(-1), 1, 1, 1}, yw] + 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 2*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, 
       yw] - G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     3*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     (G[{0}, yu]^2*Zeta[3])/2 + G[{0}, yu]*G[{0}, yv]*Zeta[3] + 
     G[{0}, yv]*G[{0}, yw]*Zeta[3] - (G[{0}, yw]^2*Zeta[3])/2 + 
     G[{0}, yu]*G[{1}, yu]*Zeta[3] - G[{0}, yw]*G[{1}, yu]*Zeta[3] - 
     G[{0}, yu]*G[{1}, yw]*Zeta[3] + G[{0}, yw]*G[{1}, yw]*Zeta[3] - 
     2*G[{0, 1}, yu]*Zeta[3] + 2*G[{0, 1}, yv]*Zeta[3] - 
     2*G[{0, 1}, yw]*Zeta[3] + 4*G[{0, yu^(-1)}, yw]*Zeta[3] - 
     2*G[{0, 1/(yu*yv)}, yw]*Zeta[3]
 
H1vwuRegI = (Pi^4*G[{0}, yu])/18 + (Pi^4*G[{0}, yv])/18 + 
     (Pi^2*G[{0}, yu]^2*G[{0}, yv])/12 + (Pi^2*G[{0}, yu]*G[{0}, yv]^2)/12 + 
     (7*Pi^4*G[{0}, yw])/120 + (Pi^2*G[{0}, yu]^2*G[{0}, yw])/12 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw])/6 + 
     (Pi^2*G[{0}, yv]^2*G[{0}, yw])/12 + 
     (G[{0}, yu]^2*G[{0}, yv]^2*G[{0}, yw])/4 + 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/12 - (Pi^2*G[{0}, yv]^2*G[{1}, yu])/12 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu])/2 - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/12 - (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/12 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/12 - (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
       G[{1}, yu]^2)/2 - (Pi^2*G[{0}, yu]^2*G[{1}, yv])/12 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/12 - (G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*
       G[{1}, yv])/2 + (G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv])/2 + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv])/6 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yu]*G[{1}, yv] - (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/12 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/12 - (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/12 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2)/2 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu])/6 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1}, yu] + (G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yu])/2 - 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/6 - 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yu])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, 1}, yu] - (G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yu])/2 + 
     (G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu])/2 + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yu])/6 + 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1}, yu] + (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu])/2 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv])/6 + 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1}, yv] + (G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yv])/2 + 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yv])/6 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, 1}, yv] + (G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yv])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yv] + (G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yv])/2 + 
     (G[{1}, yu]^3*G[{0, 1}, yv])/2 - (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/6 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yv])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1}, yv] - (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yv])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] - 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv])/2 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/2 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv])/2 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yv])/2 + 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yw])/6 + (Pi^2*G[{0}, yv]*G[{0, 1}, yw])/6 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, 1}, yw])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yw])/2 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1}, yw] + (Pi^2*G[{1}, yu]*G[{0, 1}, yw])/6 + 
     G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yw] - G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1}, yw] - G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw] + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yw])/6 - G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1}, yw] + G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] + 
     G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yw] - G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yw] - G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/3 - 
     G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] - G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] - G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw] + G[{0}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yw] - G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw] - G[{1}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw] - G[{0}, yv]*G[{0, 1}, yv]*
      G[{0, 1}, yw] - G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw] + G[{1}, yv]*G[{0, 1}, yv]*
      G[{0, 1}, yw] - 2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     (G[{0}, yw]*G[{0, 1}, yw]^2)/2 + (G[{1}, yu]*G[{0, 1}, yw]^2)/2 + 
     (G[{1}, yv]*G[{0, 1}, yw]^2)/2 + (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/
      6 + (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/6 + 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/2 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, yu^(-1)}, yv])/2 - 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/3 - 
     (G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/2 + 
     (G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] - 
     (G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv])/2 - 
     (G[{1}, yu]^3*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/2 + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     (G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     (G[{0}, yu]*G[{0, yu^(-1)}, yv]^2)/2 + 
     (G[{0}, yv]*G[{0, yu^(-1)}, yv]^2)/2 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yv]^2)/2 + 
     G[{1}, yu]*G[{0, yu^(-1)}, yv]^2 - (G[{1}, yv]*G[{0, yu^(-1)}, yv]^2)/
      2 - (Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu]^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/6 - G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - G[{0}, yv]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 
     G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 2*G[{0}, yu]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     (Pi^2*G[{0, 0, 1}, yu])/6 + (G[{0}, yu]^2*G[{0, 0, 1}, yu])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yu] + (G[{0}, yv]^2*G[{0, 0, 1}, yu])/
      2 - 2*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yu] + G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yu] - G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yu] - G[{1}, yu]^2*G[{0, 0, 1}, yu] - 
     G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu] + G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yu] - G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu] - 
     G[{1}, yv]^2*G[{0, 0, 1}, yu] + G[{0, 1}, yw]*G[{0, 0, 1}, yu] + 
     G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yu] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] + (Pi^2*G[{0, 0, 1}, yv])/6 + 
     (G[{0}, yu]^2*G[{0, 0, 1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1}, yv] + (G[{0}, yv]^2*G[{0, 0, 1}, yv])/2 + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yv] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, 1}, yv] + G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yv] - 
     G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, 1}, yv] - (3*G[{1}, yu]^2*G[{0, 0, 1}, yv])/2 - 
     G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv] + G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yv] + G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv] - 
     G[{1}, yv]^2*G[{0, 0, 1}, yv] + G[{0, 1}, yw]*G[{0, 0, 1}, yv] + 
     G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yv] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] + (Pi^2*G[{0, 0, 1}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 0, 1}, yw] + 2*G[{0, 1}, yv]*G[{0, 0, 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     (Pi^2*G[{0, 0, yu^(-1)}, yv])/3 - (G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yv])/
      2 - 2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     (G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yv])/2 + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yv] - G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     (3*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yv])/2 + G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] - G[{0, 1}, yu]*
      G[{0, 0, yu^(-1)}, yv] - G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1, 1}, yu])/3 + G[{0}, yu]^2*G[{0, 1, 1}, yu] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu] + 
     G[{0}, yv]^2*G[{0, 1, 1}, yu] - G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yu] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yu] + G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1}, yu] - G[{1}, yu]^2*G[{0, 1, 1}, yu] - 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yu] + 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yu] - G[{1}, yv]^2*G[{0, 1, 1}, yu] - 
     G[{0, 1}, yw]*G[{0, 1, 1}, yu] - G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + (Pi^2*G[{0, 1, 1}, yv])/3 + 
     G[{0}, yu]^2*G[{0, 1, 1}, yv] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1}, yv] + G[{0}, yv]^2*G[{0, 1, 1}, yv] + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yv] - G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yv] - G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv] + 
     G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv] - G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1}, yv] + G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yv] + 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv] - G[{1}, yv]^2*G[{0, 1, 1}, yv] - 
     G[{0, 1}, yw]*G[{0, 1, 1}, yv] - G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + (Pi^2*G[{0, 1, 1}, yw])/3 + 
     (G[{0}, yu]^2*G[{0, 1, 1}, yw])/2 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1}, yw] + (G[{0}, yv]^2*G[{0, 1, 1}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw] - G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yw] - G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw] - 
     (G[{1}, yu]^2*G[{0, 1, 1}, yw])/2 - G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1}, yw] - G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw] - 
     (G[{1}, yv]^2*G[{0, 1, 1}, yw])/2 - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw] + G[{0, 1}, yu]*G[{0, 1, 1}, yw] + 
     G[{0, 1}, yv]*G[{0, 1, 1}, yw] - G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yv] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - (Pi^2*G[{0, 1, yu^(-1)}, yw])/6 - 
     (G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yw])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yw] - (G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     (G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw])/2 - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     (3*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw])/2 + 
     G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - (Pi^2*G[{0, 1, yv^(-1)}, yw])/6 - 
     (G[{0}, yu]^2*G[{0, 1, yv^(-1)}, yw])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yv^(-1)}, yw] - (G[{0}, yv]^2*G[{0, 1, yv^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     (3*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw])/2 + G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] + G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     (G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw])/2 + 
     G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + (G[{0}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw])/2 + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + (3*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw])/
      2 + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + G[{0, 1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] + G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yv] - 
     G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] - G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yv] - G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + 
     G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yv] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - (2*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/3 - 
     G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yv] - G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] + G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 - 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/2 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + (G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/6 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (3*G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 - 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/6 + 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (3*G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{0, 0, 0, 1}, yu] + 3*G[{0}, yv]*G[{0, 0, 0, 1}, yu] + 
     3*G[{0}, yw]*G[{0, 0, 0, 1}, yu] + 3*G[{0}, yu]*G[{0, 0, 0, 1}, yv] - 
     3*G[{0}, yv]*G[{0, 0, 0, 1}, yv] + 3*G[{0}, yw]*G[{0, 0, 0, 1}, yv] + 
     3*G[{0}, yu]*G[{0, 0, 0, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 0, 1, 1}, yu] + 4*G[{0}, yv]*G[{0, 0, 1, 1}, yu] + 
     G[{0}, yw]*G[{0, 0, 1, 1}, yu] + 2*G[{1}, yu]*G[{0, 0, 1, 1}, yu] - 
     2*G[{1}, yv]*G[{0, 0, 1, 1}, yu] + 4*G[{0}, yu]*G[{0, 0, 1, 1}, yv] - 
     4*G[{0}, yv]*G[{0, 0, 1, 1}, yv] + G[{0}, yw]*G[{0, 0, 1, 1}, yv] - 
     3*G[{1}, yu]*G[{0, 0, 1, 1}, yv] + 2*G[{1}, yv]*G[{0, 0, 1, 1}, yv] + 
     2*G[{0}, yu]*G[{0, 0, 1, 1}, yw] + 2*G[{0}, yv]*G[{0, 0, 1, 1}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1}, yw] - 2*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv] + 3*G[{1}, yu]*
      G[{0, 0, yu^(-1), 1}, yv] - 2*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yv] + 2*G[{1}, yu]*
      G[{0, 1, 0, yu^(-1)}, yv] - G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 
     G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw] - 
     G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 
     G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{0, 1, 1, 1}, yu] + 3*G[{0}, yv]*G[{0, 1, 1, 1}, yu] + 
     3*G[{1}, yu]*G[{0, 1, 1, 1}, yu] - 3*G[{1}, yv]*G[{0, 1, 1, 1}, yu] + 
     3*G[{0}, yu]*G[{0, 1, 1, 1}, yv] - 3*G[{0}, yv]*G[{0, 1, 1, 1}, yv] - 
     3*G[{1}, yu]*G[{0, 1, 1, 1}, yv] + 3*G[{1}, yv]*G[{0, 1, 1, 1}, yv] + 
     3*G[{0}, yu]*G[{0, 1, 1, 1}, yw] + 3*G[{0}, yv]*G[{0, 1, 1, 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1, 1}, yw] + G[{1}, yu]*G[{0, 1, 1, 1}, yw] + 
     G[{1}, yv]*G[{0, 1, 1, 1}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yw] + G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{1}, yv]*
      G[{0, 1, 1, yu^(-1)}, yw] - G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{1}, yu]*
      G[{0, 1, 1, yv^(-1)}, yw] - G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] - 
     G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 2*G[{0}, yu]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yv]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - G[{0}, yw]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] - 
     G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw] - 2*G[{0}, yu]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - G[{0}, yw]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - G[{0}, yu]*G[{0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + G[{0}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yv] + 
     G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv] + 
     G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] - 
     G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv] - 2*G[{0}, yu]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] + 2*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] + 2*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] - 2*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1), 1}, yv] - G[{0}, yw]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     3*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - G[{0}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + G[{0}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0, 0, 0, 0, 1}, yu] + 6*G[{0, 0, 0, 0, 1}, yv] - 
     6*G[{0, 0, 0, 0, yu^(-1)}, yv] + 6*G[{0, 0, 0, 1, 1}, yu] + 
     6*G[{0, 0, 0, 1, 1}, yv] + 12*G[{0, 0, 0, 1, 1}, yw] - 
     3*G[{0, 0, 0, 1, yu^(-1)}, yv] - 6*G[{0, 0, 0, 1, yu^(-1)}, yw] - 
     6*G[{0, 0, 0, 1, yv^(-1)}, yw] - 3*G[{0, 0, 0, yu^(-1), 1}, yv] - 
     6*G[{0, 0, 0, yu^(-1), 1}, yw] + 6*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, 
       yw] - 6*G[{0, 0, 0, yv^(-1), 1}, yw] + 
     6*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 0, 1, 0, 1}, yw] - 
     G[{0, 0, 1, 0, yu^(-1)}, yv] - 2*G[{0, 0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0, 0, 1, 0, yv^(-1)}, yw] + 3*G[{0, 0, 1, 1, 1}, yu] + 
     3*G[{0, 0, 1, 1, 1}, yv] + 4*G[{0, 0, 1, 1, 1}, yw] + 
     2*G[{0, 0, 1, 1, yu^(-1)}, yv] - 6*G[{0, 0, 1, 1, yu^(-1)}, yw] - 
     6*G[{0, 0, 1, 1, yv^(-1)}, yw] + 2*G[{0, 0, 1, yu^(-1), 1}, yv] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - G[{0, 0, yu^(-1), 0, 1}, yv] - 
     2*G[{0, 0, yu^(-1), 0, 1}, yw] + 2*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv] + 
     2*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + G[{0, 0, yu^(-1), 1, 1}, yv] + 
     2*G[{0, 0, yu^(-1), yu^(-1), 1}, yv] - 
     12*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 0, 1}, yw] + 2*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, 
       yw] + 4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1, 0, 1, yu^(-1)}, yv] - 3*G[{0, 1, 0, 1, yu^(-1)}, yw] - 
     3*G[{0, 1, 0, 1, yv^(-1)}, yw] + G[{0, 1, 0, yu^(-1), 1}, yv] - 
     2*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] - G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, 
      yw] - G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + G[{0, 1, 1, 0, yu^(-1)}, yv] + 
     6*G[{0, 1, 1, 1, 1}, yw] - G[{0, 1, 1, 1, yu^(-1)}, yw] - 
     G[{0, 1, 1, 1, yv^(-1)}, yw] - 2*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
      yw] + G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] - G[{0, 1, yu^(-1), 0, yu^(-1)}, 
      yw] - G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] - 
     G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + G[{0, 1, yu^(-1), 1, yu^(-1)}, 
      yw] + G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - G[{0, 1, yv^(-1), 0, yv^(-1)}, 
      yw] - G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + G[{0, 1, yv^(-1), 1, yv^(-1)}, 
      yw] - 4*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yv] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1, 1}, yw] + G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
      yw] + G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     (G[{0}, yu]^2*Zeta[3])/2 - (G[{0}, yv]^2*Zeta[3])/2 + 
     G[{0}, yu]*G[{0}, yw]*Zeta[3] + G[{0}, yv]*G[{0}, yw]*Zeta[3] + 
     G[{0}, yu]*G[{1}, yu]*Zeta[3] - G[{0}, yv]*G[{1}, yu]*Zeta[3] - 
     G[{0}, yu]*G[{1}, yv]*Zeta[3] + G[{0}, yv]*G[{1}, yv]*Zeta[3] - 
     2*G[{0, 1}, yu]*Zeta[3] - 2*G[{0, 1}, yv]*Zeta[3] + 
     2*G[{0, 1}, yw]*Zeta[3] + 4*G[{0, yu^(-1)}, yv]*Zeta[3] - 
     2*G[{0, 1/(yu*yv)}, yw]*Zeta[3]
 
H1wuvRegI = (7*Pi^4*G[{0}, yu])/120 + (Pi^4*G[{0}, yv])/18 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]^2)/12 + (Pi^4*G[{0}, yw])/18 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw])/6 + 
     (Pi^2*G[{0}, yv]^2*G[{0}, yw])/12 + (Pi^2*G[{0}, yu]*G[{0}, yw]^2)/12 + 
     (Pi^2*G[{0}, yv]*G[{0}, yw]^2)/12 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]^2)/4 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/12 + (G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*
       G[{1}, yv])/2 - (Pi^2*G[{0}, yw]^2*G[{1}, yv])/12 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv])/2 - 
     (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/12 - (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/12 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/12 - (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
       G[{1}, yv]^2)/2 - (Pi^2*G[{0}, yv]^2*G[{1}, yw])/12 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw])/2 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/12 + (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*
       G[{1}, yw])/2 + (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yv]*G[{1}, yw] - (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/12 - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/12 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/12 - 
     (G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2)/2 - 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/6 + (Pi^2*G[{0}, yv]*G[{0, 1}, yu])/6 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu])/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1}, yu] + (G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yu])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1}, yu] + (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yu] - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yu])/2 + 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu])/2 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, 1}, yu] - (G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yu])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu])/2 - G[{0}, yu]*G[{1}, yv]*
      G[{1}, yw]*G[{0, 1}, yu] + G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yu])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu])/2 + (G[{0}, yu]*G[{0, 1}, yu]^2)/
      2 + (Pi^2*G[{0}, yu]*G[{0, 1}, yv])/6 + 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yv])/2 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1}, yv] + (G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yv])/2 - 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/6 - 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yv])/2 + G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]*G[{0, 1}, yv] - (G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yv])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yv])/2 + 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv])/2 - 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yv])/2 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv])/6 + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yv])/2 - G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yv] + (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] + 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv])/2 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv])/2 + G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yv] + G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + (Pi^2*G[{0}, yu]*G[{0, 1}, yw])/
      6 + (G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yw] + 
     (G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yw])/2 + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yw])/6 - G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1}, yw] + (G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yw])/2 + G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yw] + (G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yv]^2*
      G[{0, 1}, yw] + (G[{1}, yv]^3*G[{0, 1}, yw])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/6 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yw])/2 + G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yw] - (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw])/2 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] - (G[{0}, yv]^2*G[{yu^(-1)}, yv]*
       G[{0, 1}, yw])/2 + G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 + G[{0}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yw] - G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] + G[{yu^(-1)}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yw] + (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     (G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     (G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 + 
     (G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, yu^(-1)}, yv] - (G[{0}, yv]^2*G[{1}, yw]*
       G[{0, yu^(-1)}, yv])/2 + G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/2 - 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv])/2 - 
     G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] + (G[{0}, yv]^2*G[{1}, yw]*
       G[{0, yu^(-1)}, yw])/2 + G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - G[{1}, yw]*G[{0, 1}, yu]*
      G[{0, yu^(-1)}, yw] - (Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/6 - 
     (G[{0}, yu]*G[{0}, yv]^2*G[{0, yv^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/6 + 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yu]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{0}, yv]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/3 - G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, yv^(-1)}, yw] + (G[{0}, yv]^2*G[{1}, yu]*
       G[{0, yv^(-1)}, yw])/2 - G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] + (G[{0}, yw]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] + 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw])/2 + 
     G[{1}, yu]^3*G[{0, yv^(-1)}, yw] + G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + (G[{0}, yv]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yw]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - G[{1}, yu]*G[{1}, yv]^2*
      G[{0, yv^(-1)}, yw] - (G[{1}, yv]^3*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - G[{0}, yu]*G[{0, 1}, yv]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yu]*G[{0, yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{0, yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + 
     G[{1}, yv]*G[{0, yv^(-1)}, yw]^2 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/
      2 + (Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/3 + G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/6 - G[{0}, yv]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 - G[{0}, yu]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yv] - G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     (Pi^2*G[{0, 0, 1}, yu])/3 + 2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, 1}, yu] - G[{1}, yv]^2*G[{0, 0, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1}, yu] + 2*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu] - 
     G[{1}, yw]^2*G[{0, 0, 1}, yu] - 2*G[{0, 1}, yu]*G[{0, 0, 1}, yu] - 
     2*G[{0, 1}, yv]*G[{0, 0, 1}, yu] - 2*G[{0, 1}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + (Pi^2*G[{0, 0, 1}, yv])/6 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yv] + 
     (G[{0}, yv]^2*G[{0, 0, 1}, yv])/2 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1}, yv] - G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yv] + 
     (G[{0}, yw]^2*G[{0, 0, 1}, yv])/2 + G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yv] + G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv] + 
     G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv] - G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, 1}, yv] - G[{1}, yv]^2*G[{0, 0, 1}, yv] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv] - G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yv] + G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv] - 
     G[{1}, yw]^2*G[{0, 0, 1}, yv] - G[{0, 1}, yu]*G[{0, 0, 1}, yv] + 
     G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] + (Pi^2*G[{0, 0, 1}, yw])/6 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yw] + 
     (G[{0}, yv]^2*G[{0, 0, 1}, yw])/2 - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1}, yw] - G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yw] + 
     (G[{0}, yw]^2*G[{0, 0, 1}, yw])/2 + G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw] + 
     G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yw] - G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, 1}, yw] - (3*G[{1}, yv]^2*G[{0, 0, 1}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw] - G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw] - 
     G[{1}, yw]^2*G[{0, 0, 1}, yw] - 3*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] - 3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] + 
     3*G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yw] - G[{0, 1}, yu]*G[{0, 0, 1}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     (Pi^2*G[{0, 0, yu^(-1)}, yv])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yu^(-1)}, yv] - (G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yv])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yv])/2 - G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yv] - G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] + G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv] + G[{0, 1}, yu]*
      G[{0, 0, yu^(-1)}, yv] - G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yu^(-1)}, yw] - (G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw])/2 - G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] - G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     (3*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw])/2 - G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] + G[{0, 1}, yu]*
      G[{0, 0, yu^(-1)}, yw] - G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/3 - (G[{0}, yv]^2*G[{0, 0, yv^(-1)}, yw])/
      2 + 2*G[{0}, yu]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw])/2 + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - 3*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - 3*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - 3*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     (3*G[{1}, yv]^2*G[{0, 0, yv^(-1)}, yw])/2 - G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] - G[{0, 1}, yv]*
      G[{0, 0, yv^(-1)}, yw] + G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - G[{1, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 3*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + (G[{0}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 + G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{1, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + (Pi^2*G[{0, 1, 1}, yu])/3 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu] + (G[{0}, yv]^2*G[{0, 1, 1}, yu])/
      2 - G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yu] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yu] + (G[{0}, yw]^2*G[{0, 1, 1}, yu])/2 + 
     G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu] - G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1}, yu] - G[{1}, yv]^2*G[{0, 1, 1}, yu] - 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu] + G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu] - 
     G[{1}, yw]^2*G[{0, 1, 1}, yu] + (Pi^2*G[{0, 1, 1}, yv])/3 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yv] + G[{0}, yv]^2*G[{0, 1, 1}, yv] + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yv] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yv] + G[{0}, yw]^2*G[{0, 1, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv] + G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yv] - G[{1}, yv]^2*G[{0, 1, 1}, yv] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, 1}, yv] - G[{1}, yw]^2*G[{0, 1, 1}, yv] - 
     2*G[{0, 1}, yu]*G[{0, 1, 1}, yv] - G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1}, yv] + G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     (Pi^2*G[{0, 1, 1}, yw])/3 + G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yw] + 
     G[{0}, yv]^2*G[{0, 1, 1}, yw] - G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yw] + 
     G[{0}, yw]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yw] - G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw] + G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1}, yw] + G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] - G[{1}, yw]^2*G[{0, 1, 1}, yw] - 
     3*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     3*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     3*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw] - 2*G[{0, 1}, yu]*
      G[{0, 1, 1}, yw] - G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 2*G[{1, yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] - (Pi^2*G[{0, 1, yu^(-1)}, yv])/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     (G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yv])/2 + G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yv] + G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     (G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv])/2 - G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] + G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - (Pi^2*G[{0, 1, yu^(-1)}, yw])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     (G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw])/2 - G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yw] + G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/2 - G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] - G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     (3*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw])/2 + G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] - G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - (Pi^2*G[{0, yu^(-1), 1}, yv])/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1}, yv] - 
     (G[{0}, yv]^2*G[{0, yu^(-1), 1}, yv])/2 + G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] + G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yv] - 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1}, yv])/2 - G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] - 
     G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] - 
     G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] + 
     G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv] + G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] - G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), 1}, yw] - (G[{0}, yv]^2*G[{0, yu^(-1), 1}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] - 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw])/2 - G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] - G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 
     (3*G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw])/2 - G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] + G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] + 
     G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw] + G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] - G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] + 2*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] - 
     G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw] - G[{0}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), 1}, yw] - G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - (2*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/
      3 - G[{0}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/3 + G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/2 - G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + (G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), 1}, yw] + G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (3*G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (2*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 + 
     G[{0}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (G[{0}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yv] + G[{0, yv^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yv] - 3*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     3*G[{0}, yu]*G[{0, 0, 0, 1}, yv] - 3*G[{0}, yv]*G[{0, 0, 0, 1}, yv] + 
     3*G[{0}, yw]*G[{0, 0, 0, 1}, yv] + 3*G[{0}, yu]*G[{0, 0, 0, 1}, yw] + 
     3*G[{0}, yv]*G[{0, 0, 0, 1}, yw] - 3*G[{0}, yw]*G[{0, 0, 0, 1}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{0, 0, 0, 1}, yw] + 
     3*G[{0}, yu]*G[{0, 0, 0, yu^(-1)}, yv] + 
     3*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yv] - 
     3*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yv] + 
     3*G[{0}, yu]*G[{0, 0, 0, yu^(-1)}, yw] - 
     3*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw] + 
     6*G[{1}, yv]*G[{0, 0, 0, yu^(-1)}, yw] - 
     3*G[{0}, yu]*G[{0, 0, 0, yv^(-1)}, yw] + 
     3*G[{0}, yv]*G[{0, 0, 0, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw] + 
     6*G[{1}, yu]*G[{0, 0, 0, yv^(-1)}, yw] - 
     3*G[{0}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0, 0, 1, 1}, yu] + 
     2*G[{0}, yv]*G[{0, 0, 1, 1}, yu] + 2*G[{0}, yw]*G[{0, 0, 1, 1}, yu] + 
     G[{0}, yu]*G[{0, 0, 1, 1}, yv] - 4*G[{0}, yv]*G[{0, 0, 1, 1}, yv] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yv] + 2*G[{1}, yv]*G[{0, 0, 1, 1}, yv] - 
     2*G[{1}, yw]*G[{0, 0, 1, 1}, yv] + G[{0}, yu]*G[{0, 0, 1, 1}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 1, 1}, yw] - 4*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 
     3*G[{1}, yv]*G[{0, 0, 1, 1}, yw] + 2*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 
     5*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yw] + 
     G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 2*G[{1}, yv]*
      G[{0, 0, 1, yu^(-1)}, yv] + 2*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{1}, yv]*
      G[{0, 0, 1, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv] + 
     G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv] - 
     G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 2*G[{1}, yv]*
      G[{0, 0, yu^(-1), 1}, yv] + 2*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw] - 
     G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 3*G[{1}, yv]*
      G[{0, 0, yu^(-1), 1}, yw] - 2*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw] - 2*G[{0}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] + 2*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     3*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] - 2*G[{0}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     3*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 5*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - G[{0}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + G[{0}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{1}, yv]*
      G[{0, 1, 0, yv^(-1)}, yw] - G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1, 1, 1}, yu] + 3*G[{0}, yv]*G[{0, 1, 1, 1}, yu] + 
     3*G[{0}, yw]*G[{0, 1, 1, 1}, yu] - 3*G[{0}, yv]*G[{0, 1, 1, 1}, yv] + 
     3*G[{0}, yw]*G[{0, 1, 1, 1}, yv] + 3*G[{1}, yv]*G[{0, 1, 1, 1}, yv] - 
     3*G[{1}, yw]*G[{0, 1, 1, 1}, yv] + 3*G[{0}, yv]*G[{0, 1, 1, 1}, yw] - 
     3*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 3*G[{1}, yv]*G[{0, 1, 1, 1}, yw] + 
     3*G[{1}, yw]*G[{0, 1, 1, 1}, yw] - 3*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yw] - G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{1}, yv]*
      G[{0, 1, 1, yu^(-1)}, yw] - G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] + 
     G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw] - 
     G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] - G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yw] + 2*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] + 2*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - G[{0}, yu]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yv] - 
     G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv] + 
     G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yv] - 
     G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv] + 
     G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv] + 
     G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yw] + 
     G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1}, yw] + 2*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] + 2*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     2*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yv^(-1), 1, 1}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] + G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1, 1}, yw] - G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, 
       yw] + G[{0}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     3*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] - G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0, 0, 0, 0, 1}, yv] + 6*G[{0, 0, 0, 0, 1}, yw] - 
     6*G[{0, 0, 0, 0, yu^(-1)}, yv] - 6*G[{0, 0, 0, 0, yu^(-1)}, yw] - 
     6*G[{0, 0, 0, 0, yv^(-1)}, yw] + 6*G[{0, 0, 0, 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yu] + 6*G[{0, 0, 0, 1, 1}, yv] + 
     6*G[{0, 0, 0, 1, 1}, yw] - 3*G[{0, 0, 0, 1, yv^(-1)}, yw] + 
     3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 6*G[{0, 0, 0, yu^(-1), yu^(-1)}, 
       yv] - 6*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 0, 0, yv^(-1), 1}, yw] + 3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 6*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 0, 1}, yu] - G[{0, 0, 1, 0, yv^(-1)}, yw] + 
     G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{0, 0, 1, 1, 1}, yu] + 
     3*G[{0, 0, 1, 1, 1}, yv] + 3*G[{0, 0, 1, 1, 1}, yw] + 
     3*G[{0, 0, 1, 1, yu^(-1)}, yv] + 3*G[{0, 0, 1, 1, yu^(-1)}, yw] + 
     2*G[{0, 0, 1, 1, yv^(-1)}, yw] - 2*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 1, yu^(-1), 1}, yv] + 2*G[{0, 0, 1, yu^(-1), 1}, yw] - 
     2*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     2*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 1, yv^(-1), 1}, yw] - 2*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - G[{0, 0, 1, 1/(yu*yv), 1}, 
      yw] + G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, 
      yw] + 3*G[{0, 0, yu^(-1), 1, 1}, yv] + 3*G[{0, 0, yu^(-1), 1, 1}, yw] - 
     3*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] - 
     3*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), yu^(-1), 1}, yv] - 
     2*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     3*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 0, yv^(-1), 0, 1}, yw] + G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + G[{0, 0, yv^(-1), 1, 1}, yw] - 
     3*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, 1/(yu*yv), 0, 1}, yw] - G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     7*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 3*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 2*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 1, 0, 1, yv^(-1)}, yw] - G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, 
      yw] + G[{0, 1, 0, yv^(-1), 1}, yw] - G[{0, 1, 0, yv^(-1), yu^(-1)}, 
      yw] - 2*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 
     G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0, 1, 1, 0, yv^(-1)}, yw] - 
     G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 6*G[{0, 1, 1, 1, 1}, yu] + 
     3*G[{0, 1, 1, 1, yu^(-1)}, yv] + 3*G[{0, 1, 1, 1, yu^(-1)}, yw] + 
     G[{0, 1, 1, yu^(-1), 1}, yv] + G[{0, 1, 1, yu^(-1), 1}, yw] + 
     2*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] + 
     2*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + G[{0, 1, yu^(-1), 1, 1}, yv] + 
     G[{0, 1, yu^(-1), 1, 1}, yw] + G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] + 
     G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] + 
     2*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] + G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, 
      yw] + 3*G[{0, yu^(-1), 1, 1, 1}, yv] + 3*G[{0, yu^(-1), 1, 1, 1}, yw] + 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yv] + G[{0, yu^(-1), 1, yu^(-1), 1}, 
      yw] - 4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 1, 1}, yv] + 
     2*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{0, yv^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] - G[{0, yv^(-1), 1, 1, yu^(-1)}, 
      yw] - G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 2*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] - G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] + 
     3*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0}, yv]*Zeta[3] - (G[{0}, yv]^2*Zeta[3])/2 + 
     G[{0}, yu]*G[{0}, yw]*Zeta[3] - (G[{0}, yw]^2*Zeta[3])/2 + 
     G[{0}, yv]*G[{1}, yv]*Zeta[3] - G[{0}, yw]*G[{1}, yv]*Zeta[3] - 
     G[{0}, yv]*G[{1}, yw]*Zeta[3] + G[{0}, yw]*G[{1}, yw]*Zeta[3] + 
     2*G[{0, 1}, yu]*Zeta[3] - 2*G[{0, 1}, yv]*Zeta[3] - 
     2*G[{0, 1}, yw]*Zeta[3] + 4*G[{0, yv^(-1)}, yw]*Zeta[3] - 
     2*G[{0, 1/(yu*yv)}, yw]*Zeta[3]
 
J1uvwRegI = (Pi^4*G[{0}, yu])/15 - (Pi^2*G[{0}, yu]^3)/9 + 
     (13*Pi^4*G[{0}, yv])/90 + (Pi^4*G[{0}, yw])/15 + 
     (2*Pi^2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw])/3 - 
     (2*G[{0}, yu]^3*G[{0}, yv]*G[{0}, yw])/3 + G[{0}, yu]^2*G[{0}, yv]*
      G[{0}, yw]^2 - (Pi^2*G[{0}, yw]^3)/9 - 
     (2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^3)/3 + 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/3 + 2*G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu] - (Pi^2*G[{0}, yw]^2*G[{1}, yu])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yu] - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/3 - (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu]^2 - (Pi^2*G[{0}, yu]^2*G[{1}, yw])/3 - 
     2*G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw] + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*
      G[{1}, yw] + (2*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yu]*G[{1}, yw] - (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/3 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2 - 
     (2*Pi^2*G[{0}, yu]*G[{0, 1}, yu])/3 + (2*G[{0}, yu]^3*G[{0, 1}, yu])/3 + 
     (4*Pi^2*G[{0}, yv]*G[{0, 1}, yu])/3 + (2*Pi^2*G[{0}, yw]*G[{0, 1}, yu])/
      3 - 2*G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yu] - (2*G[{0}, yw]^3*G[{0, 1}, yu])/
      3 - (2*Pi^2*G[{1}, yu]*G[{0, 1}, yu])/3 - 2*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1}, yu] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yu] - 
     2*G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu] + 
     (2*Pi^2*G[{1}, yw]*G[{0, 1}, yu])/3 + 2*G[{0}, yu]^2*G[{1}, yw]*
      G[{0, 1}, yu] - 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]*G[{0, 1}, yu] + 4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1}, yu] + 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu] + 
     (2*Pi^2*G[{0}, yu]*G[{0, 1}, yv])/3 - (2*G[{0}, yu]^3*G[{0, 1}, yv])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{0, 1}, yv])/3 + 2*G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1}, yv] + (2*Pi^2*G[{0}, yw]*G[{0, 1}, yv])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yv] - (2*G[{0}, yw]^3*G[{0, 1}, yv])/
      3 + (2*Pi^2*G[{1}, yu]*G[{0, 1}, yv])/3 + 4*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1}, yv] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yv] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv] - 
     6*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yv] + 
     (4*G[{1}, yu]^3*G[{0, 1}, yv])/3 - 2*G[{0}, yu]^2*G[{1}, yw]*
      G[{0, 1}, yv] + 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yv] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv] + 8*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]*G[{0, 1}, yv] - 4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1}, yv] - 2*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv] + 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv] - 4*G[{1}, yw]*G[{0, 1}, yu]*
      G[{0, 1}, yv] + 2*G[{0}, yv]*G[{0, 1}, yv]^2 + 
     2*G[{1}, yu]*G[{0, 1}, yv]^2 + (2*Pi^2*G[{0}, yu]*G[{0, 1}, yw])/3 - 
     (2*G[{0}, yu]^3*G[{0, 1}, yw])/3 + (4*Pi^2*G[{0}, yv]*G[{0, 1}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yu]^2*G[{0}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{0}, yw]^3*G[{0, 1}, yw])/3 + (2*Pi^2*G[{1}, yu]*G[{0, 1}, yw])/3 + 
     2*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yw] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1}, yw] + 2*G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yu]^2*
      G[{0, 1}, yw] + (2*G[{1}, yu]^3*G[{0, 1}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] + 
     4*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yw] - 
     (2*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu]^2*G[{1}, yw]*
      G[{0, 1}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]*G[{0, 1}, yw] - 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 2*G[{0}, yu]^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     (8*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 + 4*G[{0}, yu]*G[{0, 1}, yv]*
      G[{0, 1}, yw] - 4*G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw] + 4*G[{1}, yw]*G[{0, 1}, yv]*
      G[{0, 1}, yw] - 4*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     (2*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/3 - 
     (2*G[{0}, yu]^3*G[{0, yu^(-1)}, yv])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]^2*G[{0}, yv]*
      G[{0, yu^(-1)}, yv] - (2*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/3 + 
     2*G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yv] + 
     (2*G[{0}, yw]^3*G[{0, yu^(-1)}, yv])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] - 
     (4*G[{1}, yu]^3*G[{0, yu^(-1)}, yv])/3 - 
     (2*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]^2 + 2*G[{0}, yv]*
      G[{0, yu^(-1)}, yv]^2 + 2*G[{0}, yw]*G[{0, yu^(-1)}, yv]^2 + 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yv]^2 - 2*G[{1}, yw]*
      G[{0, yu^(-1)}, yv]^2 + (2*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/3 - 
     (2*G[{0}, yu]^3*G[{0, yu^(-1)}, yw])/3 - 
     (4*Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 - 
     (2*G[{0}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 2*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] - 
     (2*G[{1}, yu]^3*G[{0, yu^(-1)}, yw])/3 + 
     (4*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/3 - 2*G[{0}, yu]^2*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     (4*G[{1}, yv]^3*G[{0, yu^(-1)}, yw])/3 - 2*G[{0}, yu]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]^2 - 
     (2*Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/3 + 
     (2*G[{0}, yu]^3*G[{0, yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/3 - 2*G[{0}, yu]^2*G[{0}, yv]*
      G[{0, yv^(-1)}, yw] + (2*Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{0}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     (4*Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/3 - 4*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] + 8*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yw]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw] + 
     6*G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     (8*G[{1}, yu]^3*G[{0, yv^(-1)}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - 4*G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 + 2*G[{0}, yu]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     6*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     (2*Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (2*G[{0}, yu]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1/(yu*yv)}, yw] - (2*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{0}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - 2*Pi^2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]^2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yu]^2*
      G[{0, 1/(yu*yv)}, yw] + (8*G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (4*Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + (4*G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     (8*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 4*G[{0}, yu]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*Pi^2*G[{0, 0, 1}, yu] - 2*G[{0}, yu]^2*G[{0, 0, 1}, yu] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yu] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yu] + 4*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yu]^2*G[{0, 0, 1}, yu] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yu] - 4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yu] - 4*G[{1}, yw]^2*G[{0, 0, 1}, yu] - 
     4*G[{0, 1}, yv]*G[{0, 0, 1}, yu] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yu] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     (4*Pi^2*G[{0, 0, 1}, yv])/3 - 4*G[{0}, yu]^2*G[{0, 0, 1}, yv] + 
     8*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{0}, yw]^2*G[{0, 0, 1}, yv] + 8*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yv] - 8*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yu]^2*G[{0, 0, 1}, yv] - 8*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yv] + 8*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv] + 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yw]^2*G[{0, 0, 1}, yv] - 8*G[{0, 1}, yv]*G[{0, 0, 1}, yv] + 
     8*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yv] + 8*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1}, yv] - 8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     2*Pi^2*G[{0, 0, 1}, yw] - 2*G[{0}, yu]^2*G[{0, 0, 1}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yw] - 4*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yu]^2*G[{0, 0, 1}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yw] - 4*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yw]^2*G[{0, 0, 1}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yw] + 4*G[{0, 1}, yv]*
      G[{0, 0, 1}, yw] - 4*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{1, yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     (4*Pi^2*G[{0, 0, yu^(-1)}, yv])/3 + 4*G[{0}, yu]^2*
      G[{0, 0, yu^(-1)}, yv] - 8*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yv] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yv] + 8*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 8*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 8*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 
     8*G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv] - 8*G[{0, yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 8*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     (4*Pi^2*G[{0, 0, yu^(-1)}, yw])/3 + 2*G[{0}, yu]^2*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 4*G[{0, 1}, yu]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*Pi^2*G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yu]^2*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 8*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] + 8*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] + 6*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 4*G[{0, 1}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     (4*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (8*Pi^2*G[{0, 1, 1}, yu])/3 + 4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yu] - 
     4*G[{1}, yu]^2*G[{0, 1, 1}, yu] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, 1}, yu] + 8*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu] - 
     4*G[{1}, yw]^2*G[{0, 1, 1}, yu] - 4*G[{0, 1}, yv]*G[{0, 1, 1}, yu] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + (4*Pi^2*G[{0, 1, 1}, yv])/3 - 
     2*G[{0}, yu]^2*G[{0, 1, 1}, yv] - 2*G[{0}, yw]^2*G[{0, 1, 1}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1}, yv] - 2*G[{1}, yu]^2*G[{0, 1, 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yv] + 4*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] - 
     4*G[{1}, yw]^2*G[{0, 1, 1}, yv] - 4*G[{0, 1}, yu]*G[{0, 1, 1}, yv] + 
     (8*Pi^2*G[{0, 1, 1}, yw])/3 + 4*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yw]^2*G[{0, 1, 1}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] - 4*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     (2*Pi^2*G[{0, 1, yu^(-1)}, yv])/3 - 2*G[{0}, yu]^2*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     8*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     8*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     (2*Pi^2*G[{0, 1, yv^(-1)}, yw])/3 - 2*G[{0}, yu]^2*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0, 1}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/3 + 4*G[{0}, yu]^2*
      G[{0, yu^(-1), yu^(-1)}, yv] + 8*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 8*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 8*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 8*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 8*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 8*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     (8*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 + 4*G[{1}, yw]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] + (4*Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      3 + 2*G[{0}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{0, yv^(-1), 1}, yw])/3 - 2*G[{0}, yu]^2*
      G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0, 1}, yv]*G[{0, yv^(-1), 1}, yw] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     (4*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 + 4*G[{0}, yu]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] - 8*G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 8*G[{0}, yu]*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 8*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 16*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     16*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     12*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*Pi^2*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + (8*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 
     4*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (4*Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     8*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, 0, 0, 1}, yu] - 4*G[{0}, yv]*G[{0, 0, 0, 1}, yu] - 
     4*G[{0}, yw]*G[{0, 0, 0, 1}, yu] - 4*G[{0}, yu]*G[{0, 0, 0, 1}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 0, 1}, yw] + 4*G[{0}, yw]*G[{0, 0, 0, 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 0, 0, 1}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0, 0, 1, 1}, yu] + 
     8*G[{1}, yu]*G[{0, 0, 1, 1}, yu] - 8*G[{1}, yw]*G[{0, 0, 1, 1}, yu] - 
     8*G[{0}, yv]*G[{0, 0, 1, 1}, yv] - 8*G[{1}, yu]*G[{0, 0, 1, 1}, yv] - 
     4*G[{0}, yv]*G[{0, 0, 1, 1}, yw] - 4*G[{1}, yu]*G[{0, 0, 1, 1}, yw] + 
     8*G[{1}, yw]*G[{0, 0, 1, 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1}, yw] + 8*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv] + 
     8*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv] - 
     8*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     8*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yw] - 8*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] + 8*G[{0}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, 
       yw] - 8*G[{0}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*
      G[{0, 1, 0, yu^(-1)}, yv] + 4*G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 1, 1}, yu] + 12*G[{1}, yu]*G[{0, 1, 1, 1}, yu] - 
     12*G[{1}, yw]*G[{0, 1, 1, 1}, yu] - 4*G[{0}, yu]*G[{0, 1, 1, 1}, yv] - 
     4*G[{0}, yw]*G[{0, 1, 1, 1}, yv] - 4*G[{1}, yu]*G[{0, 1, 1, 1}, yv] - 
     4*G[{0}, yv]*G[{0, 1, 1, 1}, yw] - 4*G[{1}, yu]*G[{0, 1, 1, 1}, yw] + 
     12*G[{1}, yw]*G[{0, 1, 1, 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yw] + 4*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     8*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1), 1}, yw] - 8*G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, 
       yw] + 8*G[{0}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 4*G[{0}, yv]*
      G[{0, yu^(-1), 1, 1}, yw] + 4*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1}, yw] + 4*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] + 4*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     16*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     16*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     16*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     16*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     32*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 0, 0, 1}, yu] - 8*G[{0, 0, 0, 0, 1}, yw] + 
     8*G[{0, 0, 0, 0, yu^(-1)}, yw] + 8*G[{0, 0, 0, 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 0, 0, 1/(yu*yv)}, yw] - 8*G[{0, 0, 0, 1, 1}, yu] + 
     48*G[{0, 0, 0, 1, 1}, yv] - 8*G[{0, 0, 0, 1, 1}, yw] - 
     48*G[{0, 0, 0, 1, yu^(-1)}, yv] + 12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 
     12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 48*G[{0, 0, 0, yu^(-1), 1}, yv] + 
     12*G[{0, 0, 0, yu^(-1), 1}, yw] + 48*G[{0, 0, 0, yu^(-1), yu^(-1)}, 
       yv] - 16*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 16*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 4*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 16*G[{0, 0, 1, 0, 1}, yv] - 
     16*G[{0, 0, 1, 0, yu^(-1)}, yv] + 4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 
     4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 12*G[{0, 0, 1, 1, 1}, yu] - 
     12*G[{0, 0, 1, 1, 1}, yw] - 16*G[{0, 0, 1, 1, yu^(-1)}, yv] + 
     8*G[{0, 0, 1, 1, yu^(-1)}, yw] + 4*G[{0, 0, 1, 1, yv^(-1)}, yw] - 
     8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 8*G[{0, 0, 1, yu^(-1), 1}, yw] - 
     32*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, yv^(-1), 1}, yw] - 8*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, 
       yw] - 8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{0, 0, yu^(-1), 0, 1}, yv] + 4*G[{0, 0, yu^(-1), 0, 1}, yw] + 
     16*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv] - 
     8*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, yu^(-1), 1, 1}, yw] - 8*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     16*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, 1}, yw] - 4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     16*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     12*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 8*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, 
       yw] + 8*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 1, 0, 1, yu^(-1)}, yv] + 4*G[{0, 1, 0, 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 4*G[{0, 1, 0, yu^(-1), 1}, yw] - 
     8*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1, 0, yu^(-1)}, yw] - 4*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] - 
     16*G[{0, 1, 1, 1, 1}, yu] - 8*G[{0, 1, 1, 1, 1}, yv] - 
     16*G[{0, 1, 1, 1, 1}, yw] + 4*G[{0, 1, 1, 1, yu^(-1)}, yv] + 
     4*G[{0, 1, 1, 1, yv^(-1)}, yw] + 4*G[{0, 1, 1, yv^(-1), 1}, yw] - 
     12*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] + 
     4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     16*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1, yv^(-1), 1, 1}, yw] + 4*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     16*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] - 
     16*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), 1, 1, 1}, yw] - 4*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] + 
     32*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 1, 1}, yw] + 4*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     32*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 4*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, 
       yw] + 8*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     16*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]^2*Zeta[3] + 8*G[{0}, yu]*G[{0}, yw]*Zeta[3] - 
     2*G[{0}, yw]^2*Zeta[3] + 4*G[{0}, yu]*G[{1}, yu]*Zeta[3] - 
     4*G[{0}, yw]*G[{1}, yu]*Zeta[3] - 4*G[{0}, yu]*G[{1}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1}, yw]*Zeta[3] - 8*G[{0, 1}, yv]*Zeta[3] + 
     8*G[{0, yu^(-1)}, yv]*Zeta[3] + 8*G[{0, yv^(-1)}, yw]*Zeta[3] - 
     8*G[{0, 1/(yu*yv)}, yw]*Zeta[3]
 
J1vwuRegI = (Pi^4*G[{0}, yu])/15 - (Pi^2*G[{0}, yu]^3)/9 + 
     (Pi^4*G[{0}, yv])/15 - (Pi^2*G[{0}, yv]^3)/9 + (13*Pi^4*G[{0}, yw])/90 + 
     (2*Pi^2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw])/3 - 
     (2*G[{0}, yu]^3*G[{0}, yv]*G[{0}, yw])/3 + G[{0}, yu]^2*G[{0}, yv]^2*
      G[{0}, yw] - (2*G[{0}, yu]*G[{0}, yv]^3*G[{0}, yw])/3 + 
     (Pi^2*G[{0}, yu]^2*G[{1}, yu])/3 - (Pi^2*G[{0}, yv]^2*G[{1}, yu])/3 + 
     2*G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu] - 
     2*G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu] - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/3 - (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu]^2 - (Pi^2*G[{0}, yu]^2*G[{1}, yv])/3 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/3 - 2*G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv] + 2*G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv] + 
     (2*Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yu]*G[{1}, yv] - (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/3 - (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2 - 
     (2*Pi^2*G[{0}, yu]*G[{0, 1}, yu])/3 + (2*G[{0}, yu]^3*G[{0, 1}, yu])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{0, 1}, yu])/3 - 2*G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1}, yu] + 2*G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yu] - 
     (2*G[{0}, yv]^3*G[{0, 1}, yu])/3 + (4*Pi^2*G[{0}, yw]*G[{0, 1}, yu])/3 - 
     (2*Pi^2*G[{1}, yu]*G[{0, 1}, yu])/3 - 2*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1}, yu] + 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yu] - 
     2*G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu] + 
     (2*Pi^2*G[{1}, yv]*G[{0, 1}, yu])/3 + 2*G[{0}, yu]^2*G[{1}, yv]*
      G[{0, 1}, yu] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu] + 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yu] + 4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1}, yu] + 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu] + 
     (2*Pi^2*G[{0}, yu]*G[{0, 1}, yv])/3 - (2*G[{0}, yu]^3*G[{0, 1}, yv])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{0, 1}, yv])/3 + 2*G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yv] + 
     (2*G[{0}, yv]^3*G[{0, 1}, yv])/3 + (4*Pi^2*G[{0}, yw]*G[{0, 1}, yv])/3 + 
     (2*Pi^2*G[{1}, yu]*G[{0, 1}, yv])/3 + 2*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1}, yv] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yv] + 
     2*G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yv] + 
     (2*G[{1}, yu]^3*G[{0, 1}, yv])/3 - (2*Pi^2*G[{1}, yv]*G[{0, 1}, yv])/3 - 
     2*G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yv] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1}, yv] - 2*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yv] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yv] + 
     (2*Pi^2*G[{0}, yu]*G[{0, 1}, yw])/3 - (2*G[{0}, yu]^3*G[{0, 1}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{0, 1}, yw])/3 - (2*G[{0}, yv]^3*G[{0, 1}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yu]^2*G[{0}, yw]*
      G[{0, 1}, yw] - 4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yw] + 
     (2*Pi^2*G[{1}, yu]*G[{0, 1}, yw])/3 + 4*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1}, yw] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw] - 
     6*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yw] + 
     (4*G[{1}, yu]^3*G[{0, 1}, yw])/3 + (2*Pi^2*G[{1}, yv]*G[{0, 1}, yw])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]*G[{0, 1}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yw] - 6*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1}, yw] + (4*G[{1}, yv]^3*G[{0, 1}, yw])/
      3 - (8*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/3 + 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw] - 4*G[{1}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yw] + 4*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]^2 + 2*G[{1}, yu]*G[{0, 1}, yw]^2 + 
     2*G[{1}, yv]*G[{0, 1}, yw]^2 + (2*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/
      3 - (2*G[{0}, yu]^3*G[{0, yu^(-1)}, yv])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/3 - 
     (2*G[{0}, yv]^3*G[{0, yu^(-1)}, yv])/3 - 
     (4*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/3 + 2*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yv]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] - 
     (2*G[{1}, yu]^3*G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]^2*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]^2 + 
     (2*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/3 - 
     (2*G[{0}, yu]^3*G[{0, yu^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/3 + 2*G[{0}, yu]^2*G[{0}, yv]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yv]^2*G[{0, yu^(-1)}, yw] + 
     (2*G[{0}, yv]^3*G[{0, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 - 2*G[{0}, yu]^2*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] - 
     (4*G[{1}, yu]^3*G[{0, yu^(-1)}, yw])/3 + 
     (4*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/3 - 4*G[{0}, yu]^2*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] + 8*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     (8*G[{1}, yv]^3*G[{0, yu^(-1)}, yw])/3 + 4*G[{0}, yu]*G[{0, 1}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]^2 + 2*G[{0}, yv]*
      G[{0, yu^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{0, yu^(-1)}, yw]^2 + 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yw]^2 - 
     (2*Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/3 + 
     (2*G[{0}, yu]^3*G[{0, yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/3 - 2*G[{0}, yu]^2*G[{0}, yv]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{0}, yv]^3*G[{0, yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 - 2*G[{0}, yu]^2*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw] + 
     (4*Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/3 - 4*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] + 8*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yv]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw] + 
     6*G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     6*G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     (8*G[{1}, yu]^3*G[{0, yv^(-1)}, yw])/3 - 4*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]*G[{0, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + 4*G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - 
     (4*G[{1}, yv]^3*G[{0, yv^(-1)}, yw])/3 - 4*G[{0}, yu]*G[{0, 1}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]^2 - 2*G[{0}, yv]*
      G[{0, yv^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{0, yv^(-1)}, yw]^2 + 
     4*G[{1}, yv]*G[{0, yv^(-1)}, yw]^2 - 
     (2*Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (2*G[{0}, yu]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (2*G[{0}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]^2*G[{0}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]^2*G[{0}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] + 
     6*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] + 
     (8*G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw])/3 - 2*Pi^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 6*G[{0}, yu]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + (8*G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     (8*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2 + 
     2*Pi^2*G[{0, 0, 1}, yu] - 2*G[{0}, yu]^2*G[{0, 0, 1}, yu] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yu] - 
     2*G[{0}, yv]^2*G[{0, 0, 1}, yu] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yu] - 4*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yu]^2*G[{0, 0, 1}, yu] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yu] + 4*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yu] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu] + 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yu] - 4*G[{1}, yv]^2*G[{0, 0, 1}, yu] - 
     4*G[{0, 1}, yw]*G[{0, 0, 1}, yu] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yu] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     2*Pi^2*G[{0, 0, 1}, yv] - 2*G[{0}, yu]^2*G[{0, 0, 1}, yv] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yv] - 
     2*G[{0}, yv]^2*G[{0, 0, 1}, yv] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yv] - 4*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yu]^2*G[{0, 0, 1}, yv] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yv] + 4*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yv] + 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yv] - 4*G[{1}, yv]^2*G[{0, 0, 1}, yv] - 
     4*G[{0, 1}, yw]*G[{0, 0, 1}, yv] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yv] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     (4*Pi^2*G[{0, 0, 1}, yw])/3 - 4*G[{0}, yu]^2*G[{0, 0, 1}, yw] + 
     8*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yv]^2*G[{0, 0, 1}, yw] + 8*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yw] - 8*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yu]^2*G[{0, 0, 1}, yw] - 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yw] + 8*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yv]^2*G[{0, 0, 1}, yw] - 8*G[{0, 1}, yw]*G[{0, 0, 1}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 8*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1}, yw] - 8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     (4*Pi^2*G[{0, 0, yu^(-1)}, yv])/3 + 2*G[{0}, yu]^2*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv] + 4*G[{0, 1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     (4*Pi^2*G[{0, 0, yu^(-1)}, yw])/3 + 4*G[{0}, yu]^2*
      G[{0, 0, yu^(-1)}, yw] - 8*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yw] + 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw] + 
     8*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] - 8*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 8*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (4*Pi^2*G[{0, 0, yv^(-1)}, yw])/3 + 4*G[{0}, yu]^2*
      G[{0, 0, yv^(-1)}, yw] - 8*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yv]^2*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw] + 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yv]^2*G[{0, 0, yv^(-1)}, yw] + 
     8*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 8*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 8*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     (4*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 4*G[{0}, yu]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + (8*Pi^2*G[{0, 1, 1}, yu])/3 + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yu] - 
     4*G[{1}, yu]^2*G[{0, 1, 1}, yu] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1}, yu] + 8*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu] - 
     4*G[{1}, yv]^2*G[{0, 1, 1}, yu] - 4*G[{0, 1}, yw]*G[{0, 1, 1}, yu] - 
     4*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + (8*Pi^2*G[{0, 1, 1}, yv])/3 + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yv] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yv] - 4*G[{1}, yv]^2*G[{0, 1, 1}, yv] - 
     4*G[{0, 1}, yw]*G[{0, 1, 1}, yv] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1}, yv] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     (4*Pi^2*G[{0, 1, 1}, yw])/3 - 2*G[{0}, yu]^2*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1, 1}, yw] - 4*G[{0, 1}, yu]*G[{0, 1, 1}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 1, 1}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] - (2*Pi^2*G[{0, 1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw] - 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 6*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] + 8*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 8*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, 1, yv^(-1)}, yw])/3 - 2*G[{0}, yu]^2*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 8*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 8*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (4*Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0, 1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yv] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yv] + 4*G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw] - 
     (8*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/3 + 4*G[{1}, yv]^2*
      G[{0, yu^(-1), yu^(-1)}, yv] - (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/
      3 + 4*G[{0}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 8*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 8*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 16*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     12*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     (4*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 + 4*G[{0}, yu]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] - 8*G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 8*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     16*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     12*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     (4*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 2*G[{0}, yu]^2*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (4*Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yv] - 8*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{0, 0, 0, 1}, yu] - 
     4*G[{0}, yv]*G[{0, 0, 0, 1}, yu] - 4*G[{0}, yw]*G[{0, 0, 0, 1}, yu] - 
     4*G[{0}, yu]*G[{0, 0, 0, 1}, yv] + 4*G[{0}, yv]*G[{0, 0, 0, 1}, yv] - 
     4*G[{0}, yw]*G[{0, 0, 0, 1}, yv] - 4*G[{0}, yu]*
      G[{0, 0, 0, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yu] + 8*G[{1}, yu]*G[{0, 0, 1, 1}, yu] - 
     8*G[{1}, yv]*G[{0, 0, 1, 1}, yu] - 4*G[{0}, yw]*G[{0, 0, 1, 1}, yv] - 
     4*G[{1}, yu]*G[{0, 0, 1, 1}, yv] + 8*G[{1}, yv]*G[{0, 0, 1, 1}, yv] - 
     8*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 8*G[{1}, yu]*G[{0, 0, 1, 1}, yw] - 
     8*G[{1}, yv]*G[{0, 0, 1, 1}, yw] - 8*G[{1}, yv]*
      G[{0, 0, 1, yu^(-1)}, yv] + 8*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv] - 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw] - 
     8*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw] - 
     8*G[{0}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     8*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     8*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     8*G[{0}, yu]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     16*G[{1}, yv]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{1}, yu]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1, 1}, yu] + 12*G[{1}, yu]*G[{0, 1, 1, 1}, yu] - 
     12*G[{1}, yv]*G[{0, 1, 1, 1}, yu] - 4*G[{0}, yw]*G[{0, 1, 1, 1}, yv] - 
     4*G[{1}, yu]*G[{0, 1, 1, 1}, yv] + 12*G[{1}, yv]*G[{0, 1, 1, 1}, yv] - 
     4*G[{0}, yu]*G[{0, 1, 1, 1}, yw] - 4*G[{0}, yv]*G[{0, 1, 1, 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1, 1, 1}, yw] - 4*G[{1}, yv]*G[{0, 1, 1, 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw] - 
     8*G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yu]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 8*G[{0}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 8*G[{1}, yu]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 8*G[{1}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 4*G[{0}, yu]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, yu^(-1), 1, 1}, yv] + 4*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     16*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     32*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     16*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     32*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 8*G[{0}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 0, 0, 1}, yu] - 8*G[{0, 0, 0, 0, 1}, yv] + 
     8*G[{0, 0, 0, 0, yu^(-1)}, yv] - 8*G[{0, 0, 0, 1, 1}, yu] - 
     8*G[{0, 0, 0, 1, 1}, yv] + 48*G[{0, 0, 0, 1, 1}, yw] + 
     12*G[{0, 0, 0, 1, yu^(-1)}, yv] - 48*G[{0, 0, 0, 1, yu^(-1)}, yw] - 
     48*G[{0, 0, 0, 1, yv^(-1)}, yw] + 48*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, yu^(-1), 1}, yv] - 48*G[{0, 0, 0, yu^(-1), 1}, yw] - 
     16*G[{0, 0, 0, yu^(-1), yu^(-1)}, yv] + 
     48*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] + 
     48*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     48*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     48*G[{0, 0, 0, yv^(-1), 1}, yw] + 48*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] + 48*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     48*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     48*G[{0, 0, 0, 1/(yu*yv), 1}, yw] - 48*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 48*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     48*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 16*G[{0, 0, 1, 0, 1}, yw] + 
     4*G[{0, 0, 1, 0, yu^(-1)}, yv] - 16*G[{0, 0, 1, 0, yu^(-1)}, yw] - 
     16*G[{0, 0, 1, 0, yv^(-1)}, yw] + 16*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1, 1}, yu] - 12*G[{0, 0, 1, 1, 1}, yv] + 
     8*G[{0, 0, 1, 1, yu^(-1)}, yv] - 16*G[{0, 0, 1, 1, yu^(-1)}, yw] - 
     16*G[{0, 0, 1, 1, yv^(-1)}, yw] + 8*G[{0, 0, 1, yu^(-1), 1}, yv] - 
     32*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     32*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     32*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     32*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1}, yv] - 16*G[{0, 0, yu^(-1), 0, 1}, yw] - 
     8*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv] + 
     16*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - 
     16*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, yu^(-1), 1, 1}, yv] - 8*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), 1}, yv] - 
     16*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     32*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     16*G[{0, 0, yv^(-1), 0, 1}, yw] + 16*G[{0, 0, yv^(-1), 0, yu^(-1)}, 
       yw] + 16*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     16*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] + 
     16*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     32*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     16*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 16*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - 16*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     16*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1, yu^(-1)}, yv] - 12*G[{0, 1, 0, 1, yu^(-1)}, yw] - 
     12*G[{0, 1, 0, 1, yv^(-1)}, yw] + 4*G[{0, 1, 0, yu^(-1), 1}, yv] - 
     8*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     12*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     12*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1, 0, yu^(-1)}, yv] - 16*G[{0, 1, 1, 1, 1}, yu] - 
     16*G[{0, 1, 1, 1, 1}, yv] - 8*G[{0, 1, 1, 1, 1}, yw] + 
     4*G[{0, 1, 1, 1, yu^(-1)}, yw] + 4*G[{0, 1, 1, 1, yv^(-1)}, yw] + 
     8*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] - 
     12*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     12*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     12*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     12*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] - 4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yu^(-1), 1}, yv] - 
     16*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     16*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1, 1, 1}, yv] - 8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, 
       yw] + 8*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     16*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     16*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yv] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     32*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     16*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     32*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 4*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] - 4*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]^2*Zeta[3] + 8*G[{0}, yu]*G[{0}, yv]*Zeta[3] - 
     2*G[{0}, yv]^2*Zeta[3] + 4*G[{0}, yu]*G[{1}, yu]*Zeta[3] - 
     4*G[{0}, yv]*G[{1}, yu]*Zeta[3] - 4*G[{0}, yu]*G[{1}, yv]*Zeta[3] + 
     4*G[{0}, yv]*G[{1}, yv]*Zeta[3] - 8*G[{0, 1}, yw]*Zeta[3] + 
     8*G[{0, yu^(-1)}, yw]*Zeta[3] + 8*G[{0, yv^(-1)}, yw]*Zeta[3] - 
     8*G[{0, 1/(yu*yv)}, yw]*Zeta[3]
 
J1wuvRegI = (13*Pi^4*G[{0}, yu])/90 + (Pi^4*G[{0}, yv])/15 - 
     (Pi^2*G[{0}, yv]^3)/9 + (Pi^4*G[{0}, yw])/15 + 
     (2*Pi^2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw])/3 - 
     (2*G[{0}, yu]*G[{0}, yv]^3*G[{0}, yw])/3 + G[{0}, yu]*G[{0}, yv]^2*
      G[{0}, yw]^2 - (Pi^2*G[{0}, yw]^3)/9 - 
     (2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^3)/3 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/3 + 2*G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*
      G[{1}, yv] - (Pi^2*G[{0}, yw]^2*G[{1}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv] - 
     (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/3 - (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]^2 - (Pi^2*G[{0}, yv]^2*G[{1}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw] + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*
      G[{1}, yw] + (2*Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yv]*G[{1}, yw] - (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/3 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2 - 
     (2*Pi^2*G[{0}, yu]*G[{0, 1}, yu])/3 + (2*Pi^2*G[{0}, yv]*G[{0, 1}, yu])/
      3 + 2*G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yu] - 
     (2*G[{0}, yv]^3*G[{0, 1}, yu])/3 + (2*Pi^2*G[{0}, yw]*G[{0, 1}, yu])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yu] - (2*G[{0}, yw]^3*G[{0, 1}, yu])/
      3 - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu] + 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]*G[{0, 1}, yu] - 2*G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yu] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yu] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{0, 1}, yu]^2 + (4*Pi^2*G[{0}, yu]*G[{0, 1}, yv])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{0, 1}, yv])/3 + (2*G[{0}, yv]^3*G[{0, 1}, yv])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, 1}, yv])/3 - 2*G[{0}, yv]^2*G[{0}, yw]*
      G[{0, 1}, yv] + 2*G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yv] - 
     (2*G[{0}, yw]^3*G[{0, 1}, yv])/3 + 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1}, yv] - 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv] - 
     (2*Pi^2*G[{1}, yv]*G[{0, 1}, yv])/3 - 2*G[{0}, yv]^2*G[{1}, yv]*
      G[{0, 1}, yv] + 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv] - 
     2*G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yv] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yv]^2*
      G[{0, 1}, yv] + (2*Pi^2*G[{1}, yw]*G[{0, 1}, yv])/3 + 
     2*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yv] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yv] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv] - 
     4*G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] + 4*G[{0}, yw]*G[{0, 1}, yu]*
      G[{0, 1}, yv] + 4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] - 
     4*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + 
     (4*Pi^2*G[{0}, yu]*G[{0, 1}, yw])/3 + (2*Pi^2*G[{0}, yv]*G[{0, 1}, yw])/
      3 - (2*G[{0}, yv]^3*G[{0, 1}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yv]^2*G[{0}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{0}, yw]^3*G[{0, 1}, yw])/3 - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw] + 
     (2*Pi^2*G[{1}, yv]*G[{0, 1}, yw])/3 + 2*G[{0}, yv]^2*G[{1}, yv]*
      G[{0, 1}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yw] + (2*G[{1}, yv]^3*G[{0, 1}, yw])/
      3 - (2*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yv]^2*G[{1}, yw]*
      G[{0, 1}, yw] + 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]*G[{0, 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yw] - 4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yw]^2*
      G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw] - 2*Pi^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 2*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     (8*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 + 4*G[{0}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yw] - 4*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw] + 4*G[{1}, yw]*G[{0, 1}, yu]*
      G[{0, 1}, yw] - 4*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     (2*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/3 - 2*G[{0}, yu]*G[{0}, yv]^2*
      G[{0, yu^(-1)}, yv] - (2*G[{0}, yv]^3*G[{0, yu^(-1)}, yv])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]^2*G[{0}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yv] + 
     (2*G[{0}, yw]^3*G[{0, yu^(-1)}, yv])/3 - 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + (2*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - 
     (2*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/3 - 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, yu^(-1)}, yv] - 2*G[{0}, yv]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     (2*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]^2*
      G[{0, yu^(-1)}, yw] + (2*G[{0}, yv]^3*G[{0, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw] - 
     (2*G[{0}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] + (4*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     (8*G[{1}, yv]^3*G[{0, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/3 - 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     6*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     (4*Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/3 - 
     (2*G[{0}, yv]^3*G[{0, yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     (2*G[{0}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     (4*Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/3 - 2*G[{0}, yv]^2*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     (4*G[{1}, yu]^3*G[{0, yv^(-1)}, yw])/3 + 2*G[{0}, yv]^2*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{1}, yv]^3*G[{0, yv^(-1)}, yw])/3 - 2*G[{0}, yv]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]^2 - 
     (2*Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + (2*G[{0}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 4*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + (2*G[{0}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (4*Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yv]^2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]^2*
      G[{0, 1/(yu*yv)}, yw] + (4*G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + (8*G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     (8*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 4*G[{0}, yv]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yv] + 4*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     (4*Pi^2*G[{0, 0, 1}, yu])/3 - 4*G[{0}, yv]^2*G[{0, 0, 1}, yu] + 
     8*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{0}, yw]^2*G[{0, 0, 1}, yu] + 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yu] - 8*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yv]^2*G[{0, 0, 1}, yu] - 8*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yu] + 8*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu] + 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yw]^2*G[{0, 0, 1}, yu] - 8*G[{0, 1}, yu]*G[{0, 0, 1}, yu] + 
     8*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yu] + 8*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yu] - 8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     2*Pi^2*G[{0, 0, 1}, yv] - 2*G[{0}, yv]^2*G[{0, 0, 1}, yv] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yv] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1}, yv] + 4*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, 1}, yv] - 4*G[{1}, yv]^2*G[{0, 0, 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yv] + 4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv] + 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yw]^2*G[{0, 0, 1}, yv] + 4*G[{0, 1}, yu]*G[{0, 0, 1}, yv] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] + 2*Pi^2*G[{0, 0, 1}, yw] - 
     2*G[{0}, yv]^2*G[{0, 0, 1}, yw] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yw]^2*G[{0, 0, 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yw] - 4*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{1}, yw]^2*G[{0, 0, 1}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{0, 0, 1}, yw] + 4*G[{0, 1}, yu]*
      G[{0, 0, 1}, yw] - 4*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] - 2*Pi^2*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 8*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv] + 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*Pi^2*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     6*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 8*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     (4*Pi^2*G[{0, 0, yv^(-1)}, yw])/3 + 2*G[{0}, yv]^2*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1}, yv]^2*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 4*G[{0, 1}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     (4*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + (4*Pi^2*G[{0, 1, 1}, yu])/3 - 
     2*G[{0}, yv]^2*G[{0, 1, 1}, yu] - 2*G[{0}, yw]^2*G[{0, 1, 1}, yu] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1}, yu] - 4*G[{1}, yv]^2*G[{0, 1, 1}, yu] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yu] + 8*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu] - 
     4*G[{1}, yw]^2*G[{0, 1, 1}, yu] + (8*Pi^2*G[{0, 1, 1}, yv])/3 + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yv] - 
     4*G[{1}, yv]^2*G[{0, 1, 1}, yv] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1}, yv] + 8*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yv] - 
     4*G[{1}, yw]^2*G[{0, 1, 1}, yv] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1}, yv] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     (8*Pi^2*G[{0, 1, 1}, yw])/3 + 4*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yw]^2*G[{0, 1, 1}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] - 4*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     (2*Pi^2*G[{0, 1, yu^(-1)}, yv])/3 - 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv] - 
     (2*Pi^2*G[{0, 1, yu^(-1)}, yw])/3 + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 6*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - (2*Pi^2*G[{0, yu^(-1), 1}, yv])/3 - 
     2*G[{0}, yv]^2*G[{0, yu^(-1), 1}, yv] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] + 
     4*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv] + 4*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - (2*Pi^2*G[{0, yu^(-1), 1}, yw])/3 - 
     2*G[{0}, yv]^2*G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/3 + 8*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 8*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 8*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] + 8*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 - 8*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 8*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 8*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 16*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 16*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 12*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 8*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     (8*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 + 4*G[{1}, yw]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] + (4*Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      3 + 2*G[{0}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*Pi^2*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (8*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 - 
     4*G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (4*Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     8*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 0, 0, 1}, yv] + 4*G[{0}, yv]*G[{0, 0, 0, 1}, yv] - 
     4*G[{0}, yw]*G[{0, 0, 0, 1}, yv] - 4*G[{0}, yu]*G[{0, 0, 0, 1}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 0, 1}, yw] + 4*G[{0}, yw]*G[{0, 0, 0, 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 0, 0, 1}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 8*G[{0}, yu]*G[{0, 0, 1, 1}, yu] - 
     4*G[{0}, yu]*G[{0, 0, 1, 1}, yv] + 8*G[{1}, yv]*G[{0, 0, 1, 1}, yv] - 
     8*G[{1}, yw]*G[{0, 0, 1, 1}, yv] - 4*G[{0}, yu]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, 1}, yw] + 8*G[{1}, yw]*G[{0, 0, 1, 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yw] + 
     4*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     8*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv] + 
     8*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yw] - 8*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] + 8*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 1, 1}, yu] - 4*G[{0}, yw]*G[{0, 1, 1, 1}, yu] - 
     4*G[{0}, yu]*G[{0, 1, 1, 1}, yv] + 12*G[{1}, yv]*G[{0, 1, 1, 1}, yv] - 
     12*G[{1}, yw]*G[{0, 1, 1, 1}, yv] - 4*G[{0}, yu]*G[{0, 1, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 1, 1}, yw] + 12*G[{1}, yw]*G[{0, 1, 1, 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yw] + 8*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] + 8*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*
      G[{0, yu^(-1), 1, 1}, yv] + 4*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     16*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     16*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     16*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     16*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     16*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     16*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     32*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), 1, 1}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1, 1}, yw] + 4*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, 
       yw] - 8*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 0, 0, 1}, yv] - 8*G[{0, 0, 0, 0, 1}, yw] + 
     8*G[{0, 0, 0, 0, yu^(-1)}, yv] + 8*G[{0, 0, 0, 0, yu^(-1)}, yw] + 
     8*G[{0, 0, 0, 0, yv^(-1)}, yw] - 8*G[{0, 0, 0, 0, 1/(yu*yv)}, yw] + 
     48*G[{0, 0, 0, 1, 1}, yu] - 8*G[{0, 0, 0, 1, 1}, yv] - 
     8*G[{0, 0, 0, 1, 1}, yw] + 12*G[{0, 0, 0, 1, yv^(-1)}, yw] - 
     12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{0, 0, 0, yu^(-1), yu^(-1)}, 
       yv] + 8*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] - 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] - 16*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 16*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 16*G[{0, 0, 1, 0, 1}, yu] + 
     4*G[{0, 0, 1, 0, yv^(-1)}, yw] - 4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1, 1}, yv] - 12*G[{0, 0, 1, 1, 1}, yw] + 
     4*G[{0, 0, 1, 1, yu^(-1)}, yv] + 4*G[{0, 0, 1, 1, yu^(-1)}, yw] + 
     8*G[{0, 0, 1, 1, yv^(-1)}, yw] - 8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, yu^(-1), 1}, yv] + 8*G[{0, 0, 1, yu^(-1), 1}, yw] - 
     8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, yv^(-1), 1}, yw] + 8*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1}, yv] + 4*G[{0, 0, yu^(-1), 1, 1}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] + 
     16*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     16*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     12*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, 1}, yw] - 4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, yv^(-1), 1, 1}, yw] - 4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     16*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 8*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 8*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, 1, yv^(-1)}, yw] - 4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, yv^(-1), 1}, yw] + 4*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1, 0, yv^(-1)}, yw] - 4*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 1, 1, 1}, yu] - 16*G[{0, 1, 1, 1, 1}, yv] - 
     16*G[{0, 1, 1, 1, 1}, yw] + 4*G[{0, 1, 1, 1, yu^(-1)}, yv] + 
     4*G[{0, 1, 1, 1, yu^(-1)}, yw] + 4*G[{0, 1, 1, yu^(-1), 1}, yv] + 
     4*G[{0, 1, 1, yu^(-1), 1}, yw] + 4*G[{0, 1, yu^(-1), 1, 1}, yv] + 
     4*G[{0, 1, yu^(-1), 1, 1}, yw] + 4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] + 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     16*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1, 1, 1}, yv] + 4*G[{0, yu^(-1), 1, 1, 1}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), 1}, yv] + 
     4*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     16*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv] - 
     16*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     32*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     32*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), 1, 1, 1}, yw] - 4*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 4*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, 
       yw] + 8*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]^2*Zeta[3] + 8*G[{0}, yv]*G[{0}, yw]*Zeta[3] - 
     2*G[{0}, yw]^2*Zeta[3] + 4*G[{0}, yv]*G[{1}, yv]*Zeta[3] - 
     4*G[{0}, yw]*G[{1}, yv]*Zeta[3] - 4*G[{0}, yv]*G[{1}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1}, yw]*Zeta[3] - 8*G[{0, 1}, yu]*Zeta[3] + 
     8*G[{0, yu^(-1)}, yv]*Zeta[3] + 8*G[{0, yu^(-1)}, yw]*Zeta[3] - 
     8*G[{0, 1/(yu*yv)}, yw]*Zeta[3]
 
K1uvwRegI = (-7*Pi^4*G[{0}, yu])/180 - (Pi^4*G[{0}, yv])/15 - 
     (Pi^2*G[{0}, yu]^2*G[{0}, yv])/6 - (7*Pi^4*G[{0}, yw])/180 - 
     (Pi^2*G[{0}, yu]^2*G[{0}, yw])/6 - (Pi^2*G[{0}, yu]*G[{0}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv]*G[{0}, yw]^2)/6 - G[{0}, yu]^2*G[{0}, yv]*
      G[{0}, yw]^2 - (Pi^2*G[{0}, yu]^2*G[{1}, yu])/6 - 
     G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu] + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu])/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*
      G[{1}, yu] + (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/6 + 
     (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/6 + (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2 - 
     (17*Pi^4*G[{1}, yv])/180 - (Pi^2*G[{0}, yu]^2*G[{1}, yv])/6 - 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv])/3 - 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv])/3 - 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv])/3 - G[{0}, yu]^2*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yv] - (Pi^2*G[{0}, yw]^2*G[{1}, yv])/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv] - 
     (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/6 - (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]^2 + (Pi^2*G[{0}, yu]^2*G[{1}, yw])/6 + 
     G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw] - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*
      G[{1}, yw] - (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yu]*G[{1}, yw] + (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/6 + 
     (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/6 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2 + 
     (17*Pi^4*G[{1/(yu*yv)}, yw])/180 + 
     (Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]^2*G[{1/(yu*yv)}, yw] + (Pi^2*G[{0}, yu]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yv]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yw]*G[{1}, yv]*
       G[{1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{1/(yu*yv)}, yw] - (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 - (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/3 - 
     (Pi^2*G[{0}, yv]*G[{0, 1}, yu])/3 - G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1}, yu] + (Pi^2*G[{0}, yw]*G[{0, 1}, yu])/3 + 
     G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yu] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1}, yu] - G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yu] + (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/
      3 + G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yu] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1}, yu] + G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu] + G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu] + 
     G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yu] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1}, yu] - G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu] - G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yu] - G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu] - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu])/3 - G[{0}, yu]^2*G[{1}, yw]*
      G[{0, 1}, yu] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu] - 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu] + G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{0, 1}, yu]^2 + G[{0}, yw]*G[{0, 1}, yu]^2 + 
     G[{1}, yv]*G[{0, 1}, yu]^2 - G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2 - 
     (2*Pi^2*G[{0}, yv]*G[{0, 1}, yv])/3 - G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1}, yv] - G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yv] - G[{0}, yv]*G[{0}, yw]^2*
      G[{0, 1}, yv] - Pi^2*G[{1}, yu]*G[{0, 1}, yv] - 
     3*G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yv] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1}, yv] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yv] - 
     G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yv] + 2*G[{0}, yu]*G[{1}, yu]^2*
      G[{0, 1}, yv] - G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yv] - G[{1}, yu]^3*G[{0, 1}, yv] - 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/3 - G[{0}, yu]^2*G[{1}, yv]*
      G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv] - 
     G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1}, yv] - G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yv] - G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yv] + 
     G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yv] - G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] + 
     G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv] + G[{0}, yu]*G[{1}, yw]^2*
      G[{0, 1}, yv] - G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv])/3 + 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1}, yv] - 4*G[{1}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yv] + 2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{0, 1}, yv]^2 + G[{0}, yw]*G[{0, 1}, yv]^2 + 
     G[{1}, yu]*G[{0, 1}, yv]^2 + G[{1}, yv]*G[{0, 1}, yv]^2 - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2 + (Pi^2*G[{0}, yu]*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{0, 1}, yw])/3 - G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1}, yw] - (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/3 - 
     G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1}, yw] + G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yw] - (Pi^2*G[{1}, yu]*G[{0, 1}, yw])/
      3 - G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, 1}, yw] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1}, yw] - 
     G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yw] - G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yw] - 
     G[{1}, yu]^3*G[{0, 1}, yw] - G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] + 
     G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] - 
     3*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yw] - G[{0}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yw] - 4*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yw] - 3*G[{1}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yw] + (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 + 
     G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yw] + G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{1}, yw]*G[{0, 1}, yw] + 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yw] + G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw] - G[{0}, yw]*G[{1}, yw]^2*
      G[{0, 1}, yw] - (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     6*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     6*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     (4*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 + G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu]*
      G[{0, 1}, yw] - 2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] - 2*G[{1}, yu]*G[{0, 1}, yv]*
      G[{0, 1}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     G[{0}, yu]*G[{0, 1}, yw]^2 + G[{0}, yw]*G[{0, 1}, yw]^2 + 
     G[{1}, yu]*G[{0, 1}, yw]^2 + 2*G[{1}, yv]*G[{0, 1}, yw]^2 - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2 - G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 + 
     (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/3 + 
     (2*Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/3 + G[{0}, yu]^2*G[{0}, yv]*
      G[{0, yu^(-1)}, yv] - (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/3 - 
     G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{0}, yw]^2*
      G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yv] + 
     (2*Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yv])/3 + G[{0}, yu]^2*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + G[{0}, yw]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yu]^2*
      G[{0, yu^(-1)}, yv] + G[{1}, yu]^3*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] + G[{0}, yw]^2*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] + G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yv] + G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/3 + G[{0}, yu]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yv]^2 + (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/
      3 + G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, yu^(-1)}, yw] - G[{0}, yu]*G[{0}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]^2*
      G[{0, yu^(-1)}, yw] + G[{1}, yu]^3*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 3*G[{0}, yu]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yw] - 3*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]^3*G[{0, yu^(-1)}, yw] + G[{0}, yu]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + G[{0}, yw]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]^2 - (Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/
      3 + (2*Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/3 + 
     G[{0}, yu]^2*G[{0}, yv]*G[{0, yv^(-1)}, yw] + 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 + G[{0}, yu]^2*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yu]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/3 + G[{0}, yu]^2*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]^2*
      G[{0, yv^(-1)}, yw] + G[{1}, yu]^3*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] + G[{0}, yu]*G[{1}, yv]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + G[{1}, yu]*G[{1}, yv]^2*
      G[{0, yv^(-1)}, yw] - (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     G[{0}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0, yv^(-1)}, yw]^2 - G[{0}, yv]*G[{0, yv^(-1)}, yw]^2 + 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]^2 + 2*G[{1}, yv]*G[{0, yv^(-1)}, yw]^2 - 
     G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2 - 
     (2*Pi^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/3 + G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw] + G[{0}, yu]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw] - G[{0}, yu]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     (4*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{0}, yu]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     (Pi^2*G[{0, 0, 1}, yu])/3 + 2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yu] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yu] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, 1}, yu] - 2*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, 1}, yu] + 2*G[{1}, yu]^2*G[{0, 0, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yu] + 2*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yu] + 2*G[{1}, yw]^2*G[{0, 0, 1}, yu] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yu] - 2*G[{0, 1}, yu]*
      G[{0, 0, 1}, yu] + 2*G[{0, 1}, yv]*G[{0, 0, 1}, yu] + 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yu] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yu] + 2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] + (4*Pi^2*G[{0, 0, 1}, yv])/3 + 
     2*G[{0}, yu]^2*G[{0, 0, 1}, yv] + 2*G[{0}, yw]^2*G[{0, 0, 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yv] + 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, 1}, yv] + 2*G[{1}, yu]^2*G[{0, 0, 1}, yv] - 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yv] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yv] - 4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{1}, yw]^2*G[{0, 0, 1}, yv] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] - 2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv] + 
     4*G[{0, 1}, yu]*G[{0, 0, 1}, yv] + 4*G[{0, 1}, yw]*G[{0, 0, 1}, yv] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv] + (Pi^2*G[{0, 0, 1}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, 0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{1}, yw]^2*G[{0, 0, 1}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 0, 1}, yw] + 2*G[{0, 1}, yv]*G[{0, 0, 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] + 2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - (4*Pi^2*G[{0, 0, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]^2*G[{0, 0, yu^(-1)}, yv] - 2*G[{0}, yw]^2*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yv] - 
     4*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv] - 4*G[{0, 1}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1}, yv]^2*G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 0, yv^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{0, 1, 1}, yu])/3 - 2*G[{0}, yu]^2*G[{0, 1, 1}, yu] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1}, yu] - 2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yu] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, 1}, yu] + 2*G[{1}, yu]^2*G[{0, 1, 1}, yu] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1}, yu] - 4*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yv]^2*G[{0, 1, 1}, yu] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, 1}, yu] - 4*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yu] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu] + 2*G[{0, 1}, yv]*
      G[{0, 1, 1}, yu] - 2*G[{0, 1}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + (Pi^2*G[{0, 1, 1}, yv])/3 - 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1}, yv] - 4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yv] - 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, 1}, yv] - 4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yv] - 
     4*G[{1}, yu]^2*G[{0, 1, 1}, yv] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yv] - 4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yv] - 6*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yv] - 2*G[{1}, yv]^2*G[{0, 1, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yv] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv] + 2*G[{0, 1}, yu]*
      G[{0, 1, 1}, yv] + 2*G[{0, 1}, yv]*G[{0, 1, 1}, yv] - 
     (2*Pi^2*G[{0, 1, 1}, yw])/3 - 2*G[{0}, yu]^2*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yw] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yw] - 6*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw] - 
     6*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu]^2*G[{0, 1, 1}, yw] - 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yw] - 8*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw] - 
     8*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw] - 16*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yw] - 8*G[{1}, yv]^2*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{1}, yw]^2*G[{0, 1, 1}, yw] + 
     6*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     6*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yw] + 4*G[{0, 1}, yv]*
      G[{0, 1, 1}, yw] - 4*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yw] + Pi^2*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     6*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0, 1}, yv]*G[{0, 1, yu^(-1)}, yv] + 4*G[{0, 1}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw] + 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 8*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     Pi^2*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yu]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] + 6*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     12*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 8*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]^2*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/3 - 2*G[{0}, yu]^2*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] + 4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     (2*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yu]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 8*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 8*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yv]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + Pi^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu]^2*G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw] + 6*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 6*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 6*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1}, yu]*G[{0, yv^(-1), 1}, yw] - 2*G[{0, 1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     (4*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 4*G[{0}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0, 1}, yu]*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 4*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - (2*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yv] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, 0, 1, 1}, yu] - 4*G[{1}, yu]*G[{0, 0, 1, 1}, yu] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yu] + 4*G[{0}, yu]*G[{0, 0, 1, 1}, yv] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yv] + 4*G[{1}, yu]*G[{0, 0, 1, 1}, yv] + 
     4*G[{1}, yv]*G[{0, 0, 1, 1}, yv] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yv] + 4*G[{0}, yv]*G[{0, 0, 1, 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1}, yw] - 4*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 0, 1, 1}, yw] - 
     4*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yv] - 4*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yv] - 4*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] - 4*G[{0}, yu]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{0, 1, 1, 1}, yu] - 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yu] - 6*G[{1}, yu]*G[{0, 1, 1, 1}, yu] - 
     6*G[{1}, yv]*G[{0, 1, 1, 1}, yu] + 6*G[{1}, yw]*G[{0, 1, 1, 1}, yu] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu] - 
     6*G[{0}, yv]*G[{0, 1, 1, 1}, yv] - 6*G[{1}, yu]*G[{0, 1, 1, 1}, yv] - 
     6*G[{0}, yu]*G[{0, 1, 1, 1}, yw] - 6*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 
     6*G[{1}, yu]*G[{0, 1, 1, 1}, yw] - 12*G[{1}, yv]*G[{0, 1, 1, 1}, yw] - 
     6*G[{1}, yw]*G[{0, 1, 1, 1}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1}, yw] + 6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw] + 
     6*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 12*G[{1}, yu]*
      G[{0, 1, 1, yu^(-1)}, yv] + 6*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] + 8*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 12*G[{1}, yu]*
      G[{0, 1, 1, yu^(-1)}, yw] + 16*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw] - 
     12*G[{yu^(-1)}, yv]*G[{0, 1, 1, yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yu]*
      G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 12*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yv^(-1)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     10*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 10*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yv] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] + 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{1}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*
      G[{0, yu^(-1), 1, 1}, yv] + 2*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] - 2*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] - 4*G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, 
       yw] - 4*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 8*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 6*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 8*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 8*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 8*G[{0}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     12*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     10*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yu] + 12*G[{0, 0, 0, 1, 1}, yw] - 
     12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 12*G[{0, 0, 0, 1, yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 12*G[{0, 0, 0, yu^(-1), 1}, yw] + 
     12*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] + 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] - 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 0, 1, 0, 1}, yu] + 
     4*G[{0, 0, 1, 0, 1}, yw] - 4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 
     4*G[{0, 0, 1, 0, yv^(-1)}, yw] + 4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 1, 1, 1}, yu] + 12*G[{0, 0, 1, 1, 1}, yw] - 
     4*G[{0, 0, 1, 1, yu^(-1)}, yv] - 12*G[{0, 0, 1, 1, yu^(-1)}, yw] - 
     12*G[{0, 0, 1, 1, yv^(-1)}, yw] + 8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), 1}, yv] - 8*G[{0, 0, 1, yu^(-1), 1}, yw] + 
     8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1}, yw] - 8*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0, 0, yu^(-1), 0, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1}, yv] - 8*G[{0, 0, yu^(-1), 1, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1}, yw] + 4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, 1}, yw] + 4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, 
       yw] - 8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 0, 1, 1}, yu] - 2*G[{0, 1, 0, 1, 1}, yv] + 
     2*G[{0, 1, 0, 1, 1}, yw] - 6*G[{0, 1, 0, 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 0, 1, yv^(-1)}, yw] + 4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), 1}, yv] - 4*G[{0, 1, 0, yu^(-1), 1}, yw] + 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 2*G[{0, 1, 0, yv^(-1), 1}, yw] - 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1, 0, yu^(-1)}, yv] - 2*G[{0, 1, 1, 0, yu^(-1)}, yw] + 
     2*G[{0, 1, 1, 0, yv^(-1)}, yw] + 2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1, 1, yu^(-1)}, yv] + 12*G[{0, 1, 1, 1, yu^(-1)}, yw] + 
     6*G[{0, 1, 1, 1, yv^(-1)}, yw] - 6*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1, yu^(-1), 1}, yv] + 12*G[{0, 1, 1, yu^(-1), 1}, yw] - 
     12*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] - 
     16*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     10*G[{0, 1, 1, yv^(-1), 1}, yw] - 12*G[{0, 1, 1, yv^(-1), yu^(-1)}, 
       yw] - 12*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     10*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 8*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 10*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] - 
     4*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 4*G[{0, 1, yu^(-1), 1, 1}, yv] + 
     8*G[{0, 1, yu^(-1), 1, 1}, yw] - 8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] - 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), 1, 1}, yw] - 8*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 6*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yu^(-1)}, yv] - 
     4*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1}, yv] - 
     4*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1}, yv] - 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     16*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     14*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + Pi^2*Zeta[3] + 
     2*G[{0}, yu]^2*Zeta[3] + 4*G[{0}, yu]*G[{0}, yv]*Zeta[3] + 
     2*G[{0}, yu]*G[{0}, yw]*Zeta[3] + 4*G[{0}, yv]*G[{0}, yw]*Zeta[3] + 
     2*G[{0}, yw]^2*Zeta[3] - 2*G[{0}, yu]*G[{1}, yu]*Zeta[3] + 
     2*G[{0}, yw]*G[{1}, yu]*Zeta[3] + 2*G[{0}, yu]*G[{1}, yv]*Zeta[3] + 
     4*G[{0}, yv]*G[{1}, yv]*Zeta[3] + 2*G[{0}, yw]*G[{1}, yv]*Zeta[3] + 
     2*G[{0}, yu]*G[{1}, yw]*Zeta[3] - 2*G[{0}, yw]*G[{1}, yw]*Zeta[3] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 4*G[{0, 1}, yu]*Zeta[3] + 
     4*G[{0, 1}, yv]*Zeta[3] + 4*G[{0, 1}, yw]*Zeta[3] - 
     4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 11*Zeta[5]
 
K1vwuRegI = (-7*Pi^4*G[{0}, yu])/180 - (7*Pi^4*G[{0}, yv])/180 - 
     (Pi^2*G[{0}, yu]^2*G[{0}, yv])/6 - (Pi^2*G[{0}, yu]*G[{0}, yv]^2)/6 - 
     (Pi^4*G[{0}, yw])/15 - (Pi^2*G[{0}, yu]^2*G[{0}, yw])/6 - 
     (Pi^2*G[{0}, yv]^2*G[{0}, yw])/6 - G[{0}, yu]^2*G[{0}, yv]^2*
      G[{0}, yw] - (Pi^2*G[{0}, yu]^2*G[{1}, yu])/6 + 
     (Pi^2*G[{0}, yv]^2*G[{1}, yu])/6 - G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu] + G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu] + 
     (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/6 + (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu]^2 + (Pi^2*G[{0}, yu]^2*G[{1}, yv])/6 - 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/6 + G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv] - G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yv] - 
     (Pi^2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yu]*G[{1}, yv] + (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/6 + 
     (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/6 + (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]^2 - 
     (17*Pi^4*G[{1}, yw])/180 - (Pi^2*G[{0}, yu]^2*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv]^2*G[{1}, yw])/6 - (Pi^2*G[{0}, yu]*G[{0}, yw]*
       G[{1}, yw])/3 - (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw])/3 - 
     G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw] - 
     G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw] - 
     (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/6 - (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]^2 + (17*Pi^4*G[{1/(yu*yv)}, yw])/180 + 
     (Pi^2*G[{0}, yu]^2*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     G[{0}, yu]^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 - (Pi^2*G[{0}, yu]*G[{0, 1}, yu])/3 + 
     (Pi^2*G[{0}, yv]*G[{0, 1}, yu])/3 + G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1}, yu] - G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yu] - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu])/3 - G[{0}, yu]^2*G[{0}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yu] - 
     G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yu] + (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/
      3 + G[{0}, yu]^2*G[{1}, yu]*G[{0, 1}, yu] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, 1}, yu] + G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu] + G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu] - 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yu])/3 - G[{0}, yu]^2*G[{1}, yv]*
      G[{0, 1}, yu] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu] - 
     G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu] + G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu] + 
     G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yu] - G[{0}, yv]^2*G[{1}, yw]*
      G[{0, 1}, yu] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu] - G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yu] - G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{0, 1}, yu]^2 + G[{0}, yv]*G[{0, 1}, yu]^2 + 
     G[{1}, yw]*G[{0, 1}, yu]^2 - G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2 + 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yv])/3 - (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/3 - 
     G[{0}, yu]^2*G[{0}, yv]*G[{0, 1}, yv] + G[{0}, yu]*G[{0}, yv]^2*
      G[{0, 1}, yv] - (Pi^2*G[{0}, yw]*G[{0, 1}, yv])/3 - 
     G[{0}, yu]^2*G[{0}, yw]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{0, 1}, yv] - G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yv] - 
     (Pi^2*G[{1}, yu]*G[{0, 1}, yv])/3 - G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1}, yv] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yv] - 
     G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1}, yv] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yv] - G[{1}, yu]^3*G[{0, 1}, yv] + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/3 + G[{0}, yu]^2*G[{1}, yv]*
      G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yv] + 
     G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1}, yv] + G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yv] - G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yv] + G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yv] - 
     G[{0}, yu]^2*G[{1}, yw]*G[{0, 1}, yv] + G[{0}, yv]^2*G[{1}, yw]*
      G[{0, 1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yv] - G[{0}, yu]*G[{1}, yw]^2*
      G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv] + G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv] - G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv] - 2*G[{0}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yv] - 2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{0, 1}, yv]^2 + G[{0}, yv]*G[{0, 1}, yv]^2 + 
     G[{1}, yu]*G[{0, 1}, yv]^2 + G[{1}, yw]*G[{0, 1}, yv]^2 - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2 - G[{0}, yu]^2*G[{0}, yv]*
      G[{0, 1}, yw] - G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yw] - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1}, yw])/3 - G[{0}, yu]^2*G[{0}, yw]*
      G[{0, 1}, yw] - G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yw] - 
     Pi^2*G[{1}, yu]*G[{0, 1}, yw] - 3*G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yw] - 
     G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1}, yw] - G[{0}, yw]*G[{1}, yu]^2*
      G[{0, 1}, yw] - G[{1}, yu]^3*G[{0, 1}, yw] - 
     Pi^2*G[{1}, yv]*G[{0, 1}, yw] - G[{0}, yu]^2*G[{1}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yw] - 
     3*G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1}, yw] - 4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1}, yw] - 
     G[{1}, yu]^2*G[{1}, yv]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yw] + G[{1}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yw] - G[{1}, yv]^3*G[{0, 1}, yw] - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 - G[{0}, yu]^2*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1}, yw] - G[{1}, yu]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw] - G[{0}, yu]*G[{1}, yw]^2*
      G[{0, 1}, yw] - G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/3 + 
     2*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     (8*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 + 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 4*G[{1}, yu]*G[{0, 1}, yu]*
      G[{0, 1}, yw] - 2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw] - 4*G[{1}, yv]*G[{0, 1}, yv]*
      G[{0, 1}, yw] + G[{0}, yu]*G[{0, 1}, yw]^2 + 
     G[{0}, yv]*G[{0, 1}, yw]^2 + G[{1}, yu]*G[{0, 1}, yw]^2 + 
     G[{1}, yv]*G[{0, 1}, yw]^2 + G[{1}, yw]*G[{0, 1}, yw]^2 - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2 - G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw]^2 - G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0}, yv]^2*G[{0, yu^(-1)}, yv] + 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/3 + G[{0}, yu]^2*G[{0}, yw]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1)}, yv] + G[{0}, yv]^2*G[{0}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv] + G[{0}, yv]^2*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] + 
     G[{1}, yu]^3*G[{0, yu^(-1)}, yv] + G[{0}, yu]^2*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] - G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/3 - G[{0}, yu]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - G[{0}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv] - G[{0}, yu]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yv] - G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv])/3 + 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{1}, yv]*G[{0, yu^(-1)}, yv]^2 + (Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/
      3 - (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/3 - 
     G[{0}, yu]^2*G[{0}, yv]*G[{0, yu^(-1)}, yw] + G[{0}, yu]*G[{0}, yv]^2*
      G[{0, yu^(-1)}, yw] + (2*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     G[{0}, yu]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw] + G[{0}, yv]^2*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] + (2*Pi^2*G[{1}, yu]*G[{0, yu^(-1)}, yw])/3 + 
     G[{0}, yu]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yu]*G[{0, yu^(-1)}, yw] + G[{0}, yv]^2*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu]^3*G[{0, yu^(-1)}, yw] + 
     (2*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/3 + G[{0}, yu]^2*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 3*G[{1}, yu]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yw] + G[{1}, yv]^3*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + G[{0}, yv]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + G[{1}, yu]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - G[{0}, yu]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 2*G[{1}, yv]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     (Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{0, yv^(-1)}, yw])/3 + G[{0}, yu]^2*G[{0}, yv]*
      G[{0, yv^(-1)}, yw] - G[{0}, yu]*G[{0}, yv]^2*G[{0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 + G[{0}, yu]^2*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{1}, yu]*G[{0, yv^(-1)}, yw])/3 + G[{0}, yu]^2*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]^3*G[{0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{1}, yv]*G[{0, yv^(-1)}, yw])/3 + G[{0}, yu]^2*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]^2*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv]^3*G[{0, yv^(-1)}, yw] + G[{0}, yu]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{1}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - G[{0}, yv]*G[{1}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]^2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{0}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - G[{0}, yu]^2*G[{0}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw])/3 + G[{0}, yu]^2*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - G[{0}, yu]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + G[{0}, yu]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     (8*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 
     4*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     (Pi^2*G[{0, 0, 1}, yu])/3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yu] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 0, 1}, yu] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, 1}, yu] - 2*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 0, 1}, yu] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, 1}, yu] + 2*G[{1}, yu]^2*G[{0, 0, 1}, yu] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yu] + 2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yu] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yu] + 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yu] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yu] - 2*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1}, yw]^2*G[{0, 0, 1}, yu] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yu] - 2*G[{0, 1}, yu]*
      G[{0, 0, 1}, yu] + 2*G[{0, 1}, yv]*G[{0, 0, 1}, yu] + 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yu] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yu] + 2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] + (Pi^2*G[{0, 0, 1}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yv] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1}, yv] + 2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yv] + 
     2*G[{1}, yu]^2*G[{0, 0, 1}, yv] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yv] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yv] + 2*G[{1}, yv]^2*G[{0, 0, 1}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yv] + 2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yw]^2*G[{0, 0, 1}, yv] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv] + 2*G[{0, 1}, yu]*
      G[{0, 0, 1}, yv] - 2*G[{0, 1}, yv]*G[{0, 0, 1}, yv] + 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yv] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yv] - 2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] + (4*Pi^2*G[{0, 0, 1}, yw])/3 + 
     2*G[{0}, yu]^2*G[{0, 0, 1}, yw] + 2*G[{0}, yv]^2*G[{0, 0, 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1}, yw] + 2*G[{1}, yu]^2*G[{0, 0, 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw] - 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, 1}, yw] - 4*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yw] - 2*G[{1}, yw]^2*G[{0, 0, 1}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] + 4*G[{0, 1}, yu]*
      G[{0, 0, 1}, yw] + 4*G[{0, 1}, yv]*G[{0, 0, 1}, yw] - 
     4*G[{0, yu^(-1)}, yv]*G[{0, 0, 1}, yw] - (Pi^2*G[{0, 0, yu^(-1)}, yv])/
      3 + 2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv] - 2*G[{0, 1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     (4*Pi^2*G[{0, 0, yu^(-1)}, yw])/3 - 2*G[{0}, yu]^2*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, yu^(-1)}, yw] - (4*Pi^2*G[{0, 0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]^2*G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yv]^2*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 0, yv^(-1)}, yw] + 2*G[{1}, yw]^2*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{0, 1}, yu]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, 0, yv^(-1)}, yw] + 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, yv^(-1)}, yw] + (4*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - (2*Pi^2*G[{0, 1, 1}, yu])/3 - 
     2*G[{0}, yu]^2*G[{0, 1, 1}, yu] - 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1}, yu] - 2*G[{0}, yv]^2*G[{0, 1, 1}, yu] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yu] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yu] - 2*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yu]^2*G[{0, 1, 1}, yu] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1}, yu] - 4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yv]^2*G[{0, 1, 1}, yu] - 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1}, yu] - 4*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yu] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu] - 2*G[{0, 1}, yv]*
      G[{0, 1, 1}, yu] + 2*G[{0, 1}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yu] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - (2*Pi^2*G[{0, 1, 1}, yv])/3 - 
     2*G[{0}, yu]^2*G[{0, 1, 1}, yv] - 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, 1}, yv] - 2*G[{0}, yv]^2*G[{0, 1, 1}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yv] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yv] - 6*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yv] - 
     6*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1}, yv] - 4*G[{1}, yu]^2*G[{0, 1, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yv] - 2*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yv] + 2*G[{1}, yv]^2*G[{0, 1, 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] - 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv] - 
     6*G[{1}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yv] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv] + 2*G[{0, 1}, yw]*
      G[{0, 1, 1}, yv] + 2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1}, yv] - 2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     (Pi^2*G[{0, 1, 1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yw] - 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yw] - 8*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw] - 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1}, yw] - 4*G[{1}, yu]^2*G[{0, 1, 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw] - 8*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw] - 
     12*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv]^2*G[{0, 1, 1}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw] - 6*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, 1}, yw] - 6*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1, 1}, yw] + 2*G[{0, 1}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yv] - 4*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     Pi^2*G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yu]^2*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] + 6*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 8*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     Pi^2*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yu]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]^2*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] + 6*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yu]^2*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 8*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]^2*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1, yv^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, yv^(-1)}, yw] - 
     Pi^2*G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]^2*G[{0, 1, 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yv] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     (2*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/3 + 2*G[{0}, yu]^2*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 - 2*G[{0}, yu]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     (4*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yv]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 2*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yv] - 4*G[{0, yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 4*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     8*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yu] - 4*G[{1}, yu]*G[{0, 0, 1, 1}, yu] + 
     4*G[{1}, yv]*G[{0, 0, 1, 1}, yu] + 4*G[{0}, yw]*G[{0, 0, 1, 1}, yv] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1}, yv] - 4*G[{1}, yv]*G[{0, 0, 1, 1}, yv] + 
     4*G[{0}, yu]*G[{0, 0, 1, 1}, yw] + 4*G[{0}, yv]*G[{0, 0, 1, 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1}, yw] + 4*G[{1}, yv]*G[{0, 0, 1, 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{0}, yu]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yv] - 
     2*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{0, 1, 1, 1}, yu] - 
     6*G[{0}, yv]*G[{0, 1, 1, 1}, yu] - 6*G[{1}, yu]*G[{0, 1, 1, 1}, yu] + 
     6*G[{1}, yv]*G[{0, 1, 1, 1}, yu] - 6*G[{1}, yw]*G[{0, 1, 1, 1}, yu] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu] - 
     6*G[{0}, yu]*G[{0, 1, 1, 1}, yv] - 6*G[{0}, yv]*G[{0, 1, 1, 1}, yv] - 
     6*G[{1}, yu]*G[{0, 1, 1, 1}, yv] - 6*G[{1}, yv]*G[{0, 1, 1, 1}, yv] - 
     6*G[{1}, yw]*G[{0, 1, 1, 1}, yv] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yv] - 6*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 
     6*G[{1}, yu]*G[{0, 1, 1, 1}, yw] - 6*G[{1}, yv]*G[{0, 1, 1, 1}, yw] + 
     8*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 
     8*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 12*G[{1}, yu]*
      G[{0, 1, 1, yu^(-1)}, yv] + 8*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 12*G[{1}, yu]*
      G[{0, 1, 1, yu^(-1)}, yw] + 12*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 12*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yu]*
      G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 12*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yv^(-1)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     10*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     10*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yv] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] + 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 8*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] - 8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 8*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*
      G[{0, yu^(-1), 1, 1}, yv] + 2*G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yv] + 2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yu] + 12*G[{0, 0, 0, 1, 1}, yv] - 
     12*G[{0, 0, 0, 1, yu^(-1)}, yv] - 12*G[{0, 0, 0, yu^(-1), 1}, yv] + 
     12*G[{0, 0, 0, yu^(-1), yu^(-1)}, yv] + 4*G[{0, 0, 1, 0, 1}, yu] + 
     4*G[{0, 0, 1, 0, 1}, yv] - 4*G[{0, 0, 1, 0, yu^(-1)}, yv] + 
     12*G[{0, 0, 1, 1, 1}, yu] + 12*G[{0, 0, 1, 1, 1}, yv] - 
     12*G[{0, 0, 1, 1, yu^(-1)}, yv] - 4*G[{0, 0, 1, 1, yu^(-1)}, yw] - 
     4*G[{0, 0, 1, 1, yv^(-1)}, yw] + 4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1, yu^(-1), 1}, yv] - 4*G[{0, 0, 1, yu^(-1), 1}, yw] + 
     8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), 1}, yw] + 8*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 8*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 8*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, 1}, yv] + 4*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv] - 
     8*G[{0, 0, yu^(-1), 1, 1}, yv] - 4*G[{0, 0, yu^(-1), 1, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), 1}, yv] + 
     8*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 0, yv^(-1), 1, 1}, yw] + 4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 2*G[{0, 1, 0, 1, 1}, yu] + 
     2*G[{0, 1, 0, 1, 1}, yv] - 2*G[{0, 1, 0, 1, 1}, yw] - 
     6*G[{0, 1, 0, 1, yu^(-1)}, yv] - 4*G[{0, 1, 0, yu^(-1), 1}, yv] - 
     2*G[{0, 1, 0, yu^(-1), 1}, yw] + 4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, yv^(-1), 1}, yw] + 4*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 6*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 6*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1, 0, yu^(-1)}, yv] - 2*G[{0, 1, 1, 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1, 0, yv^(-1)}, yw] + 2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 1, 1, 1, yu^(-1)}, yv] + 6*G[{0, 1, 1, 1, yu^(-1)}, yw] + 
     6*G[{0, 1, 1, 1, yv^(-1)}, yw] + 12*G[{0, 1, 1, yu^(-1), 1}, yv] + 
     6*G[{0, 1, 1, yu^(-1), 1}, yw] - 16*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] - 
     12*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1, yv^(-1), 1}, yw] - 12*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 10*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 10*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yu^(-1), 1, 1}, yv] + 4*G[{0, 1, yu^(-1), 1, 1}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1}, yw] - 8*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 6*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 6*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yv] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, 1, yu^(-1)}, yv] - 
     2*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1, yu^(-1), 1}, yv] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yv] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     16*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + Pi^2*Zeta[3] + 
     2*G[{0}, yu]^2*Zeta[3] + 2*G[{0}, yu]*G[{0}, yv]*Zeta[3] + 
     2*G[{0}, yv]^2*Zeta[3] + 4*G[{0}, yu]*G[{0}, yw]*Zeta[3] + 
     4*G[{0}, yv]*G[{0}, yw]*Zeta[3] - 2*G[{0}, yu]*G[{1}, yu]*Zeta[3] + 
     2*G[{0}, yv]*G[{1}, yu]*Zeta[3] + 2*G[{0}, yu]*G[{1}, yv]*Zeta[3] - 
     2*G[{0}, yv]*G[{1}, yv]*Zeta[3] + 2*G[{0}, yu]*G[{1}, yw]*Zeta[3] + 
     2*G[{0}, yv]*G[{1}, yw]*Zeta[3] + 4*G[{0}, yw]*G[{1}, yw]*Zeta[3] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 4*G[{0, 1}, yu]*Zeta[3] + 
     4*G[{0, 1}, yv]*Zeta[3] + 4*G[{0, 1}, yw]*Zeta[3] - 
     4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 11*Zeta[5]
 
K1wuvRegI = -(Pi^4*G[{0}, yu])/15 - (7*Pi^4*G[{0}, yv])/180 - 
     (Pi^2*G[{0}, yu]*G[{0}, yv]^2)/6 - (7*Pi^4*G[{0}, yw])/180 - 
     (Pi^2*G[{0}, yv]^2*G[{0}, yw])/6 - (Pi^2*G[{0}, yu]*G[{0}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv]*G[{0}, yw]^2)/6 - G[{0}, yu]*G[{0}, yv]^2*
      G[{0}, yw]^2 - (17*Pi^4*G[{1}, yu])/180 - 
     (Pi^2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu])/3 - 
     (Pi^2*G[{0}, yv]^2*G[{1}, yu])/6 - (Pi^2*G[{0}, yu]*G[{0}, yw]*
       G[{1}, yu])/3 - (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1}, yu])/3 - 
     G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yu] - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu])/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*
      G[{1}, yu] - (Pi^2*G[{0}, yu]*G[{1}, yu]^2)/6 - 
     (Pi^2*G[{0}, yv]*G[{1}, yu]^2)/6 - (Pi^2*G[{0}, yw]*G[{1}, yu]^2)/6 - 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]^2 - 
     (Pi^2*G[{0}, yv]^2*G[{1}, yv])/6 - G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*
      G[{1}, yv] + (Pi^2*G[{0}, yw]^2*G[{1}, yv])/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*G[{1}, yv] + 
     (Pi^2*G[{0}, yu]*G[{1}, yv]^2)/6 + (Pi^2*G[{0}, yv]*G[{1}, yv]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv]^2)/6 + G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yv]^2 + (Pi^2*G[{0}, yv]^2*G[{1}, yw])/6 + 
     G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1}, yw] - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/6 - G[{0}, yu]*G[{0}, yv]*G[{0}, yw]^2*
      G[{1}, yw] - (Pi^2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1}, yv]*G[{1}, yw] + (Pi^2*G[{0}, yu]*G[{1}, yw]^2)/6 + 
     (Pi^2*G[{0}, yv]*G[{1}, yw]^2)/6 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/6 + 
     G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]^2 + 
     (17*Pi^4*G[{1/(yu*yv)}, yw])/180 + (Pi^2*G[{0}, yu]*G[{0}, yv]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yv]^2*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     G[{0}, yu]*G[{0}, yv]^2*G[{0}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/6 + G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]^2*G[{1/(yu*yv)}, yw] + (Pi^2*G[{0}, yu]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yv]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yw]*G[{1}, yu]*
       G[{1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*
      G[{1/(yu*yv)}, yw] - (Pi^2*G[{0}, yu]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - G[{0}, yu]*G[{0}, yv]*
      G[{0}, yw]*G[{1/(yu*yv)}, yw]^2 - (2*Pi^2*G[{0}, yu]*G[{0, 1}, yu])/3 - 
     G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yu] - G[{0}, yv]^2*G[{0}, yw]*
      G[{0, 1}, yu] - G[{0}, yu]*G[{0}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yu] - (Pi^2*G[{1}, yu]*G[{0, 1}, yu])/
      3 - G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yu] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1}, yu] - G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yu] - G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yu] - G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, 1}, yu] - 
     G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yu] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]*G[{0, 1}, yu] + G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yu] + G[{0}, yv]*G[{1}, yv]^2*
      G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, 1}, yu] + 
     G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yu] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yu] - G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yu] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yu] + G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yu] + G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu])/3 + 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu] + 
     G[{0}, yv]*G[{0, 1}, yu]^2 + G[{0}, yw]*G[{0, 1}, yu]^2 + 
     G[{1}, yu]*G[{0, 1}, yu]^2 - G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]^2 - 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yv])/3 - (Pi^2*G[{0}, yv]*G[{0, 1}, yv])/3 - 
     G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yv] + (Pi^2*G[{0}, yw]*G[{0, 1}, yv])/
      3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yv] + 
     G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yv] - G[{0}, yu]*G[{0}, yw]^2*
      G[{0, 1}, yv] - G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yv] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yv] + 
     G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yv] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1}, yv] - G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yv] - 
     4*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yv] + G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yv] - G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yv] + 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yv])/3 + G[{0}, yv]^2*G[{1}, yv]*
      G[{0, 1}, yv] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yv] + 
     G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yv] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yv] + G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yv] - 
     G[{0}, yv]*G[{1}, yv]^2*G[{0, 1}, yv] + G[{0}, yw]*G[{1}, yv]^2*
      G[{0, 1}, yv] - (Pi^2*G[{1}, yw]*G[{0, 1}, yv])/3 - 
     G[{0}, yv]^2*G[{1}, yw]*G[{0, 1}, yv] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{1}, yw]*G[{0, 1}, yv] - G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yv] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, 1}, yv] - G[{0}, yv]*G[{1}, yw]^2*
      G[{0, 1}, yv] + G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv] - 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yv] - 2*G[{1}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yv] + 2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yv] + 
     G[{0}, yv]*G[{0, 1}, yv]^2 + G[{0}, yw]*G[{0, 1}, yv]^2 + 
     2*G[{1}, yu]*G[{0, 1}, yv]^2 - G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]^2 - 
     (Pi^2*G[{0}, yu]*G[{0, 1}, yw])/3 + (Pi^2*G[{0}, yv]*G[{0, 1}, yw])/3 - 
     G[{0}, yu]*G[{0}, yv]^2*G[{0, 1}, yw] - (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/
      3 - 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv]^2*G[{0}, yw]*G[{0, 1}, yw] - G[{0}, yu]*G[{0}, yw]^2*
      G[{0, 1}, yw] + G[{0}, yv]*G[{0}, yw]^2*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, 1}, yw] - 
     G[{0}, yv]^2*G[{1}, yu]*G[{0, 1}, yw] - 4*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, 1}, yw] + G[{0}, yw]^2*G[{1}, yu]*G[{0, 1}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1}, yw] - G[{0}, yv]*G[{1}, yu]^2*
      G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yu]^2*G[{0, 1}, yw] - 
     (Pi^2*G[{1}, yv]*G[{0, 1}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1}, yw] - G[{0}, yv]^2*G[{1}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*G[{0, 1}, yw] - 
     G[{0}, yw]^2*G[{1}, yv]*G[{0, 1}, yw] - 6*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, 1}, yw] - G[{0}, yu]*G[{1}, yv]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1}, yw] - 2*G[{1}, yu]*G[{1}, yv]^2*
      G[{0, 1}, yw] - G[{1}, yv]^3*G[{0, 1}, yw] + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 + G[{0}, yv]^2*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv]^2*G[{1}, yw]*G[{0, 1}, yw] + G[{0}, yu]*G[{1}, yw]^2*
      G[{0, 1}, yw] + G[{0}, yv]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 6*G[{0}, yu]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 6*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1}, yw] + 2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1}, yw] + 
     (4*G[{yu^(-1)}, yv]^3*G[{0, 1}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, 1}, yw] + 2*G[{1}, yv]*G[{0, 1}, yu]*
      G[{0, 1}, yw] - 2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] - 2*G[{0}, yw]*G[{0, 1}, yv]*
      G[{0, 1}, yw] - 4*G[{1}, yu]*G[{0, 1}, yv]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, 1}, yw] + 
     G[{0}, yv]*G[{0, 1}, yw]^2 + G[{0}, yw]*G[{0, 1}, yw]^2 + 
     2*G[{1}, yu]*G[{0, 1}, yw]^2 + G[{1}, yv]*G[{0, 1}, yw]^2 - 
     G[{yu^(-1)}, yv]*G[{0, 1}, yw]^2 - G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 + 
     (2*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yv])/3 + 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yv])/3 + G[{0}, yu]*G[{0}, yv]^2*
      G[{0, yu^(-1)}, yv] - (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yv])/3 - 
     G[{0}, yv]^2*G[{0}, yw]*G[{0, yu^(-1)}, yv] + G[{0}, yu]*G[{0}, yw]^2*
      G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]^2*G[{1}, yu]*G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, yu^(-1)}, yv] + G[{0}, yw]^2*G[{1}, yu]*
      G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yv] + G[{0}, yw]*G[{1}, yu]^2*
      G[{0, yu^(-1)}, yv] - (Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]*G[{0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1)}, yv] - G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yv] - G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yv] + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yv])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yw]*G[{0, yu^(-1)}, yv] + G[{0}, yv]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yv] + G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yv] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + G[{0}, yv]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yv] - G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yv] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yv]^2 + G[{0}, yv]*G[{0, yu^(-1)}, yv]^2 + 
     G[{0}, yw]*G[{0, yu^(-1)}, yv]^2 + 2*G[{1}, yu]*G[{0, yu^(-1)}, yv]^2 - 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]^2 + 
     (2*Pi^2*G[{0}, yu]*G[{0, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv]*G[{0, yu^(-1)}, yw])/3 + G[{0}, yu]*G[{0}, yv]^2*
      G[{0, yu^(-1)}, yw] + (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     G[{0}, yv]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw] + G[{0}, yu]*G[{0}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yv]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]^2*G[{1}, yu]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yu]*G[{0, yu^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yu]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1}, yu]^2*G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yu]^2*
      G[{0, yu^(-1)}, yw] + (2*Pi^2*G[{1}, yv]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yv]*G[{0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{1}, yv]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1}, yv]^2*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv]^3*G[{0, yu^(-1)}, yw] - (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/
      3 + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yv]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - G[{0}, yv]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu]*G[{0, yu^(-1)}, yw]^2 + G[{0}, yv]*G[{0, yu^(-1)}, yw]^2 + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]^2 + 2*G[{1}, yu]*G[{0, yu^(-1)}, yw]^2 - 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2 + 
     (Pi^2*G[{0}, yu]*G[{0, yv^(-1)}, yw])/3 + G[{0}, yu]*G[{0}, yv]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw] - G[{0}, yv]*G[{0}, yw]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{1}, yu]*G[{0, yv^(-1)}, yw] - 3*G[{0}, yv]*G[{1}, yu]^2*
      G[{0, yv^(-1)}, yw] - 3*G[{0}, yw]*G[{1}, yu]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]^3*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1}, yv]*G[{0, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{1}, yu]*
      G[{1}, yv]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1)}, yw] + G[{0}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv]^3*G[{0, yv^(-1)}, yw] + G[{0}, yv]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - G[{0}, yu]*G[{1}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{0}, yv]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 2*G[{1}, yu]*G[{1}, yw]^2*
      G[{0, yv^(-1)}, yw] + (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]^2 - 
     (2*Pi^2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw])/3 - G[{0}, yu]*G[{0}, yv]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yu]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^3*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yv]^2*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]^2*G[{1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]^3*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv)}, yw] - 
     (4*G[{yu^(-1)}, yv]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{0}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yv]*G[{0, 1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{0}, yu]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     4*G[{1}, yv]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yv] + 
     (4*Pi^2*G[{0, 0, 1}, yu])/3 + 2*G[{0}, yv]^2*G[{0, 0, 1}, yu] + 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yu] - 2*G[{1}, yu]^2*G[{0, 0, 1}, yu] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yu] + 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, 1}, yu] + 2*G[{1}, yv]^2*G[{0, 0, 1}, yu] + 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1}, yu] - 4*G[{1}, yv]*G[{1}, yw]*G[{0, 0, 1}, yu] + 
     2*G[{1}, yw]^2*G[{0, 0, 1}, yu] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu] - 2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yu] + 
     4*G[{0, 1}, yv]*G[{0, 0, 1}, yu] + 4*G[{0, 1}, yw]*G[{0, 0, 1}, yu] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu] + (Pi^2*G[{0, 0, 1}, yv])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yv] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1}, yv] - 2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1}, yv] - 2*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yv] - 
     2*G[{1}, yu]^2*G[{0, 0, 1}, yv] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yv] - 2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yv] + 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yv] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yv] + 2*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yv] + 2*G[{1}, yw]^2*G[{0, 0, 1}, yv] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv] + 2*G[{0, 1}, yu]*
      G[{0, 0, 1}, yv] - 2*G[{0, 1}, yv]*G[{0, 0, 1}, yv] + 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yv] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yv] - 2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv] + (Pi^2*G[{0, 0, 1}, yw])/3 + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, 1}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yu]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yu]^2*G[{0, 0, 1}, yw] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, 0, 1}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yv]*G[{1}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{1}, yw]^2*G[{0, 0, 1}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 0, 1}, yw] + 2*G[{0, 1}, yv]*G[{0, 0, 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 0, 1}, yw] + 2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - (Pi^2*G[{0, 0, yu^(-1)}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, 1}, yv]*G[{0, 0, yu^(-1)}, yv] - 2*G[{0, 1}, yw]*
      G[{0, 0, yu^(-1)}, yv] - 2*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yv] - 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1}, yu]^2*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 0, yu^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1}, yu]^2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 0, yv^(-1)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yu]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]^2*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1, 1}, yu])/3 - 4*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yu] - 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1}, yu] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1, 1}, yu] - 4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yu] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, 1}, yu] - 2*G[{1}, yu]^2*G[{0, 1, 1}, yu] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yu] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1, 1}, yu] + 2*G[{1}, yv]^2*G[{0, 1, 1}, yu] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1}, yu] - 4*G[{1}, yv]*G[{1}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yu] + 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] + 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu] + 2*G[{0, 1}, yu]*
      G[{0, 1, 1}, yu] - (2*Pi^2*G[{0, 1, 1}, yv])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yv]^2*G[{0, 1, 1}, yv] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1}, yv] - 4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yv] - 8*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yv] - 8*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yv] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yv] - 
     8*G[{1}, yu]^2*G[{0, 1, 1}, yv] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yv] + 2*G[{1}, yv]^2*G[{0, 1, 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yv] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, 1}, yv] + 2*G[{1}, yw]^2*G[{0, 1, 1}, yv] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv] + 4*G[{0, 1}, yu]*
      G[{0, 1, 1}, yv] - 2*G[{0, 1}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, 1}, yv] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yv] + 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv] - (2*Pi^2*G[{0, 1, 1}, yw])/3 - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv]^2*G[{0, 1, 1}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yv]*G[{0}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yw] - 8*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, 1}, yw] - 8*G[{0}, yv]*G[{1}, yu]*G[{0, 1, 1}, yw] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{0, 1, 1}, yw] - 
     8*G[{1}, yu]^2*G[{0, 1, 1}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yw] - 6*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1}, yw] - 
     6*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1}, yw] - 12*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1, 1}, yw] - 4*G[{1}, yv]^2*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1, 1}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{1}, yw]^2*G[{0, 1, 1}, yw] + 
     6*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     6*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1, 1}, yw] - 
     6*G[{yu^(-1)}, yv]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yw] + 4*G[{0, 1}, yu]*
      G[{0, 1, 1}, yw] - 2*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{1, yu^(-1)}, yv]*G[{0, 1, 1}, yw] + 
     Pi^2*G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 2*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yv] + 6*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] + 6*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] + 6*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yv] + 6*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     2*G[{0}, yv]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yv] - 
     2*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yv] + 2*G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yv] + 4*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yv] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yv] + 
     Pi^2*G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv]^2*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw] + 6*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] + 6*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] + 6*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1, yu^(-1)}, yw] + 6*G[{1}, yu]^2*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv]^2*G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 8*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]^2*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{0}, yu]*G[{1}, yu]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv]^2*G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 8*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] - 8*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + Pi^2*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yv]^2*G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     6*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     6*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     6*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), 1}, yv] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0, 1}, yv]*G[{0, yu^(-1), 1}, yv] + 2*G[{0, 1}, yw]*
      G[{0, yu^(-1), 1}, yv] - 2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yv] + 
     Pi^2*G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv]^2*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] + 6*G[{0}, yv]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] + 6*G[{0}, yw]*G[{1}, yu]*
      G[{0, yu^(-1), 1}, yw] + 6*G[{1}, yu]^2*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, 1}, yu]*G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yv]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), 1}, yw] - 
     (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yv])/3 - 2*G[{0}, yv]^2*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yv] - 2*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yv] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1), yu^(-1)}, yv] - 4*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yv] - 
     (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 - 2*G[{0}, yv]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yv]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0, 1}, yv]*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu]*G[{0}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu]*G[{1}, yv]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv]^2*G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{yu^(-1)}, yv]^2*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     (2*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 - 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yv]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 4*G[{0}, yu]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 8*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 8*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 8*G[{1}, yu]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 4*G[{0}, yu]*G[{1}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1}, yu]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yv]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu^(-1)}, yv]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 
     2*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu]^2*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 2*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 - 
     2*G[{0}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1}, yu]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{0}, yu]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yv]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 12*G[{1}, yu]*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{1}, yu]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{1}, yv]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yv]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yv] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yv] + 2*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yv] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yv] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0}, yv]*G[{0, 0, 1, 1}, yu] + 4*G[{0}, yw]*G[{0, 0, 1, 1}, yu] + 
     4*G[{1}, yu]*G[{0, 0, 1, 1}, yu] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yu] + 4*G[{0}, yu]*G[{0, 0, 1, 1}, yv] - 
     4*G[{1}, yv]*G[{0, 0, 1, 1}, yv] + 4*G[{1}, yw]*G[{0, 0, 1, 1}, yv] + 
     4*G[{0}, yu]*G[{0, 0, 1, 1}, yw] + 4*G[{1}, yv]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1}, yw] - 4*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{0}, yu]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{0}, yu]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yv] + 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1}, yv]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yv] + 4*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, yv^(-1), 1}, yw] - 4*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, 1, 0, yu^(-1)}, yv] - 2*G[{0}, yu]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{0}, yv]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{0}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0}, yu]*G[{0, 1, 1, 1}, yu] - 
     6*G[{0}, yv]*G[{0, 1, 1, 1}, yv] - 6*G[{0}, yw]*G[{0, 1, 1, 1}, yv] - 
     12*G[{1}, yu]*G[{0, 1, 1, 1}, yv] - 6*G[{1}, yv]*G[{0, 1, 1, 1}, yv] + 
     6*G[{1}, yw]*G[{0, 1, 1, 1}, yv] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yv] - 6*G[{0}, yv]*G[{0, 1, 1, 1}, yw] - 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 12*G[{1}, yu]*G[{0, 1, 1, 1}, yw] - 
     6*G[{1}, yv]*G[{0, 1, 1, 1}, yw] - 6*G[{1}, yw]*G[{0, 1, 1, 1}, yw] + 
     6*G[{yu^(-1)}, yv]*G[{0, 1, 1, 1}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yw] + 6*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yv] + 
     6*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yv] + 12*G[{1}, yu]*
      G[{0, 1, 1, yu^(-1)}, yv] + 2*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yv] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yv] + 6*G[{0}, yu]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 12*G[{1}, yu]*
      G[{0, 1, 1, yu^(-1)}, yw] + 12*G[{1}, yv]*G[{0, 1, 1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 12*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, yu^(-1)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{0}, yu]*G[{0, 1, 1, yv^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 1, 1, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 16*G[{1}, yu]*
      G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yv]*G[{0, 1, 1, yv^(-1)}, yw] - 
     12*G[{yu^(-1)}, yv]*G[{0, 1, 1, yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     6*G[{0}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     10*G[{1}, yv]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 10*G[{yu^(-1)}, yv]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yv] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yv] + 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yv] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yv] + 4*G[{0}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yv] - 4*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yv]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), 1}, yw] - 8*G[{yu^(-1)}, yv]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{0}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yv]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 6*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{0}, yv]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 4*G[{1}, yu]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv]*
      G[{0, yu^(-1), 1, 1}, yv] + 2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yv] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yv] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yv] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yv] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yv] + 2*G[{0}, yv]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yv] - 2*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yv] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yv] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yv] - 
     4*G[{0}, yu]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{0}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, 
       yw] - 2*G[{0}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yv]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yu]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yv]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 8*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{0}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 8*G[{1}, yu]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 6*G[{1}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 8*G[{1}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{yu^(-1)}, yv]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{0}, yu]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     12*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     10*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yu]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yv]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yv] + 12*G[{0, 0, 0, 1, 1}, yw] - 
     12*G[{0, 0, 0, 1, yu^(-1)}, yv] - 12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 
     12*G[{0, 0, 0, 1, yv^(-1)}, yw] + 12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1}, yv] - 12*G[{0, 0, 0, yu^(-1), 1}, yw] + 
     12*G[{0, 0, 0, yu^(-1), yu^(-1)}, yv] + 
     12*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] + 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] - 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 0, 1, 0, 1}, yv] + 
     4*G[{0, 0, 1, 0, 1}, yw] - 4*G[{0, 0, 1, 0, yu^(-1)}, yv] - 
     4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 4*G[{0, 0, 1, 0, yv^(-1)}, yw] + 
     4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 12*G[{0, 0, 1, 1, 1}, yv] + 
     12*G[{0, 0, 1, 1, 1}, yw] - 12*G[{0, 0, 1, 1, yu^(-1)}, yv] - 
     12*G[{0, 0, 1, 1, yu^(-1)}, yw] - 12*G[{0, 0, 1, 1, yv^(-1)}, yw] + 
     8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 8*G[{0, 0, 1, yu^(-1), 1}, yv] - 
     8*G[{0, 0, 1, yu^(-1), 1}, yw] - 8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1}, yw] - 4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0, 0, yu^(-1), 0, 1}, yv] - 
     4*G[{0, 0, yu^(-1), 0, 1}, yw] + 4*G[{0, 0, yu^(-1), 0, yu^(-1)}, yv] + 
     4*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yu^(-1), 1, 1}, yv] - 8*G[{0, 0, yu^(-1), 1, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, 0, yu^(-1), yu^(-1), 1}, yv] + 
     12*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yv] - 
     16*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1}, yw] + 4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, 1}, yw] + 4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, 1, 1}, yu] + 2*G[{0, 1, 0, 1, 1}, yv] + 
     2*G[{0, 1, 0, 1, 1}, yw] - 4*G[{0, 1, 0, 1, yu^(-1)}, yv] - 
     4*G[{0, 1, 0, 1, yu^(-1)}, yw] - 6*G[{0, 1, 0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1, 0, yu^(-1), 1}, yv] - 
     2*G[{0, 1, 0, yu^(-1), 1}, yw] - 4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yv] - 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, yv^(-1), 1}, yw] - 2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 0, yu^(-1)}, yv] + 2*G[{0, 1, 1, 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1, 0, yv^(-1)}, yw] + 2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1, 1, yu^(-1)}, yv] + 6*G[{0, 1, 1, 1, yu^(-1)}, yw] + 
     12*G[{0, 1, 1, 1, yv^(-1)}, yw] - 6*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 
     10*G[{0, 1, 1, yu^(-1), 1}, yv] + 10*G[{0, 1, 1, yu^(-1), 1}, yw] - 
     12*G[{0, 1, 1, yu^(-1), yu^(-1)}, yv] - 
     12*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 1, 1, yv^(-1), 1}, yw] - 12*G[{0, 1, 1, yv^(-1), yu^(-1)}, 
       yw] - 16*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     10*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 10*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 8*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, yu^(-1), 0, yu^(-1)}, yv] - 
     6*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yu^(-1), 1, 1}, yv] + 8*G[{0, 1, yu^(-1), 1, 1}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yv] - 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 1, yu^(-1), yu^(-1), 1}, yv] - 
     12*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yv] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 8*G[{0, 1, yv^(-1), 1, 1}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 6*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yu^(-1), 1}, yv] + 
     4*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yv] - 
     8*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yu^(-1)}, yv] - 
     2*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0, yu^(-1), 1, yu^(-1), 1}, yv] - 
     6*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yv] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yv] - 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yv] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yv] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     16*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     14*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + Pi^2*Zeta[3] + 
     4*G[{0}, yu]*G[{0}, yv]*Zeta[3] + 2*G[{0}, yv]^2*Zeta[3] + 
     4*G[{0}, yu]*G[{0}, yw]*Zeta[3] + 2*G[{0}, yv]*G[{0}, yw]*Zeta[3] + 
     2*G[{0}, yw]^2*Zeta[3] + 4*G[{0}, yu]*G[{1}, yu]*Zeta[3] + 
     2*G[{0}, yv]*G[{1}, yu]*Zeta[3] + 2*G[{0}, yw]*G[{1}, yu]*Zeta[3] - 
     2*G[{0}, yv]*G[{1}, yv]*Zeta[3] + 2*G[{0}, yw]*G[{1}, yv]*Zeta[3] + 
     2*G[{0}, yv]*G[{1}, yw]*Zeta[3] - 2*G[{0}, yw]*G[{1}, yw]*Zeta[3] - 
     4*G[{0}, yu]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{0}, yv]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 4*G[{0, 1}, yu]*Zeta[3] + 
     4*G[{0, 1}, yv]*Zeta[3] + 4*G[{0, 1}, yw]*Zeta[3] - 
     4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 11*Zeta[5]
